import java.chaquopy
import java.lang
import java.lang.annotation

class Generated(java.lang.annotation.Annotation):
    def comments(self) -> str: ...
    def date(self) -> str: ...
    def value(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
