import typing

import android.os
import android.util
import java
import java.lang

class VibratorEnvelopeEffectInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[VibratorEnvelopeEffectInfo]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMaxControlPointDurationMillis(self) -> int: ...
    def getMaxDurationMillis(self) -> int: ...
    def getMaxSize(self) -> int: ...
    def getMinControlPointDurationMillis(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class VibratorFrequencyProfile(java.lang.Object):
    def getFrequenciesOutputAcceleration(self) -> android.util.SparseArray[java.lang.Float]: ...
    def getFrequencyRange(self, minOutputAccelerationGs: float | java.jfloat | java.lang.Float, /) -> android.util.Range[java.lang.Float]: ...
    def getMaxFrequencyHz(self) -> float: ...
    def getMaxOutputAccelerationGs(self) -> float: ...
    def getMinFrequencyHz(self) -> float: ...
    def getOutputAccelerationGs(self, frequencyHz: float | java.jfloat | java.lang.Float, /) -> float: ...
