import typing

import android.os
import java
import java.lang
import java.util

class BleCsRangingCapabilities(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BleCsRangingCapabilities]] = ...
    CS_SECURITY_LEVEL_FOUR: typing.ClassVar[int] = ...
    CS_SECURITY_LEVEL_ONE: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getSupportedSecurityLevels(self) -> java.util.Set[java.lang.Integer]: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BleCsRangingParams(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BleCsRangingParams]] = ...
    LOCATION_TYPE_INDOOR: typing.ClassVar[int] = ...
    LOCATION_TYPE_OUTDOOR: typing.ClassVar[int] = ...
    LOCATION_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    SIGHT_TYPE_LINE_OF_SIGHT: typing.ClassVar[int] = ...
    SIGHT_TYPE_NON_LINE_OF_SIGHT: typing.ClassVar[int] = ...
    SIGHT_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getLocationType(self) -> int: ...
    def getPeerBluetoothAddress(self) -> str: ...
    def getRangingUpdateRate(self) -> int: ...
    def getSecurityLevel(self) -> int: ...
    def getSightType(self) -> int: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, peerBluetoothAddress: str | java.lang.String, /) -> None: ...
        def build(self) -> BleCsRangingParams: ...
        def setLocationType(self, locationType: int | java.jint | java.lang.Integer, /) -> BleCsRangingParams.Builder: ...
        def setRangingUpdateRate(self, updateRate: int | java.jint | java.lang.Integer, /) -> BleCsRangingParams.Builder: ...
        def setSecurityLevel(self, securityLevel: int | java.jint | java.lang.Integer, /) -> BleCsRangingParams.Builder: ...
        def setSightType(self, sightType: int | java.jint | java.lang.Integer, /) -> BleCsRangingParams.Builder: ...
