import typing

import android.app
import android.content
import android.os

class VrListenerService(android.app.Service):
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def isVrModePackageEnabled(context: android.content.Context, requestedComponent: android.content.ComponentName, /) -> bool: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onCurrentVrActivityChanged(self, component: android.content.ComponentName, /) -> None: ...
