import java
import java.lang

class BloodGlucose(java.lang.Comparable[BloodGlucose]):
    def compareTo(self, other: BloodGlucose, /) -> int: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromMillimolesPerLiter(value: float | java.jdouble | java.lang.Double, /) -> BloodGlucose: ...
    def getInMillimolesPerLiter(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class Energy(java.lang.Comparable[Energy]):
    def compareTo(self, other: Energy, /) -> int: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromCalories(value: float | java.jdouble | java.lang.Double, /) -> Energy: ...
    def getInCalories(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class Length(java.lang.Comparable[Length]):
    def compareTo(self, other: Length, /) -> int: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromMeters(value: float | java.jdouble | java.lang.Double, /) -> Length: ...
    def getInMeters(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class Mass(java.lang.Comparable[Mass]):
    def compareTo(self, other: Mass, /) -> int: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromGrams(value: float | java.jdouble | java.lang.Double, /) -> Mass: ...
    def getInGrams(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class Percentage(java.lang.Comparable[Percentage]):
    def compareTo(self, other: Percentage, /) -> int: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromValue(value: float | java.jdouble | java.lang.Double, /) -> Percentage: ...
    def getValue(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class Power(java.lang.Comparable[Power]):
    def compareTo(self, other: Power, /) -> int: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromWatts(value: float | java.jdouble | java.lang.Double, /) -> Power: ...
    def getInWatts(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class Pressure(java.lang.Comparable[Pressure]):
    def compareTo(self, other: Pressure, /) -> int: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromMillimetersOfMercury(value: float | java.jdouble | java.lang.Double, /) -> Pressure: ...
    def getInMillimetersOfMercury(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class Temperature(java.lang.Comparable[Temperature]):
    def compareTo(self, other: Temperature, /) -> int: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromCelsius(value: float | java.jdouble | java.lang.Double, /) -> Temperature: ...
    def getInCelsius(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class TemperatureDelta(java.lang.Comparable[TemperatureDelta]):
    def compareTo(self, other: TemperatureDelta, /) -> int: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromCelsius(value: float | java.jdouble | java.lang.Double, /) -> TemperatureDelta: ...
    def getInCelsius(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class Velocity(java.lang.Comparable[Velocity]):
    def compareTo(self, other: Velocity, /) -> int: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromMetersPerSecond(value: float | java.jdouble | java.lang.Double, /) -> Velocity: ...
    def getInMetersPerSecond(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class Volume(java.lang.Comparable[Volume]):
    def compareTo(self, other: Volume, /) -> int: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromLiters(value: float | java.jdouble | java.lang.Double, /) -> Volume: ...
    def getInLiters(self) -> float: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
