import typing

import android.content.pm
import android.content.res.loader
import android.graphics
import android.graphics.drawable
import android.os
import android.util
import java
import java.chaquopy
import java.io
import java.lang
import java.nio.channels
import java.util
import org.xmlpull.v1

class AssetFileDescriptor(android.os.Parcelable, java.io.Closeable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AssetFileDescriptor]] = ...
    UNKNOWN_LENGTH: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, fd: android.os.ParcelFileDescriptor, startOffset: int | java.jlong | java.lang.Long, length: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def __init__(self, fd: android.os.ParcelFileDescriptor, startOffset: int | java.jlong | java.lang.Long, length: int | java.jlong | java.lang.Long, extras: android.os.Bundle, /) -> None: ...
    def close(self) -> None: ...
    def createInputStream(self) -> java.io.FileInputStream: ...
    def createOutputStream(self) -> java.io.FileOutputStream: ...
    def describeContents(self) -> int: ...
    def getDeclaredLength(self) -> int: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getFileDescriptor(self) -> java.io.FileDescriptor: ...
    def getLength(self) -> int: ...
    def getParcelFileDescriptor(self) -> android.os.ParcelFileDescriptor: ...
    def getStartOffset(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class AutoCloseOutputStream(android.os.ParcelFileDescriptor.AutoCloseOutputStream):
        def __init__(self, fd: AssetFileDescriptor, /) -> None: ...
        @typing.overload
        def write(self, oneByte: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def write(self, buffer: java.chaquopy.JavaArrayJByte, /) -> None: ...
        @typing.overload
        def write(self, buffer: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...

    class AutoCloseInputStream(android.os.ParcelFileDescriptor.AutoCloseInputStream):
        def __init__(self, fd: AssetFileDescriptor, /) -> None: ...
        def available(self) -> int: ...
        def close(self) -> None: ...
        def getChannel(self) -> java.nio.channels.FileChannel: ...
        def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
        def markSupported(self) -> bool: ...
        @typing.overload
        def read(self) -> int: ...
        @typing.overload
        def read(self, buffer: java.chaquopy.JavaArrayJByte, /) -> int: ...
        @typing.overload
        def read(self, buffer: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> int: ...
        def reset(self) -> None: ...
        def skip(self, count: int | java.jlong | java.lang.Long, /) -> int: ...

class AssetManager(java.lang.AutoCloseable):
    ACCESS_BUFFER: typing.ClassVar[int] = ...
    ACCESS_RANDOM: typing.ClassVar[int] = ...
    ACCESS_STREAMING: typing.ClassVar[int] = ...
    ACCESS_UNKNOWN: typing.ClassVar[int] = ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getLocales(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def list(self, path: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    @typing.overload
    def open(self, fileName: str | java.lang.String, /) -> java.io.InputStream: ...
    @typing.overload
    def open(self, fileName: str | java.lang.String, accessMode: int | java.jint | java.lang.Integer, /) -> java.io.InputStream: ...
    def openFd(self, fileName: str | java.lang.String, /) -> AssetFileDescriptor: ...
    @typing.overload
    def openNonAssetFd(self, fileName: str | java.lang.String, /) -> AssetFileDescriptor: ...
    @typing.overload
    def openNonAssetFd(self, cookie: int | java.jint | java.lang.Integer, fileName: str | java.lang.String, /) -> AssetFileDescriptor: ...
    @typing.overload
    def openXmlResourceParser(self, fileName: str | java.lang.String, /) -> XmlResourceParser: ...
    @typing.overload
    def openXmlResourceParser(self, cookie: int | java.jint | java.lang.Integer, fileName: str | java.lang.String, /) -> XmlResourceParser: ...

    class AssetInputStream(java.io.InputStream):
        def available(self) -> int: ...
        def close(self) -> None: ...
        def finalize(self) -> None: ...
        def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
        def markSupported(self) -> bool: ...
        @typing.overload
        def read(self) -> int: ...
        @typing.overload
        def read(self, b: java.chaquopy.JavaArrayJByte, /) -> int: ...
        @typing.overload
        def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
        def reset(self) -> None: ...
        def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class ColorStateList(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ColorStateList]] = ...
    def __init__(self, states: java.chaquopy.JavaArray[java.chaquopy.JavaArrayJInt], colors: java.chaquopy.JavaArrayJInt, /) -> None: ...
    @typing.overload
    @staticmethod
    def createFromXml(r: Resources, parser: org.xmlpull.v1.XmlPullParser, /) -> ColorStateList: ...
    @typing.overload
    @staticmethod
    def createFromXml(r: Resources, parser: org.xmlpull.v1.XmlPullParser, theme: Resources.Theme, /) -> ColorStateList: ...
    def describeContents(self) -> int: ...
    def getChangingConfigurations(self) -> int: ...
    def getColorForState(self, stateSet: java.chaquopy.JavaArrayJInt, defaultColor: int | java.jint | java.lang.Integer, /) -> int: ...
    def getDefaultColor(self) -> int: ...
    def isOpaque(self) -> bool: ...
    def isStateful(self) -> bool: ...
    def toString(self) -> str: ...
    @staticmethod
    def valueOf(color: int | java.jint | java.lang.Integer, /) -> ColorStateList: ...
    def withAlpha(self, alpha: int | java.jint | java.lang.Integer, /) -> ColorStateList: ...
    def withLStar(self, lStar: float | java.jfloat | java.lang.Float, /) -> ColorStateList: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class Configuration(android.os.Parcelable, java.lang.Comparable[Configuration]):
    COLOR_MODE_HDR_MASK: typing.ClassVar[int] = ...
    COLOR_MODE_HDR_NO: typing.ClassVar[int] = ...
    COLOR_MODE_HDR_SHIFT: typing.ClassVar[int] = ...
    COLOR_MODE_HDR_UNDEFINED: typing.ClassVar[int] = ...
    COLOR_MODE_HDR_YES: typing.ClassVar[int] = ...
    COLOR_MODE_UNDEFINED: typing.ClassVar[int] = ...
    COLOR_MODE_WIDE_COLOR_GAMUT_MASK: typing.ClassVar[int] = ...
    COLOR_MODE_WIDE_COLOR_GAMUT_NO: typing.ClassVar[int] = ...
    COLOR_MODE_WIDE_COLOR_GAMUT_UNDEFINED: typing.ClassVar[int] = ...
    COLOR_MODE_WIDE_COLOR_GAMUT_YES: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Configuration]] = ...
    DENSITY_DPI_UNDEFINED: typing.ClassVar[int] = ...
    FONT_WEIGHT_ADJUSTMENT_UNDEFINED: typing.ClassVar[int] = ...
    GRAMMATICAL_GENDER_FEMININE: typing.ClassVar[int] = ...
    GRAMMATICAL_GENDER_MASCULINE: typing.ClassVar[int] = ...
    GRAMMATICAL_GENDER_NEUTRAL: typing.ClassVar[int] = ...
    GRAMMATICAL_GENDER_NOT_SPECIFIED: typing.ClassVar[int] = ...
    HARDKEYBOARDHIDDEN_NO: typing.ClassVar[int] = ...
    HARDKEYBOARDHIDDEN_UNDEFINED: typing.ClassVar[int] = ...
    HARDKEYBOARDHIDDEN_YES: typing.ClassVar[int] = ...
    KEYBOARDHIDDEN_NO: typing.ClassVar[int] = ...
    KEYBOARDHIDDEN_UNDEFINED: typing.ClassVar[int] = ...
    KEYBOARDHIDDEN_YES: typing.ClassVar[int] = ...
    KEYBOARD_12KEY: typing.ClassVar[int] = ...
    KEYBOARD_NOKEYS: typing.ClassVar[int] = ...
    KEYBOARD_QWERTY: typing.ClassVar[int] = ...
    KEYBOARD_UNDEFINED: typing.ClassVar[int] = ...
    MNC_ZERO: typing.ClassVar[int] = ...
    NAVIGATIONHIDDEN_NO: typing.ClassVar[int] = ...
    NAVIGATIONHIDDEN_UNDEFINED: typing.ClassVar[int] = ...
    NAVIGATIONHIDDEN_YES: typing.ClassVar[int] = ...
    NAVIGATION_DPAD: typing.ClassVar[int] = ...
    NAVIGATION_NONAV: typing.ClassVar[int] = ...
    NAVIGATION_TRACKBALL: typing.ClassVar[int] = ...
    NAVIGATION_UNDEFINED: typing.ClassVar[int] = ...
    NAVIGATION_WHEEL: typing.ClassVar[int] = ...
    ORIENTATION_LANDSCAPE: typing.ClassVar[int] = ...
    ORIENTATION_PORTRAIT: typing.ClassVar[int] = ...
    ORIENTATION_SQUARE: typing.ClassVar[int] = ...
    ORIENTATION_UNDEFINED: typing.ClassVar[int] = ...
    SCREENLAYOUT_LAYOUTDIR_LTR: typing.ClassVar[int] = ...
    SCREENLAYOUT_LAYOUTDIR_MASK: typing.ClassVar[int] = ...
    SCREENLAYOUT_LAYOUTDIR_RTL: typing.ClassVar[int] = ...
    SCREENLAYOUT_LAYOUTDIR_SHIFT: typing.ClassVar[int] = ...
    SCREENLAYOUT_LAYOUTDIR_UNDEFINED: typing.ClassVar[int] = ...
    SCREENLAYOUT_LONG_MASK: typing.ClassVar[int] = ...
    SCREENLAYOUT_LONG_NO: typing.ClassVar[int] = ...
    SCREENLAYOUT_LONG_UNDEFINED: typing.ClassVar[int] = ...
    SCREENLAYOUT_LONG_YES: typing.ClassVar[int] = ...
    SCREENLAYOUT_ROUND_MASK: typing.ClassVar[int] = ...
    SCREENLAYOUT_ROUND_NO: typing.ClassVar[int] = ...
    SCREENLAYOUT_ROUND_UNDEFINED: typing.ClassVar[int] = ...
    SCREENLAYOUT_ROUND_YES: typing.ClassVar[int] = ...
    SCREENLAYOUT_SIZE_LARGE: typing.ClassVar[int] = ...
    SCREENLAYOUT_SIZE_MASK: typing.ClassVar[int] = ...
    SCREENLAYOUT_SIZE_NORMAL: typing.ClassVar[int] = ...
    SCREENLAYOUT_SIZE_SMALL: typing.ClassVar[int] = ...
    SCREENLAYOUT_SIZE_UNDEFINED: typing.ClassVar[int] = ...
    SCREENLAYOUT_SIZE_XLARGE: typing.ClassVar[int] = ...
    SCREENLAYOUT_UNDEFINED: typing.ClassVar[int] = ...
    SCREEN_HEIGHT_DP_UNDEFINED: typing.ClassVar[int] = ...
    SCREEN_WIDTH_DP_UNDEFINED: typing.ClassVar[int] = ...
    SMALLEST_SCREEN_WIDTH_DP_UNDEFINED: typing.ClassVar[int] = ...
    TOUCHSCREEN_FINGER: typing.ClassVar[int] = ...
    TOUCHSCREEN_NOTOUCH: typing.ClassVar[int] = ...
    TOUCHSCREEN_STYLUS: typing.ClassVar[int] = ...
    TOUCHSCREEN_UNDEFINED: typing.ClassVar[int] = ...
    UI_MODE_NIGHT_MASK: typing.ClassVar[int] = ...
    UI_MODE_NIGHT_NO: typing.ClassVar[int] = ...
    UI_MODE_NIGHT_UNDEFINED: typing.ClassVar[int] = ...
    UI_MODE_NIGHT_YES: typing.ClassVar[int] = ...
    UI_MODE_TYPE_APPLIANCE: typing.ClassVar[int] = ...
    UI_MODE_TYPE_CAR: typing.ClassVar[int] = ...
    UI_MODE_TYPE_DESK: typing.ClassVar[int] = ...
    UI_MODE_TYPE_MASK: typing.ClassVar[int] = ...
    UI_MODE_TYPE_NORMAL: typing.ClassVar[int] = ...
    UI_MODE_TYPE_TELEVISION: typing.ClassVar[int] = ...
    UI_MODE_TYPE_UNDEFINED: typing.ClassVar[int] = ...
    UI_MODE_TYPE_VR_HEADSET: typing.ClassVar[int] = ...
    UI_MODE_TYPE_WATCH: typing.ClassVar[int] = ...
    colorMode: int = ...
    densityDpi: int = ...
    fontScale: float = ...
    fontWeightAdjustment: int = ...
    hardKeyboardHidden: int = ...
    keyboard: int = ...
    keyboardHidden: int = ...
    locale: java.util.Locale = ...
    mcc: int = ...
    mnc: int = ...
    navigation: int = ...
    navigationHidden: int = ...
    orientation: int = ...
    screenHeightDp: int = ...
    screenLayout: int = ...
    screenWidthDp: int = ...
    smallestScreenWidthDp: int = ...
    touchscreen: int = ...
    uiMode: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, o: Configuration, /) -> None: ...
    def compareTo(self, that: Configuration, /) -> int: ...
    def describeContents(self) -> int: ...
    def diff(self, delta: Configuration, /) -> int: ...
    @typing.overload
    def equals(self, that: Configuration, /) -> bool: ...
    @typing.overload
    def equals(self, that: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def generateDelta(base: Configuration, change: Configuration, /) -> Configuration: ...
    def getGrammaticalGender(self) -> int: ...
    def getLayoutDirection(self) -> int: ...
    def getLocales(self) -> android.os.LocaleList: ...
    def hashCode(self) -> int: ...
    def isLayoutSizeAtLeast(self, size: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isNightModeActive(self) -> bool: ...
    def isScreenHdr(self) -> bool: ...
    def isScreenRound(self) -> bool: ...
    def isScreenWideColorGamut(self) -> bool: ...
    @staticmethod
    def needNewResources(configChanges: int | java.jint | java.lang.Integer, interestingChanges: int | java.jint | java.lang.Integer, /) -> bool: ...
    def readFromParcel(self, source: android.os.Parcel, /) -> None: ...
    def setLayoutDirection(self, loc: java.util.Locale, /) -> None: ...
    def setLocale(self, loc: java.util.Locale, /) -> None: ...
    def setLocales(self, locales: android.os.LocaleList, /) -> None: ...
    def setTo(self, o: Configuration, /) -> None: ...
    def setToDefaults(self) -> None: ...
    def toString(self) -> str: ...
    def updateFrom(self, delta: Configuration, /) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class FontScaleConverter(java.lang.Object):
    def convertDpToSp(self, arg1: float | java.jfloat | java.lang.Float, /) -> float: ...
    def convertSpToDp(self, arg1: float | java.jfloat | java.lang.Float, /) -> float: ...
    @staticmethod
    def forScale(fontScale: float | java.jfloat | java.lang.Float, /) -> FontScaleConverter | None: ...
    @staticmethod
    def isNonLinearFontScalingActive(fontScale: float | java.jfloat | java.lang.Float, /) -> bool: ...

class ObbInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ObbInfo]] = ...
    OBB_OVERLAY: typing.ClassVar[int] = ...
    filename: str = ...
    flags: int = ...
    packageName: str = ...
    version: int = ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, parcelableFlags: int | java.jint | java.lang.Integer, /) -> None: ...

class ObbScanner(java.lang.Object):
    @staticmethod
    def getObbInfo(filePath: str | java.lang.String, /) -> ObbInfo: ...

class Resources(java.lang.Object):
    ID_NULL: typing.ClassVar[int] = ...
    def __init__(self, assets: AssetManager, metrics: android.util.DisplayMetrics, config: Configuration, /) -> None: ...
    def addLoaders(self, *loaders: android.content.res.loader.ResourcesLoader) -> None: ...
    def finishPreloading(self) -> None: ...
    def flushLayoutCache(self) -> None: ...
    def getAnimation(self, id: int | java.jint | java.lang.Integer, /) -> XmlResourceParser: ...
    def getAssets(self) -> AssetManager: ...
    @staticmethod
    def getAttributeSetSourceResId(set: android.util.AttributeSet, /) -> int: ...
    def getBoolean(self, id: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def getColor(self, id: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getColor(self, id: int | java.jint | java.lang.Integer, theme: Resources.Theme, /) -> int: ...
    @typing.overload
    def getColorStateList(self, id: int | java.jint | java.lang.Integer, /) -> ColorStateList: ...
    @typing.overload
    def getColorStateList(self, id: int | java.jint | java.lang.Integer, theme: Resources.Theme, /) -> ColorStateList: ...
    def getConfiguration(self) -> Configuration: ...
    def getDimension(self, id: int | java.jint | java.lang.Integer, /) -> float: ...
    def getDimensionPixelOffset(self, id: int | java.jint | java.lang.Integer, /) -> int: ...
    def getDimensionPixelSize(self, id: int | java.jint | java.lang.Integer, /) -> int: ...
    def getDisplayMetrics(self) -> android.util.DisplayMetrics: ...
    @typing.overload
    def getDrawable(self, id: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable: ...
    @typing.overload
    def getDrawable(self, id: int | java.jint | java.lang.Integer, theme: Resources.Theme, /) -> android.graphics.drawable.Drawable: ...
    @typing.overload
    def getDrawableForDensity(self, id: int | java.jint | java.lang.Integer, density: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable | None: ...
    @typing.overload
    def getDrawableForDensity(self, id: int | java.jint | java.lang.Integer, density: int | java.jint | java.lang.Integer, theme: Resources.Theme, /) -> android.graphics.drawable.Drawable | None: ...
    def getFloat(self, id: int | java.jint | java.lang.Integer, /) -> float: ...
    def getFont(self, id: int | java.jint | java.lang.Integer, /) -> android.graphics.Typeface: ...
    def getFraction(self, id: int | java.jint | java.lang.Integer, base: int | java.jint | java.lang.Integer, pbase: int | java.jint | java.lang.Integer, /) -> float: ...
    def getIdentifier(self, name: str | java.lang.String, defType: str | java.lang.String, defPackage: str | java.lang.String, /) -> int: ...
    def getIntArray(self, id: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def getInteger(self, id: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLayout(self, id: int | java.jint | java.lang.Integer, /) -> XmlResourceParser: ...
    def getMovie(self, id: int | java.jint | java.lang.Integer, /) -> android.graphics.Movie: ...
    @typing.overload
    def getQuantityString(self, id: int | java.jint | java.lang.Integer, quantity: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getQuantityString(self, id: int | java.jint | java.lang.Integer, quantity: int | java.jint | java.lang.Integer, /, *formatArgs: java.lang.Object) -> str: ...
    def getQuantityText(self, id: int | java.jint | java.lang.Integer, quantity: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    def getResourceEntryName(self, resid: int | java.jint | java.lang.Integer, /) -> str: ...
    def getResourceName(self, resid: int | java.jint | java.lang.Integer, /) -> str: ...
    def getResourcePackageName(self, resid: int | java.jint | java.lang.Integer, /) -> str: ...
    def getResourceTypeName(self, resid: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getString(self, id: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getString(self, id: int | java.jint | java.lang.Integer, /, *formatArgs: java.lang.Object) -> str: ...
    def getStringArray(self, id: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @staticmethod
    def getSystem() -> Resources: ...
    @typing.overload
    def getText(self, id: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    @typing.overload
    def getText(self, id: int | java.jint | java.lang.Integer, def_: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
    def getTextArray(self, id: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[java.lang.CharSequence]: ...
    @typing.overload
    def getValue(self, id: int | java.jint | java.lang.Integer, outValue: android.util.TypedValue, resolveRefs: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def getValue(self, name: str | java.lang.String, outValue: android.util.TypedValue, resolveRefs: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def getValueForDensity(self, id: int | java.jint | java.lang.Integer, density: int | java.jint | java.lang.Integer, outValue: android.util.TypedValue, resolveRefs: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def getXml(self, id: int | java.jint | java.lang.Integer, /) -> XmlResourceParser: ...
    def newTheme(self) -> Resources.Theme: ...
    def obtainAttributes(self, set: android.util.AttributeSet, attrs: java.chaquopy.JavaArrayJInt, /) -> TypedArray: ...
    def obtainTypedArray(self, id: int | java.jint | java.lang.Integer, /) -> TypedArray: ...
    @typing.overload
    def openRawResource(self, id: int | java.jint | java.lang.Integer, /) -> java.io.InputStream: ...
    @typing.overload
    def openRawResource(self, id: int | java.jint | java.lang.Integer, value: android.util.TypedValue, /) -> java.io.InputStream: ...
    def openRawResourceFd(self, id: int | java.jint | java.lang.Integer, /) -> AssetFileDescriptor: ...
    def parseBundleExtra(self, tagName: str | java.lang.String, attrs: android.util.AttributeSet, outBundle: android.os.Bundle, /) -> None: ...
    def parseBundleExtras(self, parser: XmlResourceParser, outBundle: android.os.Bundle, /) -> None: ...
    @staticmethod
    def registerResourcePaths(uniqueId: str | java.lang.String, appInfo: android.content.pm.ApplicationInfo, /) -> None: ...
    def removeLoaders(self, *loaders: android.content.res.loader.ResourcesLoader) -> None: ...
    def updateConfiguration(self, config: Configuration, metrics: android.util.DisplayMetrics, /) -> None: ...

    class Theme(java.lang.Object):
        def applyStyle(self, resId: int | java.jint | java.lang.Integer, force: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def dump(self, priority: int | java.jint | java.lang.Integer, tag: str | java.lang.String, prefix: str | java.lang.String, /) -> None: ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getAttributeResolutionStack(self, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, explicitStyleRes: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
        def getChangingConfigurations(self) -> int: ...
        def getDrawable(self, id: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable: ...
        def getExplicitStyle(self, set: android.util.AttributeSet, /) -> int: ...
        def getResources(self) -> Resources: ...
        def hashCode(self) -> int: ...
        @typing.overload
        def obtainStyledAttributes(self, attrs: java.chaquopy.JavaArrayJInt, /) -> TypedArray: ...
        @typing.overload
        def obtainStyledAttributes(self, resId: int | java.jint | java.lang.Integer, attrs: java.chaquopy.JavaArrayJInt, /) -> TypedArray: ...
        @typing.overload
        def obtainStyledAttributes(self, set: android.util.AttributeSet, attrs: java.chaquopy.JavaArrayJInt, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> TypedArray: ...
        def rebase(self) -> None: ...
        def resolveAttribute(self, resid: int | java.jint | java.lang.Integer, outValue: android.util.TypedValue, resolveRefs: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
        def setTo(self, other: Resources.Theme, /) -> None: ...
        def toString(self) -> str: ...

    class NotFoundException(java.lang.RuntimeException):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, name: str | java.lang.String, /) -> None: ...
        @typing.overload
        def __init__(self, name: str | java.lang.String, cause: java.lang.Exception, /) -> None: ...

class TypedArray(java.lang.AutoCloseable):
    def close(self) -> None: ...
    def getBoolean(self, index: int | java.jint | java.lang.Integer, defValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def getChangingConfigurations(self) -> int: ...
    def getColor(self, index: int | java.jint | java.lang.Integer, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getColorStateList(self, index: int | java.jint | java.lang.Integer, /) -> ColorStateList | None: ...
    def getDimension(self, index: int | java.jint | java.lang.Integer, defValue: float | java.jfloat | java.lang.Float, /) -> float: ...
    def getDimensionPixelOffset(self, index: int | java.jint | java.lang.Integer, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getDimensionPixelSize(self, index: int | java.jint | java.lang.Integer, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getDrawable(self, index: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable | None: ...
    def getFloat(self, index: int | java.jint | java.lang.Integer, defValue: float | java.jfloat | java.lang.Float, /) -> float: ...
    def getFont(self, index: int | java.jint | java.lang.Integer, /) -> android.graphics.Typeface | None: ...
    def getFraction(self, index: int | java.jint | java.lang.Integer, base: int | java.jint | java.lang.Integer, pbase: int | java.jint | java.lang.Integer, defValue: float | java.jfloat | java.lang.Float, /) -> float: ...
    def getIndex(self, at: int | java.jint | java.lang.Integer, /) -> int: ...
    def getIndexCount(self) -> int: ...
    def getInt(self, index: int | java.jint | java.lang.Integer, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getInteger(self, index: int | java.jint | java.lang.Integer, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getLayoutDimension(self, index: int | java.jint | java.lang.Integer, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getLayoutDimension(self, index: int | java.jint | java.lang.Integer, name: str | java.lang.String, /) -> int: ...
    def getNonResourceString(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def getPositionDescription(self) -> str: ...
    def getResourceId(self, index: int | java.jint | java.lang.Integer, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getResources(self) -> Resources: ...
    def getSourceResourceId(self, index: int | java.jint | java.lang.Integer, defaultValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getString(self, index: int | java.jint | java.lang.Integer, /) -> str | None: ...
    def getText(self, index: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    def getTextArray(self, index: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[java.lang.CharSequence]: ...
    def getType(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    def getValue(self, index: int | java.jint | java.lang.Integer, outValue: android.util.TypedValue, /) -> bool: ...
    def hasValue(self, index: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hasValueOrEmpty(self, index: int | java.jint | java.lang.Integer, /) -> bool: ...
    def length(self) -> int: ...
    def peekValue(self, index: int | java.jint | java.lang.Integer, /) -> android.util.TypedValue | None: ...
    def recycle(self) -> None: ...
    def toString(self) -> str: ...

class XmlResourceParser(android.util.AttributeSet, java.lang.AutoCloseable, org.xmlpull.v1.XmlPullParser):
    def close(self) -> None: ...
    def getAttributeNamespace(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
