import android.graphics
import java
import java.chaquopy
import java.lang

class ArcShape(RectShape):
    def __init__(self, startAngle: float | java.jfloat | java.lang.Float, sweepAngle: float | java.jfloat | java.lang.Float, /) -> None: ...
    def clone(self) -> ArcShape: ...
    def draw(self, canvas: android.graphics.Canvas, paint: android.graphics.Paint, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getOutline(self, outline: android.graphics.Outline, /) -> None: ...
    def getStartAngle(self) -> float: ...
    def getSweepAngle(self) -> float: ...
    def hashCode(self) -> int: ...

class OvalShape(RectShape):
    def __init__(self) -> None: ...
    def clone(self) -> OvalShape: ...
    def draw(self, canvas: android.graphics.Canvas, paint: android.graphics.Paint, /) -> None: ...
    def getOutline(self, outline: android.graphics.Outline, /) -> None: ...

class PathShape(Shape):
    def __init__(self, path: android.graphics.Path, stdWidth: float | java.jfloat | java.lang.Float, stdHeight: float | java.jfloat | java.lang.Float, /) -> None: ...
    def clone(self) -> PathShape: ...
    def draw(self, canvas: android.graphics.Canvas, paint: android.graphics.Paint, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def onResize(self, width: float | java.jfloat | java.lang.Float, height: float | java.jfloat | java.lang.Float, /) -> None: ...

class RectShape(Shape):
    def __init__(self) -> None: ...
    def clone(self) -> RectShape: ...
    def draw(self, canvas: android.graphics.Canvas, paint: android.graphics.Paint, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getOutline(self, outline: android.graphics.Outline, /) -> None: ...
    def hashCode(self) -> int: ...
    def onResize(self, width: float | java.jfloat | java.lang.Float, height: float | java.jfloat | java.lang.Float, /) -> None: ...
    def rect(self) -> android.graphics.RectF: ...

class RoundRectShape(RectShape):
    def __init__(self, outerRadii: java.chaquopy.JavaArrayJFloat, inset: android.graphics.RectF, innerRadii: java.chaquopy.JavaArrayJFloat, /) -> None: ...
    def clone(self) -> RoundRectShape: ...
    def draw(self, canvas: android.graphics.Canvas, paint: android.graphics.Paint, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getOutline(self, outline: android.graphics.Outline, /) -> None: ...
    def hashCode(self) -> int: ...
    def onResize(self, w: float | java.jfloat | java.lang.Float, h: float | java.jfloat | java.lang.Float, /) -> None: ...

class Shape(java.lang.Cloneable):
    def __init__(self) -> None: ...
    def clone(self) -> Shape: ...
    def draw(self, arg1: android.graphics.Canvas, arg2: android.graphics.Paint, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getHeight(self) -> float: ...
    def getOutline(self, outline: android.graphics.Outline, /) -> None: ...
    def getWidth(self) -> float: ...
    def hasAlpha(self) -> bool: ...
    def hashCode(self) -> int: ...
    def onResize(self, width: float | java.jfloat | java.lang.Float, height: float | java.jfloat | java.lang.Float, /) -> None: ...
    def resize(self, width: float | java.jfloat | java.lang.Float, height: float | java.jfloat | java.lang.Float, /) -> None: ...
