import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.lang.ref
import java.net
import java.nio

class ErrnoException(java.lang.Exception):
    errno: int = ...
    @typing.overload
    def __init__(self, functionName: str | java.lang.String, errno: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, functionName: str | java.lang.String, errno: int | java.jint | java.lang.Integer, cause: java.lang.Throwable, /) -> None: ...
    def getMessage(self) -> str: ...
    def rethrowAsIOException(self) -> java.io.IOException: ...
    def rethrowAsSocketException(self) -> java.net.SocketException: ...

class Int64Ref(java.lang.Object):
    value: int = ...
    def __init__(self, value: int | java.jlong | java.lang.Long, /) -> None: ...
    def toString(self) -> str: ...

class Os(java.lang.Object):
    @staticmethod
    def accept(fd: java.io.FileDescriptor, peerAddress: java.net.InetSocketAddress, /) -> java.io.FileDescriptor: ...
    @staticmethod
    def access(path: str | java.lang.String, mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    @staticmethod
    def bind(fd: java.io.FileDescriptor, address: java.net.SocketAddress, /) -> None: ...
    @typing.overload
    @staticmethod
    def bind(fd: java.io.FileDescriptor, address: java.net.InetAddress, port: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def chmod(path: str | java.lang.String, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def chown(path: str | java.lang.String, uid: int | java.jint | java.lang.Integer, gid: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def close(fd: java.io.FileDescriptor, /) -> None: ...
    @typing.overload
    @staticmethod
    def connect(fd: java.io.FileDescriptor, address: java.net.SocketAddress, /) -> None: ...
    @typing.overload
    @staticmethod
    def connect(fd: java.io.FileDescriptor, address: java.net.InetAddress, port: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def dup(oldFd: java.io.FileDescriptor, /) -> java.io.FileDescriptor: ...
    @staticmethod
    def dup2(oldFd: java.io.FileDescriptor, newFd: int | java.jint | java.lang.Integer, /) -> java.io.FileDescriptor: ...
    @staticmethod
    def environ() -> java.chaquopy.JavaArray[java.lang.String]: ...
    @staticmethod
    def execv(filename: str | java.lang.String, argv: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @staticmethod
    def execve(filename: str | java.lang.String, argv: java.chaquopy.JavaArray[java.lang.String], envp: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @staticmethod
    def fchmod(fd: java.io.FileDescriptor, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def fchown(fd: java.io.FileDescriptor, uid: int | java.jint | java.lang.Integer, gid: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def fcntlInt(fd: java.io.FileDescriptor, cmd: int | java.jint | java.lang.Integer, arg: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def fdatasync(fd: java.io.FileDescriptor, /) -> None: ...
    @staticmethod
    def fstat(fd: java.io.FileDescriptor, /) -> StructStat: ...
    @staticmethod
    def fstatvfs(fd: java.io.FileDescriptor, /) -> StructStatVfs: ...
    @staticmethod
    def fsync(fd: java.io.FileDescriptor, /) -> None: ...
    @staticmethod
    def ftruncate(fd: java.io.FileDescriptor, length: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def gai_strerror(error: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def getegid() -> int: ...
    @staticmethod
    def getenv(name: str | java.lang.String, /) -> str: ...
    @staticmethod
    def geteuid() -> int: ...
    @staticmethod
    def getgid() -> int: ...
    @staticmethod
    def getpeername(fd: java.io.FileDescriptor, /) -> java.net.SocketAddress: ...
    @staticmethod
    def getpid() -> int: ...
    @staticmethod
    def getppid() -> int: ...
    @staticmethod
    def getsockname(fd: java.io.FileDescriptor, /) -> java.net.SocketAddress: ...
    @staticmethod
    def getsockoptTimeval(fd: java.io.FileDescriptor, level: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, /) -> StructTimeval: ...
    @staticmethod
    def gettid() -> int: ...
    @staticmethod
    def getuid() -> int: ...
    @staticmethod
    def getxattr(path: str | java.lang.String, name: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte: ...
    @staticmethod
    def if_indextoname(index: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def if_nametoindex(name: str | java.lang.String, /) -> int: ...
    @staticmethod
    def inet_pton(family: int | java.jint | java.lang.Integer, address: str | java.lang.String, /) -> java.net.InetAddress: ...
    @staticmethod
    def isatty(fd: java.io.FileDescriptor, /) -> bool: ...
    @staticmethod
    def kill(pid: int | java.jint | java.lang.Integer, signal: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def lchown(path: str | java.lang.String, uid: int | java.jint | java.lang.Integer, gid: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def link(oldPath: str | java.lang.String, newPath: str | java.lang.String, /) -> None: ...
    @staticmethod
    def listen(fd: java.io.FileDescriptor, backlog: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def listxattr(path: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @staticmethod
    def lseek(fd: java.io.FileDescriptor, offset: int | java.jlong | java.lang.Long, whence: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def lstat(path: str | java.lang.String, /) -> StructStat: ...
    @staticmethod
    def memfd_create(name: str | java.lang.String, flags: int | java.jint | java.lang.Integer, /) -> java.io.FileDescriptor: ...
    @staticmethod
    def mincore(address: int | java.jlong | java.lang.Long, byteCount: int | java.jlong | java.lang.Long, vector: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @staticmethod
    def mkdir(path: str | java.lang.String, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def mkfifo(path: str | java.lang.String, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def mlock(address: int | java.jlong | java.lang.Long, byteCount: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def mmap(address: int | java.jlong | java.lang.Long, byteCount: int | java.jlong | java.lang.Long, prot: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, fd: java.io.FileDescriptor, offset: int | java.jlong | java.lang.Long, /) -> int: ...
    @staticmethod
    def msync(address: int | java.jlong | java.lang.Long, byteCount: int | java.jlong | java.lang.Long, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def munlock(address: int | java.jlong | java.lang.Long, byteCount: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def munmap(address: int | java.jlong | java.lang.Long, byteCount: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def open(path: str | java.lang.String, flags: int | java.jint | java.lang.Integer, mode: int | java.jint | java.lang.Integer, /) -> java.io.FileDescriptor: ...
    @staticmethod
    def pipe() -> java.chaquopy.JavaArray[java.io.FileDescriptor]: ...
    @staticmethod
    def poll(fds: java.chaquopy.JavaArray[StructPollfd], timeoutMs: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def posix_fallocate(fd: java.io.FileDescriptor, offset: int | java.jlong | java.lang.Long, length: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def prctl(option: int | java.jint | java.lang.Integer, arg2: int | java.jlong | java.lang.Long, arg3: int | java.jlong | java.lang.Long, arg4: int | java.jlong | java.lang.Long, arg5: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    @staticmethod
    def pread(fd: java.io.FileDescriptor, buffer: java.nio.ByteBuffer, offset: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    @staticmethod
    def pread(fd: java.io.FileDescriptor, bytes: java.chaquopy.JavaArrayJByte, byteOffset: int | java.jint | java.lang.Integer, byteCount: int | java.jint | java.lang.Integer, offset: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    @staticmethod
    def pwrite(fd: java.io.FileDescriptor, buffer: java.nio.ByteBuffer, offset: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    @staticmethod
    def pwrite(fd: java.io.FileDescriptor, bytes: java.chaquopy.JavaArrayJByte, byteOffset: int | java.jint | java.lang.Integer, byteCount: int | java.jint | java.lang.Integer, offset: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    @staticmethod
    def read(fd: java.io.FileDescriptor, buffer: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    @staticmethod
    def read(fd: java.io.FileDescriptor, bytes: java.chaquopy.JavaArrayJByte, byteOffset: int | java.jint | java.lang.Integer, byteCount: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def readlink(path: str | java.lang.String, /) -> str: ...
    @staticmethod
    def readv(fd: java.io.FileDescriptor, buffers: java.chaquopy.JavaArray[java.lang.Object], offsets: java.chaquopy.JavaArrayJInt, byteCounts: java.chaquopy.JavaArrayJInt, /) -> int: ...
    @typing.overload
    @staticmethod
    def recvfrom(fd: java.io.FileDescriptor, buffer: java.nio.ByteBuffer, flags: int | java.jint | java.lang.Integer, srcAddress: java.net.InetSocketAddress, /) -> int: ...
    @typing.overload
    @staticmethod
    def recvfrom(fd: java.io.FileDescriptor, bytes: java.chaquopy.JavaArrayJByte, byteOffset: int | java.jint | java.lang.Integer, byteCount: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, srcAddress: java.net.InetSocketAddress, /) -> int: ...
    @staticmethod
    def recvmsg(fd: java.io.FileDescriptor, msg: StructMsghdr, flags: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def remove(path: str | java.lang.String, /) -> None: ...
    @staticmethod
    def removexattr(path: str | java.lang.String, name: str | java.lang.String, /) -> None: ...
    @staticmethod
    def rename(oldPath: str | java.lang.String, newPath: str | java.lang.String, /) -> None: ...
    @staticmethod
    def sendfile(outFd: java.io.FileDescriptor, inFd: java.io.FileDescriptor, offset: Int64Ref, byteCount: int | java.jlong | java.lang.Long, /) -> int: ...
    @staticmethod
    def sendmsg(fd: java.io.FileDescriptor, msg: StructMsghdr, flags: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def sendto(fd: java.io.FileDescriptor, buffer: java.nio.ByteBuffer, flags: int | java.jint | java.lang.Integer, inetAddress: java.net.InetAddress, port: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def sendto(fd: java.io.FileDescriptor, bytes: java.chaquopy.JavaArrayJByte, byteOffset: int | java.jint | java.lang.Integer, byteCount: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, address: java.net.SocketAddress, /) -> int: ...
    @typing.overload
    @staticmethod
    def sendto(fd: java.io.FileDescriptor, bytes: java.chaquopy.JavaArrayJByte, byteOffset: int | java.jint | java.lang.Integer, byteCount: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, inetAddress: java.net.InetAddress, port: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def setegid(egid: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def setenv(name: str | java.lang.String, value: str | java.lang.String, overwrite: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def seteuid(euid: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def setgid(gid: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def setsid() -> int: ...
    @staticmethod
    def setsockoptInt(fd: java.io.FileDescriptor, level: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, value: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def setsockoptTimeval(fd: java.io.FileDescriptor, level: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, value: StructTimeval, /) -> None: ...
    @staticmethod
    def setuid(uid: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def setxattr(path: str | java.lang.String, name: str | java.lang.String, value: java.chaquopy.JavaArrayJByte, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def shutdown(fd: java.io.FileDescriptor, how: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def socket(domain: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, protocol: int | java.jint | java.lang.Integer, /) -> java.io.FileDescriptor: ...
    @staticmethod
    def socketpair(domain: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, protocol: int | java.jint | java.lang.Integer, fd1: java.io.FileDescriptor, fd2: java.io.FileDescriptor, /) -> None: ...
    @staticmethod
    def stat(path: str | java.lang.String, /) -> StructStat: ...
    @staticmethod
    def statvfs(path: str | java.lang.String, /) -> StructStatVfs: ...
    @staticmethod
    def strerror(errno: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def strsignal(signal: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def symlink(oldPath: str | java.lang.String, newPath: str | java.lang.String, /) -> None: ...
    @staticmethod
    def sysconf(name: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def tcdrain(fd: java.io.FileDescriptor, /) -> None: ...
    @staticmethod
    def tcsendbreak(fd: java.io.FileDescriptor, duration: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def umask(mask: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def uname() -> StructUtsname: ...
    @staticmethod
    def unsetenv(name: str | java.lang.String, /) -> None: ...
    @typing.overload
    @staticmethod
    def write(fd: java.io.FileDescriptor, buffer: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    @staticmethod
    def write(fd: java.io.FileDescriptor, bytes: java.chaquopy.JavaArrayJByte, byteOffset: int | java.jint | java.lang.Integer, byteCount: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def writev(fd: java.io.FileDescriptor, buffers: java.chaquopy.JavaArray[java.lang.Object], offsets: java.chaquopy.JavaArrayJInt, byteCounts: java.chaquopy.JavaArrayJInt, /) -> int: ...

class OsConstants(java.lang.Object):
    AF_INET6: typing.ClassVar[int] = ...
    AF_INET: typing.ClassVar[int] = ...
    AF_NETLINK: typing.ClassVar[int] = ...
    AF_PACKET: typing.ClassVar[int] = ...
    AF_UNIX: typing.ClassVar[int] = ...
    AF_UNSPEC: typing.ClassVar[int] = ...
    AF_VSOCK: typing.ClassVar[int] = ...
    AI_ADDRCONFIG: typing.ClassVar[int] = ...
    AI_ALL: typing.ClassVar[int] = ...
    AI_CANONNAME: typing.ClassVar[int] = ...
    AI_NUMERICHOST: typing.ClassVar[int] = ...
    AI_NUMERICSERV: typing.ClassVar[int] = ...
    AI_PASSIVE: typing.ClassVar[int] = ...
    AI_V4MAPPED: typing.ClassVar[int] = ...
    ARPHRD_ETHER: typing.ClassVar[int] = ...
    CAP_AUDIT_CONTROL: typing.ClassVar[int] = ...
    CAP_AUDIT_WRITE: typing.ClassVar[int] = ...
    CAP_BLOCK_SUSPEND: typing.ClassVar[int] = ...
    CAP_CHOWN: typing.ClassVar[int] = ...
    CAP_DAC_OVERRIDE: typing.ClassVar[int] = ...
    CAP_DAC_READ_SEARCH: typing.ClassVar[int] = ...
    CAP_FOWNER: typing.ClassVar[int] = ...
    CAP_FSETID: typing.ClassVar[int] = ...
    CAP_IPC_LOCK: typing.ClassVar[int] = ...
    CAP_IPC_OWNER: typing.ClassVar[int] = ...
    CAP_KILL: typing.ClassVar[int] = ...
    CAP_LAST_CAP: typing.ClassVar[int] = ...
    CAP_LEASE: typing.ClassVar[int] = ...
    CAP_LINUX_IMMUTABLE: typing.ClassVar[int] = ...
    CAP_MAC_ADMIN: typing.ClassVar[int] = ...
    CAP_MAC_OVERRIDE: typing.ClassVar[int] = ...
    CAP_MKNOD: typing.ClassVar[int] = ...
    CAP_NET_ADMIN: typing.ClassVar[int] = ...
    CAP_NET_BIND_SERVICE: typing.ClassVar[int] = ...
    CAP_NET_BROADCAST: typing.ClassVar[int] = ...
    CAP_NET_RAW: typing.ClassVar[int] = ...
    CAP_SETFCAP: typing.ClassVar[int] = ...
    CAP_SETGID: typing.ClassVar[int] = ...
    CAP_SETPCAP: typing.ClassVar[int] = ...
    CAP_SETUID: typing.ClassVar[int] = ...
    CAP_SYSLOG: typing.ClassVar[int] = ...
    CAP_SYS_ADMIN: typing.ClassVar[int] = ...
    CAP_SYS_BOOT: typing.ClassVar[int] = ...
    CAP_SYS_CHROOT: typing.ClassVar[int] = ...
    CAP_SYS_MODULE: typing.ClassVar[int] = ...
    CAP_SYS_NICE: typing.ClassVar[int] = ...
    CAP_SYS_PACCT: typing.ClassVar[int] = ...
    CAP_SYS_PTRACE: typing.ClassVar[int] = ...
    CAP_SYS_RAWIO: typing.ClassVar[int] = ...
    CAP_SYS_RESOURCE: typing.ClassVar[int] = ...
    CAP_SYS_TIME: typing.ClassVar[int] = ...
    CAP_SYS_TTY_CONFIG: typing.ClassVar[int] = ...
    CAP_WAKE_ALARM: typing.ClassVar[int] = ...
    E2BIG: typing.ClassVar[int] = ...
    EACCES: typing.ClassVar[int] = ...
    EADDRINUSE: typing.ClassVar[int] = ...
    EADDRNOTAVAIL: typing.ClassVar[int] = ...
    EAFNOSUPPORT: typing.ClassVar[int] = ...
    EAGAIN: typing.ClassVar[int] = ...
    EAI_AGAIN: typing.ClassVar[int] = ...
    EAI_BADFLAGS: typing.ClassVar[int] = ...
    EAI_FAIL: typing.ClassVar[int] = ...
    EAI_FAMILY: typing.ClassVar[int] = ...
    EAI_MEMORY: typing.ClassVar[int] = ...
    EAI_NODATA: typing.ClassVar[int] = ...
    EAI_NONAME: typing.ClassVar[int] = ...
    EAI_OVERFLOW: typing.ClassVar[int] = ...
    EAI_SERVICE: typing.ClassVar[int] = ...
    EAI_SOCKTYPE: typing.ClassVar[int] = ...
    EAI_SYSTEM: typing.ClassVar[int] = ...
    EALREADY: typing.ClassVar[int] = ...
    EBADF: typing.ClassVar[int] = ...
    EBADMSG: typing.ClassVar[int] = ...
    EBUSY: typing.ClassVar[int] = ...
    ECANCELED: typing.ClassVar[int] = ...
    ECHILD: typing.ClassVar[int] = ...
    ECONNABORTED: typing.ClassVar[int] = ...
    ECONNREFUSED: typing.ClassVar[int] = ...
    ECONNRESET: typing.ClassVar[int] = ...
    EDEADLK: typing.ClassVar[int] = ...
    EDESTADDRREQ: typing.ClassVar[int] = ...
    EDOM: typing.ClassVar[int] = ...
    EDQUOT: typing.ClassVar[int] = ...
    EEXIST: typing.ClassVar[int] = ...
    EFAULT: typing.ClassVar[int] = ...
    EFBIG: typing.ClassVar[int] = ...
    EHOSTUNREACH: typing.ClassVar[int] = ...
    EIDRM: typing.ClassVar[int] = ...
    EILSEQ: typing.ClassVar[int] = ...
    EINPROGRESS: typing.ClassVar[int] = ...
    EINTR: typing.ClassVar[int] = ...
    EINVAL: typing.ClassVar[int] = ...
    EIO: typing.ClassVar[int] = ...
    EISCONN: typing.ClassVar[int] = ...
    EISDIR: typing.ClassVar[int] = ...
    ELOOP: typing.ClassVar[int] = ...
    EMFILE: typing.ClassVar[int] = ...
    EMLINK: typing.ClassVar[int] = ...
    EMSGSIZE: typing.ClassVar[int] = ...
    EMULTIHOP: typing.ClassVar[int] = ...
    ENAMETOOLONG: typing.ClassVar[int] = ...
    ENETDOWN: typing.ClassVar[int] = ...
    ENETRESET: typing.ClassVar[int] = ...
    ENETUNREACH: typing.ClassVar[int] = ...
    ENFILE: typing.ClassVar[int] = ...
    ENOBUFS: typing.ClassVar[int] = ...
    ENODATA: typing.ClassVar[int] = ...
    ENODEV: typing.ClassVar[int] = ...
    ENOENT: typing.ClassVar[int] = ...
    ENOEXEC: typing.ClassVar[int] = ...
    ENOLCK: typing.ClassVar[int] = ...
    ENOLINK: typing.ClassVar[int] = ...
    ENOMEM: typing.ClassVar[int] = ...
    ENOMSG: typing.ClassVar[int] = ...
    ENONET: typing.ClassVar[int] = ...
    ENOPROTOOPT: typing.ClassVar[int] = ...
    ENOSPC: typing.ClassVar[int] = ...
    ENOSR: typing.ClassVar[int] = ...
    ENOSTR: typing.ClassVar[int] = ...
    ENOSYS: typing.ClassVar[int] = ...
    ENOTCONN: typing.ClassVar[int] = ...
    ENOTDIR: typing.ClassVar[int] = ...
    ENOTEMPTY: typing.ClassVar[int] = ...
    ENOTSOCK: typing.ClassVar[int] = ...
    ENOTSUP: typing.ClassVar[int] = ...
    ENOTTY: typing.ClassVar[int] = ...
    ENXIO: typing.ClassVar[int] = ...
    EOPNOTSUPP: typing.ClassVar[int] = ...
    EOVERFLOW: typing.ClassVar[int] = ...
    EPERM: typing.ClassVar[int] = ...
    EPIPE: typing.ClassVar[int] = ...
    EPROTO: typing.ClassVar[int] = ...
    EPROTONOSUPPORT: typing.ClassVar[int] = ...
    EPROTOTYPE: typing.ClassVar[int] = ...
    ERANGE: typing.ClassVar[int] = ...
    EROFS: typing.ClassVar[int] = ...
    ESPIPE: typing.ClassVar[int] = ...
    ESRCH: typing.ClassVar[int] = ...
    ESTALE: typing.ClassVar[int] = ...
    ETH_P_ALL: typing.ClassVar[int] = ...
    ETH_P_ARP: typing.ClassVar[int] = ...
    ETH_P_IP: typing.ClassVar[int] = ...
    ETH_P_IPV6: typing.ClassVar[int] = ...
    ETIME: typing.ClassVar[int] = ...
    ETIMEDOUT: typing.ClassVar[int] = ...
    ETXTBSY: typing.ClassVar[int] = ...
    EXDEV: typing.ClassVar[int] = ...
    EXIT_FAILURE: typing.ClassVar[int] = ...
    EXIT_SUCCESS: typing.ClassVar[int] = ...
    FD_CLOEXEC: typing.ClassVar[int] = ...
    FIONREAD: typing.ClassVar[int] = ...
    F_DUPFD: typing.ClassVar[int] = ...
    F_DUPFD_CLOEXEC: typing.ClassVar[int] = ...
    F_GETFD: typing.ClassVar[int] = ...
    F_GETFL: typing.ClassVar[int] = ...
    F_GETLK64: typing.ClassVar[int] = ...
    F_GETLK: typing.ClassVar[int] = ...
    F_GETOWN: typing.ClassVar[int] = ...
    F_OK: typing.ClassVar[int] = ...
    F_RDLCK: typing.ClassVar[int] = ...
    F_SETFD: typing.ClassVar[int] = ...
    F_SETFL: typing.ClassVar[int] = ...
    F_SETLK64: typing.ClassVar[int] = ...
    F_SETLK: typing.ClassVar[int] = ...
    F_SETLKW64: typing.ClassVar[int] = ...
    F_SETLKW: typing.ClassVar[int] = ...
    F_SETOWN: typing.ClassVar[int] = ...
    F_UNLCK: typing.ClassVar[int] = ...
    F_WRLCK: typing.ClassVar[int] = ...
    ICMP6_ECHO_REPLY: typing.ClassVar[int] = ...
    ICMP6_ECHO_REQUEST: typing.ClassVar[int] = ...
    ICMP_ECHO: typing.ClassVar[int] = ...
    ICMP_ECHOREPLY: typing.ClassVar[int] = ...
    IFA_F_DADFAILED: typing.ClassVar[int] = ...
    IFA_F_DEPRECATED: typing.ClassVar[int] = ...
    IFA_F_HOMEADDRESS: typing.ClassVar[int] = ...
    IFA_F_MANAGETEMPADDR: typing.ClassVar[int] = ...
    IFA_F_NODAD: typing.ClassVar[int] = ...
    IFA_F_NOPREFIXROUTE: typing.ClassVar[int] = ...
    IFA_F_OPTIMISTIC: typing.ClassVar[int] = ...
    IFA_F_PERMANENT: typing.ClassVar[int] = ...
    IFA_F_SECONDARY: typing.ClassVar[int] = ...
    IFA_F_TEMPORARY: typing.ClassVar[int] = ...
    IFA_F_TENTATIVE: typing.ClassVar[int] = ...
    IFF_ALLMULTI: typing.ClassVar[int] = ...
    IFF_AUTOMEDIA: typing.ClassVar[int] = ...
    IFF_BROADCAST: typing.ClassVar[int] = ...
    IFF_DEBUG: typing.ClassVar[int] = ...
    IFF_DYNAMIC: typing.ClassVar[int] = ...
    IFF_LOOPBACK: typing.ClassVar[int] = ...
    IFF_MASTER: typing.ClassVar[int] = ...
    IFF_MULTICAST: typing.ClassVar[int] = ...
    IFF_NOARP: typing.ClassVar[int] = ...
    IFF_NOTRAILERS: typing.ClassVar[int] = ...
    IFF_POINTOPOINT: typing.ClassVar[int] = ...
    IFF_PORTSEL: typing.ClassVar[int] = ...
    IFF_PROMISC: typing.ClassVar[int] = ...
    IFF_RUNNING: typing.ClassVar[int] = ...
    IFF_SLAVE: typing.ClassVar[int] = ...
    IFF_UP: typing.ClassVar[int] = ...
    IPPROTO_ESP: typing.ClassVar[int] = ...
    IPPROTO_ICMP: typing.ClassVar[int] = ...
    IPPROTO_ICMPV6: typing.ClassVar[int] = ...
    IPPROTO_IP: typing.ClassVar[int] = ...
    IPPROTO_IPV6: typing.ClassVar[int] = ...
    IPPROTO_RAW: typing.ClassVar[int] = ...
    IPPROTO_TCP: typing.ClassVar[int] = ...
    IPPROTO_UDP: typing.ClassVar[int] = ...
    IPV6_CHECKSUM: typing.ClassVar[int] = ...
    IPV6_MULTICAST_HOPS: typing.ClassVar[int] = ...
    IPV6_MULTICAST_IF: typing.ClassVar[int] = ...
    IPV6_MULTICAST_LOOP: typing.ClassVar[int] = ...
    IPV6_PKTINFO: typing.ClassVar[int] = ...
    IPV6_RECVDSTOPTS: typing.ClassVar[int] = ...
    IPV6_RECVHOPLIMIT: typing.ClassVar[int] = ...
    IPV6_RECVHOPOPTS: typing.ClassVar[int] = ...
    IPV6_RECVPKTINFO: typing.ClassVar[int] = ...
    IPV6_RECVRTHDR: typing.ClassVar[int] = ...
    IPV6_RECVTCLASS: typing.ClassVar[int] = ...
    IPV6_TCLASS: typing.ClassVar[int] = ...
    IPV6_UNICAST_HOPS: typing.ClassVar[int] = ...
    IPV6_V6ONLY: typing.ClassVar[int] = ...
    IP_MULTICAST_IF: typing.ClassVar[int] = ...
    IP_MULTICAST_LOOP: typing.ClassVar[int] = ...
    IP_MULTICAST_TTL: typing.ClassVar[int] = ...
    IP_TOS: typing.ClassVar[int] = ...
    IP_TTL: typing.ClassVar[int] = ...
    MAP_ANONYMOUS: typing.ClassVar[int] = ...
    MAP_FIXED: typing.ClassVar[int] = ...
    MAP_PRIVATE: typing.ClassVar[int] = ...
    MAP_SHARED: typing.ClassVar[int] = ...
    MCAST_BLOCK_SOURCE: typing.ClassVar[int] = ...
    MCAST_JOIN_GROUP: typing.ClassVar[int] = ...
    MCAST_JOIN_SOURCE_GROUP: typing.ClassVar[int] = ...
    MCAST_LEAVE_GROUP: typing.ClassVar[int] = ...
    MCAST_LEAVE_SOURCE_GROUP: typing.ClassVar[int] = ...
    MCAST_UNBLOCK_SOURCE: typing.ClassVar[int] = ...
    MCL_CURRENT: typing.ClassVar[int] = ...
    MCL_FUTURE: typing.ClassVar[int] = ...
    MFD_CLOEXEC: typing.ClassVar[int] = ...
    MSG_CTRUNC: typing.ClassVar[int] = ...
    MSG_DONTROUTE: typing.ClassVar[int] = ...
    MSG_EOR: typing.ClassVar[int] = ...
    MSG_OOB: typing.ClassVar[int] = ...
    MSG_PEEK: typing.ClassVar[int] = ...
    MSG_TRUNC: typing.ClassVar[int] = ...
    MSG_WAITALL: typing.ClassVar[int] = ...
    MS_ASYNC: typing.ClassVar[int] = ...
    MS_INVALIDATE: typing.ClassVar[int] = ...
    MS_SYNC: typing.ClassVar[int] = ...
    NETLINK_INET_DIAG: typing.ClassVar[int] = ...
    NETLINK_NETFILTER: typing.ClassVar[int] = ...
    NETLINK_ROUTE: typing.ClassVar[int] = ...
    NETLINK_XFRM: typing.ClassVar[int] = ...
    NI_DGRAM: typing.ClassVar[int] = ...
    NI_NAMEREQD: typing.ClassVar[int] = ...
    NI_NOFQDN: typing.ClassVar[int] = ...
    NI_NUMERICHOST: typing.ClassVar[int] = ...
    NI_NUMERICSERV: typing.ClassVar[int] = ...
    O_ACCMODE: typing.ClassVar[int] = ...
    O_APPEND: typing.ClassVar[int] = ...
    O_CLOEXEC: typing.ClassVar[int] = ...
    O_CREAT: typing.ClassVar[int] = ...
    O_DSYNC: typing.ClassVar[int] = ...
    O_EXCL: typing.ClassVar[int] = ...
    O_NOCTTY: typing.ClassVar[int] = ...
    O_NOFOLLOW: typing.ClassVar[int] = ...
    O_NONBLOCK: typing.ClassVar[int] = ...
    O_RDONLY: typing.ClassVar[int] = ...
    O_RDWR: typing.ClassVar[int] = ...
    O_SYNC: typing.ClassVar[int] = ...
    O_TRUNC: typing.ClassVar[int] = ...
    O_WRONLY: typing.ClassVar[int] = ...
    PACKET_IGNORE_OUTGOING: typing.ClassVar[int] = ...
    POLLERR: typing.ClassVar[int] = ...
    POLLHUP: typing.ClassVar[int] = ...
    POLLIN: typing.ClassVar[int] = ...
    POLLNVAL: typing.ClassVar[int] = ...
    POLLOUT: typing.ClassVar[int] = ...
    POLLPRI: typing.ClassVar[int] = ...
    POLLRDBAND: typing.ClassVar[int] = ...
    POLLRDNORM: typing.ClassVar[int] = ...
    POLLWRBAND: typing.ClassVar[int] = ...
    POLLWRNORM: typing.ClassVar[int] = ...
    PROT_EXEC: typing.ClassVar[int] = ...
    PROT_NONE: typing.ClassVar[int] = ...
    PROT_READ: typing.ClassVar[int] = ...
    PROT_WRITE: typing.ClassVar[int] = ...
    PR_GET_DUMPABLE: typing.ClassVar[int] = ...
    PR_SET_DUMPABLE: typing.ClassVar[int] = ...
    PR_SET_NO_NEW_PRIVS: typing.ClassVar[int] = ...
    RTMGRP_NEIGH: typing.ClassVar[int] = ...
    RT_SCOPE_HOST: typing.ClassVar[int] = ...
    RT_SCOPE_LINK: typing.ClassVar[int] = ...
    RT_SCOPE_NOWHERE: typing.ClassVar[int] = ...
    RT_SCOPE_SITE: typing.ClassVar[int] = ...
    RT_SCOPE_UNIVERSE: typing.ClassVar[int] = ...
    R_OK: typing.ClassVar[int] = ...
    SEEK_CUR: typing.ClassVar[int] = ...
    SEEK_END: typing.ClassVar[int] = ...
    SEEK_SET: typing.ClassVar[int] = ...
    SHUT_RD: typing.ClassVar[int] = ...
    SHUT_RDWR: typing.ClassVar[int] = ...
    SHUT_WR: typing.ClassVar[int] = ...
    SIGABRT: typing.ClassVar[int] = ...
    SIGALRM: typing.ClassVar[int] = ...
    SIGBUS: typing.ClassVar[int] = ...
    SIGCHLD: typing.ClassVar[int] = ...
    SIGCONT: typing.ClassVar[int] = ...
    SIGFPE: typing.ClassVar[int] = ...
    SIGHUP: typing.ClassVar[int] = ...
    SIGILL: typing.ClassVar[int] = ...
    SIGINT: typing.ClassVar[int] = ...
    SIGIO: typing.ClassVar[int] = ...
    SIGKILL: typing.ClassVar[int] = ...
    SIGPIPE: typing.ClassVar[int] = ...
    SIGPROF: typing.ClassVar[int] = ...
    SIGPWR: typing.ClassVar[int] = ...
    SIGQUIT: typing.ClassVar[int] = ...
    SIGRTMAX: typing.ClassVar[int] = ...
    SIGRTMIN: typing.ClassVar[int] = ...
    SIGSEGV: typing.ClassVar[int] = ...
    SIGSTKFLT: typing.ClassVar[int] = ...
    SIGSTOP: typing.ClassVar[int] = ...
    SIGSYS: typing.ClassVar[int] = ...
    SIGTERM: typing.ClassVar[int] = ...
    SIGTRAP: typing.ClassVar[int] = ...
    SIGTSTP: typing.ClassVar[int] = ...
    SIGTTIN: typing.ClassVar[int] = ...
    SIGTTOU: typing.ClassVar[int] = ...
    SIGURG: typing.ClassVar[int] = ...
    SIGUSR1: typing.ClassVar[int] = ...
    SIGUSR2: typing.ClassVar[int] = ...
    SIGVTALRM: typing.ClassVar[int] = ...
    SIGWINCH: typing.ClassVar[int] = ...
    SIGXCPU: typing.ClassVar[int] = ...
    SIGXFSZ: typing.ClassVar[int] = ...
    SIOCGIFADDR: typing.ClassVar[int] = ...
    SIOCGIFBRDADDR: typing.ClassVar[int] = ...
    SIOCGIFDSTADDR: typing.ClassVar[int] = ...
    SIOCGIFNETMASK: typing.ClassVar[int] = ...
    SOCK_CLOEXEC: typing.ClassVar[int] = ...
    SOCK_DGRAM: typing.ClassVar[int] = ...
    SOCK_NONBLOCK: typing.ClassVar[int] = ...
    SOCK_RAW: typing.ClassVar[int] = ...
    SOCK_SEQPACKET: typing.ClassVar[int] = ...
    SOCK_STREAM: typing.ClassVar[int] = ...
    SOL_PACKET: typing.ClassVar[int] = ...
    SOL_SOCKET: typing.ClassVar[int] = ...
    SOL_UDP: typing.ClassVar[int] = ...
    SO_BINDTODEVICE: typing.ClassVar[int] = ...
    SO_BROADCAST: typing.ClassVar[int] = ...
    SO_DEBUG: typing.ClassVar[int] = ...
    SO_DONTROUTE: typing.ClassVar[int] = ...
    SO_ERROR: typing.ClassVar[int] = ...
    SO_KEEPALIVE: typing.ClassVar[int] = ...
    SO_LINGER: typing.ClassVar[int] = ...
    SO_OOBINLINE: typing.ClassVar[int] = ...
    SO_PASSCRED: typing.ClassVar[int] = ...
    SO_PEERCRED: typing.ClassVar[int] = ...
    SO_RCVBUF: typing.ClassVar[int] = ...
    SO_RCVLOWAT: typing.ClassVar[int] = ...
    SO_RCVTIMEO: typing.ClassVar[int] = ...
    SO_REUSEADDR: typing.ClassVar[int] = ...
    SO_SNDBUF: typing.ClassVar[int] = ...
    SO_SNDLOWAT: typing.ClassVar[int] = ...
    SO_SNDTIMEO: typing.ClassVar[int] = ...
    SO_TYPE: typing.ClassVar[int] = ...
    STDERR_FILENO: typing.ClassVar[int] = ...
    STDIN_FILENO: typing.ClassVar[int] = ...
    STDOUT_FILENO: typing.ClassVar[int] = ...
    ST_MANDLOCK: typing.ClassVar[int] = ...
    ST_NOATIME: typing.ClassVar[int] = ...
    ST_NODEV: typing.ClassVar[int] = ...
    ST_NODIRATIME: typing.ClassVar[int] = ...
    ST_NOEXEC: typing.ClassVar[int] = ...
    ST_NOSUID: typing.ClassVar[int] = ...
    ST_RDONLY: typing.ClassVar[int] = ...
    ST_RELATIME: typing.ClassVar[int] = ...
    ST_SYNCHRONOUS: typing.ClassVar[int] = ...
    S_IFBLK: typing.ClassVar[int] = ...
    S_IFCHR: typing.ClassVar[int] = ...
    S_IFDIR: typing.ClassVar[int] = ...
    S_IFIFO: typing.ClassVar[int] = ...
    S_IFLNK: typing.ClassVar[int] = ...
    S_IFMT: typing.ClassVar[int] = ...
    S_IFREG: typing.ClassVar[int] = ...
    S_IFSOCK: typing.ClassVar[int] = ...
    S_IRGRP: typing.ClassVar[int] = ...
    S_IROTH: typing.ClassVar[int] = ...
    S_IRUSR: typing.ClassVar[int] = ...
    S_IRWXG: typing.ClassVar[int] = ...
    S_IRWXO: typing.ClassVar[int] = ...
    S_IRWXU: typing.ClassVar[int] = ...
    S_ISGID: typing.ClassVar[int] = ...
    S_ISUID: typing.ClassVar[int] = ...
    S_ISVTX: typing.ClassVar[int] = ...
    S_IWGRP: typing.ClassVar[int] = ...
    S_IWOTH: typing.ClassVar[int] = ...
    S_IWUSR: typing.ClassVar[int] = ...
    S_IXGRP: typing.ClassVar[int] = ...
    S_IXOTH: typing.ClassVar[int] = ...
    S_IXUSR: typing.ClassVar[int] = ...
    TCP_NODELAY: typing.ClassVar[int] = ...
    TCP_USER_TIMEOUT: typing.ClassVar[int] = ...
    UDP_GRO: typing.ClassVar[int] = ...
    UDP_SEGMENT: typing.ClassVar[int] = ...
    VMADDR_CID_ANY: typing.ClassVar[int] = ...
    VMADDR_CID_HOST: typing.ClassVar[int] = ...
    VMADDR_CID_LOCAL: typing.ClassVar[int] = ...
    VMADDR_PORT_ANY: typing.ClassVar[int] = ...
    WCONTINUED: typing.ClassVar[int] = ...
    WEXITED: typing.ClassVar[int] = ...
    WNOHANG: typing.ClassVar[int] = ...
    WNOWAIT: typing.ClassVar[int] = ...
    WSTOPPED: typing.ClassVar[int] = ...
    WUNTRACED: typing.ClassVar[int] = ...
    W_OK: typing.ClassVar[int] = ...
    X_OK: typing.ClassVar[int] = ...
    _SC_2_CHAR_TERM: typing.ClassVar[int] = ...
    _SC_2_C_BIND: typing.ClassVar[int] = ...
    _SC_2_C_DEV: typing.ClassVar[int] = ...
    _SC_2_C_VERSION: typing.ClassVar[int] = ...
    _SC_2_FORT_DEV: typing.ClassVar[int] = ...
    _SC_2_FORT_RUN: typing.ClassVar[int] = ...
    _SC_2_LOCALEDEF: typing.ClassVar[int] = ...
    _SC_2_SW_DEV: typing.ClassVar[int] = ...
    _SC_2_UPE: typing.ClassVar[int] = ...
    _SC_2_VERSION: typing.ClassVar[int] = ...
    _SC_AIO_LISTIO_MAX: typing.ClassVar[int] = ...
    _SC_AIO_MAX: typing.ClassVar[int] = ...
    _SC_AIO_PRIO_DELTA_MAX: typing.ClassVar[int] = ...
    _SC_ARG_MAX: typing.ClassVar[int] = ...
    _SC_ASYNCHRONOUS_IO: typing.ClassVar[int] = ...
    _SC_ATEXIT_MAX: typing.ClassVar[int] = ...
    _SC_AVPHYS_PAGES: typing.ClassVar[int] = ...
    _SC_BC_BASE_MAX: typing.ClassVar[int] = ...
    _SC_BC_DIM_MAX: typing.ClassVar[int] = ...
    _SC_BC_SCALE_MAX: typing.ClassVar[int] = ...
    _SC_BC_STRING_MAX: typing.ClassVar[int] = ...
    _SC_CHILD_MAX: typing.ClassVar[int] = ...
    _SC_CLK_TCK: typing.ClassVar[int] = ...
    _SC_COLL_WEIGHTS_MAX: typing.ClassVar[int] = ...
    _SC_DELAYTIMER_MAX: typing.ClassVar[int] = ...
    _SC_EXPR_NEST_MAX: typing.ClassVar[int] = ...
    _SC_FSYNC: typing.ClassVar[int] = ...
    _SC_GETGR_R_SIZE_MAX: typing.ClassVar[int] = ...
    _SC_GETPW_R_SIZE_MAX: typing.ClassVar[int] = ...
    _SC_IOV_MAX: typing.ClassVar[int] = ...
    _SC_JOB_CONTROL: typing.ClassVar[int] = ...
    _SC_LINE_MAX: typing.ClassVar[int] = ...
    _SC_LOGIN_NAME_MAX: typing.ClassVar[int] = ...
    _SC_MAPPED_FILES: typing.ClassVar[int] = ...
    _SC_MEMLOCK: typing.ClassVar[int] = ...
    _SC_MEMLOCK_RANGE: typing.ClassVar[int] = ...
    _SC_MEMORY_PROTECTION: typing.ClassVar[int] = ...
    _SC_MESSAGE_PASSING: typing.ClassVar[int] = ...
    _SC_MQ_OPEN_MAX: typing.ClassVar[int] = ...
    _SC_MQ_PRIO_MAX: typing.ClassVar[int] = ...
    _SC_NGROUPS_MAX: typing.ClassVar[int] = ...
    _SC_NPROCESSORS_CONF: typing.ClassVar[int] = ...
    _SC_NPROCESSORS_ONLN: typing.ClassVar[int] = ...
    _SC_OPEN_MAX: typing.ClassVar[int] = ...
    _SC_PAGESIZE: typing.ClassVar[int] = ...
    _SC_PAGE_SIZE: typing.ClassVar[int] = ...
    _SC_PASS_MAX: typing.ClassVar[int] = ...
    _SC_PHYS_PAGES: typing.ClassVar[int] = ...
    _SC_PRIORITIZED_IO: typing.ClassVar[int] = ...
    _SC_PRIORITY_SCHEDULING: typing.ClassVar[int] = ...
    _SC_REALTIME_SIGNALS: typing.ClassVar[int] = ...
    _SC_RE_DUP_MAX: typing.ClassVar[int] = ...
    _SC_RTSIG_MAX: typing.ClassVar[int] = ...
    _SC_SAVED_IDS: typing.ClassVar[int] = ...
    _SC_SEMAPHORES: typing.ClassVar[int] = ...
    _SC_SEM_NSEMS_MAX: typing.ClassVar[int] = ...
    _SC_SEM_VALUE_MAX: typing.ClassVar[int] = ...
    _SC_SHARED_MEMORY_OBJECTS: typing.ClassVar[int] = ...
    _SC_SIGQUEUE_MAX: typing.ClassVar[int] = ...
    _SC_STREAM_MAX: typing.ClassVar[int] = ...
    _SC_SYNCHRONIZED_IO: typing.ClassVar[int] = ...
    _SC_THREADS: typing.ClassVar[int] = ...
    _SC_THREAD_ATTR_STACKADDR: typing.ClassVar[int] = ...
    _SC_THREAD_ATTR_STACKSIZE: typing.ClassVar[int] = ...
    _SC_THREAD_DESTRUCTOR_ITERATIONS: typing.ClassVar[int] = ...
    _SC_THREAD_KEYS_MAX: typing.ClassVar[int] = ...
    _SC_THREAD_PRIORITY_SCHEDULING: typing.ClassVar[int] = ...
    _SC_THREAD_PRIO_INHERIT: typing.ClassVar[int] = ...
    _SC_THREAD_PRIO_PROTECT: typing.ClassVar[int] = ...
    _SC_THREAD_SAFE_FUNCTIONS: typing.ClassVar[int] = ...
    _SC_THREAD_STACK_MIN: typing.ClassVar[int] = ...
    _SC_THREAD_THREADS_MAX: typing.ClassVar[int] = ...
    _SC_TIMERS: typing.ClassVar[int] = ...
    _SC_TIMER_MAX: typing.ClassVar[int] = ...
    _SC_TTY_NAME_MAX: typing.ClassVar[int] = ...
    _SC_TZNAME_MAX: typing.ClassVar[int] = ...
    _SC_VERSION: typing.ClassVar[int] = ...
    _SC_XBS5_ILP32_OFF32: typing.ClassVar[int] = ...
    _SC_XBS5_ILP32_OFFBIG: typing.ClassVar[int] = ...
    _SC_XBS5_LP64_OFF64: typing.ClassVar[int] = ...
    _SC_XBS5_LPBIG_OFFBIG: typing.ClassVar[int] = ...
    _SC_XOPEN_CRYPT: typing.ClassVar[int] = ...
    _SC_XOPEN_ENH_I18N: typing.ClassVar[int] = ...
    _SC_XOPEN_LEGACY: typing.ClassVar[int] = ...
    _SC_XOPEN_REALTIME: typing.ClassVar[int] = ...
    _SC_XOPEN_REALTIME_THREADS: typing.ClassVar[int] = ...
    _SC_XOPEN_SHM: typing.ClassVar[int] = ...
    _SC_XOPEN_UNIX: typing.ClassVar[int] = ...
    _SC_XOPEN_VERSION: typing.ClassVar[int] = ...
    _SC_XOPEN_XCU_VERSION: typing.ClassVar[int] = ...
    @staticmethod
    def S_ISBLK(mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def S_ISCHR(mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def S_ISDIR(mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def S_ISFIFO(mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def S_ISLNK(mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def S_ISREG(mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def S_ISSOCK(mode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def WCOREDUMP(status: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def WEXITSTATUS(status: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def WIFEXITED(status: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def WIFSIGNALED(status: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def WIFSTOPPED(status: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def WSTOPSIG(status: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def WTERMSIG(status: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def errnoName(errno: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def gaiName(error: int | java.jint | java.lang.Integer, /) -> str: ...

class StructCmsghdr(java.lang.Object):
    cmsg_data: java.chaquopy.JavaArrayJByte = ...
    cmsg_level: int = ...
    cmsg_type: int = ...
    @typing.overload
    def __init__(self, cmsg_level: int | java.jint | java.lang.Integer, cmsg_type: int | java.jint | java.lang.Integer, value: int | java.jshort | java.lang.Short, /) -> None: ...
    @typing.overload
    def __init__(self, cmsg_level: int | java.jint | java.lang.Integer, cmsg_type: int | java.jint | java.lang.Integer, value: java.chaquopy.JavaArrayJByte, /) -> None: ...

class StructMsghdr(java.lang.Object):
    msg_control: java.chaquopy.JavaArray[StructCmsghdr] = ...
    msg_flags: int = ...
    msg_iov: java.chaquopy.JavaArray[java.nio.ByteBuffer] = ...
    msg_name: java.net.SocketAddress = ...
    def __init__(self, msg_name: java.net.SocketAddress, msg_iov: java.chaquopy.JavaArray[java.nio.ByteBuffer], msg_control: java.chaquopy.JavaArray[StructCmsghdr], msg_flags: int | java.jint | java.lang.Integer, /) -> None: ...

class StructPollfd(java.lang.Object):
    events: int = ...
    fd: java.io.FileDescriptor = ...
    revents: int = ...
    userData: java.lang.Object = ...
    def __init__(self) -> None: ...
    def toString(self) -> str: ...

class StructStat(java.lang.Object):
    st_atim: StructTimespec = ...
    st_atime: int = ...
    st_blksize: int = ...
    st_blocks: int = ...
    st_ctim: StructTimespec = ...
    st_ctime: int = ...
    st_dev: int = ...
    st_gid: int = ...
    st_ino: int = ...
    st_mode: int = ...
    st_mtim: StructTimespec = ...
    st_mtime: int = ...
    st_nlink: int = ...
    st_rdev: int = ...
    st_size: int = ...
    st_uid: int = ...
    @typing.overload
    def __init__(self, st_dev: int | java.jlong | java.lang.Long, st_ino: int | java.jlong | java.lang.Long, st_mode: int | java.jint | java.lang.Integer, st_nlink: int | java.jlong | java.lang.Long, st_uid: int | java.jint | java.lang.Integer, st_gid: int | java.jint | java.lang.Integer, st_rdev: int | java.jlong | java.lang.Long, st_size: int | java.jlong | java.lang.Long, st_atime: int | java.jlong | java.lang.Long, st_mtime: int | java.jlong | java.lang.Long, st_ctime: int | java.jlong | java.lang.Long, st_blksize: int | java.jlong | java.lang.Long, st_blocks: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def __init__(self, st_dev: int | java.jlong | java.lang.Long, st_ino: int | java.jlong | java.lang.Long, st_mode: int | java.jint | java.lang.Integer, st_nlink: int | java.jlong | java.lang.Long, st_uid: int | java.jint | java.lang.Integer, st_gid: int | java.jint | java.lang.Integer, st_rdev: int | java.jlong | java.lang.Long, st_size: int | java.jlong | java.lang.Long, st_atim: StructTimespec, st_mtim: StructTimespec, st_ctim: StructTimespec, st_blksize: int | java.jlong | java.lang.Long, st_blocks: int | java.jlong | java.lang.Long, /) -> None: ...
    def toString(self) -> str: ...

class StructStatVfs(java.lang.Object):
    f_bavail: int = ...
    f_bfree: int = ...
    f_blocks: int = ...
    f_bsize: int = ...
    f_favail: int = ...
    f_ffree: int = ...
    f_files: int = ...
    f_flag: int = ...
    f_frsize: int = ...
    f_fsid: int = ...
    f_namemax: int = ...
    def __init__(self, f_bsize: int | java.jlong | java.lang.Long, f_frsize: int | java.jlong | java.lang.Long, f_blocks: int | java.jlong | java.lang.Long, f_bfree: int | java.jlong | java.lang.Long, f_bavail: int | java.jlong | java.lang.Long, f_files: int | java.jlong | java.lang.Long, f_ffree: int | java.jlong | java.lang.Long, f_favail: int | java.jlong | java.lang.Long, f_fsid: int | java.jlong | java.lang.Long, f_flag: int | java.jlong | java.lang.Long, f_namemax: int | java.jlong | java.lang.Long, /) -> None: ...
    def toString(self) -> str: ...

class StructTimespec(java.lang.Comparable[StructTimespec]):
    tv_nsec: int = ...
    tv_sec: int = ...
    def __init__(self, tv_sec: int | java.jlong | java.lang.Long, tv_nsec: int | java.jlong | java.lang.Long, /) -> None: ...
    def compareTo(self, other: StructTimespec, /) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class StructTimeval(java.lang.Object):
    tv_sec: int = ...
    tv_usec: int = ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromMillis(millis: int | java.jlong | java.lang.Long, /) -> StructTimeval: ...
    def hashCode(self) -> int: ...
    def toMillis(self) -> int: ...
    def toString(self) -> str: ...

class StructUtsname(java.lang.Object):
    machine: str = ...
    nodename: str = ...
    release: str = ...
    sysname: str = ...
    version: str = ...
    def __init__(self, sysname: str | java.lang.String, nodename: str | java.lang.String, release: str | java.lang.String, version: str | java.lang.String, machine: str | java.lang.String, /) -> None: ...
    def toString(self) -> str: ...

class SystemCleaner(java.lang.Object):
    @staticmethod
    def cleaner() -> java.lang.ref.Cleaner: ...

class VmSocketAddress(java.net.SocketAddress):
    def __init__(self, svmPort: int | java.jint | java.lang.Integer, svmCid: int | java.jint | java.lang.Integer, /) -> None: ...
    def getSvmCid(self) -> int: ...
    def getSvmPort(self) -> int: ...
