import typing

import android.app
import android.content
import android.net
import android.os
import java
import java.lang
import java.util

class WallpaperDescription(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WallpaperDescription]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getComponent(self) -> android.content.ComponentName: ...
    def getContent(self) -> android.os.PersistableBundle: ...
    def getContextDescription(self) -> java.lang.CharSequence: ...
    def getContextUri(self) -> android.net.Uri: ...
    def getDescription(self) -> java.util.List[java.lang.CharSequence]: ...
    def getId(self) -> str: ...
    def getThumbnail(self) -> android.net.Uri: ...
    def getTitle(self) -> java.lang.CharSequence: ...
    def hashCode(self) -> int: ...
    def toBuilder(self) -> WallpaperDescription.Builder: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> WallpaperDescription: ...
        def setContent(self, content: android.os.PersistableBundle, /) -> WallpaperDescription.Builder: ...
        def setContextDescription(self, contextDescription: java.lang.CharSequence, /) -> WallpaperDescription.Builder: ...
        def setContextUri(self, contextUri: android.net.Uri, /) -> WallpaperDescription.Builder: ...
        def setDescription(self, description: java.util.List[java.lang.CharSequence], /) -> WallpaperDescription.Builder: ...
        def setId(self, id: str | java.lang.String, /) -> WallpaperDescription.Builder: ...
        def setThumbnail(self, thumbnail: android.net.Uri, /) -> WallpaperDescription.Builder: ...
        def setTitle(self, title: java.lang.CharSequence, /) -> WallpaperDescription.Builder: ...

class WallpaperInstance(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WallpaperInstance]] = ...
    def __init__(self, info: android.app.WallpaperInfo, description: WallpaperDescription, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDescription(self) -> WallpaperDescription: ...
    def getId(self) -> str: ...
    def getInfo(self) -> android.app.WallpaperInfo: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...
