import typing

import android.app.appsearch
import java
import java.lang

class AppSearchException(java.lang.Exception):
    @typing.overload
    def __init__(self, resultCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, resultCode: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, resultCode: int | java.jint | java.lang.Integer, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    def getResultCode(self) -> int: ...
    def toAppSearchResult(self) -> android.app.appsearch.AppSearchResult[java.lang.Object]: ...
