import typing

import java
import java.chaquopy
import java.io
import java.lang

class Callback(java.lang.Object): ...

class CallbackHandler(java.lang.Object):
    def handle(self, arg1: java.chaquopy.JavaArray[Callback], /) -> None: ...

class PasswordCallback(Callback, java.io.Serializable):
    def __init__(self, prompt: str | java.lang.String, echoOn: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def clearPassword(self) -> None: ...
    def getPassword(self) -> java.chaquopy.JavaArrayJChar: ...
    def getPrompt(self) -> str: ...
    def isEchoOn(self) -> bool: ...
    def setPassword(self, password: java.chaquopy.JavaArrayJChar, /) -> None: ...

class UnsupportedCallbackException(java.lang.Exception):
    @typing.overload
    def __init__(self, callback: Callback, /) -> None: ...
    @typing.overload
    def __init__(self, callback: Callback, msg: str | java.lang.String, /) -> None: ...
    def getCallback(self) -> Callback: ...
