import typing

import android.net.wifi.hotspot2.pps
import android.os
import java
import java.chaquopy
import java.lang

class ConfigParser(java.lang.Object):
    @staticmethod
    def parsePasspointConfig(mimeType: str | java.lang.String, data: java.chaquopy.JavaArrayJByte, /) -> PasspointConfiguration: ...

class PasspointConfiguration(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PasspointConfiguration]] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, source: PasspointConfiguration, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, thatObject: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCredential(self) -> android.net.wifi.hotspot2.pps.Credential: ...
    def getDecoratedIdentityPrefix(self) -> str | None: ...
    def getHomeSp(self) -> android.net.wifi.hotspot2.pps.HomeSp: ...
    def getSubscriptionExpirationTimeMillis(self) -> int: ...
    def getUniqueId(self) -> str: ...
    def hashCode(self) -> int: ...
    def isOsuProvisioned(self) -> bool: ...
    def setCredential(self, credential: android.net.wifi.hotspot2.pps.Credential, /) -> None: ...
    def setDecoratedIdentityPrefix(self, decoratedIdentityPrefix: str | java.lang.String, /) -> None: ...
    def setHomeSp(self, homeSp: android.net.wifi.hotspot2.pps.HomeSp, /) -> None: ...
    def setSubscriptionExpirationTimeInMillis(self, subscriptionExpirationTimeInMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...
