import typing

import android.os
import java
import java.chaquopy
import java.lang

class RttRangingCapabilities(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RttRangingCapabilities]] = ...
    def describeContents(self) -> int: ...
    def hasPeriodicRangingHardwareFeature(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class RttRangingParams(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RttRangingParams]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMatchFilter(self) -> java.chaquopy.JavaArrayJByte: ...
    def getRangingUpdateRate(self) -> int: ...
    def getServiceName(self) -> str: ...
    def hashCode(self) -> int: ...
    def isPeriodicRangingHwFeatureEnabled(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, serviceName: str | java.lang.String, /) -> None: ...
        def build(self) -> RttRangingParams: ...
        def setMatchFilter(self, matchFilter: java.chaquopy.JavaArrayJByte, /) -> RttRangingParams.Builder: ...
        def setPeriodicRangingHwFeatureEnabled(self, periodicRangingHwFeatureEnabled: bool | java.jboolean | java.lang.Boolean, /) -> RttRangingParams.Builder: ...
        def setRangingUpdateRate(self, updateRate: int | java.jint | java.lang.Integer, /) -> RttRangingParams.Builder: ...
