import typing

import android.app
import android.content
import android.os
import android.view
import android.view.accessibility
import java
import java.chaquopy
import java.io
import java.lang

class DreamService(android.app.Service, android.view.Window.Callback):
    DREAM_META_DATA: typing.ClassVar[str] = ...
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def addContentView(self, view: android.view.View, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def dispatchGenericMotionEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def dispatchKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def dispatchKeyShortcutEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def dispatchPopulateAccessibilityEvent(self, event: android.view.accessibility.AccessibilityEvent, /) -> bool: ...
    def dispatchTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def dispatchTrackballEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def dump(self, fd: java.io.FileDescriptor, pw: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def findViewById(self, id: int | java.jint | java.lang.Integer, /) -> android.view.View | None: ...
    def finish(self) -> None: ...
    def getWindow(self) -> android.view.Window | None: ...
    def getWindowManager(self) -> android.view.WindowManager | None: ...
    def isFullscreen(self) -> bool: ...
    def isInteractive(self) -> bool: ...
    def isScreenBright(self) -> bool: ...
    def onActionModeFinished(self, mode: android.view.ActionMode, /) -> None: ...
    def onActionModeStarted(self, mode: android.view.ActionMode, /) -> None: ...
    def onAttachedToWindow(self) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onContentChanged(self) -> None: ...
    def onCreate(self) -> None: ...
    def onCreatePanelMenu(self, featureId: int | java.jint | java.lang.Integer, menu: android.view.Menu, /) -> bool: ...
    def onCreatePanelView(self, featureId: int | java.jint | java.lang.Integer, /) -> android.view.View: ...
    def onDestroy(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onDreamingStarted(self) -> None: ...
    def onDreamingStopped(self) -> None: ...
    def onMenuItemSelected(self, featureId: int | java.jint | java.lang.Integer, item: android.view.MenuItem, /) -> bool: ...
    def onMenuOpened(self, featureId: int | java.jint | java.lang.Integer, menu: android.view.Menu, /) -> bool: ...
    def onPanelClosed(self, featureId: int | java.jint | java.lang.Integer, menu: android.view.Menu, /) -> None: ...
    def onPreparePanel(self, featureId: int | java.jint | java.lang.Integer, view: android.view.View, menu: android.view.Menu, /) -> bool: ...
    @typing.overload
    def onSearchRequested(self) -> bool: ...
    @typing.overload
    def onSearchRequested(self, event: android.view.SearchEvent, /) -> bool: ...
    def onUnbind(self, intent: android.content.Intent, /) -> bool: ...
    def onWakeUp(self) -> None: ...
    def onWindowAttributesChanged(self, attrs: android.view.WindowManager.LayoutParams, /) -> None: ...
    def onWindowFocusChanged(self, hasFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def onWindowStartingActionMode(self, callback: android.view.ActionMode.Callback, /) -> android.view.ActionMode: ...
    @typing.overload
    def onWindowStartingActionMode(self, callback: android.view.ActionMode.Callback, type: int | java.jint | java.lang.Integer, /) -> android.view.ActionMode: ...
    def requireViewById(self, id: int | java.jint | java.lang.Integer, /) -> android.view.View: ...
    @typing.overload
    def setContentView(self, layoutResID: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setContentView(self, view: android.view.View, /) -> None: ...
    @typing.overload
    def setContentView(self, view: android.view.View, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def setFullscreen(self, fullscreen: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setInteractive(self, interactive: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setScreenBright(self, screenBright: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def wakeUp(self) -> None: ...
