import typing

import android.content
import android.graphics
import android.net
import android.os
import android.view
import android.view.autofill
import java
import java.chaquopy
import java.lang

class AssistContent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AssistContent]] = ...
    EXTRA_APP_FUNCTION_DATA: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def describeContents(self) -> int: ...
    def getClipData(self) -> android.content.ClipData: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getIntent(self) -> android.content.Intent: ...
    def getSessionTransferUri(self) -> android.net.Uri: ...
    def getStructuredData(self) -> str: ...
    def getWebUri(self) -> android.net.Uri: ...
    def isAppProvidedIntent(self) -> bool: ...
    def isAppProvidedWebUri(self) -> bool: ...
    def setClipData(self, clip: android.content.ClipData, /) -> None: ...
    def setIntent(self, intent: android.content.Intent, /) -> None: ...
    def setSessionTransferUri(self, uri: android.net.Uri, /) -> None: ...
    def setStructuredData(self, structuredData: str | java.lang.String, /) -> None: ...
    def setWebUri(self, uri: android.net.Uri, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AssistStructure(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AssistStructure]] = ...
    def __init__(self) -> None: ...
    def describeContents(self) -> int: ...
    def getAcquisitionEndTime(self) -> int: ...
    def getAcquisitionStartTime(self) -> int: ...
    def getActivityComponent(self) -> android.content.ComponentName: ...
    def getWindowNodeAt(self, index: int | java.jint | java.lang.Integer, /) -> AssistStructure.WindowNode: ...
    def getWindowNodeCount(self) -> int: ...
    def isHomeActivity(self) -> bool: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class WindowNode(java.lang.Object):
        def getDisplayId(self) -> int: ...
        def getHeight(self) -> int: ...
        def getLeft(self) -> int: ...
        def getRootViewNode(self) -> AssistStructure.ViewNode: ...
        def getTitle(self) -> java.lang.CharSequence: ...
        def getTop(self) -> int: ...
        def getWidth(self) -> int: ...

    class ViewNode(java.lang.Object):
        TEXT_COLOR_UNDEFINED: typing.ClassVar[int] = ...
        TEXT_STYLE_BOLD: typing.ClassVar[int] = ...
        TEXT_STYLE_ITALIC: typing.ClassVar[int] = ...
        TEXT_STYLE_STRIKE_THRU: typing.ClassVar[int] = ...
        TEXT_STYLE_UNDERLINE: typing.ClassVar[int] = ...
        def getAlpha(self) -> float: ...
        def getAutofillHints(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
        def getAutofillId(self) -> android.view.autofill.AutofillId: ...
        def getAutofillOptions(self) -> java.chaquopy.JavaArray[java.lang.CharSequence]: ...
        def getAutofillType(self) -> int: ...
        def getAutofillValue(self) -> android.view.autofill.AutofillValue: ...
        def getChildAt(self, index: int | java.jint | java.lang.Integer, /) -> AssistStructure.ViewNode: ...
        def getChildCount(self) -> int: ...
        def getClassName(self) -> str: ...
        def getContentDescription(self) -> java.lang.CharSequence: ...
        def getElevation(self) -> float: ...
        def getExtras(self) -> android.os.Bundle: ...
        def getHeight(self) -> int: ...
        def getHint(self) -> str: ...
        def getHintIdEntry(self) -> str: ...
        def getHtmlInfo(self) -> android.view.ViewStructure.HtmlInfo: ...
        def getId(self) -> int: ...
        def getIdEntry(self) -> str: ...
        def getIdPackage(self) -> str: ...
        def getIdType(self) -> str: ...
        def getImportantForAutofill(self) -> int: ...
        def getInputType(self) -> int: ...
        def getLeft(self) -> int: ...
        def getLocaleList(self) -> android.os.LocaleList: ...
        def getMaxTextEms(self) -> int: ...
        def getMaxTextLength(self) -> int: ...
        def getMinTextEms(self) -> int: ...
        def getReceiveContentMimeTypes(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
        def getScrollX(self) -> int: ...
        def getScrollY(self) -> int: ...
        def getText(self) -> java.lang.CharSequence: ...
        def getTextBackgroundColor(self) -> int: ...
        def getTextColor(self) -> int: ...
        def getTextIdEntry(self) -> str: ...
        def getTextLineBaselines(self) -> java.chaquopy.JavaArrayJInt: ...
        def getTextLineCharOffsets(self) -> java.chaquopy.JavaArrayJInt: ...
        def getTextSelectionEnd(self) -> int: ...
        def getTextSelectionStart(self) -> int: ...
        def getTextSize(self) -> float: ...
        def getTextStyle(self) -> int: ...
        def getTop(self) -> int: ...
        def getTransformation(self) -> android.graphics.Matrix: ...
        def getVisibility(self) -> int: ...
        def getWebDomain(self) -> str: ...
        def getWebScheme(self) -> str: ...
        def getWidth(self) -> int: ...
        def isAccessibilityFocused(self) -> bool: ...
        def isActivated(self) -> bool: ...
        def isAssistBlocked(self) -> bool: ...
        def isCheckable(self) -> bool: ...
        def isChecked(self) -> bool: ...
        def isClickable(self) -> bool: ...
        def isContextClickable(self) -> bool: ...
        def isEnabled(self) -> bool: ...
        def isFocusable(self) -> bool: ...
        def isFocused(self) -> bool: ...
        def isLongClickable(self) -> bool: ...
        def isOpaque(self) -> bool: ...
        def isSelected(self) -> bool: ...
