import typing

import java.io
import java.lang
import java.util

class NamespaceContext(java.lang.Object):
    def getNamespaceURI(self, arg1: str | java.lang.String, /) -> str: ...
    def getPrefix(self, arg1: str | java.lang.String, /) -> str: ...
    def getPrefixes(self, arg1: str | java.lang.String, /) -> java.util.Iterator: ...

class QName(java.io.Serializable):
    @typing.overload
    def __init__(self, localPart: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, namespaceURI: str | java.lang.String, localPart: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, namespaceURI: str | java.lang.String, localPart: str | java.lang.String, prefix: str | java.lang.String, /) -> None: ...
    def equals(self, objectToTest: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getLocalPart(self) -> str: ...
    def getNamespaceURI(self) -> str: ...
    def getPrefix(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    @staticmethod
    def valueOf(qNameAsString: str | java.lang.String, /) -> QName: ...
