import android.content
import android.os
import java.lang

class RestrictionsReceiver(android.content.BroadcastReceiver):
    def __init__(self) -> None: ...
    def onReceive(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...
    def onRequestPermission(self, arg1: android.content.Context, arg2: str | java.lang.String, arg3: str | java.lang.String, arg4: str | java.lang.String, arg5: android.os.PersistableBundle, /) -> None: ...
