import typing

import java.lang

class ImsRegistrationImplBase(java.lang.Object):
    REGISTRATION_TECH_3G: typing.ClassVar[int] = ...
    REGISTRATION_TECH_CROSS_SIM: typing.ClassVar[int] = ...
    REGISTRATION_TECH_IWLAN: typing.ClassVar[int] = ...
    REGISTRATION_TECH_LTE: typing.ClassVar[int] = ...
    REGISTRATION_TECH_NONE: typing.ClassVar[int] = ...
    REGISTRATION_TECH_NR: typing.ClassVar[int] = ...
