import typing

import android.os
import java
import java.lang
import java.util

class DomainVerificationManager(java.lang.Object):
    def getDomainVerificationUserState(self, packageName: str | java.lang.String, /) -> DomainVerificationUserState | None: ...

class DomainVerificationUserState(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DomainVerificationUserState]] = ...
    DOMAIN_STATE_NONE: typing.ClassVar[int] = ...
    DOMAIN_STATE_SELECTED: typing.ClassVar[int] = ...
    DOMAIN_STATE_VERIFIED: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getHostToStateMap(self) -> java.util.Map[java.lang.String, java.lang.Integer]: ...
    def getPackageName(self) -> str: ...
    def getUser(self) -> android.os.UserHandle: ...
    def hashCode(self) -> int: ...
    def isLinkHandlingAllowed(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...
