import typing

import android.os
import java.lang
import java.util
import java.util.concurrent

class DeviceId(java.lang.Object):
    DEVICE_ID_TYPE_IMEI: typing.ClassVar[int] = ...
    DEVICE_ID_TYPE_MEID: typing.ClassVar[int] = ...
    def getId(self) -> str: ...
    def getType(self) -> int: ...

class DeviceLockManager(java.lang.Object):
    DEVICE_LOCK_ROLE_FINANCING: typing.ClassVar[int] = ...
    def getDeviceId(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[DeviceId, java.lang.Exception], /) -> None: ...
    def getKioskApps(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.util.Map[java.lang.Integer, java.lang.String], java.lang.Exception], /) -> None: ...
    def isDeviceLocked(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Boolean, java.lang.Exception], /) -> None: ...
    def lockDevice(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Void, java.lang.Exception], /) -> None: ...
    def unlockDevice(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Void, java.lang.Exception], /) -> None: ...
