import typing

import java
import java.lang

class AconfigPackage(java.lang.Object):
    def getBooleanFlagValue(self, flagName: str | java.lang.String, defaultValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @staticmethod
    def load(packageName: str | java.lang.String, /) -> AconfigPackage: ...

class AconfigStorageReadException(java.lang.RuntimeException):
    ERROR_CANNOT_READ_STORAGE_FILE: typing.ClassVar[int] = ...
    ERROR_CONTAINER_NOT_FOUND: typing.ClassVar[int] = ...
    ERROR_GENERIC: typing.ClassVar[int] = ...
    ERROR_PACKAGE_NOT_FOUND: typing.ClassVar[int] = ...
    ERROR_STORAGE_SYSTEM_NOT_FOUND: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, errorCode: int | java.jint | java.lang.Integer, msg: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, errorCode: int | java.jint | java.lang.Integer, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, errorCode: int | java.jint | java.lang.Integer, msg: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    def getErrorCode(self) -> int: ...
    def getMessage(self) -> str: ...
