import typing

import android.os
import android.telephony
import java
import java.lang

class CdmaCellLocation(android.telephony.CellLocation):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, bundle: android.os.Bundle, /) -> None: ...
    @staticmethod
    def convertQuartSecToDecDegrees(quartSec: int | java.jint | java.lang.Integer, /) -> float: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def fillInNotifierBundle(self, bundleToFill: android.os.Bundle, /) -> None: ...
    def getBaseStationId(self) -> int: ...
    def getBaseStationLatitude(self) -> int: ...
    def getBaseStationLongitude(self) -> int: ...
    def getNetworkId(self) -> int: ...
    def getSystemId(self) -> int: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def setCellLocationData(self, baseStationId: int | java.jint | java.lang.Integer, baseStationLatitude: int | java.jint | java.lang.Integer, baseStationLongitude: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setCellLocationData(self, baseStationId: int | java.jint | java.lang.Integer, baseStationLatitude: int | java.jint | java.lang.Integer, baseStationLongitude: int | java.jint | java.lang.Integer, systemId: int | java.jint | java.lang.Integer, networkId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setStateInvalid(self) -> None: ...
    def toString(self) -> str: ...
