import typing

import android.os
import java
import java.lang

class BleRssiRangingParams(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BleRssiRangingParams]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPeerBluetoothAddress(self) -> str: ...
    def getRangingUpdateRate(self) -> int: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, peerBluetoothAddress: str | java.lang.String, /) -> None: ...
        def build(self) -> BleRssiRangingParams: ...
        def setRangingUpdateRate(self, updateRate: int | java.jint | java.lang.Integer, /) -> BleRssiRangingParams.Builder: ...
