import android.content
import java.chaquopy
import java.lang

class CleartextNetworkViolation(Violation): ...

class ContentUriWithoutPermissionViolation(Violation): ...

class CredentialProtectedWhileLockedViolation(Violation): ...

class CustomViolation(Violation): ...

class DiskReadViolation(Violation): ...

class DiskWriteViolation(Violation): ...

class ExplicitGcViolation(Violation): ...

class FileUriExposedViolation(Violation): ...

class ImplicitDirectBootViolation(Violation): ...

class IncorrectContextUseViolation(Violation):
    def __init__(self, message: str | java.lang.String, originStack: java.lang.Throwable, /) -> None: ...

class InstanceCountViolation(Violation):
    def getNumberOfInstances(self) -> int: ...

class IntentReceiverLeakedViolation(Violation): ...

class LeakedClosableViolation(Violation): ...

class NetworkViolation(Violation): ...

class NonSdkApiUsedViolation(Violation): ...

class ResourceMismatchViolation(Violation): ...

class ServiceConnectionLeakedViolation(Violation): ...

class SqliteObjectLeakedViolation(Violation): ...

class UnbufferedIoViolation(Violation): ...

class UnsafeIntentLaunchViolation(Violation):
    def __init__(self, intent: android.content.Intent, /) -> None: ...
    def getIntent(self) -> android.content.Intent | None: ...

class UntaggedSocketViolation(Violation): ...

class Violation(java.lang.Throwable):
    def fillInStackTrace(self) -> java.lang.Throwable: ...
    def hashCode(self) -> int: ...
    def initCause(self, cause: java.lang.Throwable, /) -> java.lang.Throwable: ...
    def setStackTrace(self, stackTrace: java.chaquopy.JavaArray[java.lang.StackTraceElement], /) -> None: ...

class WebViewMethodCalledOnWrongThreadViolation(Violation): ...
