import java
import java.chaquopy
import java.lang
import java.security
import java.security.spec

class HpkeSpi(java.lang.Object):
    def engineExport(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def engineInitRecipient(self, arg1: java.chaquopy.JavaArrayJByte, arg2: java.security.PrivateKey, arg3: java.chaquopy.JavaArrayJByte, arg4: java.security.PublicKey, arg5: java.chaquopy.JavaArrayJByte, arg6: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def engineInitSender(self, arg1: java.security.PublicKey, arg2: java.chaquopy.JavaArrayJByte, arg3: java.security.PrivateKey, arg4: java.chaquopy.JavaArrayJByte, arg5: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def engineInitSenderWithSeed(self, arg1: java.security.PublicKey, arg2: java.chaquopy.JavaArrayJByte, arg3: java.security.PrivateKey, arg4: java.chaquopy.JavaArrayJByte, arg5: java.chaquopy.JavaArrayJByte, arg6: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def engineOpen(self, arg1: java.chaquopy.JavaArrayJByte, arg2: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def engineSeal(self, arg1: java.chaquopy.JavaArrayJByte, arg2: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def getEncapsulated(self) -> java.chaquopy.JavaArrayJByte: ...

class XdhKeySpec(java.security.spec.EncodedKeySpec):
    def __init__(self, encoded: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getFormat(self) -> str: ...
    def getKey(self) -> java.chaquopy.JavaArrayJByte: ...
    def hashCode(self) -> int: ...
