import typing

import android.os
import java
import java.lang
import java.util

class EmergencyNumber(android.os.Parcelable, java.lang.Comparable[EmergencyNumber]):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[EmergencyNumber]] = ...
    EMERGENCY_CALL_ROUTING_EMERGENCY: typing.ClassVar[int] = ...
    EMERGENCY_CALL_ROUTING_NORMAL: typing.ClassVar[int] = ...
    EMERGENCY_CALL_ROUTING_UNKNOWN: typing.ClassVar[int] = ...
    EMERGENCY_NUMBER_SOURCE_DATABASE: typing.ClassVar[int] = ...
    EMERGENCY_NUMBER_SOURCE_DEFAULT: typing.ClassVar[int] = ...
    EMERGENCY_NUMBER_SOURCE_MODEM_CONFIG: typing.ClassVar[int] = ...
    EMERGENCY_NUMBER_SOURCE_NETWORK_SIGNALING: typing.ClassVar[int] = ...
    EMERGENCY_NUMBER_SOURCE_SIM: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_AIEC: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_AMBULANCE: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_FIRE_BRIGADE: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_MARINE_GUARD: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_MIEC: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_MOUNTAIN_RESCUE: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_POLICE: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_UNSPECIFIED: typing.ClassVar[int] = ...
    def compareTo(self, emergencyNumber: EmergencyNumber, /) -> int: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCountryIso(self) -> str: ...
    def getEmergencyCallRouting(self) -> int: ...
    def getEmergencyNumberSources(self) -> java.util.List[java.lang.Integer]: ...
    def getEmergencyServiceCategories(self) -> java.util.List[java.lang.Integer]: ...
    def getEmergencyUrns(self) -> java.util.List[java.lang.String]: ...
    def getMnc(self) -> str: ...
    def getNumber(self) -> str: ...
    def hashCode(self) -> int: ...
    def isFromSources(self, sources: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isInEmergencyServiceCategories(self, categories: int | java.jint | java.lang.Integer, /) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...
