import typing

import java.chaquopy
import java.lang
import java.math
import java.security
import javax.crypto
import javax.crypto.spec

class DHKey(java.lang.Object):
    def getParams(self) -> javax.crypto.spec.DHParameterSpec: ...

class DHPrivateKey(DHKey, java.security.PrivateKey):
    serialVersionUID: typing.ClassVar[int] = ...
    def getX(self) -> java.math.BigInteger: ...

class DHPublicKey(DHKey, java.security.PublicKey):
    serialVersionUID: typing.ClassVar[int] = ...
    def getY(self) -> java.math.BigInteger: ...

class PBEKey(javax.crypto.SecretKey):
    serialVersionUID: typing.ClassVar[int] = ...
    def getIterationCount(self) -> int: ...
    def getPassword(self) -> java.chaquopy.JavaArrayJChar: ...
    def getSalt(self) -> java.chaquopy.JavaArrayJByte: ...
