import typing

import android.app
import android.content
import android.net
import android.os
import android.view
import java
import java.chaquopy
import java.lang
import java.time
import java.util
import java.util.concurrent

class AppInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AppInfo]] = ...
    def __init__(self, installed: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def isInstalled(self) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class DownloadCompletedInput(java.lang.Object):
    def __init__(self, downloadedContents: KeyValueStore, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDownloadedContents(self) -> KeyValueStore: ...
    def hashCode(self) -> int: ...

class DownloadCompletedOutput(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getRetainedKeys(self) -> java.util.List[java.lang.String]: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addRetainedKey(self, value: str | java.lang.String, /) -> DownloadCompletedOutput.Builder: ...
        def build(self) -> DownloadCompletedOutput: ...
        def setRetainedKeys(self, value: java.util.List[java.lang.String], /) -> DownloadCompletedOutput.Builder: ...

class EventInput(java.lang.Object):
    def __init__(self, requestLogRecord: RequestLogRecord, parameters: android.os.PersistableBundle, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getParameters(self) -> android.os.PersistableBundle: ...
    def getRequestLogRecord(self) -> RequestLogRecord | None: ...
    def hashCode(self) -> int: ...

class EventLogRecord(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[EventLogRecord]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getData(self) -> android.content.ContentValues | None: ...
    def getRequestLogRecord(self) -> RequestLogRecord | None: ...
    def getRowIndex(self) -> int: ...
    def getTime(self) -> java.time.Instant: ...
    def getType(self) -> int: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> EventLogRecord: ...
        def setData(self, value: android.content.ContentValues, /) -> EventLogRecord.Builder: ...
        def setRequestLogRecord(self, value: RequestLogRecord, /) -> EventLogRecord.Builder: ...
        def setRowIndex(self, value: int | java.jint | java.lang.Integer, /) -> EventLogRecord.Builder: ...
        def setType(self, value: int | java.jint | java.lang.Integer, /) -> EventLogRecord.Builder: ...

class EventOutput(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getEventLogRecord(self) -> EventLogRecord | None: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> EventOutput: ...
        def setEventLogRecord(self, value: EventLogRecord, /) -> EventOutput.Builder: ...

class EventUrlProvider(java.lang.Object):
    def createEventTrackingUrlWithRedirect(self, eventParams: android.os.PersistableBundle, destinationUrl: android.net.Uri, /) -> android.net.Uri: ...
    def createEventTrackingUrlWithResponse(self, eventParams: android.os.PersistableBundle, responseData: java.chaquopy.JavaArrayJByte, mimeType: str | java.lang.String, /) -> android.net.Uri: ...

class ExecuteInIsolatedServiceRequest(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAppParams(self) -> android.os.PersistableBundle: ...
    def getOutputSpec(self) -> ExecuteInIsolatedServiceRequest.OutputSpec: ...
    def getService(self) -> android.content.ComponentName: ...
    def hashCode(self) -> int: ...

    class OutputSpec(java.lang.Object):
        DEFAULT: typing.ClassVar[ExecuteInIsolatedServiceRequest.OutputSpec] = ...
        OUTPUT_TYPE_BEST_VALUE: typing.ClassVar[int] = ...
        OUTPUT_TYPE_NULL: typing.ClassVar[int] = ...
        @staticmethod
        def buildBestValueSpec(maxIntValue: int | java.jint | java.lang.Integer, /) -> ExecuteInIsolatedServiceRequest.OutputSpec: ...
        def getMaxIntValue(self) -> int: ...
        def getOutputType(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self, service: android.content.ComponentName, /) -> None: ...
        def build(self) -> ExecuteInIsolatedServiceRequest: ...
        def setAppParams(self, value: android.os.PersistableBundle, /) -> ExecuteInIsolatedServiceRequest.Builder: ...
        def setOutputSpec(self, value: ExecuteInIsolatedServiceRequest.OutputSpec, /) -> ExecuteInIsolatedServiceRequest.Builder: ...

class ExecuteInIsolatedServiceResponse(java.lang.Object):
    DEFAULT_BEST_VALUE: typing.ClassVar[int] = ...
    def __init__(self, surfacePackageToken: SurfacePackageToken, bestValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def getBestValue(self) -> int: ...
    def getSurfacePackageToken(self) -> SurfacePackageToken: ...

class ExecuteInput(java.lang.Object):
    def __init__(self, appPackageName: str | java.lang.String, appParams: android.os.PersistableBundle, /) -> None: ...
    def getAppPackageName(self) -> str: ...
    def getAppParams(self) -> android.os.PersistableBundle: ...

class ExecuteOutput(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBestValue(self) -> int: ...
    def getEventLogRecords(self) -> java.util.List[EventLogRecord]: ...
    def getOutputData(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getRenderingConfig(self) -> RenderingConfig | None: ...
    def getRequestLogRecord(self) -> RequestLogRecord | None: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addEventLogRecord(self, value: EventLogRecord, /) -> ExecuteOutput.Builder: ...
        def build(self) -> ExecuteOutput: ...
        def setBestValue(self, value: int | java.jint | java.lang.Integer, /) -> ExecuteOutput.Builder: ...
        def setEventLogRecords(self, value: java.util.List[EventLogRecord], /) -> ExecuteOutput.Builder: ...
        def setOutputData(self, *value: java.jbyte) -> ExecuteOutput.Builder: ...
        def setRenderingConfig(self, value: RenderingConfig, /) -> ExecuteOutput.Builder: ...
        def setRequestLogRecord(self, value: RequestLogRecord, /) -> ExecuteOutput.Builder: ...

class FederatedComputeInput(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPopulationName(self) -> str: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> FederatedComputeInput: ...
        def setPopulationName(self, value: str | java.lang.String, /) -> FederatedComputeInput.Builder: ...

class FederatedComputeScheduler(java.lang.Object):
    def cancel(self, input: FederatedComputeInput, /) -> None: ...
    def schedule(self, params: FederatedComputeScheduler.Params, input: FederatedComputeInput, /) -> None: ...

    class Params(java.lang.Object):
        def __init__(self, trainingInterval: TrainingInterval, /) -> None: ...
        def getTrainingInterval(self) -> TrainingInterval: ...

class InferenceInput(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBatchSize(self) -> int: ...
    def getExpectedOutputStructure(self) -> InferenceOutput: ...
    def getInputData(self) -> java.chaquopy.JavaArray[java.lang.Object]: ...
    def getParams(self) -> InferenceInput.Params: ...
    def hashCode(self) -> int: ...

    class Params(java.lang.Object):
        DELEGATE_CPU: typing.ClassVar[int] = ...
        MODEL_TYPE_TENSORFLOW_LITE: typing.ClassVar[int] = ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getDelegateType(self) -> int: ...
        def getKeyValueStore(self) -> KeyValueStore: ...
        def getModelKey(self) -> str: ...
        def getModelType(self) -> int: ...
        def getRecommendedNumThreads(self) -> int: ...
        def hashCode(self) -> int: ...

        class Builder(java.lang.Object):
            def __init__(self, keyValueStore: KeyValueStore, modelKey: str | java.lang.String, /) -> None: ...
            def build(self) -> InferenceInput.Params: ...
            def setDelegateType(self, value: int | java.jint | java.lang.Integer, /) -> InferenceInput.Params.Builder: ...
            def setKeyValueStore(self, value: KeyValueStore, /) -> InferenceInput.Params.Builder: ...
            def setModelKey(self, value: str | java.lang.String, /) -> InferenceInput.Params.Builder: ...
            def setModelType(self, value: int | java.jint | java.lang.Integer, /) -> InferenceInput.Params.Builder: ...
            def setRecommendedNumThreads(self, value: int | java.jint | java.lang.Integer, /) -> InferenceInput.Params.Builder: ...

    class Builder(java.lang.Object):
        def __init__(self, params: InferenceInput.Params, inputData: java.chaquopy.JavaArray[java.lang.Object], expectedOutputStructure: InferenceOutput, /) -> None: ...
        def build(self) -> InferenceInput: ...
        def setBatchSize(self, value: int | java.jint | java.lang.Integer, /) -> InferenceInput.Builder: ...
        def setExpectedOutputStructure(self, value: InferenceOutput, /) -> InferenceInput.Builder: ...
        def setInputData(self, *value: java.lang.Object) -> InferenceInput.Builder: ...
        def setParams(self, value: InferenceInput.Params, /) -> InferenceInput.Builder: ...

class InferenceOutput(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDataOutputs(self) -> java.util.Map[java.lang.Integer, java.lang.Object]: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addDataOutput(self, key: int | java.jint | java.lang.Integer, value: java.lang.Object | int | bool | float | str, /) -> InferenceOutput.Builder: ...
        def build(self) -> InferenceOutput: ...
        def setDataOutputs(self, value: java.util.Map[java.lang.Integer, java.lang.Object], /) -> InferenceOutput.Builder: ...

class IsolatedService(android.app.Service):
    def __init__(self) -> None: ...
    def getEventUrlProvider(self, requestToken: RequestToken, /) -> EventUrlProvider: ...
    def getFederatedComputeScheduler(self, requestToken: RequestToken, /) -> FederatedComputeScheduler: ...
    def getLocalData(self, requestToken: RequestToken, /) -> MutableKeyValueStore: ...
    def getLogReader(self, requestToken: RequestToken, /) -> LogReader: ...
    def getModelManager(self, requestToken: RequestToken, /) -> ModelManager: ...
    def getRemoteData(self, requestToken: RequestToken, /) -> KeyValueStore: ...
    def getUserData(self, requestToken: RequestToken, /) -> UserData | None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder | None: ...
    def onCreate(self) -> None: ...
    def onRequest(self, arg1: RequestToken, /) -> IsolatedWorker: ...

class IsolatedServiceException(java.lang.Exception):
    @typing.overload
    def __init__(self, errorCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, errorCode: int | java.jint | java.lang.Integer, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, errorCode: int | java.jint | java.lang.Integer, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    def getErrorCode(self) -> int: ...

class IsolatedWorker(java.lang.Object):
    def onDownloadCompleted(self, input: DownloadCompletedInput, receiver: android.os.OutcomeReceiver[DownloadCompletedOutput, IsolatedServiceException], /) -> None: ...
    def onEvent(self, input: EventInput, receiver: android.os.OutcomeReceiver[EventOutput, IsolatedServiceException], /) -> None: ...
    def onExecute(self, input: ExecuteInput, receiver: android.os.OutcomeReceiver[ExecuteOutput, IsolatedServiceException], /) -> None: ...
    def onRender(self, input: RenderInput, receiver: android.os.OutcomeReceiver[RenderOutput, IsolatedServiceException], /) -> None: ...
    def onTrainingExamples(self, input: TrainingExamplesInput, receiver: android.os.OutcomeReceiver[TrainingExamplesOutput, IsolatedServiceException], /) -> None: ...
    def onWebTrigger(self, input: WebTriggerInput, receiver: android.os.OutcomeReceiver[WebTriggerOutput, IsolatedServiceException], /) -> None: ...

class KeyValueStore(java.lang.Object):
    def get(self, arg1: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte: ...
    def keySet(self) -> java.util.Set[java.lang.String]: ...

class LogReader(java.lang.Object):
    def getJoinedEvents(self, startTime: java.time.Instant, endTime: java.time.Instant, /) -> java.util.List[EventLogRecord]: ...
    def getRequests(self, startTime: java.time.Instant, endTime: java.time.Instant, /) -> java.util.List[RequestLogRecord]: ...

class ModelManager(java.lang.Object):
    def run(self, input: InferenceInput, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[InferenceOutput, java.lang.Exception], /) -> None: ...

class MutableKeyValueStore(KeyValueStore):
    def put(self, arg1: str | java.lang.String, arg2: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def remove(self, arg1: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte: ...

class OnDevicePersonalizationException(java.lang.Exception):
    ERROR_INFERENCE_FAILED: typing.ClassVar[int] = ...
    ERROR_INFERENCE_MODEL_NOT_FOUND: typing.ClassVar[int] = ...
    ERROR_INVALID_TRAINING_MANIFEST: typing.ClassVar[int] = ...
    ERROR_ISOLATED_SERVICE_FAILED: typing.ClassVar[int] = ...
    ERROR_ISOLATED_SERVICE_LOADING_FAILED: typing.ClassVar[int] = ...
    ERROR_ISOLATED_SERVICE_MANIFEST_PARSING_FAILED: typing.ClassVar[int] = ...
    ERROR_ISOLATED_SERVICE_TIMEOUT: typing.ClassVar[int] = ...
    ERROR_PERSONALIZATION_DISABLED: typing.ClassVar[int] = ...
    ERROR_SCHEDULE_TRAINING_FAILED: typing.ClassVar[int] = ...
    def getErrorCode(self) -> int: ...

class OnDevicePersonalizationManager(java.lang.Object):
    def execute(self, service: android.content.ComponentName, params: android.os.PersistableBundle, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[OnDevicePersonalizationManager.ExecuteResult, java.lang.Exception], /) -> None: ...
    def executeInIsolatedService(self, request: ExecuteInIsolatedServiceRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[ExecuteInIsolatedServiceResponse, java.lang.Exception], /) -> None: ...
    def requestSurfacePackage(self, surfacePackageToken: SurfacePackageToken, surfaceViewHostToken: android.os.IBinder, displayId: int | java.jint | java.lang.Integer, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[android.view.SurfaceControlViewHost.SurfacePackage, java.lang.Exception], /) -> None: ...

    class ExecuteResult(java.lang.Object):
        def getOutputData(self) -> java.chaquopy.JavaArrayJByte: ...
        def getSurfacePackageToken(self) -> SurfacePackageToken: ...

class RenderInput(java.lang.Object):
    def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, renderingConfig: RenderingConfig, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getHeight(self) -> int: ...
    def getRenderingConfig(self) -> RenderingConfig | None: ...
    def getWidth(self) -> int: ...
    def hashCode(self) -> int: ...

class RenderOutput(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getContent(self) -> str | None: ...
    def getTemplateId(self) -> str | None: ...
    def getTemplateParams(self) -> android.os.PersistableBundle: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> RenderOutput: ...
        def setContent(self, value: str | java.lang.String, /) -> RenderOutput.Builder: ...
        def setTemplateId(self, value: str | java.lang.String, /) -> RenderOutput.Builder: ...
        def setTemplateParams(self, value: android.os.PersistableBundle, /) -> RenderOutput.Builder: ...

class RenderingConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RenderingConfig]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getKeys(self) -> java.util.List[java.lang.String]: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addKey(self, value: str | java.lang.String, /) -> RenderingConfig.Builder: ...
        def build(self) -> RenderingConfig: ...
        def setKeys(self, value: java.util.List[java.lang.String], /) -> RenderingConfig.Builder: ...

class RequestLogRecord(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RequestLogRecord]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getRows(self) -> java.util.List[android.content.ContentValues]: ...
    def getTime(self) -> java.time.Instant: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addRow(self, value: android.content.ContentValues, /) -> RequestLogRecord.Builder: ...
        def build(self) -> RequestLogRecord: ...
        def setRows(self, value: java.util.List[android.content.ContentValues], /) -> RequestLogRecord.Builder: ...

class RequestToken(java.lang.Object): ...

class SurfacePackageToken(java.lang.Object): ...

class TrainingExampleRecord(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TrainingExampleRecord]] = ...
    def describeContents(self) -> int: ...
    def getResumptionToken(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getTrainingExample(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> TrainingExampleRecord: ...
        def setResumptionToken(self, *value: java.jbyte) -> TrainingExampleRecord.Builder: ...
        def setTrainingExample(self, *value: java.jbyte) -> TrainingExampleRecord.Builder: ...

class TrainingExamplesInput(java.lang.Object):
    def __init__(self, populationName: str | java.lang.String, taskName: str | java.lang.String, resumptionToken: java.chaquopy.JavaArrayJByte, collectionName: str | java.lang.String, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCollectionName(self) -> str: ...
    def getPopulationName(self) -> str: ...
    def getResumptionToken(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getTaskName(self) -> str: ...
    def hashCode(self) -> int: ...

class TrainingExamplesOutput(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getTrainingExampleRecords(self) -> java.util.List[TrainingExampleRecord]: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addTrainingExampleRecord(self, value: TrainingExampleRecord, /) -> TrainingExamplesOutput.Builder: ...
        def build(self) -> TrainingExamplesOutput: ...
        def setTrainingExampleRecords(self, value: java.util.List[TrainingExampleRecord], /) -> TrainingExamplesOutput.Builder: ...

class TrainingInterval(java.lang.Object):
    SCHEDULING_MODE_ONE_TIME: typing.ClassVar[int] = ...
    SCHEDULING_MODE_RECURRENT: typing.ClassVar[int] = ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMinimumInterval(self) -> java.time.Duration: ...
    def getSchedulingMode(self) -> int: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> TrainingInterval: ...
        def setMinimumInterval(self, value: java.time.Duration, /) -> TrainingInterval.Builder: ...
        def setSchedulingMode(self, value: int | java.jint | java.lang.Integer, /) -> TrainingInterval.Builder: ...

class UserData(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UserData]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAppInfos(self) -> java.util.Map[java.lang.String, AppInfo]: ...
    def getAvailableStorageBytes(self) -> int: ...
    def getBatteryPercentage(self) -> int: ...
    def getCarrier(self) -> str: ...
    def getDataNetworkType(self) -> int: ...
    def getNetworkCapabilities(self) -> android.net.NetworkCapabilities | None: ...
    def getOrientation(self) -> int: ...
    def getTimezoneUtcOffset(self) -> java.time.Duration: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class WebTriggerInput(java.lang.Object):
    def __init__(self, destinationUrl: android.net.Uri, appPackageName: str | java.lang.String, data: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAppPackageName(self) -> str: ...
    def getData(self) -> java.chaquopy.JavaArrayJByte: ...
    def getDestinationUrl(self) -> android.net.Uri: ...
    def hashCode(self) -> int: ...

class WebTriggerOutput(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getEventLogRecords(self) -> java.util.List[EventLogRecord]: ...
    def getRequestLogRecord(self) -> RequestLogRecord | None: ...
    def hashCode(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addEventLogRecord(self, value: EventLogRecord, /) -> WebTriggerOutput.Builder: ...
        def build(self) -> WebTriggerOutput: ...
        def setEventLogRecords(self, value: java.util.List[EventLogRecord], /) -> WebTriggerOutput.Builder: ...
        def setRequestLogRecord(self, value: RequestLogRecord, /) -> WebTriggerOutput.Builder: ...
