import typing

import android.accessibilityservice
import android.content.pm
import android.graphics
import android.os
import android.util
import android.view
import java
import java.lang
import java.time
import java.util
import java.util.concurrent

class AccessibilityEvent(android.os.Parcelable, AccessibilityRecord):
    CONTENT_CHANGE_TYPE_CHECKED: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_CONTENT_DESCRIPTION: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_CONTENT_INVALID: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_DRAG_CANCELLED: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_DRAG_DROPPED: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_DRAG_STARTED: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_ENABLED: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_ERROR: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_EXPANDED: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_PANE_APPEARED: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_PANE_DISAPPEARED: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_PANE_TITLE: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_STATE_DESCRIPTION: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_SUBTREE: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_SUPPLEMENTAL_DESCRIPTION: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_TEXT: typing.ClassVar[int] = ...
    CONTENT_CHANGE_TYPE_UNDEFINED: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AccessibilityEvent]] = ...
    INVALID_POSITION: typing.ClassVar[int] = ...
    MAX_TEXT_LENGTH: typing.ClassVar[int] = ...
    SPEECH_STATE_LISTENING_END: typing.ClassVar[int] = ...
    SPEECH_STATE_LISTENING_START: typing.ClassVar[int] = ...
    SPEECH_STATE_SPEAKING_END: typing.ClassVar[int] = ...
    SPEECH_STATE_SPEAKING_START: typing.ClassVar[int] = ...
    TYPES_ALL_MASK: typing.ClassVar[int] = ...
    TYPE_ANNOUNCEMENT: typing.ClassVar[int] = ...
    TYPE_ASSIST_READING_CONTEXT: typing.ClassVar[int] = ...
    TYPE_GESTURE_DETECTION_END: typing.ClassVar[int] = ...
    TYPE_GESTURE_DETECTION_START: typing.ClassVar[int] = ...
    TYPE_NOTIFICATION_STATE_CHANGED: typing.ClassVar[int] = ...
    TYPE_SPEECH_STATE_CHANGE: typing.ClassVar[int] = ...
    TYPE_TOUCH_EXPLORATION_GESTURE_END: typing.ClassVar[int] = ...
    TYPE_TOUCH_EXPLORATION_GESTURE_START: typing.ClassVar[int] = ...
    TYPE_TOUCH_INTERACTION_END: typing.ClassVar[int] = ...
    TYPE_TOUCH_INTERACTION_START: typing.ClassVar[int] = ...
    TYPE_VIEW_ACCESSIBILITY_FOCUSED: typing.ClassVar[int] = ...
    TYPE_VIEW_ACCESSIBILITY_FOCUS_CLEARED: typing.ClassVar[int] = ...
    TYPE_VIEW_CLICKED: typing.ClassVar[int] = ...
    TYPE_VIEW_CONTEXT_CLICKED: typing.ClassVar[int] = ...
    TYPE_VIEW_FOCUSED: typing.ClassVar[int] = ...
    TYPE_VIEW_HOVER_ENTER: typing.ClassVar[int] = ...
    TYPE_VIEW_HOVER_EXIT: typing.ClassVar[int] = ...
    TYPE_VIEW_LONG_CLICKED: typing.ClassVar[int] = ...
    TYPE_VIEW_SCROLLED: typing.ClassVar[int] = ...
    TYPE_VIEW_SELECTED: typing.ClassVar[int] = ...
    TYPE_VIEW_TARGETED_BY_SCROLL: typing.ClassVar[int] = ...
    TYPE_VIEW_TEXT_CHANGED: typing.ClassVar[int] = ...
    TYPE_VIEW_TEXT_SELECTION_CHANGED: typing.ClassVar[int] = ...
    TYPE_VIEW_TEXT_TRAVERSED_AT_MOVEMENT_GRANULARITY: typing.ClassVar[int] = ...
    TYPE_WINDOWS_CHANGED: typing.ClassVar[int] = ...
    TYPE_WINDOW_CONTENT_CHANGED: typing.ClassVar[int] = ...
    TYPE_WINDOW_STATE_CHANGED: typing.ClassVar[int] = ...
    WINDOWS_CHANGE_ACCESSIBILITY_FOCUSED: typing.ClassVar[int] = ...
    WINDOWS_CHANGE_ACTIVE: typing.ClassVar[int] = ...
    WINDOWS_CHANGE_ADDED: typing.ClassVar[int] = ...
    WINDOWS_CHANGE_BOUNDS: typing.ClassVar[int] = ...
    WINDOWS_CHANGE_CHILDREN: typing.ClassVar[int] = ...
    WINDOWS_CHANGE_FOCUSED: typing.ClassVar[int] = ...
    WINDOWS_CHANGE_LAYER: typing.ClassVar[int] = ...
    WINDOWS_CHANGE_PARENT: typing.ClassVar[int] = ...
    WINDOWS_CHANGE_PIP: typing.ClassVar[int] = ...
    WINDOWS_CHANGE_REMOVED: typing.ClassVar[int] = ...
    WINDOWS_CHANGE_TITLE: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, eventType: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, event: AccessibilityEvent, /) -> None: ...
    def appendRecord(self, record: AccessibilityRecord, /) -> None: ...
    def describeContents(self) -> int: ...
    @staticmethod
    def eventTypeToString(eventType: int | java.jint | java.lang.Integer, /) -> str: ...
    def getAction(self) -> int: ...
    def getContentChangeTypes(self) -> int: ...
    def getEventTime(self) -> int: ...
    def getEventType(self) -> int: ...
    def getMovementGranularity(self) -> int: ...
    def getPackageName(self) -> java.lang.CharSequence: ...
    def getRecord(self, index: int | java.jint | java.lang.Integer, /) -> AccessibilityRecord: ...
    def getRecordCount(self) -> int: ...
    def getSpeechStateChangeTypes(self) -> int: ...
    def getWindowChanges(self) -> int: ...
    def initFromParcel(self, parcel: android.os.Parcel, /) -> None: ...
    def isAccessibilityDataSensitive(self) -> bool: ...
    @typing.overload
    @staticmethod
    def obtain() -> AccessibilityEvent: ...
    @typing.overload
    @staticmethod
    def obtain(eventType: int | java.jint | java.lang.Integer, /) -> AccessibilityEvent: ...
    @typing.overload
    @staticmethod
    def obtain(event: AccessibilityEvent, /) -> AccessibilityEvent: ...
    def recycle(self) -> None: ...
    def setAccessibilityDataSensitive(self, accessibilityDataSensitive: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAction(self, action: int | java.jint | java.lang.Integer, /) -> None: ...
    def setContentChangeTypes(self, changeTypes: int | java.jint | java.lang.Integer, /) -> None: ...
    def setEventTime(self, eventTime: int | java.jlong | java.lang.Long, /) -> None: ...
    def setEventType(self, eventType: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMovementGranularity(self, granularity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPackageName(self, packageName: java.lang.CharSequence, /) -> None: ...
    def setSpeechStateChangeTypes(self, state: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AccessibilityEventSource(java.lang.Object):
    def sendAccessibilityEvent(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def sendAccessibilityEventUnchecked(self, arg1: AccessibilityEvent, /) -> None: ...

class AccessibilityManager(java.lang.Object):
    FLAG_CONTENT_CONTROLS: typing.ClassVar[int] = ...
    FLAG_CONTENT_ICONS: typing.ClassVar[int] = ...
    FLAG_CONTENT_TEXT: typing.ClassVar[int] = ...
    def addAccessibilityRequestPreparer(self, preparer: AccessibilityRequestPreparer, /) -> None: ...
    @typing.overload
    def addAccessibilityServicesStateChangeListener(self, listener: AccessibilityManager.AccessibilityServicesStateChangeListener, /) -> None: ...
    @typing.overload
    def addAccessibilityServicesStateChangeListener(self, executor: java.util.concurrent.Executor, listener: AccessibilityManager.AccessibilityServicesStateChangeListener, /) -> None: ...
    @typing.overload
    def addAccessibilityStateChangeListener(self, listener: AccessibilityManager.AccessibilityStateChangeListener, /) -> bool: ...
    @typing.overload
    def addAccessibilityStateChangeListener(self, listener: AccessibilityManager.AccessibilityStateChangeListener, handler: android.os.Handler, /) -> None: ...
    def addAudioDescriptionRequestedChangeListener(self, executor: java.util.concurrent.Executor, listener: AccessibilityManager.AudioDescriptionRequestedChangeListener, /) -> None: ...
    def addHighContrastTextStateChangeListener(self, executor: java.util.concurrent.Executor, listener: AccessibilityManager.HighContrastTextStateChangeListener, /) -> None: ...
    @typing.overload
    def addTouchExplorationStateChangeListener(self, listener: AccessibilityManager.TouchExplorationStateChangeListener, /) -> bool: ...
    @typing.overload
    def addTouchExplorationStateChangeListener(self, listener: AccessibilityManager.TouchExplorationStateChangeListener, handler: android.os.Handler, /) -> None: ...
    def getAccessibilityFocusColor(self) -> int: ...
    def getAccessibilityFocusStrokeWidth(self) -> int: ...
    def getAccessibilityServiceList(self) -> java.util.List[android.content.pm.ServiceInfo]: ...
    def getEnabledAccessibilityServiceList(self, feedbackTypeFlags: int | java.jint | java.lang.Integer, /) -> java.util.List[android.accessibilityservice.AccessibilityServiceInfo]: ...
    def getInstalledAccessibilityServiceList(self) -> java.util.List[android.accessibilityservice.AccessibilityServiceInfo]: ...
    def getRecommendedTimeoutMillis(self, originalTimeout: int | java.jint | java.lang.Integer, uiContentFlags: int | java.jint | java.lang.Integer, /) -> int: ...
    def interrupt(self) -> None: ...
    @staticmethod
    def isAccessibilityButtonSupported() -> bool: ...
    def isAudioDescriptionRequested(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isHighContrastTextEnabled(self) -> bool: ...
    def isRequestFromAccessibilityTool(self) -> bool: ...
    def isTouchExplorationEnabled(self) -> bool: ...
    def removeAccessibilityRequestPreparer(self, preparer: AccessibilityRequestPreparer, /) -> None: ...
    def removeAccessibilityServicesStateChangeListener(self, listener: AccessibilityManager.AccessibilityServicesStateChangeListener, /) -> bool: ...
    def removeAccessibilityStateChangeListener(self, listener: AccessibilityManager.AccessibilityStateChangeListener, /) -> bool: ...
    def removeAudioDescriptionRequestedChangeListener(self, listener: AccessibilityManager.AudioDescriptionRequestedChangeListener, /) -> bool: ...
    def removeHighContrastTextStateChangeListener(self, listener: AccessibilityManager.HighContrastTextStateChangeListener, /) -> None: ...
    def removeTouchExplorationStateChangeListener(self, listener: AccessibilityManager.TouchExplorationStateChangeListener, /) -> bool: ...
    def sendAccessibilityEvent(self, event: AccessibilityEvent, /) -> None: ...

    class TouchExplorationStateChangeListener(java.lang.Object):
        def onTouchExplorationStateChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class HighContrastTextStateChangeListener(java.lang.Object):
        def onHighContrastTextStateChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class AudioDescriptionRequestedChangeListener(java.lang.Object):
        def onAudioDescriptionRequestedChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class AccessibilityStateChangeListener(java.lang.Object):
        def onAccessibilityStateChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class AccessibilityServicesStateChangeListener(java.lang.Object):
        def onAccessibilityServicesStateChanged(self, arg1: AccessibilityManager, /) -> None: ...

class AccessibilityNodeInfo(android.os.Parcelable):
    ACTION_ACCESSIBILITY_FOCUS: typing.ClassVar[int] = ...
    ACTION_ARGUMENT_COLUMN_INT: typing.ClassVar[str] = ...
    ACTION_ARGUMENT_DIRECTION_INT: typing.ClassVar[str] = ...
    ACTION_ARGUMENT_EXTEND_SELECTION_BOOLEAN: typing.ClassVar[str] = ...
    ACTION_ARGUMENT_HTML_ELEMENT_STRING: typing.ClassVar[str] = ...
    ACTION_ARGUMENT_MOVEMENT_GRANULARITY_INT: typing.ClassVar[str] = ...
    ACTION_ARGUMENT_MOVE_WINDOW_X: typing.ClassVar[str] = ...
    ACTION_ARGUMENT_MOVE_WINDOW_Y: typing.ClassVar[str] = ...
    ACTION_ARGUMENT_PRESS_AND_HOLD_DURATION_MILLIS_INT: typing.ClassVar[str] = ...
    ACTION_ARGUMENT_PROGRESS_VALUE: typing.ClassVar[str] = ...
    ACTION_ARGUMENT_ROW_INT: typing.ClassVar[str] = ...
    ACTION_ARGUMENT_SCROLL_AMOUNT_FLOAT: typing.ClassVar[str] = ...
    ACTION_ARGUMENT_SELECTION_END_INT: typing.ClassVar[str] = ...
    ACTION_ARGUMENT_SELECTION_START_INT: typing.ClassVar[str] = ...
    ACTION_ARGUMENT_SET_TEXT_CHARSEQUENCE: typing.ClassVar[str] = ...
    ACTION_CLEAR_ACCESSIBILITY_FOCUS: typing.ClassVar[int] = ...
    ACTION_CLEAR_FOCUS: typing.ClassVar[int] = ...
    ACTION_CLEAR_SELECTION: typing.ClassVar[int] = ...
    ACTION_CLICK: typing.ClassVar[int] = ...
    ACTION_COLLAPSE: typing.ClassVar[int] = ...
    ACTION_COPY: typing.ClassVar[int] = ...
    ACTION_CUT: typing.ClassVar[int] = ...
    ACTION_DISMISS: typing.ClassVar[int] = ...
    ACTION_EXPAND: typing.ClassVar[int] = ...
    ACTION_FOCUS: typing.ClassVar[int] = ...
    ACTION_LONG_CLICK: typing.ClassVar[int] = ...
    ACTION_NEXT_AT_MOVEMENT_GRANULARITY: typing.ClassVar[int] = ...
    ACTION_NEXT_HTML_ELEMENT: typing.ClassVar[int] = ...
    ACTION_PASTE: typing.ClassVar[int] = ...
    ACTION_PREVIOUS_AT_MOVEMENT_GRANULARITY: typing.ClassVar[int] = ...
    ACTION_PREVIOUS_HTML_ELEMENT: typing.ClassVar[int] = ...
    ACTION_SCROLL_BACKWARD: typing.ClassVar[int] = ...
    ACTION_SCROLL_FORWARD: typing.ClassVar[int] = ...
    ACTION_SELECT: typing.ClassVar[int] = ...
    ACTION_SET_SELECTION: typing.ClassVar[int] = ...
    ACTION_SET_TEXT: typing.ClassVar[int] = ...
    CHECKED_STATE_FALSE: typing.ClassVar[int] = ...
    CHECKED_STATE_PARTIAL: typing.ClassVar[int] = ...
    CHECKED_STATE_TRUE: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AccessibilityNodeInfo]] = ...
    EXPANDED_STATE_COLLAPSED: typing.ClassVar[int] = ...
    EXPANDED_STATE_FULL: typing.ClassVar[int] = ...
    EXPANDED_STATE_PARTIAL: typing.ClassVar[int] = ...
    EXPANDED_STATE_UNDEFINED: typing.ClassVar[int] = ...
    EXTRA_DATA_RENDERING_INFO_KEY: typing.ClassVar[str] = ...
    EXTRA_DATA_TEXT_CHARACTER_LOCATION_ARG_LENGTH: typing.ClassVar[str] = ...
    EXTRA_DATA_TEXT_CHARACTER_LOCATION_ARG_MAX_LENGTH: typing.ClassVar[int] = ...
    EXTRA_DATA_TEXT_CHARACTER_LOCATION_ARG_START_INDEX: typing.ClassVar[str] = ...
    EXTRA_DATA_TEXT_CHARACTER_LOCATION_IN_WINDOW_KEY: typing.ClassVar[str] = ...
    EXTRA_DATA_TEXT_CHARACTER_LOCATION_KEY: typing.ClassVar[str] = ...
    FLAG_PREFETCH_ANCESTORS: typing.ClassVar[int] = ...
    FLAG_PREFETCH_DESCENDANTS_BREADTH_FIRST: typing.ClassVar[int] = ...
    FLAG_PREFETCH_DESCENDANTS_DEPTH_FIRST: typing.ClassVar[int] = ...
    FLAG_PREFETCH_DESCENDANTS_HYBRID: typing.ClassVar[int] = ...
    FLAG_PREFETCH_SIBLINGS: typing.ClassVar[int] = ...
    FLAG_PREFETCH_UNINTERRUPTIBLE: typing.ClassVar[int] = ...
    FOCUS_ACCESSIBILITY: typing.ClassVar[int] = ...
    FOCUS_INPUT: typing.ClassVar[int] = ...
    MAX_NUMBER_OF_PREFETCHED_NODES: typing.ClassVar[int] = ...
    MOVEMENT_GRANULARITY_CHARACTER: typing.ClassVar[int] = ...
    MOVEMENT_GRANULARITY_LINE: typing.ClassVar[int] = ...
    MOVEMENT_GRANULARITY_PAGE: typing.ClassVar[int] = ...
    MOVEMENT_GRANULARITY_PARAGRAPH: typing.ClassVar[int] = ...
    MOVEMENT_GRANULARITY_WORD: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, source: android.view.View, /) -> None: ...
    @typing.overload
    def __init__(self, info: AccessibilityNodeInfo, /) -> None: ...
    @typing.overload
    def __init__(self, root: android.view.View, virtualDescendantId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addAction(self, action: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addAction(self, action: AccessibilityNodeInfo.AccessibilityAction, /) -> None: ...
    @typing.overload
    def addChild(self, child: android.view.View, /) -> None: ...
    @typing.overload
    def addChild(self, root: android.view.View, virtualDescendantId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addLabeledBy(self, label: android.view.View, /) -> None: ...
    @typing.overload
    def addLabeledBy(self, root: android.view.View, virtualDescendantId: int | java.jint | java.lang.Integer, /) -> None: ...
    def canOpenPopup(self) -> bool: ...
    def describeContents(self) -> int: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def findAccessibilityNodeInfosByText(self, text: str | java.lang.String, /) -> java.util.List[AccessibilityNodeInfo]: ...
    def findAccessibilityNodeInfosByViewId(self, viewId: str | java.lang.String, /) -> java.util.List[AccessibilityNodeInfo]: ...
    def findFocus(self, focus: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo | None: ...
    def focusSearch(self, direction: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo: ...
    def getActionList(self) -> java.util.List[AccessibilityNodeInfo.AccessibilityAction]: ...
    def getActions(self) -> int: ...
    def getAvailableExtraData(self) -> java.util.List[java.lang.String]: ...
    def getBoundsInParent(self, outBounds: android.graphics.Rect, /) -> None: ...
    def getBoundsInScreen(self, outBounds: android.graphics.Rect, /) -> None: ...
    def getBoundsInWindow(self, outBounds: android.graphics.Rect, /) -> None: ...
    def getChecked(self) -> int: ...
    @typing.overload
    def getChild(self, index: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo | None: ...
    @typing.overload
    def getChild(self, index: int | java.jint | java.lang.Integer, prefetchingStrategy: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo | None: ...
    def getChildCount(self) -> int: ...
    def getClassName(self) -> java.lang.CharSequence: ...
    def getCollectionInfo(self) -> AccessibilityNodeInfo.CollectionInfo: ...
    def getCollectionItemInfo(self) -> AccessibilityNodeInfo.CollectionItemInfo: ...
    def getContainerTitle(self) -> java.lang.CharSequence | None: ...
    def getContentDescription(self) -> java.lang.CharSequence: ...
    def getDrawingOrder(self) -> int: ...
    def getError(self) -> java.lang.CharSequence: ...
    def getExpandedState(self) -> int: ...
    def getExtraRenderingInfo(self) -> AccessibilityNodeInfo.ExtraRenderingInfo | None: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getHintText(self) -> java.lang.CharSequence: ...
    def getInputType(self) -> int: ...
    def getLabelFor(self) -> AccessibilityNodeInfo: ...
    def getLabeledBy(self) -> AccessibilityNodeInfo: ...
    def getLabeledByList(self) -> java.util.List[AccessibilityNodeInfo]: ...
    def getLiveRegion(self) -> int: ...
    def getMaxTextLength(self) -> int: ...
    def getMinDurationBetweenContentChanges(self) -> java.time.Duration: ...
    def getMovementGranularities(self) -> int: ...
    def getPackageName(self) -> java.lang.CharSequence: ...
    def getPaneTitle(self) -> java.lang.CharSequence | None: ...
    @typing.overload
    def getParent(self) -> AccessibilityNodeInfo | None: ...
    @typing.overload
    def getParent(self, prefetchingStrategy: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo | None: ...
    def getRangeInfo(self) -> AccessibilityNodeInfo.RangeInfo: ...
    def getStateDescription(self) -> java.lang.CharSequence | None: ...
    def getSupplementalDescription(self) -> java.lang.CharSequence: ...
    def getText(self) -> java.lang.CharSequence: ...
    def getTextSelectionEnd(self) -> int: ...
    def getTextSelectionStart(self) -> int: ...
    def getTooltipText(self) -> java.lang.CharSequence | None: ...
    def getTouchDelegateInfo(self) -> AccessibilityNodeInfo.TouchDelegateInfo | None: ...
    def getTraversalAfter(self) -> AccessibilityNodeInfo: ...
    def getTraversalBefore(self) -> AccessibilityNodeInfo: ...
    def getUniqueId(self) -> str | None: ...
    def getViewIdResourceName(self) -> str: ...
    def getWindow(self) -> AccessibilityWindowInfo: ...
    def getWindowId(self) -> int: ...
    def hasRequestInitialAccessibilityFocus(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isAccessibilityDataSensitive(self) -> bool: ...
    def isAccessibilityFocused(self) -> bool: ...
    def isCheckable(self) -> bool: ...
    def isChecked(self) -> bool: ...
    def isClickable(self) -> bool: ...
    def isContentInvalid(self) -> bool: ...
    def isContextClickable(self) -> bool: ...
    def isDismissable(self) -> bool: ...
    def isEditable(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isFieldRequired(self) -> bool: ...
    def isFocusable(self) -> bool: ...
    def isFocused(self) -> bool: ...
    def isGranularScrollingSupported(self) -> bool: ...
    def isHeading(self) -> bool: ...
    def isImportantForAccessibility(self) -> bool: ...
    def isLongClickable(self) -> bool: ...
    def isMultiLine(self) -> bool: ...
    def isPassword(self) -> bool: ...
    def isScreenReaderFocusable(self) -> bool: ...
    def isScrollable(self) -> bool: ...
    def isSelected(self) -> bool: ...
    def isShowingHintText(self) -> bool: ...
    def isTextEntryKey(self) -> bool: ...
    def isTextSelectable(self) -> bool: ...
    def isVisibleToUser(self) -> bool: ...
    @typing.overload
    @staticmethod
    def obtain() -> AccessibilityNodeInfo: ...
    @typing.overload
    @staticmethod
    def obtain(source: android.view.View, /) -> AccessibilityNodeInfo: ...
    @typing.overload
    @staticmethod
    def obtain(info: AccessibilityNodeInfo, /) -> AccessibilityNodeInfo: ...
    @typing.overload
    @staticmethod
    def obtain(root: android.view.View, virtualDescendantId: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo: ...
    @typing.overload
    def performAction(self, action: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def performAction(self, action: int | java.jint | java.lang.Integer, arguments: android.os.Bundle, /) -> bool: ...
    def recycle(self) -> None: ...
    def refresh(self) -> bool: ...
    def refreshWithExtraData(self, extraDataKey: str | java.lang.String, args: android.os.Bundle, /) -> bool: ...
    @typing.overload
    def removeAction(self, action: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def removeAction(self, action: AccessibilityNodeInfo.AccessibilityAction, /) -> bool: ...
    @typing.overload
    def removeChild(self, child: android.view.View, /) -> bool: ...
    @typing.overload
    def removeChild(self, root: android.view.View, virtualDescendantId: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def removeLabeledBy(self, label: android.view.View, /) -> bool: ...
    @typing.overload
    def removeLabeledBy(self, root: android.view.View, virtualDescendantId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setAccessibilityDataSensitive(self, accessibilityDataSensitive: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAccessibilityFocused(self, focused: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAvailableExtraData(self, extraDataKeys: java.util.List[java.lang.String], /) -> None: ...
    def setBoundsInParent(self, bounds: android.graphics.Rect, /) -> None: ...
    def setBoundsInScreen(self, bounds: android.graphics.Rect, /) -> None: ...
    def setBoundsInWindow(self, bounds: android.graphics.Rect, /) -> None: ...
    def setCanOpenPopup(self, opensPopup: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCheckable(self, checkable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setChecked(self, checked: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setChecked(self, checked: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setClassName(self, className: java.lang.CharSequence, /) -> None: ...
    def setClickable(self, clickable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCollectionInfo(self, collectionInfo: AccessibilityNodeInfo.CollectionInfo, /) -> None: ...
    def setCollectionItemInfo(self, collectionItemInfo: AccessibilityNodeInfo.CollectionItemInfo, /) -> None: ...
    def setContainerTitle(self, containerTitle: java.lang.CharSequence, /) -> None: ...
    def setContentDescription(self, contentDescription: java.lang.CharSequence, /) -> None: ...
    def setContentInvalid(self, contentInvalid: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setContextClickable(self, contextClickable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDismissable(self, dismissable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDrawingOrder(self, drawingOrderInParent: int | java.jint | java.lang.Integer, /) -> None: ...
    def setEditable(self, editable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setError(self, error: java.lang.CharSequence, /) -> None: ...
    def setExpandedState(self, state: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFieldRequired(self, required: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFocusable(self, focusable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFocused(self, focused: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setGranularScrollingSupported(self, granularScrollingSupported: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setHeading(self, isHeading: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setHintText(self, hintText: java.lang.CharSequence, /) -> None: ...
    def setImportantForAccessibility(self, important: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setInputType(self, inputType: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setLabelFor(self, labeled: android.view.View, /) -> None: ...
    @typing.overload
    def setLabelFor(self, root: android.view.View, virtualDescendantId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setLabeledBy(self, label: android.view.View, /) -> None: ...
    @typing.overload
    def setLabeledBy(self, root: android.view.View, virtualDescendantId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLiveRegion(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLongClickable(self, longClickable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMaxTextLength(self, max: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinDurationBetweenContentChanges(self, duration: java.time.Duration, /) -> None: ...
    def setMovementGranularities(self, granularities: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMultiLine(self, multiLine: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setPackageName(self, packageName: java.lang.CharSequence, /) -> None: ...
    def setPaneTitle(self, paneTitle: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setParent(self, parent: android.view.View, /) -> None: ...
    @typing.overload
    def setParent(self, root: android.view.View, virtualDescendantId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPassword(self, password: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setQueryFromAppProcessEnabled(self, view: android.view.View, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setRangeInfo(self, rangeInfo: AccessibilityNodeInfo.RangeInfo, /) -> None: ...
    def setRequestInitialAccessibilityFocus(self, requestInitialAccessibilityFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setScreenReaderFocusable(self, screenReaderFocusable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setScrollable(self, scrollable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSelected(self, selected: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setShowingHintText(self, showingHintText: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setSource(self, source: android.view.View, /) -> None: ...
    @typing.overload
    def setSource(self, root: android.view.View, virtualDescendantId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setStateDescription(self, stateDescription: java.lang.CharSequence, /) -> None: ...
    def setSupplementalDescription(self, supplementalDescription: java.lang.CharSequence, /) -> None: ...
    def setText(self, text: java.lang.CharSequence, /) -> None: ...
    def setTextEntryKey(self, isTextEntryKey: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTextSelectable(self, selectableText: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTextSelection(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTooltipText(self, tooltipText: java.lang.CharSequence, /) -> None: ...
    def setTouchDelegateInfo(self, delegatedInfo: AccessibilityNodeInfo.TouchDelegateInfo, /) -> None: ...
    @typing.overload
    def setTraversalAfter(self, view: android.view.View, /) -> None: ...
    @typing.overload
    def setTraversalAfter(self, root: android.view.View, virtualDescendantId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTraversalBefore(self, view: android.view.View, /) -> None: ...
    @typing.overload
    def setTraversalBefore(self, root: android.view.View, virtualDescendantId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setUniqueId(self, uniqueId: str | java.lang.String, /) -> None: ...
    def setViewIdResourceName(self, viewIdResName: str | java.lang.String, /) -> None: ...
    def setVisibleToUser(self, visibleToUser: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class TouchDelegateInfo(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AccessibilityNodeInfo.TouchDelegateInfo]] = ...
        def __init__(self, targetMap: java.util.Map[android.graphics.Region, android.view.View], /) -> None: ...
        def describeContents(self) -> int: ...
        def getRegionAt(self, index: int | java.jint | java.lang.Integer, /) -> android.graphics.Region: ...
        def getRegionCount(self) -> int: ...
        def getTargetForRegion(self, region: android.graphics.Region, /) -> AccessibilityNodeInfo: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class RangeInfo(java.lang.Object):
        INDETERMINATE: typing.ClassVar[AccessibilityNodeInfo.RangeInfo] = ...
        RANGE_TYPE_FLOAT: typing.ClassVar[int] = ...
        RANGE_TYPE_INDETERMINATE: typing.ClassVar[int] = ...
        RANGE_TYPE_INT: typing.ClassVar[int] = ...
        RANGE_TYPE_PERCENT: typing.ClassVar[int] = ...
        def __init__(self, type: int | java.jint | java.lang.Integer, min: float | java.jfloat | java.lang.Float, max: float | java.jfloat | java.lang.Float, current: float | java.jfloat | java.lang.Float, /) -> None: ...
        def getCurrent(self) -> float: ...
        def getMax(self) -> float: ...
        def getMin(self) -> float: ...
        def getType(self) -> int: ...
        @staticmethod
        def obtain(type: int | java.jint | java.lang.Integer, min: float | java.jfloat | java.lang.Float, max: float | java.jfloat | java.lang.Float, current: float | java.jfloat | java.lang.Float, /) -> AccessibilityNodeInfo.RangeInfo: ...

    class ExtraRenderingInfo(java.lang.Object):
        def getLayoutSize(self) -> android.util.Size: ...
        def getTextSizeInPx(self) -> float: ...
        def getTextSizeUnit(self) -> int: ...

    class CollectionItemInfo(java.lang.Object):
        @typing.overload
        def __init__(self, rowIndex: int | java.jint | java.lang.Integer, rowSpan: int | java.jint | java.lang.Integer, columnIndex: int | java.jint | java.lang.Integer, columnSpan: int | java.jint | java.lang.Integer, heading: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        @typing.overload
        def __init__(self, rowIndex: int | java.jint | java.lang.Integer, rowSpan: int | java.jint | java.lang.Integer, columnIndex: int | java.jint | java.lang.Integer, columnSpan: int | java.jint | java.lang.Integer, heading: bool | java.jboolean | java.lang.Boolean, selected: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def getColumnIndex(self) -> int: ...
        def getColumnSpan(self) -> int: ...
        def getColumnTitle(self) -> str: ...
        def getRowIndex(self) -> int: ...
        def getRowSpan(self) -> int: ...
        def getRowTitle(self) -> str: ...
        def isHeading(self) -> bool: ...
        def isSelected(self) -> bool: ...
        @typing.overload
        @staticmethod
        def obtain(rowIndex: int | java.jint | java.lang.Integer, rowSpan: int | java.jint | java.lang.Integer, columnIndex: int | java.jint | java.lang.Integer, columnSpan: int | java.jint | java.lang.Integer, heading: bool | java.jboolean | java.lang.Boolean, /) -> AccessibilityNodeInfo.CollectionItemInfo: ...
        @typing.overload
        @staticmethod
        def obtain(rowIndex: int | java.jint | java.lang.Integer, rowSpan: int | java.jint | java.lang.Integer, columnIndex: int | java.jint | java.lang.Integer, columnSpan: int | java.jint | java.lang.Integer, heading: bool | java.jboolean | java.lang.Boolean, selected: bool | java.jboolean | java.lang.Boolean, /) -> AccessibilityNodeInfo.CollectionItemInfo: ...

        class Builder(java.lang.Object):
            def __init__(self) -> None: ...
            def build(self) -> AccessibilityNodeInfo.CollectionItemInfo: ...
            def setColumnIndex(self, columnIndex: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo.CollectionItemInfo.Builder: ...
            def setColumnSpan(self, columnSpan: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo.CollectionItemInfo.Builder: ...
            def setColumnTitle(self, columnTitle: str | java.lang.String, /) -> AccessibilityNodeInfo.CollectionItemInfo.Builder: ...
            def setHeading(self, heading: bool | java.jboolean | java.lang.Boolean, /) -> AccessibilityNodeInfo.CollectionItemInfo.Builder: ...
            def setRowIndex(self, rowIndex: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo.CollectionItemInfo.Builder: ...
            def setRowSpan(self, rowSpan: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo.CollectionItemInfo.Builder: ...
            def setRowTitle(self, rowTitle: str | java.lang.String, /) -> AccessibilityNodeInfo.CollectionItemInfo.Builder: ...
            def setSelected(self, selected: bool | java.jboolean | java.lang.Boolean, /) -> AccessibilityNodeInfo.CollectionItemInfo.Builder: ...

    class CollectionInfo(java.lang.Object):
        SELECTION_MODE_MULTIPLE: typing.ClassVar[int] = ...
        SELECTION_MODE_NONE: typing.ClassVar[int] = ...
        SELECTION_MODE_SINGLE: typing.ClassVar[int] = ...
        UNDEFINED: typing.ClassVar[int] = ...
        @typing.overload
        def __init__(self, rowCount: int | java.jint | java.lang.Integer, columnCount: int | java.jint | java.lang.Integer, hierarchical: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        @typing.overload
        def __init__(self, rowCount: int | java.jint | java.lang.Integer, columnCount: int | java.jint | java.lang.Integer, hierarchical: bool | java.jboolean | java.lang.Boolean, selectionMode: int | java.jint | java.lang.Integer, /) -> None: ...
        def getColumnCount(self) -> int: ...
        def getImportantForAccessibilityItemCount(self) -> int: ...
        def getItemCount(self) -> int: ...
        def getRowCount(self) -> int: ...
        def getSelectionMode(self) -> int: ...
        def isHierarchical(self) -> bool: ...
        @typing.overload
        @staticmethod
        def obtain(rowCount: int | java.jint | java.lang.Integer, columnCount: int | java.jint | java.lang.Integer, hierarchical: bool | java.jboolean | java.lang.Boolean, /) -> AccessibilityNodeInfo.CollectionInfo: ...
        @typing.overload
        @staticmethod
        def obtain(rowCount: int | java.jint | java.lang.Integer, columnCount: int | java.jint | java.lang.Integer, hierarchical: bool | java.jboolean | java.lang.Boolean, selectionMode: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo.CollectionInfo: ...

        class Builder(java.lang.Object):
            def __init__(self) -> None: ...
            def build(self) -> AccessibilityNodeInfo.CollectionInfo: ...
            def setColumnCount(self, columnCount: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo.CollectionInfo.Builder: ...
            def setHierarchical(self, hierarchical: bool | java.jboolean | java.lang.Boolean, /) -> AccessibilityNodeInfo.CollectionInfo.Builder: ...
            def setImportantForAccessibilityItemCount(self, importantForAccessibilityItemCount: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo.CollectionInfo.Builder: ...
            def setItemCount(self, itemCount: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo.CollectionInfo.Builder: ...
            def setRowCount(self, rowCount: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo.CollectionInfo.Builder: ...
            def setSelectionMode(self, selectionMode: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo.CollectionInfo.Builder: ...

    class AccessibilityAction(android.os.Parcelable):
        ACTION_ACCESSIBILITY_FOCUS: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_CLEAR_ACCESSIBILITY_FOCUS: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_CLEAR_FOCUS: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_CLEAR_SELECTION: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_CLICK: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_COLLAPSE: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_CONTEXT_CLICK: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_COPY: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_CUT: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_DISMISS: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_DRAG_CANCEL: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_DRAG_DROP: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_DRAG_START: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_EXPAND: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_FOCUS: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_HIDE_TOOLTIP: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_IME_ENTER: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_LONG_CLICK: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_MOVE_WINDOW: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_NEXT_AT_MOVEMENT_GRANULARITY: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_NEXT_HTML_ELEMENT: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_PAGE_DOWN: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_PAGE_LEFT: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_PAGE_RIGHT: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_PAGE_UP: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_PASTE: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_PRESS_AND_HOLD: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_PREVIOUS_AT_MOVEMENT_GRANULARITY: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_PREVIOUS_HTML_ELEMENT: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SCROLL_BACKWARD: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SCROLL_DOWN: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SCROLL_FORWARD: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SCROLL_IN_DIRECTION: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SCROLL_LEFT: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SCROLL_RIGHT: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SCROLL_TO_POSITION: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SCROLL_UP: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SELECT: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SET_PROGRESS: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SET_SELECTION: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SET_TEXT: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SHOW_ON_SCREEN: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SHOW_TEXT_SUGGESTIONS: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        ACTION_SHOW_TOOLTIP: typing.ClassVar[AccessibilityNodeInfo.AccessibilityAction] = ...
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AccessibilityNodeInfo.AccessibilityAction]] = ...
        def __init__(self, actionId: int | java.jint | java.lang.Integer, label: java.lang.CharSequence, /) -> None: ...
        def describeContents(self) -> int: ...
        def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getId(self) -> int: ...
        def getLabel(self) -> java.lang.CharSequence: ...
        def hashCode(self) -> int: ...
        def toString(self) -> str: ...
        def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AccessibilityNodeProvider(java.lang.Object):
    HOST_VIEW_ID: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def addExtraDataToAccessibilityNodeInfo(self, virtualViewId: int | java.jint | java.lang.Integer, info: AccessibilityNodeInfo, extraDataKey: str | java.lang.String, arguments: android.os.Bundle, /) -> None: ...
    def createAccessibilityNodeInfo(self, virtualViewId: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo | None: ...
    def findAccessibilityNodeInfosByText(self, text: str | java.lang.String, virtualViewId: int | java.jint | java.lang.Integer, /) -> java.util.List[AccessibilityNodeInfo] | None: ...
    def findFocus(self, focus: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo | None: ...
    def performAction(self, virtualViewId: int | java.jint | java.lang.Integer, action: int | java.jint | java.lang.Integer, arguments: android.os.Bundle, /) -> bool: ...

class AccessibilityRecord(java.lang.Object):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, record: AccessibilityRecord, /) -> None: ...
    def getAddedCount(self) -> int: ...
    def getBeforeText(self) -> java.lang.CharSequence | None: ...
    def getClassName(self) -> java.lang.CharSequence | None: ...
    def getContentDescription(self) -> java.lang.CharSequence | None: ...
    def getCurrentItemIndex(self) -> int: ...
    def getDisplayId(self) -> int: ...
    def getFromIndex(self) -> int: ...
    def getItemCount(self) -> int: ...
    def getMaxScrollX(self) -> int: ...
    def getMaxScrollY(self) -> int: ...
    def getParcelableData(self) -> android.os.Parcelable | None: ...
    def getRemovedCount(self) -> int: ...
    def getScrollDeltaX(self) -> int: ...
    def getScrollDeltaY(self) -> int: ...
    def getScrollX(self) -> int: ...
    def getScrollY(self) -> int: ...
    @typing.overload
    def getSource(self) -> AccessibilityNodeInfo | None: ...
    @typing.overload
    def getSource(self, prefetchingStrategy: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo | None: ...
    def getText(self) -> java.util.List[java.lang.CharSequence]: ...
    def getToIndex(self) -> int: ...
    def getWindowId(self) -> int: ...
    def isChecked(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isFullScreen(self) -> bool: ...
    def isPassword(self) -> bool: ...
    def isScrollable(self) -> bool: ...
    @typing.overload
    @staticmethod
    def obtain() -> AccessibilityRecord: ...
    @typing.overload
    @staticmethod
    def obtain(record: AccessibilityRecord, /) -> AccessibilityRecord: ...
    def recycle(self) -> None: ...
    def setAddedCount(self, addedCount: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBeforeText(self, beforeText: java.lang.CharSequence, /) -> None: ...
    def setChecked(self, isChecked: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setClassName(self, className: java.lang.CharSequence, /) -> None: ...
    def setContentDescription(self, contentDescription: java.lang.CharSequence, /) -> None: ...
    def setCurrentItemIndex(self, currentItemIndex: int | java.jint | java.lang.Integer, /) -> None: ...
    def setEnabled(self, isEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFromIndex(self, fromIndex: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFullScreen(self, isFullScreen: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setItemCount(self, itemCount: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaxScrollX(self, maxScrollX: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaxScrollY(self, maxScrollY: int | java.jint | java.lang.Integer, /) -> None: ...
    def setParcelableData(self, parcelableData: android.os.Parcelable, /) -> None: ...
    def setPassword(self, isPassword: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setRemovedCount(self, removedCount: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScrollDeltaX(self, scrollDeltaX: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScrollDeltaY(self, scrollDeltaY: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScrollX(self, scrollX: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScrollY(self, scrollY: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScrollable(self, scrollable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setSource(self, source: android.view.View, /) -> None: ...
    @typing.overload
    def setSource(self, root: android.view.View, virtualDescendantId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setToIndex(self, toIndex: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...

class AccessibilityRequestPreparer(java.lang.Object):
    REQUEST_TYPE_EXTRA_DATA: typing.ClassVar[int] = ...
    def __init__(self, view: android.view.View, requestTypes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getView(self) -> android.view.View | None: ...
    def onPrepareExtraData(self, arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, arg3: android.os.Bundle, arg4: android.os.Message, /) -> None: ...

class AccessibilityWindowInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AccessibilityWindowInfo]] = ...
    TYPE_ACCESSIBILITY_OVERLAY: typing.ClassVar[int] = ...
    TYPE_APPLICATION: typing.ClassVar[int] = ...
    TYPE_INPUT_METHOD: typing.ClassVar[int] = ...
    TYPE_MAGNIFICATION_OVERLAY: typing.ClassVar[int] = ...
    TYPE_SPLIT_SCREEN_DIVIDER: typing.ClassVar[int] = ...
    TYPE_SYSTEM: typing.ClassVar[int] = ...
    TYPE_WINDOW_CONTROL: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, info: AccessibilityWindowInfo, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAnchor(self) -> AccessibilityNodeInfo: ...
    def getBoundsInScreen(self, outBounds: android.graphics.Rect, /) -> None: ...
    def getChild(self, index: int | java.jint | java.lang.Integer, /) -> AccessibilityWindowInfo: ...
    def getChildCount(self) -> int: ...
    def getDisplayId(self) -> int: ...
    def getId(self) -> int: ...
    def getLayer(self) -> int: ...
    def getLocales(self) -> android.os.LocaleList: ...
    def getParent(self) -> AccessibilityWindowInfo: ...
    def getRegionInScreen(self, outRegion: android.graphics.Region, /) -> None: ...
    @typing.overload
    def getRoot(self) -> AccessibilityNodeInfo | None: ...
    @typing.overload
    def getRoot(self, prefetchingStrategy: int | java.jint | java.lang.Integer, /) -> AccessibilityNodeInfo | None: ...
    def getTitle(self) -> java.lang.CharSequence | None: ...
    def getTransitionTimeMillis(self) -> int: ...
    def getType(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAccessibilityFocused(self) -> bool: ...
    def isActive(self) -> bool: ...
    def isFocused(self) -> bool: ...
    def isInPictureInPictureMode(self) -> bool: ...
    @typing.overload
    @staticmethod
    def obtain() -> AccessibilityWindowInfo: ...
    @typing.overload
    @staticmethod
    def obtain(info: AccessibilityWindowInfo, /) -> AccessibilityWindowInfo: ...
    def recycle(self) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CaptioningManager(java.lang.Object):
    def addCaptioningChangeListener(self, listener: CaptioningManager.CaptioningChangeListener, /) -> None: ...
    def getFontScale(self) -> float: ...
    def getLocale(self) -> java.util.Locale | None: ...
    def getUserStyle(self) -> CaptioningManager.CaptionStyle: ...
    def isCallCaptioningEnabled(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isSystemAudioCaptioningEnabled(self) -> bool: ...
    def isSystemAudioCaptioningUiEnabled(self) -> bool: ...
    def removeCaptioningChangeListener(self, listener: CaptioningManager.CaptioningChangeListener, /) -> None: ...

    class CaptioningChangeListener(java.lang.Object):
        def __init__(self) -> None: ...
        def onEnabledChanged(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onFontScaleChanged(self, fontScale: float | java.jfloat | java.lang.Float, /) -> None: ...
        def onLocaleChanged(self, locale: java.util.Locale, /) -> None: ...
        def onSystemAudioCaptioningChanged(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onSystemAudioCaptioningUiChanged(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onUserStyleChanged(self, userStyle: CaptioningManager.CaptionStyle, /) -> None: ...

    class CaptionStyle(java.lang.Object):
        EDGE_TYPE_DEPRESSED: typing.ClassVar[int] = ...
        EDGE_TYPE_DROP_SHADOW: typing.ClassVar[int] = ...
        EDGE_TYPE_NONE: typing.ClassVar[int] = ...
        EDGE_TYPE_OUTLINE: typing.ClassVar[int] = ...
        EDGE_TYPE_RAISED: typing.ClassVar[int] = ...
        EDGE_TYPE_UNSPECIFIED: typing.ClassVar[int] = ...
        backgroundColor: int = ...
        edgeColor: int = ...
        edgeType: int = ...
        foregroundColor: int = ...
        windowColor: int = ...
        def getTypeface(self) -> android.graphics.Typeface: ...
        def hasBackgroundColor(self) -> bool: ...
        def hasEdgeColor(self) -> bool: ...
        def hasEdgeType(self) -> bool: ...
        def hasForegroundColor(self) -> bool: ...
        def hasWindowColor(self) -> bool: ...
