import typing

import android.app
import android.content
import android.graphics.drawable
import android.os
import java
import java.lang
import java.util

class AdditionalContentContract(java.lang.Object):

    class MethodNames(java.lang.Object):
        ON_SELECTION_CHANGED: typing.ClassVar[str] = ...

    class CursorExtraKeys(java.lang.Object):
        POSITION: typing.ClassVar[str] = ...

    class Columns(java.lang.Object):
        URI: typing.ClassVar[str] = ...

class ChooserAction(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ChooserAction]] = ...
    def describeContents(self) -> int: ...
    def getAction(self) -> android.app.PendingIntent: ...
    def getIcon(self) -> android.graphics.drawable.Icon: ...
    def getLabel(self) -> java.lang.CharSequence: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, icon: android.graphics.drawable.Icon, label: java.lang.CharSequence, action: android.app.PendingIntent, /) -> None: ...
        def build(self) -> ChooserAction: ...

class ChooserResult(android.os.Parcelable):
    CHOOSER_RESULT_COPY: typing.ClassVar[int] = ...
    CHOOSER_RESULT_EDIT: typing.ClassVar[int] = ...
    CHOOSER_RESULT_SELECTED_COMPONENT: typing.ClassVar[int] = ...
    CHOOSER_RESULT_UNKNOWN: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ChooserResult]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getSelectedComponent(self) -> android.content.ComponentName | None: ...
    def getType(self) -> int: ...
    def hashCode(self) -> int: ...
    def isShortcut(self) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ChooserTarget(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ChooserTarget]] = ...
    def __init__(self, title: java.lang.CharSequence, icon: android.graphics.drawable.Icon, score: float | java.jfloat | java.lang.Float, componentName: android.content.ComponentName, intentExtras: android.os.Bundle, /) -> None: ...
    def describeContents(self) -> int: ...
    def getComponentName(self) -> android.content.ComponentName: ...
    def getIcon(self) -> android.graphics.drawable.Icon: ...
    def getIntentExtras(self) -> android.os.Bundle: ...
    def getScore(self) -> float: ...
    def getTitle(self) -> java.lang.CharSequence: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ChooserTargetService(android.app.Service):
    BIND_PERMISSION: typing.ClassVar[str] = ...
    META_DATA_NAME: typing.ClassVar[str] = ...
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onGetChooserTargets(self, arg1: android.content.ComponentName, arg2: android.content.IntentFilter, /) -> java.util.List[ChooserTarget]: ...
