import typing

import java.lang
import javax.xml.transform
import org.w3c.dom

class DOMLocator(javax.xml.transform.SourceLocator):
    def getOriginatingNode(self) -> org.w3c.dom.Node: ...

class DOMResult(javax.xml.transform.Result):
    FEATURE: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, node: org.w3c.dom.Node, /) -> None: ...
    @typing.overload
    def __init__(self, node: org.w3c.dom.Node, systemId: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, node: org.w3c.dom.Node, nextSibling: org.w3c.dom.Node, /) -> None: ...
    @typing.overload
    def __init__(self, node: org.w3c.dom.Node, nextSibling: org.w3c.dom.Node, systemId: str | java.lang.String, /) -> None: ...
    def getNextSibling(self) -> org.w3c.dom.Node: ...
    def getNode(self) -> org.w3c.dom.Node: ...
    def getSystemId(self) -> str: ...
    def setNextSibling(self, nextSibling: org.w3c.dom.Node, /) -> None: ...
    def setNode(self, node: org.w3c.dom.Node, /) -> None: ...
    def setSystemId(self, systemId: str | java.lang.String, /) -> None: ...

class DOMSource(javax.xml.transform.Source):
    FEATURE: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, n: org.w3c.dom.Node, /) -> None: ...
    @typing.overload
    def __init__(self, node: org.w3c.dom.Node, systemID: str | java.lang.String, /) -> None: ...
    def getNode(self) -> org.w3c.dom.Node: ...
    def getSystemId(self) -> str: ...
    def setNode(self, node: org.w3c.dom.Node, /) -> None: ...
    def setSystemId(self, systemID: str | java.lang.String, /) -> None: ...
