import typing

import android.os
import android.view.autofill
import java
import java.lang
import java.util

class FieldClassification(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[FieldClassification]] = ...
    def __init__(self, autofillId: android.view.autofill.AutofillId, hints: java.util.Set[java.lang.String], /) -> None: ...
    def describeContents(self) -> int: ...
    def getAutofillId(self) -> android.view.autofill.AutofillId: ...
    def getHints(self) -> java.util.Set[java.lang.String]: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...
