import typing

import android.graphics
import android.os
import android.util
import android.view
import java
import java.lang

class InlineContentView(android.view.ViewGroup):
    def getSurfaceControl(self) -> android.view.SurfaceControl | None: ...
    def isZOrderedOnTop(self) -> bool: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def setClipBounds(self, clipBounds: android.graphics.Rect, /) -> None: ...
    def setSurfaceControlCallback(self, callback: InlineContentView.SurfaceControlCallback, /) -> None: ...
    def setZOrderedOnTop(self, onTop: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...

    class SurfaceControlCallback(java.lang.Object):
        def onCreated(self, arg1: android.view.SurfaceControl, /) -> None: ...
        def onDestroyed(self, arg1: android.view.SurfaceControl, /) -> None: ...

class InlinePresentationSpec(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[InlinePresentationSpec]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMaxSize(self) -> android.util.Size: ...
    def getMinSize(self) -> android.util.Size: ...
    def getStyle(self) -> android.os.Bundle: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, minSize: android.util.Size, maxSize: android.util.Size, /) -> None: ...
        def build(self) -> InlinePresentationSpec: ...
        def setStyle(self, value: android.os.Bundle, /) -> InlinePresentationSpec.Builder: ...
