import typing

import java
import java.chaquopy
import java.lang
import java.lang.annotation
import java.net
import java.nio
import java.nio.channels
import java.nio.charset
import java.nio.file
import java.security
import java.util
import java.util.stream

class BufferedInputStream(FilterInputStream):
    buf: java.chaquopy.JavaArrayJByte = ...
    count: int = ...
    marklimit: int = ...
    markpos: int = ...
    pos: int = ...
    @typing.overload
    def __init__(self, in_: InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, in_: InputStream, size: int | java.jint | java.lang.Integer, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class BufferedOutputStream(FilterOutputStream):
    buf: java.chaquopy.JavaArrayJByte = ...
    count: int = ...
    @typing.overload
    def __init__(self, out: OutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, size: int | java.jint | java.lang.Integer, /) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class BufferedReader(Reader):
    @typing.overload
    def __init__(self, in_: Reader, /) -> None: ...
    @typing.overload
    def __init__(self, in_: Reader, sz: int | java.jint | java.lang.Integer, /) -> None: ...
    def close(self) -> None: ...
    def lines(self) -> java.util.stream.Stream[java.lang.String]: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def readLine(self) -> str | None: ...
    def ready(self) -> bool: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class BufferedWriter(Writer):
    @typing.overload
    def __init__(self, out: Writer, /) -> None: ...
    @typing.overload
    def __init__(self, out: Writer, sz: int | java.jint | java.lang.Integer, /) -> None: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    def newLine(self) -> None: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, s: str | java.lang.String, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class ByteArrayInputStream(InputStream):
    buf: java.chaquopy.JavaArrayJByte = ...
    count: int = ...
    mark: int = ...
    pos: int = ...
    @typing.overload
    def __init__(self, buf: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, buf: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def readAllBytes(self) -> java.chaquopy.JavaArrayJByte: ...
    def readNBytes(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...
    def transferTo(self, out: OutputStream, /) -> int: ...

class ByteArrayOutputStream(OutputStream):
    buf: java.chaquopy.JavaArrayJByte = ...
    count: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, size: int | java.jint | java.lang.Integer, /) -> None: ...
    def close(self) -> None: ...
    def reset(self) -> None: ...
    def size(self) -> int: ...
    def toByteArray(self) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def toString(self) -> str: ...
    @typing.overload
    def toString(self, hibyte: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def toString(self, charsetName: str | java.lang.String, /) -> str: ...
    @typing.overload
    def toString(self, charset: java.nio.charset.Charset, /) -> str: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBytes(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def writeTo(self, out: OutputStream, /) -> None: ...

class CharArrayReader(Reader):
    buf: java.chaquopy.JavaArrayJChar = ...
    count: int = ...
    markedPos: int = ...
    pos: int = ...
    @typing.overload
    def __init__(self, buf: java.chaquopy.JavaArrayJChar, /) -> None: ...
    @typing.overload
    def __init__(self, buf: java.chaquopy.JavaArrayJChar, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def close(self) -> None: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, target: java.nio.CharBuffer, /) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def ready(self) -> bool: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class CharArrayWriter(Writer):
    buf: java.chaquopy.JavaArrayJChar = ...
    count: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, initialSize: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def append(self, c: str | java.jchar | java.lang.Character, /) -> CharArrayWriter: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, /) -> CharArrayWriter: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> CharArrayWriter: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    def reset(self) -> None: ...
    def size(self) -> int: ...
    def toCharArray(self) -> java.chaquopy.JavaArrayJChar: ...
    def toString(self) -> str: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, str: str | java.lang.String, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, c: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeTo(self, out: Writer, /) -> None: ...

class CharConversionException(IOException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class Closeable(java.lang.AutoCloseable):
    def close(self) -> None: ...

class Console(Flushable):
    def charset(self) -> java.nio.charset.Charset: ...
    def flush(self) -> None: ...
    def format(self, fmt: str | java.lang.String, /, *args: java.lang.Object) -> Console: ...
    def printf(self, format: str | java.lang.String, /, *args: java.lang.Object) -> Console: ...
    @typing.overload
    def readLine(self) -> str: ...
    @typing.overload
    def readLine(self, fmt: str | java.lang.String, /, *args: java.lang.Object) -> str: ...
    @typing.overload
    def readPassword(self) -> java.chaquopy.JavaArrayJChar: ...
    @typing.overload
    def readPassword(self, fmt: str | java.lang.String, /, *args: java.lang.Object) -> java.chaquopy.JavaArrayJChar: ...
    def reader(self) -> Reader: ...
    def writer(self) -> PrintWriter: ...

class DataInput(java.lang.Object):
    def readBoolean(self) -> bool: ...
    def readByte(self) -> int: ...
    def readChar(self) -> str: ...
    def readDouble(self) -> float: ...
    def readFloat(self) -> float: ...
    @typing.overload
    def readFully(self, arg1: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def readFully(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def readInt(self) -> int: ...
    def readLine(self) -> str: ...
    def readLong(self) -> int: ...
    def readShort(self) -> int: ...
    def readUTF(self) -> str: ...
    def readUnsignedByte(self) -> int: ...
    def readUnsignedShort(self) -> int: ...
    def skipBytes(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...

class DataInputStream(DataInput, FilterInputStream):
    def __init__(self, in_: InputStream, /) -> None: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def readBoolean(self) -> bool: ...
    def readByte(self) -> int: ...
    def readChar(self) -> str: ...
    def readDouble(self) -> float: ...
    def readFloat(self) -> float: ...
    @typing.overload
    def readFully(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def readFully(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def readInt(self) -> int: ...
    def readLine(self) -> str: ...
    def readLong(self) -> int: ...
    def readShort(self) -> int: ...
    @typing.overload
    def readUTF(self) -> str: ...
    @typing.overload
    @staticmethod
    def readUTF(in_: DataInput, /) -> str: ...
    def readUnsignedByte(self) -> int: ...
    def readUnsignedShort(self) -> int: ...
    def skipBytes(self, n: int | java.jint | java.lang.Integer, /) -> int: ...

class DataOutput(java.lang.Object):
    @typing.overload
    def write(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBoolean(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def writeByte(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBytes(self, arg1: str | java.lang.String, /) -> None: ...
    def writeChar(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeChars(self, arg1: str | java.lang.String, /) -> None: ...
    def writeDouble(self, arg1: float | java.jdouble | java.lang.Double, /) -> None: ...
    def writeFloat(self, arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    def writeInt(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeLong(self, arg1: int | java.jlong | java.lang.Long, /) -> None: ...
    def writeShort(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeUTF(self, arg1: str | java.lang.String, /) -> None: ...

class DataOutputStream(DataOutput, FilterOutputStream):
    written: int = ...
    def __init__(self, out: OutputStream, /) -> None: ...
    def flush(self) -> None: ...
    def size(self) -> int: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBoolean(self, v: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def writeByte(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBytes(self, s: str | java.lang.String, /) -> None: ...
    def writeChar(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeChars(self, s: str | java.lang.String, /) -> None: ...
    def writeDouble(self, v: float | java.jdouble | java.lang.Double, /) -> None: ...
    def writeFloat(self, v: float | java.jfloat | java.lang.Float, /) -> None: ...
    def writeInt(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeLong(self, v: int | java.jlong | java.lang.Long, /) -> None: ...
    def writeShort(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeUTF(self, str: str | java.lang.String, /) -> None: ...

class EOFException(IOException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class Externalizable(Serializable):
    def readExternal(self, arg1: ObjectInput, /) -> None: ...
    def writeExternal(self, arg1: ObjectOutput, /) -> None: ...

class File(Serializable, java.lang.Comparable[File]):
    pathSeparator: typing.ClassVar[str] = ...
    pathSeparatorChar: typing.ClassVar[str] = ...
    separator: typing.ClassVar[str] = ...
    separatorChar: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self, pathname: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, uri: java.net.URI, /) -> None: ...
    @typing.overload
    def __init__(self, parent: File, child: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, parent: str | java.lang.String, child: str | java.lang.String, /) -> None: ...
    def canExecute(self) -> bool: ...
    def canRead(self) -> bool: ...
    def canWrite(self) -> bool: ...
    def compareTo(self, pathname: File, /) -> int: ...
    def createNewFile(self) -> bool: ...
    @typing.overload
    @staticmethod
    def createTempFile(prefix: str | java.lang.String, suffix: str | java.lang.String, /) -> File: ...
    @typing.overload
    @staticmethod
    def createTempFile(prefix: str | java.lang.String, suffix: str | java.lang.String, directory: File, /) -> File: ...
    def delete(self) -> bool: ...
    def deleteOnExit(self) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def exists(self) -> bool: ...
    def getAbsoluteFile(self) -> File: ...
    def getAbsolutePath(self) -> str: ...
    def getCanonicalFile(self) -> File: ...
    def getCanonicalPath(self) -> str: ...
    def getFreeSpace(self) -> int: ...
    def getName(self) -> str: ...
    def getParent(self) -> str | None: ...
    def getParentFile(self) -> File | None: ...
    def getPath(self) -> str: ...
    def getTotalSpace(self) -> int: ...
    def getUsableSpace(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAbsolute(self) -> bool: ...
    def isDirectory(self) -> bool: ...
    def isFile(self) -> bool: ...
    def isHidden(self) -> bool: ...
    def lastModified(self) -> int: ...
    def length(self) -> int: ...
    @typing.overload
    def list(self) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    @typing.overload
    def list(self, filter: FilenameFilter, /) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    @typing.overload
    def listFiles(self) -> java.chaquopy.JavaArray[File] | None: ...
    @typing.overload
    def listFiles(self, filter: FileFilter, /) -> java.chaquopy.JavaArray[File] | None: ...
    @typing.overload
    def listFiles(self, filter: FilenameFilter, /) -> java.chaquopy.JavaArray[File] | None: ...
    @staticmethod
    def listRoots() -> java.chaquopy.JavaArray[File]: ...
    def mkdir(self) -> bool: ...
    def mkdirs(self) -> bool: ...
    def renameTo(self, dest: File, /) -> bool: ...
    @typing.overload
    def setExecutable(self, executable: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def setExecutable(self, executable: bool | java.jboolean | java.lang.Boolean, ownerOnly: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def setLastModified(self, time: int | java.jlong | java.lang.Long, /) -> bool: ...
    def setReadOnly(self) -> bool: ...
    @typing.overload
    def setReadable(self, readable: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def setReadable(self, readable: bool | java.jboolean | java.lang.Boolean, ownerOnly: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def setWritable(self, writable: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def setWritable(self, writable: bool | java.jboolean | java.lang.Boolean, ownerOnly: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def toPath(self) -> java.nio.file.Path: ...
    def toString(self) -> str: ...
    def toURI(self) -> java.net.URI: ...
    def toURL(self) -> java.net.URL: ...

class FileDescriptor(java.lang.Object):
    err: typing.ClassVar[FileDescriptor] = ...
    in_: typing.ClassVar[FileDescriptor] = ...
    out: typing.ClassVar[FileDescriptor] = ...
    def __init__(self) -> None: ...
    def sync(self) -> None: ...
    def valid(self) -> bool: ...

class FileFilter(java.lang.Object):
    def accept(self, arg1: File, /) -> bool: ...

class FileInputStream(InputStream):
    @typing.overload
    def __init__(self, file: File, /) -> None: ...
    @typing.overload
    def __init__(self, fdObj: FileDescriptor, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getChannel(self) -> java.nio.channels.FileChannel: ...
    def getFD(self) -> FileDescriptor: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class FileNotFoundException(IOException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class FileOutputStream(OutputStream):
    @typing.overload
    def __init__(self, file: File, /) -> None: ...
    @typing.overload
    def __init__(self, fdObj: FileDescriptor, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, append: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, append: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getChannel(self) -> java.nio.channels.FileChannel: ...
    def getFD(self) -> FileDescriptor: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class FilePermission(Serializable, java.security.Permission):
    def __init__(self, path: str | java.lang.String, actions: str | java.lang.String, /) -> None: ...
    def getActions(self) -> str: ...
    def implies(self, p: java.security.Permission, /) -> bool: ...

class FileReader(InputStreamReader):
    @typing.overload
    def __init__(self, file: File, /) -> None: ...
    @typing.overload
    def __init__(self, fd: FileDescriptor, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, charset: java.nio.charset.Charset, /) -> None: ...

class FileWriter(OutputStreamWriter):
    @typing.overload
    def __init__(self, file: File, /) -> None: ...
    @typing.overload
    def __init__(self, fd: FileDescriptor, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, append: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, append: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, charset: java.nio.charset.Charset, append: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, charset: java.nio.charset.Charset, append: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class FilenameFilter(java.lang.Object):
    def accept(self, arg1: File, arg2: str | java.lang.String, /) -> bool: ...

class FilterInputStream(InputStream):
    in_: InputStream = ...
    def __init__(self, in_: InputStream, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class FilterOutputStream(OutputStream):
    out: OutputStream = ...
    def __init__(self, out: OutputStream, /) -> None: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class FilterReader(Reader):
    in_: Reader = ...
    def __init__(self, in_: Reader, /) -> None: ...
    def close(self) -> None: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def ready(self) -> bool: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class FilterWriter(Writer):
    out: Writer = ...
    def __init__(self, out: Writer, /) -> None: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, str: str | java.lang.String, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class Flushable(java.lang.Object):
    def flush(self) -> None: ...

class IOError(java.lang.Error):
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...

class IOException(java.lang.Exception):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class InputStream(Closeable):
    def __init__(self) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @staticmethod
    def nullInputStream() -> InputStream: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def readAllBytes(self) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def readNBytes(self, len: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def readNBytes(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...
    def skipNBytes(self, n: int | java.jlong | java.lang.Long, /) -> None: ...
    def transferTo(self, out: OutputStream, /) -> int: ...

class InputStreamReader(Reader):
    @typing.overload
    def __init__(self, in_: InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, in_: InputStream, charsetName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, in_: InputStream, cs: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, in_: InputStream, dec: java.nio.charset.CharsetDecoder, /) -> None: ...
    def close(self) -> None: ...
    def getEncoding(self) -> str: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, target: java.nio.CharBuffer, /) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def ready(self) -> bool: ...

class InterruptedIOException(IOException):
    bytesTransferred: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class InvalidClassException(ObjectStreamException):
    classname: str = ...
    @typing.overload
    def __init__(self, reason: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cname: str | java.lang.String, reason: str | java.lang.String, /) -> None: ...
    def getMessage(self) -> str: ...

class InvalidObjectException(ObjectStreamException):
    def __init__(self, reason: str | java.lang.String, /) -> None: ...

class LineNumberInputStream(FilterInputStream):
    def __init__(self, in_: InputStream, /) -> None: ...
    def available(self) -> int: ...
    def getLineNumber(self) -> int: ...
    def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def setLineNumber(self, lineNumber: int | java.jint | java.lang.Integer, /) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class LineNumberReader(BufferedReader):
    @typing.overload
    def __init__(self, in_: Reader, /) -> None: ...
    @typing.overload
    def __init__(self, in_: Reader, sz: int | java.jint | java.lang.Integer, /) -> None: ...
    def getLineNumber(self) -> int: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def readLine(self) -> str: ...
    def reset(self) -> None: ...
    def setLineNumber(self, lineNumber: int | java.jint | java.lang.Integer, /) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class NotActiveException(ObjectStreamException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, reason: str | java.lang.String, /) -> None: ...

class NotSerializableException(ObjectStreamException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, classname: str | java.lang.String, /) -> None: ...

class ObjectInput(DataInput, java.lang.AutoCloseable):
    def available(self) -> int: ...
    def close(self) -> None: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, arg1: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def read(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...
    def readObject(self) -> java.lang.Object: ...
    def skip(self, arg1: int | java.jlong | java.lang.Long, /) -> int: ...

class ObjectInputStream(InputStream, ObjectInput, ObjectStreamConstants):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, in_: InputStream, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def defaultReadObject(self) -> None: ...
    def enableResolveObject(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, buf: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def readBoolean(self) -> bool: ...
    def readByte(self) -> int: ...
    def readChar(self) -> str: ...
    def readClassDescriptor(self) -> ObjectStreamClass: ...
    def readDouble(self) -> float: ...
    def readFields(self) -> ObjectInputStream.GetField: ...
    def readFloat(self) -> float: ...
    @typing.overload
    def readFully(self, buf: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def readFully(self, buf: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def readInt(self) -> int: ...
    def readLine(self) -> str: ...
    def readLong(self) -> int: ...
    def readObject(self) -> java.lang.Object: ...
    def readObjectOverride(self) -> java.lang.Object: ...
    def readShort(self) -> int: ...
    def readStreamHeader(self) -> None: ...
    def readUTF(self) -> str: ...
    def readUnshared(self) -> java.lang.Object: ...
    def readUnsignedByte(self) -> int: ...
    def readUnsignedShort(self) -> int: ...
    def registerValidation(self, obj: ObjectInputValidation, prio: int | java.jint | java.lang.Integer, /) -> None: ...
    def resolveClass(self, desc: ObjectStreamClass, /) -> typing.Type[java.lang.Object]: ...
    def resolveObject(self, obj: java.lang.Object | int | bool | float | str, /) -> java.lang.Object: ...
    def resolveProxyClass(self, interfaces: java.chaquopy.JavaArray[java.lang.String], /) -> typing.Type[java.lang.Object]: ...
    def skipBytes(self, len: int | java.jint | java.lang.Integer, /) -> int: ...

    class GetField(java.lang.Object):
        def __init__(self) -> None: ...
        def defaulted(self, arg1: str | java.lang.String, /) -> bool: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: int | java.jbyte | java.lang.Byte, /) -> int: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: str | java.jchar | java.lang.Character, /) -> str: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: float | java.jdouble | java.lang.Double, /) -> float: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: float | java.jfloat | java.lang.Float, /) -> float: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: int | java.jlong | java.lang.Long, /) -> int: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> java.lang.Object: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: int | java.jshort | java.lang.Short, /) -> int: ...
        @typing.overload
        def get(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
        def getObjectStreamClass(self) -> ObjectStreamClass: ...

class ObjectInputValidation(java.lang.Object):
    def validateObject(self) -> None: ...

class ObjectOutput(DataOutput, java.lang.AutoCloseable):
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeObject(self, arg1: java.lang.Object | int | bool | float | str, /) -> None: ...

class ObjectOutputStream(ObjectOutput, ObjectStreamConstants, OutputStream):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, /) -> None: ...
    def annotateClass(self, cl: typing.Type[java.lang.Object], /) -> None: ...
    def annotateProxyClass(self, cl: typing.Type[java.lang.Object], /) -> None: ...
    def close(self) -> None: ...
    def defaultWriteObject(self) -> None: ...
    def drain(self) -> None: ...
    def enableReplaceObject(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def flush(self) -> None: ...
    def putFields(self) -> ObjectOutputStream.PutField: ...
    def replaceObject(self, obj: java.lang.Object | int | bool | float | str, /) -> java.lang.Object: ...
    def reset(self) -> None: ...
    def useProtocolVersion(self, version: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, val: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, buf: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, buf: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBoolean(self, val: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def writeByte(self, val: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBytes(self, str: str | java.lang.String, /) -> None: ...
    def writeChar(self, val: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeChars(self, str: str | java.lang.String, /) -> None: ...
    def writeClassDescriptor(self, desc: ObjectStreamClass, /) -> None: ...
    def writeDouble(self, val: float | java.jdouble | java.lang.Double, /) -> None: ...
    def writeFields(self) -> None: ...
    def writeFloat(self, val: float | java.jfloat | java.lang.Float, /) -> None: ...
    def writeInt(self, val: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeLong(self, val: int | java.jlong | java.lang.Long, /) -> None: ...
    def writeObject(self, obj: java.lang.Object | int | bool | float | str, /) -> None: ...
    def writeObjectOverride(self, obj: java.lang.Object | int | bool | float | str, /) -> None: ...
    def writeShort(self, val: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeStreamHeader(self) -> None: ...
    def writeUTF(self, str: str | java.lang.String, /) -> None: ...
    def writeUnshared(self, obj: java.lang.Object | int | bool | float | str, /) -> None: ...

    class PutField(java.lang.Object):
        def __init__(self) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: int | java.jbyte | java.lang.Byte, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: str | java.jchar | java.lang.Character, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: float | java.jdouble | java.lang.Double, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: int | java.jlong | java.lang.Long, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: int | java.jshort | java.lang.Short, /) -> None: ...
        @typing.overload
        def put(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def write(self, arg1: ObjectOutput, /) -> None: ...

class ObjectStreamClass(Serializable):
    NO_FIELDS: typing.ClassVar[java.chaquopy.JavaArray[ObjectStreamField]] = ...
    def forClass(self) -> typing.Type[java.lang.Object]: ...
    def getField(self, name: str | java.lang.String, /) -> ObjectStreamField: ...
    def getFields(self) -> java.chaquopy.JavaArray[ObjectStreamField]: ...
    def getName(self) -> str: ...
    def getSerialVersionUID(self) -> int: ...
    @staticmethod
    def lookup(cl: typing.Type[java.lang.Object], /) -> ObjectStreamClass: ...
    @staticmethod
    def lookupAny(cl: typing.Type[java.lang.Object], /) -> ObjectStreamClass: ...
    def toString(self) -> str: ...

class ObjectStreamConstants(java.lang.Object):
    PROTOCOL_VERSION_1: typing.ClassVar[int] = ...
    PROTOCOL_VERSION_2: typing.ClassVar[int] = ...
    SC_BLOCK_DATA: typing.ClassVar[int] = ...
    SC_ENUM: typing.ClassVar[int] = ...
    SC_EXTERNALIZABLE: typing.ClassVar[int] = ...
    SC_SERIALIZABLE: typing.ClassVar[int] = ...
    SC_WRITE_METHOD: typing.ClassVar[int] = ...
    STREAM_MAGIC: typing.ClassVar[int] = ...
    STREAM_VERSION: typing.ClassVar[int] = ...
    SUBCLASS_IMPLEMENTATION_PERMISSION: typing.ClassVar[SerializablePermission] = ...
    SUBSTITUTION_PERMISSION: typing.ClassVar[SerializablePermission] = ...
    TC_ARRAY: typing.ClassVar[int] = ...
    TC_BASE: typing.ClassVar[int] = ...
    TC_BLOCKDATA: typing.ClassVar[int] = ...
    TC_BLOCKDATALONG: typing.ClassVar[int] = ...
    TC_CLASS: typing.ClassVar[int] = ...
    TC_CLASSDESC: typing.ClassVar[int] = ...
    TC_ENDBLOCKDATA: typing.ClassVar[int] = ...
    TC_ENUM: typing.ClassVar[int] = ...
    TC_EXCEPTION: typing.ClassVar[int] = ...
    TC_LONGSTRING: typing.ClassVar[int] = ...
    TC_MAX: typing.ClassVar[int] = ...
    TC_NULL: typing.ClassVar[int] = ...
    TC_OBJECT: typing.ClassVar[int] = ...
    TC_PROXYCLASSDESC: typing.ClassVar[int] = ...
    TC_REFERENCE: typing.ClassVar[int] = ...
    TC_RESET: typing.ClassVar[int] = ...
    TC_STRING: typing.ClassVar[int] = ...
    baseWireHandle: typing.ClassVar[int] = ...

class ObjectStreamException(IOException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...

class ObjectStreamField(java.lang.Comparable[java.lang.Object]):
    @typing.overload
    def __init__(self, name: str | java.lang.String, type: typing.Type[java.lang.Object], /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, type: typing.Type[java.lang.Object], unshared: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def compareTo(self, obj: java.lang.Object | int | bool | float | str, /) -> int: ...
    def getName(self) -> str: ...
    def getOffset(self) -> int: ...
    def getType(self) -> typing.Type[java.lang.Object]: ...
    def getTypeCode(self) -> str: ...
    def getTypeString(self) -> str: ...
    def isPrimitive(self) -> bool: ...
    def isUnshared(self) -> bool: ...
    def setOffset(self, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...

class OptionalDataException(ObjectStreamException):
    eof: bool = ...
    length: int = ...

class OutputStream(Closeable, Flushable):
    def __init__(self) -> None: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @staticmethod
    def nullOutputStream() -> OutputStream: ...
    @typing.overload
    def write(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class OutputStreamWriter(Writer):
    @typing.overload
    def __init__(self, out: OutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, charsetName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, cs: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, enc: java.nio.charset.CharsetEncoder, /) -> None: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, /) -> Writer: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> Writer: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    def getEncoding(self) -> str: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, str: str | java.lang.String, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class PipedInputStream(InputStream):
    PIPE_SIZE: typing.ClassVar[int] = ...
    buffer: java.chaquopy.JavaArrayJByte = ...
    in_: int = ...
    out: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, pipeSize: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, src: PipedOutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, src: PipedOutputStream, pipeSize: int | java.jint | java.lang.Integer, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def connect(self, src: PipedOutputStream, /) -> None: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def receive(self, b: int | java.jint | java.lang.Integer, /) -> None: ...

class PipedOutputStream(OutputStream):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, snk: PipedInputStream, /) -> None: ...
    def close(self) -> None: ...
    def connect(self, snk: PipedInputStream, /) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class PipedReader(Reader):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, pipeSize: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, src: PipedWriter, /) -> None: ...
    @typing.overload
    def __init__(self, src: PipedWriter, pipeSize: int | java.jint | java.lang.Integer, /) -> None: ...
    def close(self) -> None: ...
    def connect(self, src: PipedWriter, /) -> None: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def ready(self) -> bool: ...

class PipedWriter(Writer):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, snk: PipedReader, /) -> None: ...
    def close(self) -> None: ...
    def connect(self, snk: PipedReader, /) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class PrintStream(FilterOutputStream, Closeable, java.lang.Appendable):
    @typing.overload
    def __init__(self, file: File, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, csn: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, autoFlush: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, csn: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, autoFlush: bool | java.jboolean | java.lang.Boolean, encoding: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, autoFlush: bool | java.jboolean | java.lang.Boolean, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def append(self, c: str | java.jchar | java.lang.Character, /) -> PrintStream: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, /) -> PrintStream: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> PrintStream: ...
    def checkError(self) -> bool: ...
    def clearError(self) -> None: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def format(self, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintStream: ...
    @typing.overload
    def format(self, l: java.util.Locale, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintStream: ...
    @typing.overload
    def print_(self, c: str | java.jchar | java.lang.Character, /) -> None: ...
    @typing.overload
    def print_(self, d: float | java.jdouble | java.lang.Double, /) -> None: ...
    @typing.overload
    def print_(self, f: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def print_(self, i: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def print_(self, l: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def print_(self, obj: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def print_(self, s: str | java.lang.String, /) -> None: ...
    @typing.overload
    def print_(self, b: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def print_(self, s: java.chaquopy.JavaArrayJChar, /) -> None: ...
    @typing.overload
    def printf(self, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintStream: ...
    @typing.overload
    def printf(self, l: java.util.Locale, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintStream: ...
    @typing.overload
    def println(self) -> None: ...
    @typing.overload
    def println(self, x: str | java.jchar | java.lang.Character, /) -> None: ...
    @typing.overload
    def println(self, x: float | java.jdouble | java.lang.Double, /) -> None: ...
    @typing.overload
    def println(self, x: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def println(self, x: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def println(self, x: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def println(self, x: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def println(self, x: str | java.lang.String, /) -> None: ...
    @typing.overload
    def println(self, x: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def println(self, x: java.chaquopy.JavaArrayJChar, /) -> None: ...
    def setError(self) -> None: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, buf: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, buf: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBytes(self, buf: java.chaquopy.JavaArrayJByte, /) -> None: ...

class PrintWriter(Writer):
    out: Writer = ...
    @typing.overload
    def __init__(self, file: File, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, out: Writer, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, csn: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, file: File, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, autoFlush: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, out: Writer, autoFlush: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, csn: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, fileName: str | java.lang.String, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def __init__(self, out: OutputStream, autoFlush: bool | java.jboolean | java.lang.Boolean, charset: java.nio.charset.Charset, /) -> None: ...
    @typing.overload
    def append(self, c: str | java.jchar | java.lang.Character, /) -> PrintWriter: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, /) -> PrintWriter: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> PrintWriter: ...
    def checkError(self) -> bool: ...
    def clearError(self) -> None: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def format(self, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintWriter: ...
    @typing.overload
    def format(self, l: java.util.Locale, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintWriter: ...
    @typing.overload
    def print_(self, c: str | java.jchar | java.lang.Character, /) -> None: ...
    @typing.overload
    def print_(self, d: float | java.jdouble | java.lang.Double, /) -> None: ...
    @typing.overload
    def print_(self, f: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def print_(self, i: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def print_(self, l: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def print_(self, obj: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def print_(self, s: str | java.lang.String, /) -> None: ...
    @typing.overload
    def print_(self, b: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def print_(self, s: java.chaquopy.JavaArrayJChar, /) -> None: ...
    @typing.overload
    def printf(self, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintWriter: ...
    @typing.overload
    def printf(self, l: java.util.Locale, format: str | java.lang.String, /, *args: java.lang.Object) -> PrintWriter: ...
    @typing.overload
    def println(self) -> None: ...
    @typing.overload
    def println(self, x: str | java.jchar | java.lang.Character, /) -> None: ...
    @typing.overload
    def println(self, x: float | java.jdouble | java.lang.Double, /) -> None: ...
    @typing.overload
    def println(self, x: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def println(self, x: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def println(self, x: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def println(self, x: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def println(self, x: str | java.lang.String, /) -> None: ...
    @typing.overload
    def println(self, x: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def println(self, x: java.chaquopy.JavaArrayJChar, /) -> None: ...
    def setError(self) -> None: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, s: str | java.lang.String, /) -> None: ...
    @typing.overload
    def write(self, buf: java.chaquopy.JavaArrayJChar, /) -> None: ...
    @typing.overload
    def write(self, s: str | java.lang.String, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, buf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class PushbackInputStream(FilterInputStream):
    buf: java.chaquopy.JavaArrayJByte = ...
    pos: int = ...
    @typing.overload
    def __init__(self, in_: InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, in_: InputStream, size: int | java.jint | java.lang.Integer, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    def unread(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def unread(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def unread(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class PushbackReader(FilterReader):
    @typing.overload
    def __init__(self, in_: Reader, /) -> None: ...
    @typing.overload
    def __init__(self, in_: Reader, size: int | java.jint | java.lang.Integer, /) -> None: ...
    def close(self) -> None: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def ready(self) -> bool: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    def unread(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def unread(self, cbuf: java.chaquopy.JavaArrayJChar, /) -> None: ...
    @typing.overload
    def unread(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class RandomAccessFile(Closeable, DataInput, DataOutput):
    @typing.overload
    def __init__(self, file: File, mode: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, mode: str | java.lang.String, /) -> None: ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getChannel(self) -> java.nio.channels.FileChannel: ...
    def getFD(self) -> FileDescriptor: ...
    def getFilePointer(self) -> int: ...
    def length(self) -> int: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def readBoolean(self) -> bool: ...
    def readByte(self) -> int: ...
    def readChar(self) -> str: ...
    def readDouble(self) -> float: ...
    def readFloat(self) -> float: ...
    @typing.overload
    def readFully(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def readFully(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def readInt(self) -> int: ...
    def readLine(self) -> str: ...
    def readLong(self) -> int: ...
    def readShort(self) -> int: ...
    def readUTF(self) -> str: ...
    def readUnsignedByte(self) -> int: ...
    def readUnsignedShort(self) -> int: ...
    def seek(self, pos: int | java.jlong | java.lang.Long, /) -> None: ...
    def setLength(self, newLength: int | java.jlong | java.lang.Long, /) -> None: ...
    def skipBytes(self, n: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBoolean(self, v: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def writeByte(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeBytes(self, s: str | java.lang.String, /) -> None: ...
    def writeChar(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeChars(self, s: str | java.lang.String, /) -> None: ...
    def writeDouble(self, v: float | java.jdouble | java.lang.Double, /) -> None: ...
    def writeFloat(self, v: float | java.jfloat | java.lang.Float, /) -> None: ...
    def writeInt(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeLong(self, v: int | java.jlong | java.lang.Long, /) -> None: ...
    def writeShort(self, v: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeUTF(self, str: str | java.lang.String, /) -> None: ...

class Reader(Closeable, java.lang.Readable):
    lock: java.lang.Object = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, lock: java.lang.Object | int | bool | float | str, /) -> None: ...
    def close(self) -> None: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @staticmethod
    def nullReader() -> Reader: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, target: java.nio.CharBuffer, /) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, /) -> int: ...
    @typing.overload
    def read(self, arg1: java.chaquopy.JavaArrayJChar, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...
    def ready(self) -> bool: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...
    def transferTo(self, out: Writer, /) -> int: ...

class SequenceInputStream(InputStream):
    @typing.overload
    def __init__(self, e: java.util.Enumeration[InputStream], /) -> None: ...
    @typing.overload
    def __init__(self, s1: InputStream, s2: InputStream, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...

class Serial(java.lang.annotation.Annotation): ...

class Serializable(java.lang.Object): ...

class SerializablePermission(java.security.BasicPermission):
    @typing.overload
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, actions: str | java.lang.String, /) -> None: ...

class StreamCorruptedException(ObjectStreamException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, reason: str | java.lang.String, /) -> None: ...

class StreamTokenizer(java.lang.Object):
    TT_EOF: typing.ClassVar[int] = ...
    TT_EOL: typing.ClassVar[int] = ...
    TT_NUMBER: typing.ClassVar[int] = ...
    TT_WORD: typing.ClassVar[int] = ...
    nval: float = ...
    sval: str = ...
    ttype: int = ...
    @typing.overload
    def __init__(self, is_: InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, r: Reader, /) -> None: ...
    def commentChar(self, ch: int | java.jint | java.lang.Integer, /) -> None: ...
    def eolIsSignificant(self, flag: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def lineno(self) -> int: ...
    def lowerCaseMode(self, fl: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def nextToken(self) -> int: ...
    def ordinaryChar(self, ch: int | java.jint | java.lang.Integer, /) -> None: ...
    def ordinaryChars(self, low: int | java.jint | java.lang.Integer, hi: int | java.jint | java.lang.Integer, /) -> None: ...
    def parseNumbers(self) -> None: ...
    def pushBack(self) -> None: ...
    def quoteChar(self, ch: int | java.jint | java.lang.Integer, /) -> None: ...
    def resetSyntax(self) -> None: ...
    def slashSlashComments(self, flag: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def slashStarComments(self, flag: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def toString(self) -> str: ...
    def whitespaceChars(self, low: int | java.jint | java.lang.Integer, hi: int | java.jint | java.lang.Integer, /) -> None: ...
    def wordChars(self, low: int | java.jint | java.lang.Integer, hi: int | java.jint | java.lang.Integer, /) -> None: ...

class StringBufferInputStream(InputStream):
    buffer: str = ...
    count: int = ...
    pos: int = ...
    def __init__(self, s: str | java.lang.String, /) -> None: ...
    def available(self) -> int: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class StringReader(Reader):
    def __init__(self, s: str | java.lang.String, /) -> None: ...
    def close(self) -> None: ...
    def mark(self, readAheadLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def ready(self) -> bool: ...
    def reset(self) -> None: ...
    def skip(self, ns: int | java.jlong | java.lang.Long, /) -> int: ...

class StringWriter(Writer):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, initialSize: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def append(self, c: str | java.jchar | java.lang.Character, /) -> StringWriter: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, /) -> StringWriter: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> StringWriter: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    def getBuffer(self) -> java.lang.StringBuffer: ...
    def toString(self) -> str: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, str: str | java.lang.String, /) -> None: ...
    @typing.overload
    def write(self, str: str | java.lang.String, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, cbuf: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class SyncFailedException(IOException):
    def __init__(self, desc: str | java.lang.String, /) -> None: ...

class UTFDataFormatException(IOException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class UncheckedIOException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self, cause: IOException, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: IOException, /) -> None: ...
    def getCause(self) -> IOException: ...

class UnsupportedEncodingException(IOException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...

class WriteAbortedException(ObjectStreamException):
    detail: java.lang.Exception = ...
    def __init__(self, s: str | java.lang.String, ex: java.lang.Exception, /) -> None: ...
    def getCause(self) -> java.lang.Throwable: ...
    def getMessage(self) -> str: ...

class Writer(Closeable, Flushable, java.lang.Appendable):
    lock: java.lang.Object = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, lock: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def append(self, c: str | java.jchar | java.lang.Character, /) -> Writer: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, /) -> Writer: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> Writer: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @staticmethod
    def nullWriter() -> Writer: ...
    @typing.overload
    def write(self, c: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, str: str | java.lang.String, /) -> None: ...
    @typing.overload
    def write(self, cbuf: java.chaquopy.JavaArrayJChar, /) -> None: ...
    @typing.overload
    def write(self, str: str | java.lang.String, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, arg1: java.chaquopy.JavaArrayJChar, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
