import typing

import android.content
import android.os
import java
import java.lang
import java.util.concurrent

class AppSetId(java.lang.Object):
    SCOPE_APP: typing.ClassVar[int] = ...
    SCOPE_DEVELOPER: typing.ClassVar[int] = ...
    def __init__(self, appSetId: str | java.lang.String, appSetIdScope: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getId(self) -> str: ...
    def getScope(self) -> int: ...
    def hashCode(self) -> int: ...

class AppSetIdManager(java.lang.Object):
    @staticmethod
    def get(context: android.content.Context, /) -> AppSetIdManager: ...
    def getAppSetId(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[AppSetId, java.lang.Exception], /) -> None: ...
