import typing

import android.app
import android.content
import android.os
import android.view.textservice
import java
import java.chaquopy
import java.lang

class SpellCheckerService(android.app.Service):
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def createSession(self) -> SpellCheckerService.Session: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...

    class Session(java.lang.Object):
        def __init__(self) -> None: ...
        def getBundle(self) -> android.os.Bundle: ...
        def getLocale(self) -> str: ...
        def getSupportedAttributes(self) -> int: ...
        def onCancel(self) -> None: ...
        def onClose(self) -> None: ...
        def onCreate(self) -> None: ...
        def onGetSentenceSuggestionsMultiple(self, textInfos: java.chaquopy.JavaArray[android.view.textservice.TextInfo], suggestionsLimit: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[android.view.textservice.SentenceSuggestionsInfo]: ...
        def onGetSuggestions(self, arg1: android.view.textservice.TextInfo, arg2: int | java.jint | java.lang.Integer, /) -> android.view.textservice.SuggestionsInfo: ...
        def onGetSuggestionsMultiple(self, textInfos: java.chaquopy.JavaArray[android.view.textservice.TextInfo], suggestionsLimit: int | java.jint | java.lang.Integer, sequentialWords: bool | java.jboolean | java.lang.Boolean, /) -> java.chaquopy.JavaArray[android.view.textservice.SuggestionsInfo]: ...
