import typing

import java.lang

class XMLConstants(java.lang.Object):
    DEFAULT_NS_PREFIX: typing.ClassVar[str] = ...
    FEATURE_SECURE_PROCESSING: typing.ClassVar[str] = ...
    NULL_NS_URI: typing.ClassVar[str] = ...
    RELAXNG_NS_URI: typing.ClassVar[str] = ...
    W3C_XML_SCHEMA_INSTANCE_NS_URI: typing.ClassVar[str] = ...
    W3C_XML_SCHEMA_NS_URI: typing.ClassVar[str] = ...
    W3C_XPATH_DATATYPE_NS_URI: typing.ClassVar[str] = ...
    XMLNS_ATTRIBUTE: typing.ClassVar[str] = ...
    XMLNS_ATTRIBUTE_NS_URI: typing.ClassVar[str] = ...
    XML_DTD_NS_URI: typing.ClassVar[str] = ...
    XML_NS_PREFIX: typing.ClassVar[str] = ...
    XML_NS_URI: typing.ClassVar[str] = ...
