import android.content
import android.net
import android.os
import java.lang
import java.util.concurrent

class ProtectedSignalsManager(java.lang.Object):
    @staticmethod
    def get(context: android.content.Context, /) -> ProtectedSignalsManager: ...
    def updateSignals(self, updateSignalsRequest: UpdateSignalsRequest, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...

class UpdateSignalsRequest(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getUpdateUri(self) -> android.net.Uri: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

    class Builder(java.lang.Object):
        def __init__(self, updateUri: android.net.Uri, /) -> None: ...
        def build(self) -> UpdateSignalsRequest: ...
        def setUpdateUri(self, updateUri: android.net.Uri, /) -> UpdateSignalsRequest.Builder: ...
