import typing

import android.graphics
import android.net
import android.os
import java
import java.lang
import java.util

class PdfPageGotoLinkContent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PdfPageGotoLinkContent]] = ...
    def __init__(self, bounds: java.util.List[android.graphics.RectF], destination: PdfPageGotoLinkContent.Destination, /) -> None: ...
    def describeContents(self) -> int: ...
    def getBounds(self) -> java.util.List[android.graphics.RectF]: ...
    def getDestination(self) -> PdfPageGotoLinkContent.Destination: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Destination(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PdfPageGotoLinkContent.Destination]] = ...
        def __init__(self, pageNumber: int | java.jint | java.lang.Integer, xCoordinate: float | java.jfloat | java.lang.Float, yCoordinate: float | java.jfloat | java.lang.Float, zoom: float | java.jfloat | java.lang.Float, /) -> None: ...
        def describeContents(self) -> int: ...
        def getPageNumber(self) -> int: ...
        def getXCoordinate(self) -> float: ...
        def getYCoordinate(self) -> float: ...
        def getZoom(self) -> float: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PdfPageImageContent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PdfPageImageContent]] = ...
    def __init__(self, altText: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getAltText(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PdfPageLinkContent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PdfPageLinkContent]] = ...
    def __init__(self, bounds: java.util.List[android.graphics.RectF], uri: android.net.Uri, /) -> None: ...
    def describeContents(self) -> int: ...
    def getBounds(self) -> java.util.List[android.graphics.RectF]: ...
    def getUri(self) -> android.net.Uri: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PdfPageTextContent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PdfPageTextContent]] = ...
    @typing.overload
    def __init__(self, text: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, text: str | java.lang.String, bounds: java.util.List[android.graphics.RectF], /) -> None: ...
    def describeContents(self) -> int: ...
    def getBounds(self) -> java.util.List[android.graphics.RectF]: ...
    def getText(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...
