import typing

import java.lang

class OpcodeInfo(java.lang.Object):
    MAXIMUM_PACKED_VALUE: typing.ClassVar[int] = ...
    MAXIMUM_VALUE: typing.ClassVar[int] = ...

class Opcodes(java.lang.Object):
    OP_ADD_DOUBLE: typing.ClassVar[int] = ...
    OP_ADD_DOUBLE_2ADDR: typing.ClassVar[int] = ...
    OP_ADD_FLOAT: typing.ClassVar[int] = ...
    OP_ADD_FLOAT_2ADDR: typing.ClassVar[int] = ...
    OP_ADD_INT: typing.ClassVar[int] = ...
    OP_ADD_INT_2ADDR: typing.ClassVar[int] = ...
    OP_ADD_INT_LIT16: typing.ClassVar[int] = ...
    OP_ADD_INT_LIT8: typing.ClassVar[int] = ...
    OP_ADD_LONG: typing.ClassVar[int] = ...
    OP_ADD_LONG_2ADDR: typing.ClassVar[int] = ...
    OP_AGET: typing.ClassVar[int] = ...
    OP_AGET_BOOLEAN: typing.ClassVar[int] = ...
    OP_AGET_BYTE: typing.ClassVar[int] = ...
    OP_AGET_CHAR: typing.ClassVar[int] = ...
    OP_AGET_OBJECT: typing.ClassVar[int] = ...
    OP_AGET_SHORT: typing.ClassVar[int] = ...
    OP_AGET_WIDE: typing.ClassVar[int] = ...
    OP_AND_INT: typing.ClassVar[int] = ...
    OP_AND_INT_2ADDR: typing.ClassVar[int] = ...
    OP_AND_INT_LIT16: typing.ClassVar[int] = ...
    OP_AND_INT_LIT8: typing.ClassVar[int] = ...
    OP_AND_LONG: typing.ClassVar[int] = ...
    OP_AND_LONG_2ADDR: typing.ClassVar[int] = ...
    OP_APUT: typing.ClassVar[int] = ...
    OP_APUT_BOOLEAN: typing.ClassVar[int] = ...
    OP_APUT_BYTE: typing.ClassVar[int] = ...
    OP_APUT_CHAR: typing.ClassVar[int] = ...
    OP_APUT_OBJECT: typing.ClassVar[int] = ...
    OP_APUT_SHORT: typing.ClassVar[int] = ...
    OP_APUT_WIDE: typing.ClassVar[int] = ...
    OP_ARRAY_LENGTH: typing.ClassVar[int] = ...
    OP_BREAKPOINT: typing.ClassVar[int] = ...
    OP_CHECK_CAST: typing.ClassVar[int] = ...
    OP_CHECK_CAST_JUMBO: typing.ClassVar[int] = ...
    OP_CMPG_DOUBLE: typing.ClassVar[int] = ...
    OP_CMPG_FLOAT: typing.ClassVar[int] = ...
    OP_CMPL_DOUBLE: typing.ClassVar[int] = ...
    OP_CMPL_FLOAT: typing.ClassVar[int] = ...
    OP_CMP_LONG: typing.ClassVar[int] = ...
    OP_CONST: typing.ClassVar[int] = ...
    OP_CONST_16: typing.ClassVar[int] = ...
    OP_CONST_4: typing.ClassVar[int] = ...
    OP_CONST_CLASS: typing.ClassVar[int] = ...
    OP_CONST_CLASS_JUMBO: typing.ClassVar[int] = ...
    OP_CONST_HIGH16: typing.ClassVar[int] = ...
    OP_CONST_METHOD_HANDLE: typing.ClassVar[int] = ...
    OP_CONST_METHOD_TYPE: typing.ClassVar[int] = ...
    OP_CONST_STRING: typing.ClassVar[int] = ...
    OP_CONST_STRING_JUMBO: typing.ClassVar[int] = ...
    OP_CONST_WIDE: typing.ClassVar[int] = ...
    OP_CONST_WIDE_16: typing.ClassVar[int] = ...
    OP_CONST_WIDE_32: typing.ClassVar[int] = ...
    OP_CONST_WIDE_HIGH16: typing.ClassVar[int] = ...
    OP_DIV_DOUBLE: typing.ClassVar[int] = ...
    OP_DIV_DOUBLE_2ADDR: typing.ClassVar[int] = ...
    OP_DIV_FLOAT: typing.ClassVar[int] = ...
    OP_DIV_FLOAT_2ADDR: typing.ClassVar[int] = ...
    OP_DIV_INT: typing.ClassVar[int] = ...
    OP_DIV_INT_2ADDR: typing.ClassVar[int] = ...
    OP_DIV_INT_LIT16: typing.ClassVar[int] = ...
    OP_DIV_INT_LIT8: typing.ClassVar[int] = ...
    OP_DIV_LONG: typing.ClassVar[int] = ...
    OP_DIV_LONG_2ADDR: typing.ClassVar[int] = ...
    OP_DOUBLE_TO_FLOAT: typing.ClassVar[int] = ...
    OP_DOUBLE_TO_INT: typing.ClassVar[int] = ...
    OP_DOUBLE_TO_LONG: typing.ClassVar[int] = ...
    OP_EXECUTE_INLINE: typing.ClassVar[int] = ...
    OP_EXECUTE_INLINE_RANGE: typing.ClassVar[int] = ...
    OP_FILLED_NEW_ARRAY: typing.ClassVar[int] = ...
    OP_FILLED_NEW_ARRAY_JUMBO: typing.ClassVar[int] = ...
    OP_FILLED_NEW_ARRAY_RANGE: typing.ClassVar[int] = ...
    OP_FILL_ARRAY_DATA: typing.ClassVar[int] = ...
    OP_FLOAT_TO_DOUBLE: typing.ClassVar[int] = ...
    OP_FLOAT_TO_INT: typing.ClassVar[int] = ...
    OP_FLOAT_TO_LONG: typing.ClassVar[int] = ...
    OP_GOTO: typing.ClassVar[int] = ...
    OP_GOTO_16: typing.ClassVar[int] = ...
    OP_GOTO_32: typing.ClassVar[int] = ...
    OP_IF_EQ: typing.ClassVar[int] = ...
    OP_IF_EQZ: typing.ClassVar[int] = ...
    OP_IF_GE: typing.ClassVar[int] = ...
    OP_IF_GEZ: typing.ClassVar[int] = ...
    OP_IF_GT: typing.ClassVar[int] = ...
    OP_IF_GTZ: typing.ClassVar[int] = ...
    OP_IF_LE: typing.ClassVar[int] = ...
    OP_IF_LEZ: typing.ClassVar[int] = ...
    OP_IF_LT: typing.ClassVar[int] = ...
    OP_IF_LTZ: typing.ClassVar[int] = ...
    OP_IF_NE: typing.ClassVar[int] = ...
    OP_IF_NEZ: typing.ClassVar[int] = ...
    OP_IGET: typing.ClassVar[int] = ...
    OP_IGET_BOOLEAN: typing.ClassVar[int] = ...
    OP_IGET_BOOLEAN_JUMBO: typing.ClassVar[int] = ...
    OP_IGET_BYTE: typing.ClassVar[int] = ...
    OP_IGET_BYTE_JUMBO: typing.ClassVar[int] = ...
    OP_IGET_CHAR: typing.ClassVar[int] = ...
    OP_IGET_CHAR_JUMBO: typing.ClassVar[int] = ...
    OP_IGET_JUMBO: typing.ClassVar[int] = ...
    OP_IGET_OBJECT: typing.ClassVar[int] = ...
    OP_IGET_OBJECT_JUMBO: typing.ClassVar[int] = ...
    OP_IGET_OBJECT_QUICK: typing.ClassVar[int] = ...
    OP_IGET_QUICK: typing.ClassVar[int] = ...
    OP_IGET_SHORT: typing.ClassVar[int] = ...
    OP_IGET_SHORT_JUMBO: typing.ClassVar[int] = ...
    OP_IGET_WIDE: typing.ClassVar[int] = ...
    OP_IGET_WIDE_JUMBO: typing.ClassVar[int] = ...
    OP_IGET_WIDE_QUICK: typing.ClassVar[int] = ...
    OP_IGET_WIDE_VOLATILE: typing.ClassVar[int] = ...
    OP_INSTANCE_OF: typing.ClassVar[int] = ...
    OP_INSTANCE_OF_JUMBO: typing.ClassVar[int] = ...
    OP_INT_TO_BYTE: typing.ClassVar[int] = ...
    OP_INT_TO_CHAR: typing.ClassVar[int] = ...
    OP_INT_TO_DOUBLE: typing.ClassVar[int] = ...
    OP_INT_TO_FLOAT: typing.ClassVar[int] = ...
    OP_INT_TO_LONG: typing.ClassVar[int] = ...
    OP_INT_TO_SHORT: typing.ClassVar[int] = ...
    OP_INVOKE_CUSTOM: typing.ClassVar[int] = ...
    OP_INVOKE_CUSTOM_RANGE: typing.ClassVar[int] = ...
    OP_INVOKE_DIRECT: typing.ClassVar[int] = ...
    OP_INVOKE_DIRECT_EMPTY: typing.ClassVar[int] = ...
    OP_INVOKE_DIRECT_JUMBO: typing.ClassVar[int] = ...
    OP_INVOKE_DIRECT_RANGE: typing.ClassVar[int] = ...
    OP_INVOKE_INTERFACE: typing.ClassVar[int] = ...
    OP_INVOKE_INTERFACE_JUMBO: typing.ClassVar[int] = ...
    OP_INVOKE_INTERFACE_RANGE: typing.ClassVar[int] = ...
    OP_INVOKE_POLYMORPHIC: typing.ClassVar[int] = ...
    OP_INVOKE_POLYMORPHIC_RANGE: typing.ClassVar[int] = ...
    OP_INVOKE_STATIC: typing.ClassVar[int] = ...
    OP_INVOKE_STATIC_JUMBO: typing.ClassVar[int] = ...
    OP_INVOKE_STATIC_RANGE: typing.ClassVar[int] = ...
    OP_INVOKE_SUPER: typing.ClassVar[int] = ...
    OP_INVOKE_SUPER_JUMBO: typing.ClassVar[int] = ...
    OP_INVOKE_SUPER_QUICK: typing.ClassVar[int] = ...
    OP_INVOKE_SUPER_QUICK_RANGE: typing.ClassVar[int] = ...
    OP_INVOKE_SUPER_RANGE: typing.ClassVar[int] = ...
    OP_INVOKE_VIRTUAL: typing.ClassVar[int] = ...
    OP_INVOKE_VIRTUAL_JUMBO: typing.ClassVar[int] = ...
    OP_INVOKE_VIRTUAL_QUICK: typing.ClassVar[int] = ...
    OP_INVOKE_VIRTUAL_QUICK_RANGE: typing.ClassVar[int] = ...
    OP_INVOKE_VIRTUAL_RANGE: typing.ClassVar[int] = ...
    OP_IPUT: typing.ClassVar[int] = ...
    OP_IPUT_BOOLEAN: typing.ClassVar[int] = ...
    OP_IPUT_BOOLEAN_JUMBO: typing.ClassVar[int] = ...
    OP_IPUT_BYTE: typing.ClassVar[int] = ...
    OP_IPUT_BYTE_JUMBO: typing.ClassVar[int] = ...
    OP_IPUT_CHAR: typing.ClassVar[int] = ...
    OP_IPUT_CHAR_JUMBO: typing.ClassVar[int] = ...
    OP_IPUT_JUMBO: typing.ClassVar[int] = ...
    OP_IPUT_OBJECT: typing.ClassVar[int] = ...
    OP_IPUT_OBJECT_JUMBO: typing.ClassVar[int] = ...
    OP_IPUT_OBJECT_QUICK: typing.ClassVar[int] = ...
    OP_IPUT_QUICK: typing.ClassVar[int] = ...
    OP_IPUT_SHORT: typing.ClassVar[int] = ...
    OP_IPUT_SHORT_JUMBO: typing.ClassVar[int] = ...
    OP_IPUT_WIDE: typing.ClassVar[int] = ...
    OP_IPUT_WIDE_JUMBO: typing.ClassVar[int] = ...
    OP_IPUT_WIDE_QUICK: typing.ClassVar[int] = ...
    OP_IPUT_WIDE_VOLATILE: typing.ClassVar[int] = ...
    OP_LONG_TO_DOUBLE: typing.ClassVar[int] = ...
    OP_LONG_TO_FLOAT: typing.ClassVar[int] = ...
    OP_LONG_TO_INT: typing.ClassVar[int] = ...
    OP_MONITOR_ENTER: typing.ClassVar[int] = ...
    OP_MONITOR_EXIT: typing.ClassVar[int] = ...
    OP_MOVE: typing.ClassVar[int] = ...
    OP_MOVE_16: typing.ClassVar[int] = ...
    OP_MOVE_EXCEPTION: typing.ClassVar[int] = ...
    OP_MOVE_FROM16: typing.ClassVar[int] = ...
    OP_MOVE_OBJECT: typing.ClassVar[int] = ...
    OP_MOVE_OBJECT_16: typing.ClassVar[int] = ...
    OP_MOVE_OBJECT_FROM16: typing.ClassVar[int] = ...
    OP_MOVE_RESULT: typing.ClassVar[int] = ...
    OP_MOVE_RESULT_OBJECT: typing.ClassVar[int] = ...
    OP_MOVE_RESULT_WIDE: typing.ClassVar[int] = ...
    OP_MOVE_WIDE: typing.ClassVar[int] = ...
    OP_MOVE_WIDE_16: typing.ClassVar[int] = ...
    OP_MOVE_WIDE_FROM16: typing.ClassVar[int] = ...
    OP_MUL_DOUBLE: typing.ClassVar[int] = ...
    OP_MUL_DOUBLE_2ADDR: typing.ClassVar[int] = ...
    OP_MUL_FLOAT: typing.ClassVar[int] = ...
    OP_MUL_FLOAT_2ADDR: typing.ClassVar[int] = ...
    OP_MUL_INT: typing.ClassVar[int] = ...
    OP_MUL_INT_2ADDR: typing.ClassVar[int] = ...
    OP_MUL_INT_LIT16: typing.ClassVar[int] = ...
    OP_MUL_INT_LIT8: typing.ClassVar[int] = ...
    OP_MUL_LONG: typing.ClassVar[int] = ...
    OP_MUL_LONG_2ADDR: typing.ClassVar[int] = ...
    OP_NEG_DOUBLE: typing.ClassVar[int] = ...
    OP_NEG_FLOAT: typing.ClassVar[int] = ...
    OP_NEG_INT: typing.ClassVar[int] = ...
    OP_NEG_LONG: typing.ClassVar[int] = ...
    OP_NEW_ARRAY: typing.ClassVar[int] = ...
    OP_NEW_ARRAY_JUMBO: typing.ClassVar[int] = ...
    OP_NEW_INSTANCE: typing.ClassVar[int] = ...
    OP_NEW_INSTANCE_JUMBO: typing.ClassVar[int] = ...
    OP_NOP: typing.ClassVar[int] = ...
    OP_NOT_INT: typing.ClassVar[int] = ...
    OP_NOT_LONG: typing.ClassVar[int] = ...
    OP_OR_INT: typing.ClassVar[int] = ...
    OP_OR_INT_2ADDR: typing.ClassVar[int] = ...
    OP_OR_INT_LIT16: typing.ClassVar[int] = ...
    OP_OR_INT_LIT8: typing.ClassVar[int] = ...
    OP_OR_LONG: typing.ClassVar[int] = ...
    OP_OR_LONG_2ADDR: typing.ClassVar[int] = ...
    OP_PACKED_SWITCH: typing.ClassVar[int] = ...
    OP_REM_DOUBLE: typing.ClassVar[int] = ...
    OP_REM_DOUBLE_2ADDR: typing.ClassVar[int] = ...
    OP_REM_FLOAT: typing.ClassVar[int] = ...
    OP_REM_FLOAT_2ADDR: typing.ClassVar[int] = ...
    OP_REM_INT: typing.ClassVar[int] = ...
    OP_REM_INT_2ADDR: typing.ClassVar[int] = ...
    OP_REM_INT_LIT16: typing.ClassVar[int] = ...
    OP_REM_INT_LIT8: typing.ClassVar[int] = ...
    OP_REM_LONG: typing.ClassVar[int] = ...
    OP_REM_LONG_2ADDR: typing.ClassVar[int] = ...
    OP_RETURN: typing.ClassVar[int] = ...
    OP_RETURN_OBJECT: typing.ClassVar[int] = ...
    OP_RETURN_VOID: typing.ClassVar[int] = ...
    OP_RETURN_WIDE: typing.ClassVar[int] = ...
    OP_RSUB_INT: typing.ClassVar[int] = ...
    OP_RSUB_INT_LIT8: typing.ClassVar[int] = ...
    OP_SGET: typing.ClassVar[int] = ...
    OP_SGET_BOOLEAN: typing.ClassVar[int] = ...
    OP_SGET_BOOLEAN_JUMBO: typing.ClassVar[int] = ...
    OP_SGET_BYTE: typing.ClassVar[int] = ...
    OP_SGET_BYTE_JUMBO: typing.ClassVar[int] = ...
    OP_SGET_CHAR: typing.ClassVar[int] = ...
    OP_SGET_CHAR_JUMBO: typing.ClassVar[int] = ...
    OP_SGET_JUMBO: typing.ClassVar[int] = ...
    OP_SGET_OBJECT: typing.ClassVar[int] = ...
    OP_SGET_OBJECT_JUMBO: typing.ClassVar[int] = ...
    OP_SGET_SHORT: typing.ClassVar[int] = ...
    OP_SGET_SHORT_JUMBO: typing.ClassVar[int] = ...
    OP_SGET_WIDE: typing.ClassVar[int] = ...
    OP_SGET_WIDE_JUMBO: typing.ClassVar[int] = ...
    OP_SGET_WIDE_VOLATILE: typing.ClassVar[int] = ...
    OP_SHL_INT: typing.ClassVar[int] = ...
    OP_SHL_INT_2ADDR: typing.ClassVar[int] = ...
    OP_SHL_INT_LIT8: typing.ClassVar[int] = ...
    OP_SHL_LONG: typing.ClassVar[int] = ...
    OP_SHL_LONG_2ADDR: typing.ClassVar[int] = ...
    OP_SHR_INT: typing.ClassVar[int] = ...
    OP_SHR_INT_2ADDR: typing.ClassVar[int] = ...
    OP_SHR_INT_LIT8: typing.ClassVar[int] = ...
    OP_SHR_LONG: typing.ClassVar[int] = ...
    OP_SHR_LONG_2ADDR: typing.ClassVar[int] = ...
    OP_SPARSE_SWITCH: typing.ClassVar[int] = ...
    OP_SPUT: typing.ClassVar[int] = ...
    OP_SPUT_BOOLEAN: typing.ClassVar[int] = ...
    OP_SPUT_BOOLEAN_JUMBO: typing.ClassVar[int] = ...
    OP_SPUT_BYTE: typing.ClassVar[int] = ...
    OP_SPUT_BYTE_JUMBO: typing.ClassVar[int] = ...
    OP_SPUT_CHAR: typing.ClassVar[int] = ...
    OP_SPUT_CHAR_JUMBO: typing.ClassVar[int] = ...
    OP_SPUT_JUMBO: typing.ClassVar[int] = ...
    OP_SPUT_OBJECT: typing.ClassVar[int] = ...
    OP_SPUT_OBJECT_JUMBO: typing.ClassVar[int] = ...
    OP_SPUT_SHORT: typing.ClassVar[int] = ...
    OP_SPUT_SHORT_JUMBO: typing.ClassVar[int] = ...
    OP_SPUT_WIDE: typing.ClassVar[int] = ...
    OP_SPUT_WIDE_JUMBO: typing.ClassVar[int] = ...
    OP_SPUT_WIDE_VOLATILE: typing.ClassVar[int] = ...
    OP_SUB_DOUBLE: typing.ClassVar[int] = ...
    OP_SUB_DOUBLE_2ADDR: typing.ClassVar[int] = ...
    OP_SUB_FLOAT: typing.ClassVar[int] = ...
    OP_SUB_FLOAT_2ADDR: typing.ClassVar[int] = ...
    OP_SUB_INT: typing.ClassVar[int] = ...
    OP_SUB_INT_2ADDR: typing.ClassVar[int] = ...
    OP_SUB_LONG: typing.ClassVar[int] = ...
    OP_SUB_LONG_2ADDR: typing.ClassVar[int] = ...
    OP_THROW: typing.ClassVar[int] = ...
    OP_THROW_VERIFICATION_ERROR: typing.ClassVar[int] = ...
    OP_USHR_INT: typing.ClassVar[int] = ...
    OP_USHR_INT_2ADDR: typing.ClassVar[int] = ...
    OP_USHR_INT_LIT8: typing.ClassVar[int] = ...
    OP_USHR_LONG: typing.ClassVar[int] = ...
    OP_USHR_LONG_2ADDR: typing.ClassVar[int] = ...
    OP_XOR_INT: typing.ClassVar[int] = ...
    OP_XOR_INT_2ADDR: typing.ClassVar[int] = ...
    OP_XOR_INT_LIT16: typing.ClassVar[int] = ...
    OP_XOR_INT_LIT8: typing.ClassVar[int] = ...
    OP_XOR_LONG: typing.ClassVar[int] = ...
    OP_XOR_LONG_2ADDR: typing.ClassVar[int] = ...
