import typing

import java
import java.chaquopy
import java.lang
import java.nio

class GL(java.lang.Object): ...

class GL10(GL):
    GL_ADD: typing.ClassVar[int] = ...
    GL_ALIASED_LINE_WIDTH_RANGE: typing.ClassVar[int] = ...
    GL_ALIASED_POINT_SIZE_RANGE: typing.ClassVar[int] = ...
    GL_ALPHA: typing.ClassVar[int] = ...
    GL_ALPHA_BITS: typing.ClassVar[int] = ...
    GL_ALPHA_TEST: typing.ClassVar[int] = ...
    GL_ALWAYS: typing.ClassVar[int] = ...
    GL_AMBIENT: typing.ClassVar[int] = ...
    GL_AMBIENT_AND_DIFFUSE: typing.ClassVar[int] = ...
    GL_AND: typing.ClassVar[int] = ...
    GL_AND_INVERTED: typing.ClassVar[int] = ...
    GL_AND_REVERSE: typing.ClassVar[int] = ...
    GL_BACK: typing.ClassVar[int] = ...
    GL_BLEND: typing.ClassVar[int] = ...
    GL_BLUE_BITS: typing.ClassVar[int] = ...
    GL_BYTE: typing.ClassVar[int] = ...
    GL_CCW: typing.ClassVar[int] = ...
    GL_CLAMP_TO_EDGE: typing.ClassVar[int] = ...
    GL_CLEAR: typing.ClassVar[int] = ...
    GL_COLOR_ARRAY: typing.ClassVar[int] = ...
    GL_COLOR_BUFFER_BIT: typing.ClassVar[int] = ...
    GL_COLOR_LOGIC_OP: typing.ClassVar[int] = ...
    GL_COLOR_MATERIAL: typing.ClassVar[int] = ...
    GL_COMPRESSED_TEXTURE_FORMATS: typing.ClassVar[int] = ...
    GL_CONSTANT_ATTENUATION: typing.ClassVar[int] = ...
    GL_COPY: typing.ClassVar[int] = ...
    GL_COPY_INVERTED: typing.ClassVar[int] = ...
    GL_CULL_FACE: typing.ClassVar[int] = ...
    GL_CW: typing.ClassVar[int] = ...
    GL_DECAL: typing.ClassVar[int] = ...
    GL_DECR: typing.ClassVar[int] = ...
    GL_DEPTH_BITS: typing.ClassVar[int] = ...
    GL_DEPTH_BUFFER_BIT: typing.ClassVar[int] = ...
    GL_DEPTH_TEST: typing.ClassVar[int] = ...
    GL_DIFFUSE: typing.ClassVar[int] = ...
    GL_DITHER: typing.ClassVar[int] = ...
    GL_DONT_CARE: typing.ClassVar[int] = ...
    GL_DST_ALPHA: typing.ClassVar[int] = ...
    GL_DST_COLOR: typing.ClassVar[int] = ...
    GL_EMISSION: typing.ClassVar[int] = ...
    GL_EQUAL: typing.ClassVar[int] = ...
    GL_EQUIV: typing.ClassVar[int] = ...
    GL_EXP2: typing.ClassVar[int] = ...
    GL_EXP: typing.ClassVar[int] = ...
    GL_EXTENSIONS: typing.ClassVar[int] = ...
    GL_FALSE: typing.ClassVar[int] = ...
    GL_FASTEST: typing.ClassVar[int] = ...
    GL_FIXED: typing.ClassVar[int] = ...
    GL_FLAT: typing.ClassVar[int] = ...
    GL_FLOAT: typing.ClassVar[int] = ...
    GL_FOG: typing.ClassVar[int] = ...
    GL_FOG_COLOR: typing.ClassVar[int] = ...
    GL_FOG_DENSITY: typing.ClassVar[int] = ...
    GL_FOG_END: typing.ClassVar[int] = ...
    GL_FOG_HINT: typing.ClassVar[int] = ...
    GL_FOG_MODE: typing.ClassVar[int] = ...
    GL_FOG_START: typing.ClassVar[int] = ...
    GL_FRONT: typing.ClassVar[int] = ...
    GL_FRONT_AND_BACK: typing.ClassVar[int] = ...
    GL_GEQUAL: typing.ClassVar[int] = ...
    GL_GREATER: typing.ClassVar[int] = ...
    GL_GREEN_BITS: typing.ClassVar[int] = ...
    GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES: typing.ClassVar[int] = ...
    GL_IMPLEMENTATION_COLOR_READ_TYPE_OES: typing.ClassVar[int] = ...
    GL_INCR: typing.ClassVar[int] = ...
    GL_INVALID_ENUM: typing.ClassVar[int] = ...
    GL_INVALID_OPERATION: typing.ClassVar[int] = ...
    GL_INVALID_VALUE: typing.ClassVar[int] = ...
    GL_INVERT: typing.ClassVar[int] = ...
    GL_KEEP: typing.ClassVar[int] = ...
    GL_LEQUAL: typing.ClassVar[int] = ...
    GL_LESS: typing.ClassVar[int] = ...
    GL_LIGHT0: typing.ClassVar[int] = ...
    GL_LIGHT1: typing.ClassVar[int] = ...
    GL_LIGHT2: typing.ClassVar[int] = ...
    GL_LIGHT3: typing.ClassVar[int] = ...
    GL_LIGHT4: typing.ClassVar[int] = ...
    GL_LIGHT5: typing.ClassVar[int] = ...
    GL_LIGHT6: typing.ClassVar[int] = ...
    GL_LIGHT7: typing.ClassVar[int] = ...
    GL_LIGHTING: typing.ClassVar[int] = ...
    GL_LIGHT_MODEL_AMBIENT: typing.ClassVar[int] = ...
    GL_LIGHT_MODEL_TWO_SIDE: typing.ClassVar[int] = ...
    GL_LINEAR: typing.ClassVar[int] = ...
    GL_LINEAR_ATTENUATION: typing.ClassVar[int] = ...
    GL_LINEAR_MIPMAP_LINEAR: typing.ClassVar[int] = ...
    GL_LINEAR_MIPMAP_NEAREST: typing.ClassVar[int] = ...
    GL_LINES: typing.ClassVar[int] = ...
    GL_LINE_LOOP: typing.ClassVar[int] = ...
    GL_LINE_SMOOTH: typing.ClassVar[int] = ...
    GL_LINE_SMOOTH_HINT: typing.ClassVar[int] = ...
    GL_LINE_STRIP: typing.ClassVar[int] = ...
    GL_LUMINANCE: typing.ClassVar[int] = ...
    GL_LUMINANCE_ALPHA: typing.ClassVar[int] = ...
    GL_MAX_ELEMENTS_INDICES: typing.ClassVar[int] = ...
    GL_MAX_ELEMENTS_VERTICES: typing.ClassVar[int] = ...
    GL_MAX_LIGHTS: typing.ClassVar[int] = ...
    GL_MAX_MODELVIEW_STACK_DEPTH: typing.ClassVar[int] = ...
    GL_MAX_PROJECTION_STACK_DEPTH: typing.ClassVar[int] = ...
    GL_MAX_TEXTURE_SIZE: typing.ClassVar[int] = ...
    GL_MAX_TEXTURE_STACK_DEPTH: typing.ClassVar[int] = ...
    GL_MAX_TEXTURE_UNITS: typing.ClassVar[int] = ...
    GL_MAX_VIEWPORT_DIMS: typing.ClassVar[int] = ...
    GL_MODELVIEW: typing.ClassVar[int] = ...
    GL_MODULATE: typing.ClassVar[int] = ...
    GL_MULTISAMPLE: typing.ClassVar[int] = ...
    GL_NAND: typing.ClassVar[int] = ...
    GL_NEAREST: typing.ClassVar[int] = ...
    GL_NEAREST_MIPMAP_LINEAR: typing.ClassVar[int] = ...
    GL_NEAREST_MIPMAP_NEAREST: typing.ClassVar[int] = ...
    GL_NEVER: typing.ClassVar[int] = ...
    GL_NICEST: typing.ClassVar[int] = ...
    GL_NOOP: typing.ClassVar[int] = ...
    GL_NOR: typing.ClassVar[int] = ...
    GL_NORMALIZE: typing.ClassVar[int] = ...
    GL_NORMAL_ARRAY: typing.ClassVar[int] = ...
    GL_NOTEQUAL: typing.ClassVar[int] = ...
    GL_NO_ERROR: typing.ClassVar[int] = ...
    GL_NUM_COMPRESSED_TEXTURE_FORMATS: typing.ClassVar[int] = ...
    GL_ONE: typing.ClassVar[int] = ...
    GL_ONE_MINUS_DST_ALPHA: typing.ClassVar[int] = ...
    GL_ONE_MINUS_DST_COLOR: typing.ClassVar[int] = ...
    GL_ONE_MINUS_SRC_ALPHA: typing.ClassVar[int] = ...
    GL_ONE_MINUS_SRC_COLOR: typing.ClassVar[int] = ...
    GL_OR: typing.ClassVar[int] = ...
    GL_OR_INVERTED: typing.ClassVar[int] = ...
    GL_OR_REVERSE: typing.ClassVar[int] = ...
    GL_OUT_OF_MEMORY: typing.ClassVar[int] = ...
    GL_PACK_ALIGNMENT: typing.ClassVar[int] = ...
    GL_PALETTE4_R5_G6_B5_OES: typing.ClassVar[int] = ...
    GL_PALETTE4_RGB5_A1_OES: typing.ClassVar[int] = ...
    GL_PALETTE4_RGB8_OES: typing.ClassVar[int] = ...
    GL_PALETTE4_RGBA4_OES: typing.ClassVar[int] = ...
    GL_PALETTE4_RGBA8_OES: typing.ClassVar[int] = ...
    GL_PALETTE8_R5_G6_B5_OES: typing.ClassVar[int] = ...
    GL_PALETTE8_RGB5_A1_OES: typing.ClassVar[int] = ...
    GL_PALETTE8_RGB8_OES: typing.ClassVar[int] = ...
    GL_PALETTE8_RGBA4_OES: typing.ClassVar[int] = ...
    GL_PALETTE8_RGBA8_OES: typing.ClassVar[int] = ...
    GL_PERSPECTIVE_CORRECTION_HINT: typing.ClassVar[int] = ...
    GL_POINTS: typing.ClassVar[int] = ...
    GL_POINT_FADE_THRESHOLD_SIZE: typing.ClassVar[int] = ...
    GL_POINT_SIZE: typing.ClassVar[int] = ...
    GL_POINT_SMOOTH: typing.ClassVar[int] = ...
    GL_POINT_SMOOTH_HINT: typing.ClassVar[int] = ...
    GL_POLYGON_OFFSET_FILL: typing.ClassVar[int] = ...
    GL_POLYGON_SMOOTH_HINT: typing.ClassVar[int] = ...
    GL_POSITION: typing.ClassVar[int] = ...
    GL_PROJECTION: typing.ClassVar[int] = ...
    GL_QUADRATIC_ATTENUATION: typing.ClassVar[int] = ...
    GL_RED_BITS: typing.ClassVar[int] = ...
    GL_RENDERER: typing.ClassVar[int] = ...
    GL_REPEAT: typing.ClassVar[int] = ...
    GL_REPLACE: typing.ClassVar[int] = ...
    GL_RESCALE_NORMAL: typing.ClassVar[int] = ...
    GL_RGB: typing.ClassVar[int] = ...
    GL_RGBA: typing.ClassVar[int] = ...
    GL_SAMPLE_ALPHA_TO_COVERAGE: typing.ClassVar[int] = ...
    GL_SAMPLE_ALPHA_TO_ONE: typing.ClassVar[int] = ...
    GL_SAMPLE_COVERAGE: typing.ClassVar[int] = ...
    GL_SCISSOR_TEST: typing.ClassVar[int] = ...
    GL_SET: typing.ClassVar[int] = ...
    GL_SHININESS: typing.ClassVar[int] = ...
    GL_SHORT: typing.ClassVar[int] = ...
    GL_SMOOTH: typing.ClassVar[int] = ...
    GL_SMOOTH_LINE_WIDTH_RANGE: typing.ClassVar[int] = ...
    GL_SMOOTH_POINT_SIZE_RANGE: typing.ClassVar[int] = ...
    GL_SPECULAR: typing.ClassVar[int] = ...
    GL_SPOT_CUTOFF: typing.ClassVar[int] = ...
    GL_SPOT_DIRECTION: typing.ClassVar[int] = ...
    GL_SPOT_EXPONENT: typing.ClassVar[int] = ...
    GL_SRC_ALPHA: typing.ClassVar[int] = ...
    GL_SRC_ALPHA_SATURATE: typing.ClassVar[int] = ...
    GL_SRC_COLOR: typing.ClassVar[int] = ...
    GL_STACK_OVERFLOW: typing.ClassVar[int] = ...
    GL_STACK_UNDERFLOW: typing.ClassVar[int] = ...
    GL_STENCIL_BITS: typing.ClassVar[int] = ...
    GL_STENCIL_BUFFER_BIT: typing.ClassVar[int] = ...
    GL_STENCIL_TEST: typing.ClassVar[int] = ...
    GL_SUBPIXEL_BITS: typing.ClassVar[int] = ...
    GL_TEXTURE0: typing.ClassVar[int] = ...
    GL_TEXTURE10: typing.ClassVar[int] = ...
    GL_TEXTURE11: typing.ClassVar[int] = ...
    GL_TEXTURE12: typing.ClassVar[int] = ...
    GL_TEXTURE13: typing.ClassVar[int] = ...
    GL_TEXTURE14: typing.ClassVar[int] = ...
    GL_TEXTURE15: typing.ClassVar[int] = ...
    GL_TEXTURE16: typing.ClassVar[int] = ...
    GL_TEXTURE17: typing.ClassVar[int] = ...
    GL_TEXTURE18: typing.ClassVar[int] = ...
    GL_TEXTURE19: typing.ClassVar[int] = ...
    GL_TEXTURE1: typing.ClassVar[int] = ...
    GL_TEXTURE20: typing.ClassVar[int] = ...
    GL_TEXTURE21: typing.ClassVar[int] = ...
    GL_TEXTURE22: typing.ClassVar[int] = ...
    GL_TEXTURE23: typing.ClassVar[int] = ...
    GL_TEXTURE24: typing.ClassVar[int] = ...
    GL_TEXTURE25: typing.ClassVar[int] = ...
    GL_TEXTURE26: typing.ClassVar[int] = ...
    GL_TEXTURE27: typing.ClassVar[int] = ...
    GL_TEXTURE28: typing.ClassVar[int] = ...
    GL_TEXTURE29: typing.ClassVar[int] = ...
    GL_TEXTURE2: typing.ClassVar[int] = ...
    GL_TEXTURE30: typing.ClassVar[int] = ...
    GL_TEXTURE31: typing.ClassVar[int] = ...
    GL_TEXTURE3: typing.ClassVar[int] = ...
    GL_TEXTURE4: typing.ClassVar[int] = ...
    GL_TEXTURE5: typing.ClassVar[int] = ...
    GL_TEXTURE6: typing.ClassVar[int] = ...
    GL_TEXTURE7: typing.ClassVar[int] = ...
    GL_TEXTURE8: typing.ClassVar[int] = ...
    GL_TEXTURE9: typing.ClassVar[int] = ...
    GL_TEXTURE: typing.ClassVar[int] = ...
    GL_TEXTURE_2D: typing.ClassVar[int] = ...
    GL_TEXTURE_COORD_ARRAY: typing.ClassVar[int] = ...
    GL_TEXTURE_ENV: typing.ClassVar[int] = ...
    GL_TEXTURE_ENV_COLOR: typing.ClassVar[int] = ...
    GL_TEXTURE_ENV_MODE: typing.ClassVar[int] = ...
    GL_TEXTURE_MAG_FILTER: typing.ClassVar[int] = ...
    GL_TEXTURE_MIN_FILTER: typing.ClassVar[int] = ...
    GL_TEXTURE_WRAP_S: typing.ClassVar[int] = ...
    GL_TEXTURE_WRAP_T: typing.ClassVar[int] = ...
    GL_TRIANGLES: typing.ClassVar[int] = ...
    GL_TRIANGLE_FAN: typing.ClassVar[int] = ...
    GL_TRIANGLE_STRIP: typing.ClassVar[int] = ...
    GL_TRUE: typing.ClassVar[int] = ...
    GL_UNPACK_ALIGNMENT: typing.ClassVar[int] = ...
    GL_UNSIGNED_BYTE: typing.ClassVar[int] = ...
    GL_UNSIGNED_SHORT: typing.ClassVar[int] = ...
    GL_UNSIGNED_SHORT_4_4_4_4: typing.ClassVar[int] = ...
    GL_UNSIGNED_SHORT_5_5_5_1: typing.ClassVar[int] = ...
    GL_UNSIGNED_SHORT_5_6_5: typing.ClassVar[int] = ...
    GL_VENDOR: typing.ClassVar[int] = ...
    GL_VERSION: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY: typing.ClassVar[int] = ...
    GL_XOR: typing.ClassVar[int] = ...
    GL_ZERO: typing.ClassVar[int] = ...
    def glActiveTexture(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glAlphaFunc(self, arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glAlphaFuncx(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glBindTexture(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glBlendFunc(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glClear(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glClearColor(self, arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glClearColorx(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glClearDepthf(self, arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glClearDepthx(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glClearStencil(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glClientActiveTexture(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glColor4f(self, arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glColor4x(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glColorMask(self, arg1: bool | java.jboolean | java.lang.Boolean, arg2: bool | java.jboolean | java.lang.Boolean, arg3: bool | java.jboolean | java.lang.Boolean, arg4: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def glColorPointer(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, /) -> None: ...
    def glCompressedTexImage2D(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: java.nio.Buffer, /) -> None: ...
    def glCompressedTexSubImage2D(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: java.nio.Buffer, /) -> None: ...
    def glCopyTexImage2D(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, /) -> None: ...
    def glCopyTexSubImage2D(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, /) -> None: ...
    def glCullFace(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glDeleteTextures(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glDeleteTextures(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glDepthFunc(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glDepthMask(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def glDepthRangef(self, arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glDepthRangex(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glDisable(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glDisableClientState(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glDrawArrays(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glDrawElements(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, /) -> None: ...
    def glEnable(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glEnableClientState(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glFinish(self) -> None: ...
    def glFlush(self) -> None: ...
    def glFogf(self, arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def glFogfv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glFogfv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glFogx(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glFogxv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glFogxv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glFrontFace(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glFrustumf(self, arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, arg6: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glFrustumx(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGenTextures(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGenTextures(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glGetError(self) -> int: ...
    @typing.overload
    def glGetIntegerv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetIntegerv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glGetString(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    def glHint(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glLightModelf(self, arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def glLightModelfv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glLightModelfv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glLightModelx(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glLightModelxv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glLightModelxv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glLightf(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def glLightfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glLightfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glLightx(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glLightxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glLightxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glLineWidth(self, arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glLineWidthx(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glLoadIdentity(self) -> None: ...
    @typing.overload
    def glLoadMatrixf(self, arg1: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glLoadMatrixf(self, arg1: java.chaquopy.JavaArrayJFloat, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glLoadMatrixx(self, arg1: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glLoadMatrixx(self, arg1: java.chaquopy.JavaArrayJInt, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glLogicOp(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glMaterialf(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def glMaterialfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glMaterialfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glMaterialx(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glMaterialxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glMaterialxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glMatrixMode(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glMultMatrixf(self, arg1: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glMultMatrixf(self, arg1: java.chaquopy.JavaArrayJFloat, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glMultMatrixx(self, arg1: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glMultMatrixx(self, arg1: java.chaquopy.JavaArrayJInt, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glMultiTexCoord4f(self, arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glMultiTexCoord4x(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    def glNormal3f(self, arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glNormal3x(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glNormalPointer(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.Buffer, /) -> None: ...
    def glOrthof(self, arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, arg6: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glOrthox(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    def glPixelStorei(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glPointSize(self, arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glPointSizex(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glPolygonOffset(self, arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glPolygonOffsetx(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glPopMatrix(self) -> None: ...
    def glPushMatrix(self) -> None: ...
    def glReadPixels(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: java.nio.Buffer, /) -> None: ...
    def glRotatef(self, arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glRotatex(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glSampleCoverage(self, arg1: float | java.jfloat | java.lang.Float, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def glSampleCoveragex(self, arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def glScalef(self, arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glScalex(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glScissor(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glShadeModel(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glStencilFunc(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glStencilMask(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glStencilOp(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glTexCoordPointer(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, /) -> None: ...
    def glTexEnvf(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def glTexEnvfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glTexEnvfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glTexEnvx(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glTexEnvxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glTexEnvxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glTexImage2D(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: java.nio.Buffer, /) -> None: ...
    def glTexParameterf(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glTexParameterx(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glTexSubImage2D(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: java.nio.Buffer, /) -> None: ...
    def glTranslatef(self, arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    def glTranslatex(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glVertexPointer(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, /) -> None: ...
    def glViewport(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...

class GL10Ext(GL):
    @typing.overload
    def glQueryMatrixxOES(self, arg1: java.nio.IntBuffer, arg2: java.nio.IntBuffer, /) -> int: ...
    @typing.overload
    def glQueryMatrixxOES(self, arg1: java.chaquopy.JavaArrayJInt, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> int: ...

class GL11(GL10):
    GL_ACTIVE_TEXTURE: typing.ClassVar[int] = ...
    GL_ADD_SIGNED: typing.ClassVar[int] = ...
    GL_ALPHA_SCALE: typing.ClassVar[int] = ...
    GL_ALPHA_TEST_FUNC: typing.ClassVar[int] = ...
    GL_ALPHA_TEST_REF: typing.ClassVar[int] = ...
    GL_ARRAY_BUFFER: typing.ClassVar[int] = ...
    GL_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_BLEND_DST: typing.ClassVar[int] = ...
    GL_BLEND_SRC: typing.ClassVar[int] = ...
    GL_BUFFER_ACCESS: typing.ClassVar[int] = ...
    GL_BUFFER_SIZE: typing.ClassVar[int] = ...
    GL_BUFFER_USAGE: typing.ClassVar[int] = ...
    GL_CLIENT_ACTIVE_TEXTURE: typing.ClassVar[int] = ...
    GL_CLIP_PLANE0: typing.ClassVar[int] = ...
    GL_CLIP_PLANE1: typing.ClassVar[int] = ...
    GL_CLIP_PLANE2: typing.ClassVar[int] = ...
    GL_CLIP_PLANE3: typing.ClassVar[int] = ...
    GL_CLIP_PLANE4: typing.ClassVar[int] = ...
    GL_CLIP_PLANE5: typing.ClassVar[int] = ...
    GL_COLOR_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_COLOR_ARRAY_POINTER: typing.ClassVar[int] = ...
    GL_COLOR_ARRAY_SIZE: typing.ClassVar[int] = ...
    GL_COLOR_ARRAY_STRIDE: typing.ClassVar[int] = ...
    GL_COLOR_ARRAY_TYPE: typing.ClassVar[int] = ...
    GL_COLOR_CLEAR_VALUE: typing.ClassVar[int] = ...
    GL_COLOR_WRITEMASK: typing.ClassVar[int] = ...
    GL_COMBINE: typing.ClassVar[int] = ...
    GL_COMBINE_ALPHA: typing.ClassVar[int] = ...
    GL_COMBINE_RGB: typing.ClassVar[int] = ...
    GL_CONSTANT: typing.ClassVar[int] = ...
    GL_COORD_REPLACE_OES: typing.ClassVar[int] = ...
    GL_CULL_FACE_MODE: typing.ClassVar[int] = ...
    GL_CURRENT_COLOR: typing.ClassVar[int] = ...
    GL_CURRENT_NORMAL: typing.ClassVar[int] = ...
    GL_CURRENT_TEXTURE_COORDS: typing.ClassVar[int] = ...
    GL_DEPTH_CLEAR_VALUE: typing.ClassVar[int] = ...
    GL_DEPTH_FUNC: typing.ClassVar[int] = ...
    GL_DEPTH_RANGE: typing.ClassVar[int] = ...
    GL_DEPTH_WRITEMASK: typing.ClassVar[int] = ...
    GL_DOT3_RGB: typing.ClassVar[int] = ...
    GL_DOT3_RGBA: typing.ClassVar[int] = ...
    GL_DYNAMIC_DRAW: typing.ClassVar[int] = ...
    GL_ELEMENT_ARRAY_BUFFER: typing.ClassVar[int] = ...
    GL_ELEMENT_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_FRONT_FACE: typing.ClassVar[int] = ...
    GL_GENERATE_MIPMAP: typing.ClassVar[int] = ...
    GL_GENERATE_MIPMAP_HINT: typing.ClassVar[int] = ...
    GL_INTERPOLATE: typing.ClassVar[int] = ...
    GL_LINE_WIDTH: typing.ClassVar[int] = ...
    GL_LOGIC_OP_MODE: typing.ClassVar[int] = ...
    GL_MATRIX_MODE: typing.ClassVar[int] = ...
    GL_MAX_CLIP_PLANES: typing.ClassVar[int] = ...
    GL_MODELVIEW_MATRIX: typing.ClassVar[int] = ...
    GL_MODELVIEW_MATRIX_FLOAT_AS_INT_BITS_OES: typing.ClassVar[int] = ...
    GL_MODELVIEW_STACK_DEPTH: typing.ClassVar[int] = ...
    GL_NORMAL_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_NORMAL_ARRAY_POINTER: typing.ClassVar[int] = ...
    GL_NORMAL_ARRAY_STRIDE: typing.ClassVar[int] = ...
    GL_NORMAL_ARRAY_TYPE: typing.ClassVar[int] = ...
    GL_OPERAND0_ALPHA: typing.ClassVar[int] = ...
    GL_OPERAND0_RGB: typing.ClassVar[int] = ...
    GL_OPERAND1_ALPHA: typing.ClassVar[int] = ...
    GL_OPERAND1_RGB: typing.ClassVar[int] = ...
    GL_OPERAND2_ALPHA: typing.ClassVar[int] = ...
    GL_OPERAND2_RGB: typing.ClassVar[int] = ...
    GL_POINT_DISTANCE_ATTENUATION: typing.ClassVar[int] = ...
    GL_POINT_FADE_THRESHOLD_SIZE: typing.ClassVar[int] = ...
    GL_POINT_SIZE: typing.ClassVar[int] = ...
    GL_POINT_SIZE_ARRAY_BUFFER_BINDING_OES: typing.ClassVar[int] = ...
    GL_POINT_SIZE_ARRAY_OES: typing.ClassVar[int] = ...
    GL_POINT_SIZE_ARRAY_POINTER_OES: typing.ClassVar[int] = ...
    GL_POINT_SIZE_ARRAY_STRIDE_OES: typing.ClassVar[int] = ...
    GL_POINT_SIZE_ARRAY_TYPE_OES: typing.ClassVar[int] = ...
    GL_POINT_SIZE_MAX: typing.ClassVar[int] = ...
    GL_POINT_SIZE_MIN: typing.ClassVar[int] = ...
    GL_POINT_SPRITE_OES: typing.ClassVar[int] = ...
    GL_POLYGON_OFFSET_FACTOR: typing.ClassVar[int] = ...
    GL_POLYGON_OFFSET_UNITS: typing.ClassVar[int] = ...
    GL_PREVIOUS: typing.ClassVar[int] = ...
    GL_PRIMARY_COLOR: typing.ClassVar[int] = ...
    GL_PROJECTION_MATRIX: typing.ClassVar[int] = ...
    GL_PROJECTION_MATRIX_FLOAT_AS_INT_BITS_OES: typing.ClassVar[int] = ...
    GL_PROJECTION_STACK_DEPTH: typing.ClassVar[int] = ...
    GL_RGB_SCALE: typing.ClassVar[int] = ...
    GL_SAMPLES: typing.ClassVar[int] = ...
    GL_SAMPLE_BUFFERS: typing.ClassVar[int] = ...
    GL_SAMPLE_COVERAGE_INVERT: typing.ClassVar[int] = ...
    GL_SAMPLE_COVERAGE_VALUE: typing.ClassVar[int] = ...
    GL_SCISSOR_BOX: typing.ClassVar[int] = ...
    GL_SHADE_MODEL: typing.ClassVar[int] = ...
    GL_SRC0_ALPHA: typing.ClassVar[int] = ...
    GL_SRC0_RGB: typing.ClassVar[int] = ...
    GL_SRC1_ALPHA: typing.ClassVar[int] = ...
    GL_SRC1_RGB: typing.ClassVar[int] = ...
    GL_SRC2_ALPHA: typing.ClassVar[int] = ...
    GL_SRC2_RGB: typing.ClassVar[int] = ...
    GL_STATIC_DRAW: typing.ClassVar[int] = ...
    GL_STENCIL_CLEAR_VALUE: typing.ClassVar[int] = ...
    GL_STENCIL_FAIL: typing.ClassVar[int] = ...
    GL_STENCIL_FUNC: typing.ClassVar[int] = ...
    GL_STENCIL_PASS_DEPTH_FAIL: typing.ClassVar[int] = ...
    GL_STENCIL_PASS_DEPTH_PASS: typing.ClassVar[int] = ...
    GL_STENCIL_REF: typing.ClassVar[int] = ...
    GL_STENCIL_VALUE_MASK: typing.ClassVar[int] = ...
    GL_STENCIL_WRITEMASK: typing.ClassVar[int] = ...
    GL_SUBTRACT: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_2D: typing.ClassVar[int] = ...
    GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_TEXTURE_COORD_ARRAY_POINTER: typing.ClassVar[int] = ...
    GL_TEXTURE_COORD_ARRAY_SIZE: typing.ClassVar[int] = ...
    GL_TEXTURE_COORD_ARRAY_STRIDE: typing.ClassVar[int] = ...
    GL_TEXTURE_COORD_ARRAY_TYPE: typing.ClassVar[int] = ...
    GL_TEXTURE_MATRIX: typing.ClassVar[int] = ...
    GL_TEXTURE_MATRIX_FLOAT_AS_INT_BITS_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_STACK_DEPTH: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY_POINTER: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY_SIZE: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY_STRIDE: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY_TYPE: typing.ClassVar[int] = ...
    GL_VIEWPORT: typing.ClassVar[int] = ...
    GL_WRITE_ONLY: typing.ClassVar[int] = ...
    def glBindBuffer(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glBufferData(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.Buffer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glBufferSubData(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, /) -> None: ...
    @typing.overload
    def glClipPlanef(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glClipPlanef(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glClipPlanex(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glClipPlanex(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glColor4ub(self, arg1: int | java.jbyte | java.lang.Byte, arg2: int | java.jbyte | java.lang.Byte, arg3: int | java.jbyte | java.lang.Byte, arg4: int | java.jbyte | java.lang.Byte, /) -> None: ...
    def glColorPointer(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glDeleteBuffers(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glDeleteBuffers(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glDrawElements(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGenBuffers(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGenBuffers(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetBooleanv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetBooleanv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJBoolean, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetBufferParameteriv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetBufferParameteriv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetClipPlanef(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glGetClipPlanef(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetClipPlanex(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetClipPlanex(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetFixedv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetFixedv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetFloatv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glGetFloatv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetLightfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glGetLightfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetLightxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetLightxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetMaterialfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glGetMaterialfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetMaterialxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetMaterialxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glGetPointerv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArray[java.nio.Buffer], /) -> None: ...
    @typing.overload
    def glGetTexEnviv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetTexEnviv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetTexEnvxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetTexEnvxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetTexParameterfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glGetTexParameterfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetTexParameteriv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetTexParameteriv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetTexParameterxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetTexParameterxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glIsBuffer(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    def glIsEnabled(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    def glIsTexture(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    def glNormalPointer(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glPointParameterf(self, arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def glPointParameterfv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glPointParameterfv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glPointParameterx(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glPointParameterxv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glPointParameterxv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glPointSizePointerOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.Buffer, /) -> None: ...
    def glTexCoordPointer(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glTexEnvi(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glTexEnviv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glTexEnviv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glTexParameterfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glTexParameterfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glTexParameteri(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glTexParameteriv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glTexParameteriv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glTexParameterxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glTexParameterxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glVertexPointer(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...

class GL11Ext(GL):
    GL_MATRIX_INDEX_ARRAY_BUFFER_BINDING_OES: typing.ClassVar[int] = ...
    GL_MATRIX_INDEX_ARRAY_OES: typing.ClassVar[int] = ...
    GL_MATRIX_INDEX_ARRAY_POINTER_OES: typing.ClassVar[int] = ...
    GL_MATRIX_INDEX_ARRAY_SIZE_OES: typing.ClassVar[int] = ...
    GL_MATRIX_INDEX_ARRAY_STRIDE_OES: typing.ClassVar[int] = ...
    GL_MATRIX_INDEX_ARRAY_TYPE_OES: typing.ClassVar[int] = ...
    GL_MATRIX_PALETTE_OES: typing.ClassVar[int] = ...
    GL_MAX_PALETTE_MATRICES_OES: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_UNITS_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_CROP_RECT_OES: typing.ClassVar[int] = ...
    GL_WEIGHT_ARRAY_BUFFER_BINDING_OES: typing.ClassVar[int] = ...
    GL_WEIGHT_ARRAY_OES: typing.ClassVar[int] = ...
    GL_WEIGHT_ARRAY_POINTER_OES: typing.ClassVar[int] = ...
    GL_WEIGHT_ARRAY_SIZE_OES: typing.ClassVar[int] = ...
    GL_WEIGHT_ARRAY_STRIDE_OES: typing.ClassVar[int] = ...
    GL_WEIGHT_ARRAY_TYPE_OES: typing.ClassVar[int] = ...
    def glCurrentPaletteMatrixOES(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glDrawTexfOES(self, arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def glDrawTexfvOES(self, arg1: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glDrawTexfvOES(self, arg1: java.chaquopy.JavaArrayJFloat, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glDrawTexiOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glDrawTexivOES(self, arg1: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glDrawTexivOES(self, arg1: java.chaquopy.JavaArrayJInt, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glDrawTexsOES(self, arg1: int | java.jshort | java.lang.Short, arg2: int | java.jshort | java.lang.Short, arg3: int | java.jshort | java.lang.Short, arg4: int | java.jshort | java.lang.Short, arg5: int | java.jshort | java.lang.Short, /) -> None: ...
    @typing.overload
    def glDrawTexsvOES(self, arg1: java.nio.ShortBuffer, /) -> None: ...
    @typing.overload
    def glDrawTexsvOES(self, arg1: java.chaquopy.JavaArrayJShort, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glDrawTexxOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glDrawTexxvOES(self, arg1: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glDrawTexxvOES(self, arg1: java.chaquopy.JavaArrayJInt, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glEnable(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glEnableClientState(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glLoadPaletteFromModelViewMatrixOES(self) -> None: ...
    @typing.overload
    def glMatrixIndexPointerOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glMatrixIndexPointerOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, /) -> None: ...
    def glTexParameterfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glWeightPointerOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glWeightPointerOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, /) -> None: ...

class GL11ExtensionPack(GL):
    GL_BLEND_DST_ALPHA: typing.ClassVar[int] = ...
    GL_BLEND_DST_RGB: typing.ClassVar[int] = ...
    GL_BLEND_EQUATION: typing.ClassVar[int] = ...
    GL_BLEND_EQUATION_ALPHA: typing.ClassVar[int] = ...
    GL_BLEND_EQUATION_RGB: typing.ClassVar[int] = ...
    GL_BLEND_SRC_ALPHA: typing.ClassVar[int] = ...
    GL_BLEND_SRC_RGB: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT0_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT10_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT11_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT12_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT13_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT14_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT15_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT1_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT2_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT3_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT4_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT5_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT6_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT7_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT8_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT9_OES: typing.ClassVar[int] = ...
    GL_DECR_WRAP: typing.ClassVar[int] = ...
    GL_DEPTH_ATTACHMENT_OES: typing.ClassVar[int] = ...
    GL_DEPTH_COMPONENT16: typing.ClassVar[int] = ...
    GL_DEPTH_COMPONENT24: typing.ClassVar[int] = ...
    GL_DEPTH_COMPONENT32: typing.ClassVar[int] = ...
    GL_DEPTH_COMPONENT: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_BINDING_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_COMPLETE_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_FORMATS_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_UNSUPPORTED_OES: typing.ClassVar[int] = ...
    GL_FUNC_ADD: typing.ClassVar[int] = ...
    GL_FUNC_REVERSE_SUBTRACT: typing.ClassVar[int] = ...
    GL_FUNC_SUBTRACT: typing.ClassVar[int] = ...
    GL_INCR_WRAP: typing.ClassVar[int] = ...
    GL_INVALID_FRAMEBUFFER_OPERATION_OES: typing.ClassVar[int] = ...
    GL_MAX_COLOR_ATTACHMENTS_OES: typing.ClassVar[int] = ...
    GL_MAX_CUBE_MAP_TEXTURE_SIZE: typing.ClassVar[int] = ...
    GL_MAX_RENDERBUFFER_SIZE_OES: typing.ClassVar[int] = ...
    GL_MIRRORED_REPEAT: typing.ClassVar[int] = ...
    GL_NORMAL_MAP: typing.ClassVar[int] = ...
    GL_REFLECTION_MAP: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_ALPHA_SIZE_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_BINDING_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_BLUE_SIZE_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_DEPTH_SIZE_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_GREEN_SIZE_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_HEIGHT_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_INTERNAL_FORMAT_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_RED_SIZE_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_STENCIL_SIZE_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_WIDTH_OES: typing.ClassVar[int] = ...
    GL_RGB565_OES: typing.ClassVar[int] = ...
    GL_RGB5_A1: typing.ClassVar[int] = ...
    GL_RGB8: typing.ClassVar[int] = ...
    GL_RGBA4: typing.ClassVar[int] = ...
    GL_RGBA8: typing.ClassVar[int] = ...
    GL_STENCIL_ATTACHMENT_OES: typing.ClassVar[int] = ...
    GL_STENCIL_INDEX1_OES: typing.ClassVar[int] = ...
    GL_STENCIL_INDEX4_OES: typing.ClassVar[int] = ...
    GL_STENCIL_INDEX8_OES: typing.ClassVar[int] = ...
    GL_STENCIL_INDEX: typing.ClassVar[int] = ...
    GL_STR: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_CUBE_MAP: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_NEGATIVE_X: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_NEGATIVE_Y: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_NEGATIVE_Z: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_POSITIVE_X: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_POSITIVE_Y: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_POSITIVE_Z: typing.ClassVar[int] = ...
    GL_TEXTURE_GEN_MODE: typing.ClassVar[int] = ...
    GL_TEXTURE_GEN_STR: typing.ClassVar[int] = ...
    def glBindFramebufferOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glBindRenderbufferOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glBindTexture(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glBlendEquation(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glBlendEquationSeparate(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def glBlendFuncSeparate(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glCheckFramebufferStatusOES(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def glCompressedTexImage2D(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: java.nio.Buffer, /) -> None: ...
    def glCopyTexImage2D(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glDeleteFramebuffersOES(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glDeleteFramebuffersOES(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glDeleteRenderbuffersOES(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glDeleteRenderbuffersOES(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glEnable(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def glFramebufferRenderbufferOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glFramebufferTexture2DOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGenFramebuffersOES(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGenFramebuffersOES(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGenRenderbuffersOES(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGenRenderbuffersOES(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glGenerateMipmapOES(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetFramebufferAttachmentParameterivOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetFramebufferAttachmentParameterivOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetIntegerv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetIntegerv(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetRenderbufferParameterivOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetRenderbufferParameterivOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetTexGenfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glGetTexGenfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetTexGeniv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetTexGeniv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glGetTexGenxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glGetTexGenxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glIsFramebufferOES(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    def glIsRenderbufferOES(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    def glRenderbufferStorageOES(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glStencilOp(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def glTexEnvf(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def glTexEnvfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glTexEnvfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glTexEnvx(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glTexEnvxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glTexEnvxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glTexGenf(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def glTexGenfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    def glTexGenfv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glTexGeni(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glTexGeniv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glTexGeniv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glTexGenx(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def glTexGenxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    def glTexGenxv(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def glTexParameterf(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
