import java.lang
import java.nio.charset
import java.util

class CharsetProvider(java.lang.Object):
    def __init__(self) -> None: ...
    def charsetForName(self, arg1: str | java.lang.String, /) -> java.nio.charset.Charset: ...
    def charsets(self) -> java.util.Iterator[java.nio.charset.Charset]: ...
