import typing

import java
import java.lang

class MmTelFeature(java.lang.Object):

    class MmTelCapabilities(java.lang.Object):
        CAPABILITY_TYPE_CALL_COMPOSER: typing.ClassVar[int] = ...
        CAPABILITY_TYPE_CALL_COMPOSER_BUSINESS_ONLY: typing.ClassVar[int] = ...
        CAPABILITY_TYPE_SMS: typing.ClassVar[int] = ...
        CAPABILITY_TYPE_UT: typing.ClassVar[int] = ...
        CAPABILITY_TYPE_VIDEO: typing.ClassVar[int] = ...
        CAPABILITY_TYPE_VOICE: typing.ClassVar[int] = ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def hashCode(self) -> int: ...
        def isCapable(self, capabilities: int | java.jint | java.lang.Integer, /) -> bool: ...
        def toString(self) -> str: ...
