import android.content
import android.graphics
import android.graphics.pdf
import android.print_
import java
import java.lang

class PrintedPdfDocument(android.graphics.pdf.PdfDocument):
    def __init__(self, context: android.content.Context, attributes: android.print_.PrintAttributes, /) -> None: ...
    def getPageContentRect(self) -> android.graphics.Rect: ...
    def getPageHeight(self) -> int: ...
    def getPageWidth(self) -> int: ...
    def startPage(self, pageNumber: int | java.jint | java.lang.Integer, /) -> android.graphics.pdf.PdfDocument.Page: ...
