import typing

import android.content
import java.lang

class RoleManager(java.lang.Object):
    ROLE_ASSISTANT: typing.ClassVar[str] = ...
    ROLE_BROWSER: typing.ClassVar[str] = ...
    ROLE_CALL_REDIRECTION: typing.ClassVar[str] = ...
    ROLE_CALL_SCREENING: typing.ClassVar[str] = ...
    ROLE_DIALER: typing.ClassVar[str] = ...
    ROLE_EMERGENCY: typing.ClassVar[str] = ...
    ROLE_HOME: typing.ClassVar[str] = ...
    ROLE_NOTES: typing.ClassVar[str] = ...
    ROLE_SMS: typing.ClassVar[str] = ...
    ROLE_WALLET: typing.ClassVar[str] = ...
    def createRequestRoleIntent(self, roleName: str | java.lang.String, /) -> android.content.Intent: ...
    def isRoleAvailable(self, roleName: str | java.lang.String, /) -> bool: ...
    def isRoleHeld(self, roleName: str | java.lang.String, /) -> bool: ...
