import android.net.wifi.hotspot2
import java.lang

class PpsMoParser(java.lang.Object):
    @staticmethod
    def parseMoText(xmlString: str | java.lang.String, /) -> android.net.wifi.hotspot2.PasspointConfiguration: ...
