import typing

import android.animation
import android.app
import android.content
import android.content.res
import android.database
import android.graphics
import android.graphics.drawable
import android.media
import android.net
import android.os
import android.text
import android.text.method
import android.text.style
import android.transition
import android.util
import android.view
import android.view.accessibility
import android.view.animation
import android.view.autofill
import android.view.inputmethod
import android.view.textclassifier
import android.view.translation
import java
import java.chaquopy
import java.io
import java.lang
import java.lang.annotation
import java.util
import java.util.function

class AbsListView(android.text.TextWatcher, android.view.ViewTreeObserver.OnGlobalLayoutListener, android.view.ViewTreeObserver.OnTouchModeChangeListener, AdapterView[ListAdapter], Filter.FilterListener):
    CHOICE_MODE_MULTIPLE: typing.ClassVar[int] = ...
    CHOICE_MODE_MULTIPLE_MODAL: typing.ClassVar[int] = ...
    CHOICE_MODE_NONE: typing.ClassVar[int] = ...
    CHOICE_MODE_SINGLE: typing.ClassVar[int] = ...
    TRANSCRIPT_MODE_ALWAYS_SCROLL: typing.ClassVar[int] = ...
    TRANSCRIPT_MODE_DISABLED: typing.ClassVar[int] = ...
    TRANSCRIPT_MODE_NORMAL: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def addTouchables(self, views: java.util.ArrayList[android.view.View], /) -> None: ...
    def afterTextChanged(self, s: android.text.Editable, /) -> None: ...
    def beforeTextChanged(self, s: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, after: int | java.jint | java.lang.Integer, /) -> None: ...
    def canScrollList(self, direction: int | java.jint | java.lang.Integer, /) -> bool: ...
    def checkInputConnectionProxy(self, view: android.view.View, /) -> bool: ...
    def checkLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> bool: ...
    def clearChoices(self) -> None: ...
    def clearTextFilter(self) -> None: ...
    def computeVerticalScrollExtent(self) -> int: ...
    def computeVerticalScrollOffset(self) -> int: ...
    def computeVerticalScrollRange(self) -> int: ...
    def deferNotifyDataSetChanged(self) -> None: ...
    def dispatchDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def dispatchDrawableHotspotChanged(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> None: ...
    def dispatchSetPressed(self, pressed: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def draw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def drawableStateChanged(self) -> None: ...
    def fling(self, velocityY: int | java.jint | java.lang.Integer, /) -> None: ...
    def generateDefaultLayoutParams(self) -> android.view.ViewGroup.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, attrs: android.util.AttributeSet, /) -> AbsListView.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> android.view.ViewGroup.LayoutParams: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getBottomEdgeEffectColor(self) -> int: ...
    def getBottomFadingEdgeStrength(self) -> float: ...
    def getBottomPaddingOffset(self) -> int: ...
    def getCacheColorHint(self) -> int: ...
    def getCheckedItemCount(self) -> int: ...
    def getCheckedItemIds(self) -> java.chaquopy.JavaArrayJLong: ...
    def getCheckedItemPosition(self) -> int: ...
    def getCheckedItemPositions(self) -> android.util.SparseBooleanArray: ...
    def getChoiceMode(self) -> int: ...
    def getContextMenuInfo(self) -> android.view.ContextMenu.ContextMenuInfo: ...
    def getFocusedRect(self, r: android.graphics.Rect, /) -> None: ...
    def getLeftPaddingOffset(self) -> int: ...
    def getListPaddingBottom(self) -> int: ...
    def getListPaddingLeft(self) -> int: ...
    def getListPaddingRight(self) -> int: ...
    def getListPaddingTop(self) -> int: ...
    def getRightPaddingOffset(self) -> int: ...
    def getSelectedView(self) -> android.view.View: ...
    def getSelector(self) -> android.graphics.drawable.Drawable: ...
    def getSolidColor(self) -> int: ...
    def getTextFilter(self) -> java.lang.CharSequence | None: ...
    def getTopEdgeEffectColor(self) -> int: ...
    def getTopFadingEdgeStrength(self) -> float: ...
    def getTopPaddingOffset(self) -> int: ...
    def getTranscriptMode(self) -> int: ...
    def getVerticalScrollbarWidth(self) -> int: ...
    def handleDataChanged(self) -> None: ...
    def hasTextFilter(self) -> bool: ...
    def invalidateViews(self) -> None: ...
    def isDrawSelectorOnTop(self) -> bool: ...
    def isFastScrollAlwaysVisible(self) -> bool: ...
    def isFastScrollEnabled(self) -> bool: ...
    def isInFilterMode(self) -> bool: ...
    def isItemChecked(self, position: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isPaddingOffsetRequired(self) -> bool: ...
    def isScrollingCacheEnabled(self) -> bool: ...
    def isSelectedChildViewEnabled(self) -> bool: ...
    def isSmoothScrollbarEnabled(self) -> bool: ...
    def isStackFromBottom(self) -> bool: ...
    def isTextFilterEnabled(self) -> bool: ...
    def jumpDrawablesToCurrentState(self) -> None: ...
    def layoutChildren(self) -> None: ...
    def onAttachedToWindow(self) -> None: ...
    def onCancelPendingInputEvents(self) -> None: ...
    def onCreateInputConnection(self, outAttrs: android.view.inputmethod.EditorInfo, /) -> android.view.inputmethod.InputConnection: ...
    def onDetachedFromWindow(self) -> None: ...
    def onDisplayHint(self, hint: int | java.jint | java.lang.Integer, /) -> None: ...
    def onFilterComplete(self, count: int | java.jint | java.lang.Integer, /) -> None: ...
    def onFocusChanged(self, gainFocus: bool | java.jboolean | java.lang.Boolean, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> None: ...
    def onGenericMotionEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onGlobalLayout(self) -> None: ...
    def onInitializeAccessibilityNodeInfoForItem(self, view: android.view.View, position: int | java.jint | java.lang.Integer, info: android.view.accessibility.AccessibilityNodeInfo, /) -> None: ...
    def onInterceptHoverEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onInterceptTouchEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onNestedFling(self, target: android.view.View, velocityX: float | java.jfloat | java.lang.Float, velocityY: float | java.jfloat | java.lang.Float, consumed: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def onNestedScroll(self, target: android.view.View, dxConsumed: int | java.jint | java.lang.Integer, dyConsumed: int | java.jint | java.lang.Integer, dxUnconsumed: int | java.jint | java.lang.Integer, dyUnconsumed: int | java.jint | java.lang.Integer, /) -> None: ...
    def onNestedScrollAccepted(self, child: android.view.View, target: android.view.View, axes: int | java.jint | java.lang.Integer, /) -> None: ...
    def onOverScrolled(self, scrollX: int | java.jint | java.lang.Integer, scrollY: int | java.jint | java.lang.Integer, clampedX: bool | java.jboolean | java.lang.Boolean, clampedY: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onProvideContentCaptureStructure(self, structure: android.view.ViewStructure, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRemoteAdapterConnected(self) -> bool: ...
    def onRemoteAdapterDisconnected(self) -> None: ...
    def onResolvePointerIcon(self, event: android.view.MotionEvent, pointerIndex: int | java.jint | java.lang.Integer, /) -> android.view.PointerIcon: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onRtlPropertiesChanged(self, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onSizeChanged(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, oldw: int | java.jint | java.lang.Integer, oldh: int | java.jint | java.lang.Integer, /) -> None: ...
    def onStartNestedScroll(self, child: android.view.View, target: android.view.View, nestedScrollAxes: int | java.jint | java.lang.Integer, /) -> bool: ...
    def onTextChanged(self, s: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, before: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTouchEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def onTouchModeChanged(self, isInTouchMode: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onWindowFocusChanged(self, hasWindowFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def performItemClick(self, view: android.view.View, position: int | java.jint | java.lang.Integer, id: int | java.jlong | java.lang.Long, /) -> bool: ...
    def pointToPosition(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> int: ...
    def pointToRowId(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> int: ...
    def reclaimViews(self, views: java.util.List[android.view.View], /) -> None: ...
    def requestDisallowInterceptTouchEvent(self, disallowIntercept: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def requestLayout(self) -> None: ...
    def scrollListBy(self, y: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAdapter(self, adapter: ListAdapter, /) -> None: ...
    def setBottomEdgeEffectColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCacheColorHint(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setChoiceMode(self, choiceMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDrawSelectorOnTop(self, onTop: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setEdgeEffectColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFastScrollAlwaysVisible(self, alwaysShow: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFastScrollEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFastScrollStyle(self, styleResId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFilterText(self, filterText: str | java.lang.String, /) -> None: ...
    def setFriction(self, friction: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setItemChecked(self, position: int | java.jint | java.lang.Integer, value: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMultiChoiceModeListener(self, listener: AbsListView.MultiChoiceModeListener, /) -> None: ...
    def setOnScrollListener(self, l: AbsListView.OnScrollListener, /) -> None: ...
    def setRecyclerListener(self, listener: AbsListView.RecyclerListener, /) -> None: ...
    def setRemoteViewsAdapter(self, intent: android.content.Intent, /) -> None: ...
    def setScrollBarStyle(self, style: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScrollIndicators(self, up: android.view.View, down: android.view.View, /) -> None: ...
    def setScrollingCacheEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSelectedChildViewEnabled(self, selectedChildViewEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSelectionFromTop(self, position: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSelector(self, resID: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSelector(self, sel: android.graphics.drawable.Drawable, /) -> None: ...
    def setSmoothScrollbarEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setStackFromBottom(self, stackFromBottom: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTextFilterEnabled(self, textFilterEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTopEdgeEffectColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTranscriptMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setVelocityScale(self, scale: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setVerticalScrollbarPosition(self, position: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def showContextMenu(self) -> bool: ...
    @typing.overload
    def showContextMenu(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> bool: ...
    @typing.overload
    def showContextMenuForChild(self, originalView: android.view.View, /) -> bool: ...
    @typing.overload
    def showContextMenuForChild(self, originalView: android.view.View, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> bool: ...
    def smoothScrollBy(self, distance: int | java.jint | java.lang.Integer, duration: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def smoothScrollToPosition(self, position: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def smoothScrollToPosition(self, position: int | java.jint | java.lang.Integer, boundPosition: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def smoothScrollToPositionFromTop(self, position: int | java.jint | java.lang.Integer, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def smoothScrollToPositionFromTop(self, position: int | java.jint | java.lang.Integer, offset: int | java.jint | java.lang.Integer, duration: int | java.jint | java.lang.Integer, /) -> None: ...
    def verifyDrawable(self, dr: android.graphics.drawable.Drawable, /) -> bool: ...

    class LayoutParams(android.view.ViewGroup.LayoutParams):
        @typing.overload
        def __init__(self, source: android.view.ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, c: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
        @typing.overload
        def __init__(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, viewType: int | java.jint | java.lang.Integer, /) -> None: ...

    class SelectionBoundsAdjuster(java.lang.Object):
        def adjustListItemSelectionBounds(self, arg1: android.graphics.Rect, /) -> None: ...

    class RecyclerListener(java.lang.Object):
        def onMovedToScrapHeap(self, arg1: android.view.View, /) -> None: ...

    class OnScrollListener(java.lang.Object):
        SCROLL_STATE_FLING: typing.ClassVar[int] = ...
        SCROLL_STATE_IDLE: typing.ClassVar[int] = ...
        SCROLL_STATE_TOUCH_SCROLL: typing.ClassVar[int] = ...
        def onScroll(self, arg1: AbsListView, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
        def onScrollStateChanged(self, arg1: AbsListView, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

    class MultiChoiceModeListener(android.view.ActionMode.Callback):
        def onItemCheckedStateChanged(self, arg1: android.view.ActionMode, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jlong | java.lang.Long, arg4: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class AbsSeekBar(ProgressBar):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def drawableHotspotChanged(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> None: ...
    def drawableStateChanged(self) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getKeyProgressIncrement(self) -> int: ...
    def getSplitTrack(self) -> bool: ...
    def getThumb(self) -> android.graphics.drawable.Drawable: ...
    def getThumbOffset(self) -> int: ...
    def getThumbTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getThumbTintList(self) -> android.content.res.ColorStateList | None: ...
    def getThumbTintMode(self) -> android.graphics.PorterDuff.Mode | None: ...
    def getTickMark(self) -> android.graphics.drawable.Drawable: ...
    def getTickMarkTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getTickMarkTintList(self) -> android.content.res.ColorStateList | None: ...
    def getTickMarkTintMode(self) -> android.graphics.PorterDuff.Mode | None: ...
    def jumpDrawablesToCurrentState(self) -> None: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRtlPropertiesChanged(self, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSizeChanged(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, oldw: int | java.jint | java.lang.Integer, oldh: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def setKeyProgressIncrement(self, increment: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMax(self, max: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMin(self, min: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSplitTrack(self, splitTrack: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSystemGestureExclusionRects(self, rects: java.util.List[android.graphics.Rect], /) -> None: ...
    def setThumb(self, thumb: android.graphics.drawable.Drawable, /) -> None: ...
    def setThumbOffset(self, thumbOffset: int | java.jint | java.lang.Integer, /) -> None: ...
    def setThumbTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setThumbTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setThumbTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> None: ...
    def setTickMark(self, tickMark: android.graphics.drawable.Drawable, /) -> None: ...
    def setTickMarkTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setTickMarkTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setTickMarkTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> None: ...
    def verifyDrawable(self, who: android.graphics.drawable.Drawable, /) -> bool: ...

class AbsSpinner(AdapterView[SpinnerAdapter]):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def autofill(self, value: android.view.autofill.AutofillValue, /) -> None: ...
    def dispatchRestoreInstanceState(self, container: android.util.SparseArray[android.os.Parcelable], /) -> None: ...
    def generateDefaultLayoutParams(self) -> android.view.ViewGroup.LayoutParams: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAdapter(self) -> SpinnerAdapter: ...
    def getAutofillType(self) -> int: ...
    def getAutofillValue(self) -> android.view.autofill.AutofillValue: ...
    def getCount(self) -> int: ...
    def getSelectedView(self) -> android.view.View: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def pointToPosition(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> int: ...
    def requestLayout(self) -> None: ...
    def setAdapter(self, adapter: SpinnerAdapter, /) -> None: ...
    @typing.overload
    def setSelection(self, position: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSelection(self, position: int | java.jint | java.lang.Integer, animate: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class AbsoluteLayout(android.view.ViewGroup):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def checkLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> bool: ...
    def generateDefaultLayoutParams(self) -> android.view.ViewGroup.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, attrs: android.util.AttributeSet, /) -> android.view.ViewGroup.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> android.view.ViewGroup.LayoutParams: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def shouldDelayChildPressedState(self) -> bool: ...

    class LayoutParams(android.view.ViewGroup.LayoutParams):
        x: int = ...
        y: int = ...
        @typing.overload
        def __init__(self, source: android.view.ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, c: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
        @typing.overload
        def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> None: ...
        def debug(self, output: str | java.lang.String, /) -> str: ...

class ActionMenuView(LinearLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def checkLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> bool: ...
    def dismissPopupMenus(self) -> None: ...
    def generateDefaultLayoutParams(self) -> ActionMenuView.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, attrs: android.util.AttributeSet, /) -> ActionMenuView.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> ActionMenuView.LayoutParams: ...
    def getMenu(self) -> android.view.Menu: ...
    def getOverflowIcon(self) -> android.graphics.drawable.Drawable | None: ...
    def getPopupTheme(self) -> int: ...
    def hideOverflowMenu(self) -> bool: ...
    def isOverflowMenuShowing(self) -> bool: ...
    def onConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOnMenuItemClickListener(self, listener: ActionMenuView.OnMenuItemClickListener, /) -> None: ...
    def setOverflowIcon(self, icon: android.graphics.drawable.Drawable, /) -> None: ...
    def setPopupTheme(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def showOverflowMenu(self) -> bool: ...

    class LayoutParams(LinearLayout.LayoutParams):
        @typing.overload
        def __init__(self, other: android.view.ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, other: ActionMenuView.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, c: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...

    class OnMenuItemClickListener(java.lang.Object):
        def onMenuItemClick(self, arg1: android.view.MenuItem, /) -> bool: ...

class Adapter(java.lang.Object):
    IGNORE_ITEM_VIEW_TYPE: typing.ClassVar[int] = ...
    NO_SELECTION: typing.ClassVar[int] = ...
    def getAutofillOptions(self) -> java.chaquopy.JavaArray[java.lang.CharSequence] | None: ...
    def getCount(self) -> int: ...
    def getItem(self, arg1: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def getItemId(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getItemViewType(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getView(self, arg1: int | java.jint | java.lang.Integer, arg2: android.view.View, arg3: android.view.ViewGroup, /) -> android.view.View: ...
    def getViewTypeCount(self) -> int: ...
    def hasStableIds(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def registerDataSetObserver(self, arg1: android.database.DataSetObserver, /) -> None: ...
    def unregisterDataSetObserver(self, arg1: android.database.DataSetObserver, /) -> None: ...

_AdapterView__T = typing.TypeVar('_AdapterView__T')  # <T>
class AdapterView(android.view.ViewGroup, typing.Generic[_AdapterView__T]):
    INVALID_POSITION: typing.ClassVar[int] = ...
    INVALID_ROW_ID: typing.ClassVar[int] = ...
    ITEM_VIEW_TYPE_HEADER_OR_FOOTER: typing.ClassVar[int] = ...
    ITEM_VIEW_TYPE_IGNORE: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, index: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, index: int | java.jint | java.lang.Integer, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def canAnimate(self) -> bool: ...
    def dispatchRestoreInstanceState(self, container: android.util.SparseArray[android.os.Parcelable], /) -> None: ...
    def dispatchSaveInstanceState(self, container: android.util.SparseArray[android.os.Parcelable], /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAdapter(self) -> _AdapterView__T: ...
    def getCount(self) -> int: ...
    def getEmptyView(self) -> android.view.View: ...
    def getFirstVisiblePosition(self) -> int: ...
    def getItemAtPosition(self, position: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def getItemIdAtPosition(self, position: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLastVisiblePosition(self) -> int: ...
    def getOnItemClickListener(self) -> AdapterView.OnItemClickListener | None: ...
    def getOnItemLongClickListener(self) -> AdapterView.OnItemLongClickListener | None: ...
    def getOnItemSelectedListener(self) -> AdapterView.OnItemSelectedListener | None: ...
    def getPositionForView(self, view: android.view.View, /) -> int: ...
    def getSelectedItem(self) -> java.lang.Object | None: ...
    def getSelectedItemId(self) -> int: ...
    def getSelectedItemPosition(self) -> int: ...
    def getSelectedView(self) -> android.view.View | None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onProvideAutofillStructure(self, structure: android.view.ViewStructure, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def performItemClick(self, view: android.view.View, position: int | java.jint | java.lang.Integer, id: int | java.jlong | java.lang.Long, /) -> bool: ...
    def removeAllViews(self) -> None: ...
    def removeView(self, child: android.view.View, /) -> None: ...
    def removeViewAt(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAdapter(self, arg1: _AdapterView__T, /) -> None: ...
    def setEmptyView(self, emptyView: android.view.View, /) -> None: ...
    def setFocusable(self, focusable: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFocusableInTouchMode(self, focusable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOnClickListener(self, l: android.view.View.OnClickListener, /) -> None: ...
    def setOnItemClickListener(self, listener: AdapterView.OnItemClickListener, /) -> None: ...
    def setOnItemLongClickListener(self, listener: AdapterView.OnItemLongClickListener, /) -> None: ...
    def setOnItemSelectedListener(self, listener: AdapterView.OnItemSelectedListener, /) -> None: ...
    def setSelection(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnItemSelectedListener(java.lang.Object):
        def onItemSelected(self, arg1: AdapterView[java.lang.Object], arg2: android.view.View, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jlong | java.lang.Long, /) -> None: ...
        def onNothingSelected(self, arg1: AdapterView[java.lang.Object], /) -> None: ...

    class OnItemLongClickListener(java.lang.Object):
        def onItemLongClick(self, arg1: AdapterView[java.lang.Object], arg2: android.view.View, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jlong | java.lang.Long, /) -> bool: ...

    class OnItemClickListener(java.lang.Object):
        def onItemClick(self, arg1: AdapterView[java.lang.Object], arg2: android.view.View, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jlong | java.lang.Long, /) -> None: ...

    class AdapterContextMenuInfo(android.view.ContextMenu.ContextMenuInfo):
        id: int = ...
        position: int = ...
        targetView: android.view.View = ...
        def __init__(self, targetView: android.view.View, position: int | java.jint | java.lang.Integer, id: int | java.jlong | java.lang.Long, /) -> None: ...

class AdapterViewAnimator(AdapterView[Adapter], Advanceable):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def advance(self) -> None: ...
    def deferNotifyDataSetChanged(self) -> None: ...
    def fyiWillBeAdvancedByHostKThx(self) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAdapter(self) -> Adapter: ...
    def getBaseline(self) -> int: ...
    def getCurrentView(self) -> android.view.View: ...
    def getDisplayedChild(self) -> int: ...
    def getInAnimation(self) -> android.animation.ObjectAnimator | None: ...
    def getOutAnimation(self) -> android.animation.ObjectAnimator | None: ...
    def getSelectedView(self) -> android.view.View: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRemoteAdapterConnected(self) -> bool: ...
    def onRemoteAdapterDisconnected(self) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onTouchEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def setAdapter(self, adapter: Adapter, /) -> None: ...
    def setAnimateFirstView(self, animate: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDisplayedChild(self, whichChild: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setInAnimation(self, inAnimation: android.animation.ObjectAnimator, /) -> None: ...
    @typing.overload
    def setInAnimation(self, context: android.content.Context, resourceID: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setOutAnimation(self, outAnimation: android.animation.ObjectAnimator, /) -> None: ...
    @typing.overload
    def setOutAnimation(self, context: android.content.Context, resourceID: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRemoteViewsAdapter(self, intent: android.content.Intent, /) -> None: ...
    def setSelection(self, position: int | java.jint | java.lang.Integer, /) -> None: ...
    def showNext(self) -> None: ...
    def showPrevious(self) -> None: ...

class AdapterViewFlipper(AdapterViewAnimator):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def fyiWillBeAdvancedByHostKThx(self) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getFlipInterval(self) -> int: ...
    def isAutoStart(self) -> bool: ...
    def isFlipping(self) -> bool: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onWindowVisibilityChanged(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAdapter(self, adapter: Adapter, /) -> None: ...
    def setAutoStart(self, autoStart: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFlipInterval(self, flipInterval: int | java.jint | java.lang.Integer, /) -> None: ...
    def showNext(self) -> None: ...
    def showPrevious(self) -> None: ...
    def startFlipping(self) -> None: ...
    def stopFlipping(self) -> None: ...

class Advanceable(java.lang.Object):
    def advance(self) -> None: ...
    def fyiWillBeAdvancedByHostKThx(self) -> None: ...

class AlphabetIndexer(android.database.DataSetObserver, SectionIndexer):
    mAlphabet: java.lang.CharSequence = ...
    mColumnIndex: int = ...
    mDataCursor: android.database.Cursor = ...
    def __init__(self, cursor: android.database.Cursor, sortedColumnIndex: int | java.jint | java.lang.Integer, alphabet: java.lang.CharSequence, /) -> None: ...
    def compare(self, word: str | java.lang.String, letter: str | java.lang.String, /) -> int: ...
    def getPositionForSection(self, sectionIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getSectionForPosition(self, position: int | java.jint | java.lang.Integer, /) -> int: ...
    def getSections(self) -> java.chaquopy.JavaArray[java.lang.Object]: ...
    def onChanged(self) -> None: ...
    def onInvalidated(self) -> None: ...
    def setCursor(self, cursor: android.database.Cursor, /) -> None: ...

class AnalogClock(android.view.View):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getDialTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getDialTintList(self) -> android.content.res.ColorStateList | None: ...
    def getHourHandTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getHourHandTintList(self) -> android.content.res.ColorStateList | None: ...
    def getMinuteHandTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getMinuteHandTintList(self) -> android.content.res.ColorStateList | None: ...
    def getSecondHandTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getSecondHandTintList(self) -> android.content.res.ColorStateList | None: ...
    def getTimeZone(self) -> str | None: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSizeChanged(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, oldw: int | java.jint | java.lang.Integer, oldh: int | java.jint | java.lang.Integer, /) -> None: ...
    def onVisibilityAggregated(self, isVisible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDial(self, icon: android.graphics.drawable.Icon, /) -> None: ...
    def setDialTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setDialTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setHourHand(self, icon: android.graphics.drawable.Icon, /) -> None: ...
    def setHourHandTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setHourHandTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setMinuteHand(self, icon: android.graphics.drawable.Icon, /) -> None: ...
    def setMinuteHandTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setMinuteHandTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setSecondHand(self, icon: android.graphics.drawable.Icon, /) -> None: ...
    def setSecondHandTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setSecondHandTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setTimeZone(self, timeZone: str | java.lang.String, /) -> None: ...

_ArrayAdapter__T = typing.TypeVar('_ArrayAdapter__T')  # <T>
class ArrayAdapter(BaseAdapter, Filterable, ThemedSpinnerAdapter, typing.Generic[_ArrayAdapter__T]):
    @typing.overload
    def __init__(self, context: android.content.Context, resource: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, resource: int | java.jint | java.lang.Integer, textViewResourceId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, resource: int | java.jint | java.lang.Integer, objects: java.util.List[_ArrayAdapter__T], /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, resource: int | java.jint | java.lang.Integer, objects: java.chaquopy.JavaArray[_ArrayAdapter__T], /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, resource: int | java.jint | java.lang.Integer, textViewResourceId: int | java.jint | java.lang.Integer, objects: java.util.List[_ArrayAdapter__T], /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, resource: int | java.jint | java.lang.Integer, textViewResourceId: int | java.jint | java.lang.Integer, objects: java.chaquopy.JavaArray[_ArrayAdapter__T], /) -> None: ...
    def add(self, object: _ArrayAdapter__T, /) -> None: ...
    @typing.overload
    def addAll(self, collection: java.util.Collection[_ArrayAdapter__T], /) -> None: ...
    @typing.overload
    def addAll(self, *items: _ArrayAdapter__T) -> None: ...
    def clear(self) -> None: ...
    @staticmethod
    def createFromResource(context: android.content.Context, textArrayResId: int | java.jint | java.lang.Integer, textViewResId: int | java.jint | java.lang.Integer, /) -> ArrayAdapter[java.lang.CharSequence]: ...
    def getAutofillOptions(self) -> java.chaquopy.JavaArray[java.lang.CharSequence]: ...
    def getContext(self) -> android.content.Context: ...
    def getCount(self) -> int: ...
    def getDropDownView(self, position: int | java.jint | java.lang.Integer, convertView: android.view.View, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def getDropDownViewTheme(self) -> android.content.res.Resources.Theme | None: ...
    def getFilter(self) -> Filter: ...
    def getItem(self, position: int | java.jint | java.lang.Integer, /) -> _ArrayAdapter__T | None: ...
    def getItemId(self, position: int | java.jint | java.lang.Integer, /) -> int: ...
    def getPosition(self, item: _ArrayAdapter__T, /) -> int: ...
    def getView(self, position: int | java.jint | java.lang.Integer, convertView: android.view.View, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def insert(self, object: _ArrayAdapter__T, index: int | java.jint | java.lang.Integer, /) -> None: ...
    def notifyDataSetChanged(self) -> None: ...
    def remove(self, object: _ArrayAdapter__T, /) -> None: ...
    def setDropDownViewResource(self, resource: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDropDownViewTheme(self, theme: android.content.res.Resources.Theme, /) -> None: ...
    def setNotifyOnChange(self, notifyOnChange: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def sort(self, comparator: java.util.Comparator[_ArrayAdapter__T], /) -> None: ...

class AutoCompleteTextView(EditText, Filter.FilterListener):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, popupTheme: android.content.res.Resources.Theme, /) -> None: ...
    def clearListSelection(self) -> None: ...
    def convertSelectionToString(self, selectedItem: java.lang.Object | int | bool | float | str, /) -> java.lang.CharSequence: ...
    def dismissDropDown(self) -> None: ...
    def enoughToFilter(self) -> bool: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAdapter(self) -> ListAdapter: ...
    def getCompletionHint(self) -> java.lang.CharSequence: ...
    def getDropDownAnchor(self) -> int: ...
    def getDropDownBackground(self) -> android.graphics.drawable.Drawable: ...
    def getDropDownHeight(self) -> int: ...
    def getDropDownHorizontalOffset(self) -> int: ...
    def getDropDownVerticalOffset(self) -> int: ...
    def getDropDownWidth(self) -> int: ...
    def getFilter(self) -> Filter: ...
    def getInputMethodMode(self) -> int: ...
    def getItemClickListener(self) -> AdapterView.OnItemClickListener: ...
    def getItemSelectedListener(self) -> AdapterView.OnItemSelectedListener: ...
    def getListSelection(self) -> int: ...
    def getOnItemClickListener(self) -> AdapterView.OnItemClickListener: ...
    def getOnItemSelectedListener(self) -> AdapterView.OnItemSelectedListener: ...
    def getThreshold(self) -> int: ...
    def getValidator(self) -> AutoCompleteTextView.Validator: ...
    def isPerformingCompletion(self) -> bool: ...
    def isPopupShowing(self) -> bool: ...
    def onAttachedToWindow(self) -> None: ...
    def onCommitCompletion(self, completion: android.view.inputmethod.CompletionInfo, /) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onDisplayHint(self, hint: int | java.jint | java.lang.Integer, /) -> None: ...
    def onFilterComplete(self, count: int | java.jint | java.lang.Integer, /) -> None: ...
    def onFocusChanged(self, focused: bool | java.jboolean | java.lang.Boolean, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> None: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyPreIme(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onWindowFocusChanged(self, hasWindowFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def performCompletion(self) -> None: ...
    def performFiltering(self, text: java.lang.CharSequence, keyCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def performValidation(self) -> None: ...
    def refreshAutoCompleteResults(self) -> None: ...
    def replaceText(self, text: java.lang.CharSequence, /) -> None: ...
    def setAdapter(self, adapter: java.lang.Object, /) -> None: ...
    def setCompletionHint(self, hint: java.lang.CharSequence, /) -> None: ...
    def setDropDownAnchor(self, id: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDropDownBackgroundDrawable(self, d: android.graphics.drawable.Drawable, /) -> None: ...
    def setDropDownBackgroundResource(self, id: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDropDownHeight(self, height: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDropDownHorizontalOffset(self, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDropDownVerticalOffset(self, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDropDownWidth(self, width: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFrame(self, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setInputMethodMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setListSelection(self, position: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOnClickListener(self, listener: android.view.View.OnClickListener, /) -> None: ...
    def setOnDismissListener(self, dismissListener: AutoCompleteTextView.OnDismissListener, /) -> None: ...
    def setOnItemClickListener(self, l: AdapterView.OnItemClickListener, /) -> None: ...
    def setOnItemSelectedListener(self, l: AdapterView.OnItemSelectedListener, /) -> None: ...
    def setText(self, text: java.lang.CharSequence, filter: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setThreshold(self, threshold: int | java.jint | java.lang.Integer, /) -> None: ...
    def setValidator(self, validator: AutoCompleteTextView.Validator, /) -> None: ...
    def showDropDown(self) -> None: ...

    class Validator(java.lang.Object):
        def fixText(self, arg1: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
        def isValid(self, arg1: java.lang.CharSequence, /) -> bool: ...

    class OnDismissListener(java.lang.Object):
        def onDismiss(self) -> None: ...

class BaseAdapter(ListAdapter, SpinnerAdapter):
    def __init__(self) -> None: ...
    def areAllItemsEnabled(self) -> bool: ...
    def getAutofillOptions(self) -> java.chaquopy.JavaArray[java.lang.CharSequence]: ...
    def getDropDownView(self, position: int | java.jint | java.lang.Integer, convertView: android.view.View, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def getItemViewType(self, position: int | java.jint | java.lang.Integer, /) -> int: ...
    def getViewTypeCount(self) -> int: ...
    def hasStableIds(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def isEnabled(self, position: int | java.jint | java.lang.Integer, /) -> bool: ...
    def notifyDataSetChanged(self) -> None: ...
    def notifyDataSetInvalidated(self) -> None: ...
    def registerDataSetObserver(self, observer: android.database.DataSetObserver, /) -> None: ...
    def setAutofillOptions(self, *options: java.lang.CharSequence) -> None: ...
    def unregisterDataSetObserver(self, observer: android.database.DataSetObserver, /) -> None: ...

class BaseExpandableListAdapter(ExpandableListAdapter, HeterogeneousExpandableList):
    def __init__(self) -> None: ...
    def areAllItemsEnabled(self) -> bool: ...
    def getChildType(self, groupPosition: int | java.jint | java.lang.Integer, childPosition: int | java.jint | java.lang.Integer, /) -> int: ...
    def getChildTypeCount(self) -> int: ...
    def getCombinedChildId(self, groupId: int | java.jlong | java.lang.Long, childId: int | java.jlong | java.lang.Long, /) -> int: ...
    def getCombinedGroupId(self, groupId: int | java.jlong | java.lang.Long, /) -> int: ...
    def getGroupType(self, groupPosition: int | java.jint | java.lang.Integer, /) -> int: ...
    def getGroupTypeCount(self) -> int: ...
    def isEmpty(self) -> bool: ...
    def notifyDataSetChanged(self) -> None: ...
    def notifyDataSetInvalidated(self) -> None: ...
    def onGroupCollapsed(self, groupPosition: int | java.jint | java.lang.Integer, /) -> None: ...
    def onGroupExpanded(self, groupPosition: int | java.jint | java.lang.Integer, /) -> None: ...
    def registerDataSetObserver(self, observer: android.database.DataSetObserver, /) -> None: ...
    def unregisterDataSetObserver(self, observer: android.database.DataSetObserver, /) -> None: ...

class Button(TextView):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def onResolvePointerIcon(self, event: android.view.MotionEvent, pointerIndex: int | java.jint | java.lang.Integer, /) -> android.view.PointerIcon: ...

class CalendarView(FrameLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getDate(self) -> int: ...
    def getDateTextAppearance(self) -> int: ...
    def getFirstDayOfWeek(self) -> int: ...
    def getFocusedMonthDateColor(self) -> int: ...
    def getMaxDate(self) -> int: ...
    def getMinDate(self) -> int: ...
    def getSelectedDateVerticalBar(self) -> android.graphics.drawable.Drawable: ...
    def getSelectedWeekBackgroundColor(self) -> int: ...
    def getShowWeekNumber(self) -> bool: ...
    def getShownWeekCount(self) -> int: ...
    def getUnfocusedMonthDateColor(self) -> int: ...
    def getWeekDayTextAppearance(self) -> int: ...
    def getWeekNumberColor(self) -> int: ...
    def getWeekSeparatorLineColor(self) -> int: ...
    def onConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    @typing.overload
    def setDate(self, date: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def setDate(self, date: int | java.jlong | java.lang.Long, animate: bool | java.jboolean | java.lang.Boolean, center: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDateTextAppearance(self, resourceId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFirstDayOfWeek(self, firstDayOfWeek: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFocusedMonthDateColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaxDate(self, maxDate: int | java.jlong | java.lang.Long, /) -> None: ...
    def setMinDate(self, minDate: int | java.jlong | java.lang.Long, /) -> None: ...
    def setOnDateChangeListener(self, listener: CalendarView.OnDateChangeListener, /) -> None: ...
    @typing.overload
    def setSelectedDateVerticalBar(self, resourceId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSelectedDateVerticalBar(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def setSelectedWeekBackgroundColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setShowWeekNumber(self, showWeekNumber: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setShownWeekCount(self, count: int | java.jint | java.lang.Integer, /) -> None: ...
    def setUnfocusedMonthDateColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setWeekDayTextAppearance(self, resourceId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setWeekNumberColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setWeekSeparatorLineColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnDateChangeListener(java.lang.Object):
        def onSelectedDayChange(self, arg1: CalendarView, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...

class CheckBox(CompoundButton):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...

class Checkable(java.lang.Object):
    def isChecked(self) -> bool: ...
    def setChecked(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def toggle(self) -> None: ...

class CheckedTextView(Checkable, TextView):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def drawableHotspotChanged(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> None: ...
    def drawableStateChanged(self) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getCheckMarkDrawable(self) -> android.graphics.drawable.Drawable: ...
    def getCheckMarkTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getCheckMarkTintList(self) -> android.content.res.ColorStateList | None: ...
    def getCheckMarkTintMode(self) -> android.graphics.PorterDuff.Mode | None: ...
    def isChecked(self) -> bool: ...
    def jumpDrawablesToCurrentState(self) -> None: ...
    def onCreateDrawableState(self, extraSpace: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onRtlPropertiesChanged(self, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    @typing.overload
    def setCheckMarkDrawable(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setCheckMarkDrawable(self, d: android.graphics.drawable.Drawable, /) -> None: ...
    def setCheckMarkTintBlendMode(self, tintMode: android.graphics.BlendMode, /) -> None: ...
    def setCheckMarkTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setCheckMarkTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> None: ...
    def setChecked(self, checked: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setVisibility(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def toggle(self) -> None: ...
    def verifyDrawable(self, who: android.graphics.drawable.Drawable, /) -> bool: ...

class Chronometer(TextView):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getBase(self) -> int: ...
    def getContentDescription(self) -> java.lang.CharSequence: ...
    def getFormat(self) -> str: ...
    def getOnChronometerTickListener(self) -> Chronometer.OnChronometerTickListener | None: ...
    def isCountDown(self) -> bool: ...
    def isTheFinalCountDown(self) -> bool: ...
    def onDetachedFromWindow(self) -> None: ...
    def onVisibilityChanged(self, changedView: android.view.View, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def onWindowVisibilityChanged(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBase(self, base: int | java.jlong | java.lang.Long, /) -> None: ...
    def setCountDown(self, countDown: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFormat(self, format: str | java.lang.String, /) -> None: ...
    def setOnChronometerTickListener(self, listener: Chronometer.OnChronometerTickListener, /) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...

    class OnChronometerTickListener(java.lang.Object):
        def onChronometerTick(self, arg1: Chronometer, /) -> None: ...

class CompoundButton(Button, Checkable):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def autofill(self, value: android.view.autofill.AutofillValue, /) -> None: ...
    def drawableHotspotChanged(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> None: ...
    def drawableStateChanged(self) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAutofillType(self) -> int: ...
    def getAutofillValue(self) -> android.view.autofill.AutofillValue: ...
    def getButtonDrawable(self) -> android.graphics.drawable.Drawable | None: ...
    def getButtonTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getButtonTintList(self) -> android.content.res.ColorStateList | None: ...
    def getButtonTintMode(self) -> android.graphics.PorterDuff.Mode | None: ...
    def getCompoundPaddingLeft(self) -> int: ...
    def getCompoundPaddingRight(self) -> int: ...
    def isChecked(self) -> bool: ...
    def jumpDrawablesToCurrentState(self) -> None: ...
    def onCreateDrawableState(self, extraSpace: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def performClick(self) -> bool: ...
    @typing.overload
    def setButtonDrawable(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setButtonDrawable(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def setButtonIcon(self, icon: android.graphics.drawable.Icon, /) -> None: ...
    def setButtonTintBlendMode(self, tintMode: android.graphics.BlendMode, /) -> None: ...
    def setButtonTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setButtonTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> None: ...
    def setChecked(self, checked: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOnCheckedChangeListener(self, listener: CompoundButton.OnCheckedChangeListener, /) -> None: ...
    def setStateDescription(self, stateDescription: java.lang.CharSequence, /) -> None: ...
    def toggle(self) -> None: ...
    def verifyDrawable(self, who: android.graphics.drawable.Drawable, /) -> bool: ...

    class OnCheckedChangeListener(java.lang.Object):
        def onCheckedChanged(self, arg1: CompoundButton, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class CursorAdapter(BaseAdapter, Filterable, ThemedSpinnerAdapter):
    FLAG_AUTO_REQUERY: typing.ClassVar[int] = ...
    FLAG_REGISTER_CONTENT_OBSERVER: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, c: android.database.Cursor, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, c: android.database.Cursor, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, c: android.database.Cursor, autoRequery: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def bindView(self, arg1: android.view.View, arg2: android.content.Context, arg3: android.database.Cursor, /) -> None: ...
    def changeCursor(self, cursor: android.database.Cursor, /) -> None: ...
    def convertToString(self, cursor: android.database.Cursor, /) -> java.lang.CharSequence: ...
    def getCount(self) -> int: ...
    def getCursor(self) -> android.database.Cursor: ...
    def getDropDownView(self, position: int | java.jint | java.lang.Integer, convertView: android.view.View, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def getDropDownViewTheme(self) -> android.content.res.Resources.Theme: ...
    def getFilter(self) -> Filter: ...
    def getFilterQueryProvider(self) -> FilterQueryProvider | None: ...
    def getItem(self, position: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def getItemId(self, position: int | java.jint | java.lang.Integer, /) -> int: ...
    def getView(self, position: int | java.jint | java.lang.Integer, convertView: android.view.View, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def hasStableIds(self) -> bool: ...
    def init(self, context: android.content.Context, c: android.database.Cursor, autoRequery: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def newDropDownView(self, context: android.content.Context, cursor: android.database.Cursor, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def newView(self, arg1: android.content.Context, arg2: android.database.Cursor, arg3: android.view.ViewGroup, /) -> android.view.View: ...
    def onContentChanged(self) -> None: ...
    def runQueryOnBackgroundThread(self, constraint: java.lang.CharSequence, /) -> android.database.Cursor: ...
    def setDropDownViewTheme(self, theme: android.content.res.Resources.Theme, /) -> None: ...
    def setFilterQueryProvider(self, filterQueryProvider: FilterQueryProvider, /) -> None: ...
    def swapCursor(self, newCursor: android.database.Cursor, /) -> android.database.Cursor | None: ...

class CursorTreeAdapter(BaseExpandableListAdapter, Filterable):
    @typing.overload
    def __init__(self, cursor: android.database.Cursor, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, cursor: android.database.Cursor, context: android.content.Context, autoRequery: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def bindChildView(self, arg1: android.view.View, arg2: android.content.Context, arg3: android.database.Cursor, arg4: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def bindGroupView(self, arg1: android.view.View, arg2: android.content.Context, arg3: android.database.Cursor, arg4: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def changeCursor(self, cursor: android.database.Cursor, /) -> None: ...
    def convertToString(self, cursor: android.database.Cursor, /) -> str: ...
    def getChild(self, groupPosition: int | java.jint | java.lang.Integer, childPosition: int | java.jint | java.lang.Integer, /) -> android.database.Cursor: ...
    def getChildId(self, groupPosition: int | java.jint | java.lang.Integer, childPosition: int | java.jint | java.lang.Integer, /) -> int: ...
    def getChildView(self, groupPosition: int | java.jint | java.lang.Integer, childPosition: int | java.jint | java.lang.Integer, isLastChild: bool | java.jboolean | java.lang.Boolean, convertView: android.view.View, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def getChildrenCount(self, groupPosition: int | java.jint | java.lang.Integer, /) -> int: ...
    def getChildrenCursor(self, arg1: android.database.Cursor, /) -> android.database.Cursor: ...
    def getCursor(self) -> android.database.Cursor: ...
    def getFilter(self) -> Filter: ...
    def getFilterQueryProvider(self) -> FilterQueryProvider: ...
    def getGroup(self, groupPosition: int | java.jint | java.lang.Integer, /) -> android.database.Cursor: ...
    def getGroupCount(self) -> int: ...
    def getGroupId(self, groupPosition: int | java.jint | java.lang.Integer, /) -> int: ...
    def getGroupView(self, groupPosition: int | java.jint | java.lang.Integer, isExpanded: bool | java.jboolean | java.lang.Boolean, convertView: android.view.View, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def hasStableIds(self) -> bool: ...
    def isChildSelectable(self, groupPosition: int | java.jint | java.lang.Integer, childPosition: int | java.jint | java.lang.Integer, /) -> bool: ...
    def newChildView(self, arg1: android.content.Context, arg2: android.database.Cursor, arg3: bool | java.jboolean | java.lang.Boolean, arg4: android.view.ViewGroup, /) -> android.view.View: ...
    def newGroupView(self, arg1: android.content.Context, arg2: android.database.Cursor, arg3: bool | java.jboolean | java.lang.Boolean, arg4: android.view.ViewGroup, /) -> android.view.View: ...
    @typing.overload
    def notifyDataSetChanged(self) -> None: ...
    @typing.overload
    def notifyDataSetChanged(self, releaseCursors: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def notifyDataSetInvalidated(self) -> None: ...
    def onGroupCollapsed(self, groupPosition: int | java.jint | java.lang.Integer, /) -> None: ...
    def runQueryOnBackgroundThread(self, constraint: java.lang.CharSequence, /) -> android.database.Cursor: ...
    def setChildrenCursor(self, groupPosition: int | java.jint | java.lang.Integer, childrenCursor: android.database.Cursor, /) -> None: ...
    def setFilterQueryProvider(self, filterQueryProvider: FilterQueryProvider, /) -> None: ...
    def setGroupCursor(self, cursor: android.database.Cursor, /) -> None: ...

class DatePicker(FrameLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def autofill(self, value: android.view.autofill.AutofillValue, /) -> None: ...
    def dispatchProvideAutofillStructure(self, structure: android.view.ViewStructure, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchRestoreInstanceState(self, container: android.util.SparseArray[android.os.Parcelable], /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAutofillType(self) -> int: ...
    def getAutofillValue(self) -> android.view.autofill.AutofillValue: ...
    def getCalendarView(self) -> CalendarView: ...
    def getCalendarViewShown(self) -> bool: ...
    def getDayOfMonth(self) -> int: ...
    def getFirstDayOfWeek(self) -> int: ...
    def getMaxDate(self) -> int: ...
    def getMinDate(self) -> int: ...
    def getMonth(self) -> int: ...
    def getSpinnersShown(self) -> bool: ...
    def getYear(self) -> int: ...
    def init(self, year: int | java.jint | java.lang.Integer, monthOfYear: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, onDateChangedListener: DatePicker.OnDateChangedListener, /) -> None: ...
    def isEnabled(self) -> bool: ...
    def onConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def setCalendarViewShown(self, shown: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFirstDayOfWeek(self, firstDayOfWeek: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaxDate(self, maxDate: int | java.jlong | java.lang.Long, /) -> None: ...
    def setMinDate(self, minDate: int | java.jlong | java.lang.Long, /) -> None: ...
    def setOnDateChangedListener(self, onDateChangedListener: DatePicker.OnDateChangedListener, /) -> None: ...
    def setSpinnersShown(self, shown: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def updateDate(self, year: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnDateChangedListener(java.lang.Object):
        def onDateChanged(self, arg1: DatePicker, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...

class DialerFilter(RelativeLayout):
    DIGITS_AND_LETTERS: typing.ClassVar[int] = ...
    DIGITS_AND_LETTERS_NO_DIGITS: typing.ClassVar[int] = ...
    DIGITS_AND_LETTERS_NO_LETTERS: typing.ClassVar[int] = ...
    DIGITS_ONLY: typing.ClassVar[int] = ...
    LETTERS_ONLY: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def append(self, text: str | java.lang.String, /) -> None: ...
    def clearText(self) -> None: ...
    def getDigits(self) -> java.lang.CharSequence: ...
    def getFilterText(self) -> java.lang.CharSequence: ...
    def getLetters(self) -> java.lang.CharSequence: ...
    def getMode(self) -> int: ...
    def isQwertyKeyboard(self) -> bool: ...
    def onFinishInflate(self) -> None: ...
    def onFocusChanged(self, focused: bool | java.jboolean | java.lang.Boolean, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> None: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onModeChange(self, oldMode: int | java.jint | java.lang.Integer, newMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def removeFilterWatcher(self, watcher: android.text.TextWatcher, /) -> None: ...
    def setDigitsWatcher(self, watcher: android.text.TextWatcher, /) -> None: ...
    def setFilterWatcher(self, watcher: android.text.TextWatcher, /) -> None: ...
    def setLettersWatcher(self, watcher: android.text.TextWatcher, /) -> None: ...
    def setMode(self, newMode: int | java.jint | java.lang.Integer, /) -> None: ...

class DigitalClock(TextView):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...

class EdgeEffect(java.lang.Object):
    DEFAULT_BLEND_MODE: typing.ClassVar[android.graphics.BlendMode] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def draw(self, canvas: android.graphics.Canvas, /) -> bool: ...
    def finish(self) -> None: ...
    def getBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getColor(self) -> int: ...
    def getDistance(self) -> float: ...
    def getMaxHeight(self) -> int: ...
    def isFinished(self) -> bool: ...
    def onAbsorb(self, velocity: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def onPull(self, deltaDistance: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def onPull(self, deltaDistance: float | java.jfloat | java.lang.Float, displacement: float | java.jfloat | java.lang.Float, /) -> None: ...
    def onPullDistance(self, deltaDistance: float | java.jfloat | java.lang.Float, displacement: float | java.jfloat | java.lang.Float, /) -> float: ...
    def onRelease(self) -> None: ...
    def setBlendMode(self, blendmode: android.graphics.BlendMode, /) -> None: ...
    def setColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSize(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...

class EditText(TextView):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def extendSelection(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getDefaultEditable(self) -> bool: ...
    def getDefaultMovementMethod(self) -> android.text.method.MovementMethod: ...
    def getFreezesText(self) -> bool: ...
    def getText(self) -> android.text.Editable: ...
    def isStyleShortcutEnabled(self) -> bool: ...
    def onKeyShortcut(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onTextContextMenuItem(self, id: int | java.jint | java.lang.Integer, /) -> bool: ...
    def selectAll(self) -> None: ...
    def setEllipsize(self, ellipsis: android.text.TextUtils.TruncateAt, /) -> None: ...
    @typing.overload
    def setSelection(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSelection(self, start: int | java.jint | java.lang.Integer, stop: int | java.jint | java.lang.Integer, /) -> None: ...
    def setStyleShortcutsEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setText(self, text: java.lang.CharSequence, type: TextView.BufferType, /) -> None: ...

class ExpandableListAdapter(java.lang.Object):
    def areAllItemsEnabled(self) -> bool: ...
    def getChild(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def getChildId(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
    def getChildView(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: android.view.View, arg5: android.view.ViewGroup, /) -> android.view.View: ...
    def getChildrenCount(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getCombinedChildId(self, arg1: int | java.jlong | java.lang.Long, arg2: int | java.jlong | java.lang.Long, /) -> int: ...
    def getCombinedGroupId(self, arg1: int | java.jlong | java.lang.Long, /) -> int: ...
    def getGroup(self, arg1: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def getGroupCount(self) -> int: ...
    def getGroupId(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getGroupView(self, arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, arg3: android.view.View, arg4: android.view.ViewGroup, /) -> android.view.View: ...
    def hasStableIds(self) -> bool: ...
    def isChildSelectable(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isEmpty(self) -> bool: ...
    def onGroupCollapsed(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def onGroupExpanded(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def registerDataSetObserver(self, arg1: android.database.DataSetObserver, /) -> None: ...
    def unregisterDataSetObserver(self, arg1: android.database.DataSetObserver, /) -> None: ...

class ExpandableListView(ListView):
    CHILD_INDICATOR_INHERIT: typing.ClassVar[int] = ...
    PACKED_POSITION_TYPE_CHILD: typing.ClassVar[int] = ...
    PACKED_POSITION_TYPE_GROUP: typing.ClassVar[int] = ...
    PACKED_POSITION_TYPE_NULL: typing.ClassVar[int] = ...
    PACKED_POSITION_VALUE_NULL: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def collapseGroup(self, groupPos: int | java.jint | java.lang.Integer, /) -> bool: ...
    def dispatchDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    @typing.overload
    def expandGroup(self, groupPos: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def expandGroup(self, groupPos: int | java.jint | java.lang.Integer, animate: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAdapter(self) -> ListAdapter: ...
    def getExpandableListAdapter(self) -> ExpandableListAdapter: ...
    def getExpandableListPosition(self, flatListPosition: int | java.jint | java.lang.Integer, /) -> int: ...
    def getFlatListPosition(self, packedPosition: int | java.jlong | java.lang.Long, /) -> int: ...
    @staticmethod
    def getPackedPositionChild(packedPosition: int | java.jlong | java.lang.Long, /) -> int: ...
    @staticmethod
    def getPackedPositionForChild(groupPosition: int | java.jint | java.lang.Integer, childPosition: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getPackedPositionForGroup(groupPosition: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getPackedPositionGroup(packedPosition: int | java.jlong | java.lang.Long, /) -> int: ...
    @staticmethod
    def getPackedPositionType(packedPosition: int | java.jlong | java.lang.Long, /) -> int: ...
    def getSelectedId(self) -> int: ...
    def getSelectedPosition(self) -> int: ...
    def isGroupExpanded(self, groupPosition: int | java.jint | java.lang.Integer, /) -> bool: ...
    def onInitializeAccessibilityNodeInfoForItem(self, view: android.view.View, position: int | java.jint | java.lang.Integer, info: android.view.accessibility.AccessibilityNodeInfo, /) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onRtlPropertiesChanged(self, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def performItemClick(self, v: android.view.View, position: int | java.jint | java.lang.Integer, id: int | java.jlong | java.lang.Long, /) -> bool: ...
    @typing.overload
    def setAdapter(self, adapter: ExpandableListAdapter, /) -> None: ...
    @typing.overload
    def setAdapter(self, adapter: ListAdapter, /) -> None: ...
    def setChildDivider(self, childDivider: android.graphics.drawable.Drawable, /) -> None: ...
    def setChildIndicator(self, childIndicator: android.graphics.drawable.Drawable, /) -> None: ...
    def setChildIndicatorBounds(self, left: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, /) -> None: ...
    def setChildIndicatorBoundsRelative(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> None: ...
    def setGroupIndicator(self, groupIndicator: android.graphics.drawable.Drawable, /) -> None: ...
    def setIndicatorBounds(self, left: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, /) -> None: ...
    def setIndicatorBoundsRelative(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOnChildClickListener(self, onChildClickListener: ExpandableListView.OnChildClickListener, /) -> None: ...
    def setOnGroupClickListener(self, onGroupClickListener: ExpandableListView.OnGroupClickListener, /) -> None: ...
    def setOnGroupCollapseListener(self, onGroupCollapseListener: ExpandableListView.OnGroupCollapseListener, /) -> None: ...
    def setOnGroupExpandListener(self, onGroupExpandListener: ExpandableListView.OnGroupExpandListener, /) -> None: ...
    def setOnItemClickListener(self, l: AdapterView.OnItemClickListener, /) -> None: ...
    def setSelectedChild(self, groupPosition: int | java.jint | java.lang.Integer, childPosition: int | java.jint | java.lang.Integer, shouldExpandGroup: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def setSelectedGroup(self, groupPosition: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnGroupExpandListener(java.lang.Object):
        def onGroupExpand(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnGroupCollapseListener(java.lang.Object):
        def onGroupCollapse(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnGroupClickListener(java.lang.Object):
        def onGroupClick(self, arg1: ExpandableListView, arg2: android.view.View, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jlong | java.lang.Long, /) -> bool: ...

    class OnChildClickListener(java.lang.Object):
        def onChildClick(self, arg1: ExpandableListView, arg2: android.view.View, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jlong | java.lang.Long, /) -> bool: ...

    class ExpandableListContextMenuInfo(android.view.ContextMenu.ContextMenuInfo):
        id: int = ...
        packedPosition: int = ...
        targetView: android.view.View = ...
        def __init__(self, targetView: android.view.View, packedPosition: int | java.jlong | java.lang.Long, id: int | java.jlong | java.lang.Long, /) -> None: ...

class Filter(java.lang.Object):
    def __init__(self) -> None: ...
    def convertResultToString(self, resultValue: java.lang.Object | int | bool | float | str, /) -> java.lang.CharSequence: ...
    @typing.overload
    def filter(self, constraint: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def filter(self, constraint: java.lang.CharSequence, listener: Filter.FilterListener, /) -> None: ...
    def performFiltering(self, arg1: java.lang.CharSequence, /) -> Filter.FilterResults: ...
    def publishResults(self, arg1: java.lang.CharSequence, arg2: Filter.FilterResults, /) -> None: ...

    class FilterResults(java.lang.Object):
        count: int = ...
        values: java.lang.Object = ...
        def __init__(self) -> None: ...

    class FilterListener(java.lang.Object):
        def onFilterComplete(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class FilterQueryProvider(java.lang.Object):
    def runQuery(self, arg1: java.lang.CharSequence, /) -> android.database.Cursor: ...

class Filterable(java.lang.Object):
    def getFilter(self) -> Filter: ...

class FrameLayout(android.view.ViewGroup):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def checkLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> bool: ...
    def generateDefaultLayoutParams(self) -> FrameLayout.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, attrs: android.util.AttributeSet, /) -> FrameLayout.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, lp: android.view.ViewGroup.LayoutParams, /) -> android.view.ViewGroup.LayoutParams: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getConsiderGoneChildrenWhenMeasuring(self) -> bool: ...
    def getMeasureAllChildren(self) -> bool: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def setForegroundGravity(self, foregroundGravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMeasureAllChildren(self, measureAll: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def shouldDelayChildPressedState(self) -> bool: ...

    class LayoutParams(android.view.ViewGroup.MarginLayoutParams):
        UNSPECIFIED_GRAVITY: typing.ClassVar[int] = ...
        gravity: int = ...
        @typing.overload
        def __init__(self, source: android.view.ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: android.view.ViewGroup.MarginLayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: FrameLayout.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, c: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
        @typing.overload
        def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, gravity: int | java.jint | java.lang.Integer, /) -> None: ...

class Gallery(android.view.GestureDetector.OnGestureListener, AbsSpinner):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def checkLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> bool: ...
    def computeHorizontalScrollExtent(self) -> int: ...
    def computeHorizontalScrollOffset(self) -> int: ...
    def computeHorizontalScrollRange(self) -> int: ...
    def dispatchKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def dispatchSetPressed(self, pressed: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dispatchSetSelected(self, selected: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def generateDefaultLayoutParams(self) -> android.view.ViewGroup.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, attrs: android.util.AttributeSet, /) -> android.view.ViewGroup.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> android.view.ViewGroup.LayoutParams: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getChildDrawingOrder(self, childCount: int | java.jint | java.lang.Integer, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def getChildStaticTransformation(self, child: android.view.View, t: android.view.animation.Transformation, /) -> bool: ...
    def getContextMenuInfo(self) -> android.view.ContextMenu.ContextMenuInfo: ...
    def onAttachedToWindow(self) -> None: ...
    def onDown(self, e: android.view.MotionEvent, /) -> bool: ...
    def onFling(self, e1: android.view.MotionEvent, e2: android.view.MotionEvent, velocityX: float | java.jfloat | java.lang.Float, velocityY: float | java.jfloat | java.lang.Float, /) -> bool: ...
    def onFocusChanged(self, gainFocus: bool | java.jboolean | java.lang.Boolean, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> None: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def onLongPress(self, e: android.view.MotionEvent, /) -> None: ...
    def onScroll(self, e1: android.view.MotionEvent, e2: android.view.MotionEvent, distanceX: float | java.jfloat | java.lang.Float, distanceY: float | java.jfloat | java.lang.Float, /) -> bool: ...
    def onShowPress(self, e: android.view.MotionEvent, /) -> None: ...
    def onSingleTapUp(self, e: android.view.MotionEvent, /) -> bool: ...
    def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def setAnimationDuration(self, animationDurationMillis: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCallbackDuringFling(self, shouldCallback: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setGravity(self, gravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSpacing(self, spacing: int | java.jint | java.lang.Integer, /) -> None: ...
    def setUnselectedAlpha(self, unselectedAlpha: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def showContextMenu(self) -> bool: ...
    @typing.overload
    def showContextMenu(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> bool: ...
    @typing.overload
    def showContextMenuForChild(self, originalView: android.view.View, /) -> bool: ...
    @typing.overload
    def showContextMenuForChild(self, originalView: android.view.View, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> bool: ...

    class LayoutParams(android.view.ViewGroup.LayoutParams):
        @typing.overload
        def __init__(self, source: android.view.ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, c: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...

class GridLayout(android.view.ViewGroup):
    ALIGN_BOUNDS: typing.ClassVar[int] = ...
    ALIGN_MARGINS: typing.ClassVar[int] = ...
    BASELINE: typing.ClassVar[GridLayout.Alignment] = ...
    BOTTOM: typing.ClassVar[GridLayout.Alignment] = ...
    CENTER: typing.ClassVar[GridLayout.Alignment] = ...
    END: typing.ClassVar[GridLayout.Alignment] = ...
    FILL: typing.ClassVar[GridLayout.Alignment] = ...
    HORIZONTAL: typing.ClassVar[int] = ...
    LEFT: typing.ClassVar[GridLayout.Alignment] = ...
    RIGHT: typing.ClassVar[GridLayout.Alignment] = ...
    START: typing.ClassVar[GridLayout.Alignment] = ...
    TOP: typing.ClassVar[GridLayout.Alignment] = ...
    UNDEFINED: typing.ClassVar[int] = ...
    VERTICAL: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def checkLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> bool: ...
    def generateDefaultLayoutParams(self) -> GridLayout.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, attrs: android.util.AttributeSet, /) -> GridLayout.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, lp: android.view.ViewGroup.LayoutParams, /) -> GridLayout.LayoutParams: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAlignmentMode(self) -> int: ...
    def getColumnCount(self) -> int: ...
    def getOrientation(self) -> int: ...
    def getRowCount(self) -> int: ...
    def getUseDefaultMargins(self) -> bool: ...
    def isColumnOrderPreserved(self) -> bool: ...
    def isRowOrderPreserved(self) -> bool: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthSpec: int | java.jint | java.lang.Integer, heightSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onViewAdded(self, child: android.view.View, /) -> None: ...
    def onViewRemoved(self, child: android.view.View, /) -> None: ...
    def requestLayout(self) -> None: ...
    def setAlignmentMode(self, alignmentMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setColumnCount(self, columnCount: int | java.jint | java.lang.Integer, /) -> None: ...
    def setColumnOrderPreserved(self, columnOrderPreserved: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOrientation(self, orientation: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRowCount(self, rowCount: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRowOrderPreserved(self, rowOrderPreserved: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setUseDefaultMargins(self, useDefaultMargins: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    @staticmethod
    def spec(start: int | java.jint | java.lang.Integer, /) -> GridLayout.Spec: ...
    @typing.overload
    @staticmethod
    def spec(start: int | java.jint | java.lang.Integer, weight: float | java.jfloat | java.lang.Float, /) -> GridLayout.Spec: ...
    @typing.overload
    @staticmethod
    def spec(start: int | java.jint | java.lang.Integer, size: int | java.jint | java.lang.Integer, /) -> GridLayout.Spec: ...
    @typing.overload
    @staticmethod
    def spec(start: int | java.jint | java.lang.Integer, alignment: GridLayout.Alignment, /) -> GridLayout.Spec: ...
    @typing.overload
    @staticmethod
    def spec(start: int | java.jint | java.lang.Integer, size: int | java.jint | java.lang.Integer, weight: float | java.jfloat | java.lang.Float, /) -> GridLayout.Spec: ...
    @typing.overload
    @staticmethod
    def spec(start: int | java.jint | java.lang.Integer, size: int | java.jint | java.lang.Integer, alignment: GridLayout.Alignment, /) -> GridLayout.Spec: ...
    @typing.overload
    @staticmethod
    def spec(start: int | java.jint | java.lang.Integer, alignment: GridLayout.Alignment, weight: float | java.jfloat | java.lang.Float, /) -> GridLayout.Spec: ...
    @typing.overload
    @staticmethod
    def spec(start: int | java.jint | java.lang.Integer, size: int | java.jint | java.lang.Integer, alignment: GridLayout.Alignment, weight: float | java.jfloat | java.lang.Float, /) -> GridLayout.Spec: ...

    class LayoutParams(android.view.ViewGroup.MarginLayoutParams):
        columnSpec: GridLayout.Spec = ...
        rowSpec: GridLayout.Spec = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, params: android.view.ViewGroup.MarginLayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: GridLayout.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
        @typing.overload
        def __init__(self, rowSpec: GridLayout.Spec, columnSpec: GridLayout.Spec, /) -> None: ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def hashCode(self) -> int: ...
        def setBaseAttributes(self, attributes: android.content.res.TypedArray, widthAttr: int | java.jint | java.lang.Integer, heightAttr: int | java.jint | java.lang.Integer, /) -> None: ...
        def setGravity(self, gravity: int | java.jint | java.lang.Integer, /) -> None: ...

    class Alignment(java.lang.Object): ...

    class Spec(java.lang.Object):
        def equals(self, that: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def hashCode(self) -> int: ...

class GridView(AbsListView):
    AUTO_FIT: typing.ClassVar[int] = ...
    NO_STRETCH: typing.ClassVar[int] = ...
    STRETCH_COLUMN_WIDTH: typing.ClassVar[int] = ...
    STRETCH_SPACING: typing.ClassVar[int] = ...
    STRETCH_SPACING_UNIFORM: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def attachLayoutAnimationParameters(self, child: android.view.View, params: android.view.ViewGroup.LayoutParams, index: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...
    def computeVerticalScrollExtent(self) -> int: ...
    def computeVerticalScrollOffset(self) -> int: ...
    def computeVerticalScrollRange(self) -> int: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAdapter(self) -> ListAdapter: ...
    def getColumnWidth(self) -> int: ...
    def getGravity(self) -> int: ...
    def getHorizontalSpacing(self) -> int: ...
    def getNumColumns(self) -> int: ...
    def getRequestedColumnWidth(self) -> int: ...
    def getRequestedHorizontalSpacing(self) -> int: ...
    def getStretchMode(self) -> int: ...
    def getVerticalSpacing(self) -> int: ...
    def layoutChildren(self) -> None: ...
    def onFocusChanged(self, gainFocus: bool | java.jboolean | java.lang.Boolean, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> None: ...
    def onInitializeAccessibilityNodeInfoForItem(self, view: android.view.View, position: int | java.jint | java.lang.Integer, info: android.view.accessibility.AccessibilityNodeInfo, /) -> None: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyMultiple(self, keyCode: int | java.jint | java.lang.Integer, repeatCount: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAdapter(self, adapter: ListAdapter, /) -> None: ...
    def setColumnWidth(self, columnWidth: int | java.jint | java.lang.Integer, /) -> None: ...
    def setGravity(self, gravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setHorizontalSpacing(self, horizontalSpacing: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNumColumns(self, numColumns: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRemoteViewsAdapter(self, intent: android.content.Intent, /) -> None: ...
    def setSelection(self, position: int | java.jint | java.lang.Integer, /) -> None: ...
    def setStretchMode(self, stretchMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setVerticalSpacing(self, verticalSpacing: int | java.jint | java.lang.Integer, /) -> None: ...
    def smoothScrollByOffset(self, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def smoothScrollToPosition(self, position: int | java.jint | java.lang.Integer, /) -> None: ...

class HeaderViewListAdapter(Filterable, WrapperListAdapter):
    def __init__(self, headerViewInfos: java.util.ArrayList[ListView.FixedViewInfo], footerViewInfos: java.util.ArrayList[ListView.FixedViewInfo], adapter: ListAdapter, /) -> None: ...
    def areAllItemsEnabled(self) -> bool: ...
    def getCount(self) -> int: ...
    def getFilter(self) -> Filter: ...
    def getFootersCount(self) -> int: ...
    def getHeadersCount(self) -> int: ...
    def getItem(self, position: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def getItemId(self, position: int | java.jint | java.lang.Integer, /) -> int: ...
    def getItemViewType(self, position: int | java.jint | java.lang.Integer, /) -> int: ...
    def getView(self, position: int | java.jint | java.lang.Integer, convertView: android.view.View, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def getViewTypeCount(self) -> int: ...
    def getWrappedAdapter(self) -> ListAdapter: ...
    def hasStableIds(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def isEnabled(self, position: int | java.jint | java.lang.Integer, /) -> bool: ...
    def registerDataSetObserver(self, observer: android.database.DataSetObserver, /) -> None: ...
    def removeFooter(self, v: android.view.View, /) -> bool: ...
    def removeHeader(self, v: android.view.View, /) -> bool: ...
    def unregisterDataSetObserver(self, observer: android.database.DataSetObserver, /) -> None: ...

class HeterogeneousExpandableList(java.lang.Object):
    def getChildType(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
    def getChildTypeCount(self) -> int: ...
    def getGroupType(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getGroupTypeCount(self) -> int: ...

class HorizontalScrollView(FrameLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, index: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, index: int | java.jint | java.lang.Integer, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def arrowScroll(self, direction: int | java.jint | java.lang.Integer, /) -> bool: ...
    def computeHorizontalScrollOffset(self) -> int: ...
    def computeHorizontalScrollRange(self) -> int: ...
    def computeScroll(self) -> None: ...
    def computeScrollDeltaToGetChildRectOnScreen(self, rect: android.graphics.Rect, /) -> int: ...
    def dispatchKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def draw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def executeKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def fling(self, velocityX: int | java.jint | java.lang.Integer, /) -> None: ...
    def fullScroll(self, direction: int | java.jint | java.lang.Integer, /) -> bool: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getLeftEdgeEffectColor(self) -> int: ...
    def getLeftFadingEdgeStrength(self) -> float: ...
    def getMaxScrollAmount(self) -> int: ...
    def getRightEdgeEffectColor(self) -> int: ...
    def getRightFadingEdgeStrength(self) -> float: ...
    def isFillViewport(self) -> bool: ...
    def isSmoothScrollingEnabled(self) -> bool: ...
    def measureChild(self, child: android.view.View, parentWidthMeasureSpec: int | java.jint | java.lang.Integer, parentHeightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def measureChildWithMargins(self, child: android.view.View, parentWidthMeasureSpec: int | java.jint | java.lang.Integer, widthUsed: int | java.jint | java.lang.Integer, parentHeightMeasureSpec: int | java.jint | java.lang.Integer, heightUsed: int | java.jint | java.lang.Integer, /) -> None: ...
    def onGenericMotionEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onInterceptTouchEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onOverScrolled(self, scrollX: int | java.jint | java.lang.Integer, scrollY: int | java.jint | java.lang.Integer, clampedX: bool | java.jboolean | java.lang.Boolean, clampedY: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onRequestFocusInDescendants(self, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> bool: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onSizeChanged(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, oldw: int | java.jint | java.lang.Integer, oldh: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTouchEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def pageScroll(self, direction: int | java.jint | java.lang.Integer, /) -> bool: ...
    def requestChildFocus(self, child: android.view.View, focused: android.view.View, /) -> None: ...
    def requestChildRectangleOnScreen(self, child: android.view.View, rectangle: android.graphics.Rect, immediate: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def requestDisallowInterceptTouchEvent(self, disallowIntercept: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def requestLayout(self) -> None: ...
    def scrollTo(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> None: ...
    def setEdgeEffectColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFillViewport(self, fillViewport: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setLeftEdgeEffectColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRightEdgeEffectColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSmoothScrollingEnabled(self, smoothScrollingEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def shouldDelayChildPressedState(self) -> bool: ...
    def smoothScrollBy(self, dx: int | java.jint | java.lang.Integer, dy: int | java.jint | java.lang.Integer, /) -> None: ...
    def smoothScrollTo(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> None: ...

class ImageButton(ImageView):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def onResolvePointerIcon(self, event: android.view.MotionEvent, pointerIndex: int | java.jint | java.lang.Integer, /) -> android.view.PointerIcon: ...
    def onSetAlpha(self, alpha: int | java.jint | java.lang.Integer, /) -> bool: ...

class ImageSwitcher(ViewSwitcher):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def setImageDrawable(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def setImageResource(self, resid: int | java.jint | java.lang.Integer, /) -> None: ...
    def setImageURI(self, uri: android.net.Uri, /) -> None: ...

class ImageView(android.view.View):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def animateTransform(self, matrix: android.graphics.Matrix, /) -> None: ...
    def clearColorFilter(self) -> None: ...
    def drawableHotspotChanged(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> None: ...
    def drawableStateChanged(self) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAdjustViewBounds(self) -> bool: ...
    def getBaseline(self) -> int: ...
    def getBaselineAlignBottom(self) -> bool: ...
    def getColorFilter(self) -> android.graphics.ColorFilter: ...
    def getCropToPadding(self) -> bool: ...
    def getDrawable(self) -> android.graphics.drawable.Drawable | None: ...
    def getImageAlpha(self) -> int: ...
    def getImageMatrix(self) -> android.graphics.Matrix: ...
    def getImageTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getImageTintList(self) -> android.content.res.ColorStateList | None: ...
    def getImageTintMode(self) -> android.graphics.PorterDuff.Mode | None: ...
    def getMaxHeight(self) -> int: ...
    def getMaxWidth(self) -> int: ...
    def getScaleType(self) -> ImageView.ScaleType: ...
    def hasOverlappingRendering(self) -> bool: ...
    def invalidateDrawable(self, dr: android.graphics.drawable.Drawable, /) -> None: ...
    def isOpaque(self) -> bool: ...
    def jumpDrawablesToCurrentState(self) -> None: ...
    def onAttachedToWindow(self) -> None: ...
    def onCreateDrawableState(self, extraSpace: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def onDetachedFromWindow(self) -> None: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRtlPropertiesChanged(self, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
    def onVisibilityAggregated(self, isVisible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAdjustViewBounds(self, adjustViewBounds: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAlpha(self, alpha: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBaseline(self, baseline: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBaselineAlignBottom(self, aligned: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setColorFilter(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setColorFilter(self, cf: android.graphics.ColorFilter, /) -> None: ...
    @typing.overload
    def setColorFilter(self, color: int | java.jint | java.lang.Integer, mode: android.graphics.PorterDuff.Mode, /) -> None: ...
    def setCropToPadding(self, cropToPadding: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFrame(self, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setImageAlpha(self, alpha: int | java.jint | java.lang.Integer, /) -> None: ...
    def setImageBitmap(self, bm: android.graphics.Bitmap, /) -> None: ...
    def setImageDrawable(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def setImageIcon(self, icon: android.graphics.drawable.Icon, /) -> None: ...
    def setImageLevel(self, level: int | java.jint | java.lang.Integer, /) -> None: ...
    def setImageMatrix(self, matrix: android.graphics.Matrix, /) -> None: ...
    def setImageResource(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setImageState(self, state: java.chaquopy.JavaArrayJInt, merge: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setImageTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setImageTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setImageTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> None: ...
    def setImageURI(self, uri: android.net.Uri, /) -> None: ...
    def setMaxHeight(self, maxHeight: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaxWidth(self, maxWidth: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScaleType(self, scaleType: ImageView.ScaleType, /) -> None: ...
    def setSelected(self, selected: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setVisibility(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def verifyDrawable(self, dr: android.graphics.drawable.Drawable, /) -> bool: ...

    class ScaleType(java.lang.Enum[ImageView.ScaleType]):
        CENTER: typing.ClassVar[ImageView.ScaleType] = ...
        CENTER_CROP: typing.ClassVar[ImageView.ScaleType] = ...
        CENTER_INSIDE: typing.ClassVar[ImageView.ScaleType] = ...
        FIT_CENTER: typing.ClassVar[ImageView.ScaleType] = ...
        FIT_END: typing.ClassVar[ImageView.ScaleType] = ...
        FIT_START: typing.ClassVar[ImageView.ScaleType] = ...
        FIT_XY: typing.ClassVar[ImageView.ScaleType] = ...
        MATRIX: typing.ClassVar[ImageView.ScaleType] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> ImageView.ScaleType: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[ImageView.ScaleType]: ...

class LinearLayout(android.view.ViewGroup):
    HORIZONTAL: typing.ClassVar[int] = ...
    SHOW_DIVIDER_BEGINNING: typing.ClassVar[int] = ...
    SHOW_DIVIDER_END: typing.ClassVar[int] = ...
    SHOW_DIVIDER_MIDDLE: typing.ClassVar[int] = ...
    SHOW_DIVIDER_NONE: typing.ClassVar[int] = ...
    VERTICAL: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def checkLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> bool: ...
    def generateDefaultLayoutParams(self) -> LinearLayout.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, attrs: android.util.AttributeSet, /) -> LinearLayout.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, lp: android.view.ViewGroup.LayoutParams, /) -> LinearLayout.LayoutParams: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getBaseline(self) -> int: ...
    def getBaselineAlignedChildIndex(self) -> int: ...
    def getDividerDrawable(self) -> android.graphics.drawable.Drawable: ...
    def getDividerPadding(self) -> int: ...
    def getGravity(self) -> int: ...
    def getOrientation(self) -> int: ...
    def getShowDividers(self) -> int: ...
    def getWeightSum(self) -> float: ...
    def isBaselineAligned(self) -> bool: ...
    def isMeasureWithLargestChildEnabled(self) -> bool: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRtlPropertiesChanged(self, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBaselineAligned(self, baselineAligned: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setBaselineAlignedChildIndex(self, i: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDividerDrawable(self, divider: android.graphics.drawable.Drawable, /) -> None: ...
    def setDividerPadding(self, padding: int | java.jint | java.lang.Integer, /) -> None: ...
    def setGravity(self, gravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setHorizontalGravity(self, horizontalGravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMeasureWithLargestChildEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOrientation(self, orientation: int | java.jint | java.lang.Integer, /) -> None: ...
    def setShowDividers(self, showDividers: int | java.jint | java.lang.Integer, /) -> None: ...
    def setVerticalGravity(self, verticalGravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setWeightSum(self, weightSum: float | java.jfloat | java.lang.Float, /) -> None: ...
    def shouldDelayChildPressedState(self) -> bool: ...

    class LayoutParams(android.view.ViewGroup.MarginLayoutParams):
        gravity: int = ...
        weight: float = ...
        @typing.overload
        def __init__(self, p: android.view.ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: android.view.ViewGroup.MarginLayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: LinearLayout.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, c: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
        @typing.overload
        def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, weight: float | java.jfloat | java.lang.Float, /) -> None: ...
        def debug(self, output: str | java.lang.String, /) -> str: ...

class ListAdapter(Adapter):
    def areAllItemsEnabled(self) -> bool: ...
    def isEnabled(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...

class ListPopupWindow(java.lang.Object):
    INPUT_METHOD_FROM_FOCUSABLE: typing.ClassVar[int] = ...
    INPUT_METHOD_NEEDED: typing.ClassVar[int] = ...
    INPUT_METHOD_NOT_NEEDED: typing.ClassVar[int] = ...
    MATCH_PARENT: typing.ClassVar[int] = ...
    POSITION_PROMPT_ABOVE: typing.ClassVar[int] = ...
    POSITION_PROMPT_BELOW: typing.ClassVar[int] = ...
    WRAP_CONTENT: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def clearListSelection(self) -> None: ...
    def createDragToOpenListener(self, src: android.view.View, /) -> android.view.View.OnTouchListener: ...
    def dismiss(self) -> None: ...
    def getAnchorView(self) -> android.view.View | None: ...
    def getAnimationStyle(self) -> int: ...
    def getBackground(self) -> android.graphics.drawable.Drawable | None: ...
    def getEpicenterBounds(self) -> android.graphics.Rect | None: ...
    def getHeight(self) -> int: ...
    def getHorizontalOffset(self) -> int: ...
    def getInputMethodMode(self) -> int: ...
    def getListView(self) -> ListView | None: ...
    def getPromptPosition(self) -> int: ...
    def getSelectedItem(self) -> java.lang.Object | None: ...
    def getSelectedItemId(self) -> int: ...
    def getSelectedItemPosition(self) -> int: ...
    def getSelectedView(self) -> android.view.View | None: ...
    def getSoftInputMode(self) -> int: ...
    def getVerticalOffset(self) -> int: ...
    def getWidth(self) -> int: ...
    def isInputMethodNotNeeded(self) -> bool: ...
    def isModal(self) -> bool: ...
    def isShowing(self) -> bool: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyPreIme(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def performItemClick(self, position: int | java.jint | java.lang.Integer, /) -> bool: ...
    def postShow(self) -> None: ...
    def setAdapter(self, adapter: ListAdapter, /) -> None: ...
    def setAnchorView(self, anchor: android.view.View, /) -> None: ...
    def setAnimationStyle(self, animationStyle: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBackgroundDrawable(self, d: android.graphics.drawable.Drawable, /) -> None: ...
    def setContentWidth(self, width: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDropDownGravity(self, gravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setEpicenterBounds(self, bounds: android.graphics.Rect, /) -> None: ...
    def setHeight(self, height: int | java.jint | java.lang.Integer, /) -> None: ...
    def setHorizontalOffset(self, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def setInputMethodMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setListSelector(self, selector: android.graphics.drawable.Drawable, /) -> None: ...
    def setModal(self, modal: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOnDismissListener(self, listener: PopupWindow.OnDismissListener, /) -> None: ...
    def setOnItemClickListener(self, clickListener: AdapterView.OnItemClickListener, /) -> None: ...
    def setOnItemSelectedListener(self, selectedListener: AdapterView.OnItemSelectedListener, /) -> None: ...
    def setPromptPosition(self, position: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPromptView(self, prompt: android.view.View, /) -> None: ...
    def setSelection(self, position: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSoftInputMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setVerticalOffset(self, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def setWidth(self, width: int | java.jint | java.lang.Integer, /) -> None: ...
    def setWindowLayoutType(self, layoutType: int | java.jint | java.lang.Integer, /) -> None: ...
    def show(self) -> None: ...

class ListView(AbsListView):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addFooterView(self, v: android.view.View, /) -> None: ...
    @typing.overload
    def addFooterView(self, v: android.view.View, data: java.lang.Object | int | bool | float | str, isSelectable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def addHeaderView(self, v: android.view.View, /) -> None: ...
    @typing.overload
    def addHeaderView(self, v: android.view.View, data: java.lang.Object | int | bool | float | str, isSelectable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def areFooterDividersEnabled(self) -> bool: ...
    def areHeaderDividersEnabled(self) -> bool: ...
    def canAnimate(self) -> bool: ...
    def dispatchDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def dispatchKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def drawChild(self, canvas: android.graphics.Canvas, child: android.view.View, drawingTime: int | java.jlong | java.lang.Long, /) -> bool: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAdapter(self) -> ListAdapter: ...
    def getCheckItemIds(self) -> java.chaquopy.JavaArrayJLong: ...
    def getDivider(self) -> android.graphics.drawable.Drawable | None: ...
    def getDividerHeight(self) -> int: ...
    def getFooterViewsCount(self) -> int: ...
    def getHeaderViewsCount(self) -> int: ...
    def getItemsCanFocus(self) -> bool: ...
    def getMaxScrollAmount(self) -> int: ...
    def getOverscrollFooter(self) -> android.graphics.drawable.Drawable: ...
    def getOverscrollHeader(self) -> android.graphics.drawable.Drawable: ...
    def isOpaque(self) -> bool: ...
    def layoutChildren(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onFinishInflate(self) -> None: ...
    def onFocusChanged(self, gainFocus: bool | java.jboolean | java.lang.Boolean, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> None: ...
    def onInitializeAccessibilityNodeInfoForItem(self, view: android.view.View, position: int | java.jint | java.lang.Integer, info: android.view.accessibility.AccessibilityNodeInfo, /) -> None: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyMultiple(self, keyCode: int | java.jint | java.lang.Integer, repeatCount: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSizeChanged(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, oldw: int | java.jint | java.lang.Integer, oldh: int | java.jint | java.lang.Integer, /) -> None: ...
    def removeFooterView(self, v: android.view.View, /) -> bool: ...
    def removeHeaderView(self, v: android.view.View, /) -> bool: ...
    def requestChildRectangleOnScreen(self, child: android.view.View, rect: android.graphics.Rect, immediate: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def setAdapter(self, adapter: ListAdapter, /) -> None: ...
    def setCacheColorHint(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDivider(self, divider: android.graphics.drawable.Drawable, /) -> None: ...
    def setDividerHeight(self, height: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFooterDividersEnabled(self, footerDividersEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setHeaderDividersEnabled(self, headerDividersEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setItemsCanFocus(self, itemsCanFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOverscrollFooter(self, footer: android.graphics.drawable.Drawable, /) -> None: ...
    def setOverscrollHeader(self, header: android.graphics.drawable.Drawable, /) -> None: ...
    def setRemoteViewsAdapter(self, intent: android.content.Intent, /) -> None: ...
    def setSelection(self, position: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSelectionAfterHeaderView(self) -> None: ...
    def smoothScrollByOffset(self, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def smoothScrollToPosition(self, position: int | java.jint | java.lang.Integer, /) -> None: ...

    class FixedViewInfo(java.lang.Object):
        data: java.lang.Object = ...
        isSelectable: bool = ...
        view: android.view.View = ...
        def __init__(self, this_0: ListView, /) -> None: ...

class Magnifier(java.lang.Object):
    SOURCE_BOUND_MAX_IN_SURFACE: typing.ClassVar[int] = ...
    SOURCE_BOUND_MAX_VISIBLE: typing.ClassVar[int] = ...
    def __init__(self, view: android.view.View, /) -> None: ...
    def dismiss(self) -> None: ...
    def getCornerRadius(self) -> float: ...
    def getDefaultHorizontalSourceToMagnifierOffset(self) -> int: ...
    def getDefaultVerticalSourceToMagnifierOffset(self) -> int: ...
    def getElevation(self) -> float: ...
    def getHeight(self) -> int: ...
    def getOverlay(self) -> android.graphics.drawable.Drawable | None: ...
    def getPosition(self) -> android.graphics.Point | None: ...
    def getSourceHeight(self) -> int: ...
    def getSourcePosition(self) -> android.graphics.Point | None: ...
    def getSourceWidth(self) -> int: ...
    def getWidth(self) -> int: ...
    def getZoom(self) -> float: ...
    def isClippingEnabled(self) -> bool: ...
    def setZoom(self, zoom: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def show(self, sourceCenterX: float | java.jfloat | java.lang.Float, sourceCenterY: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def show(self, sourceCenterX: float | java.jfloat | java.lang.Float, sourceCenterY: float | java.jfloat | java.lang.Float, magnifierCenterX: float | java.jfloat | java.lang.Float, magnifierCenterY: float | java.jfloat | java.lang.Float, /) -> None: ...
    def update(self) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, view: android.view.View, /) -> None: ...
        def build(self) -> Magnifier: ...
        def setClippingEnabled(self, clip: bool | java.jboolean | java.lang.Boolean, /) -> Magnifier.Builder: ...
        def setCornerRadius(self, cornerRadius: float | java.jfloat | java.lang.Float, /) -> Magnifier.Builder: ...
        def setDefaultSourceToMagnifierOffset(self, horizontalOffset: int | java.jint | java.lang.Integer, verticalOffset: int | java.jint | java.lang.Integer, /) -> Magnifier.Builder: ...
        def setElevation(self, elevation: float | java.jfloat | java.lang.Float, /) -> Magnifier.Builder: ...
        def setInitialZoom(self, zoom: float | java.jfloat | java.lang.Float, /) -> Magnifier.Builder: ...
        def setOverlay(self, overlay: android.graphics.drawable.Drawable, /) -> Magnifier.Builder: ...
        def setSize(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> Magnifier.Builder: ...
        def setSourceBounds(self, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> Magnifier.Builder: ...

class MediaController(FrameLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, useFastForward: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dispatchKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def hide(self) -> None: ...
    def isShowing(self) -> bool: ...
    def onFinishInflate(self) -> None: ...
    def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onTrackballEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def setAnchorView(self, view: android.view.View, /) -> None: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMediaPlayer(self, player: MediaController.MediaPlayerControl, /) -> None: ...
    def setPrevNextListeners(self, next: android.view.View.OnClickListener, prev: android.view.View.OnClickListener, /) -> None: ...
    @typing.overload
    def show(self) -> None: ...
    @typing.overload
    def show(self, timeout: int | java.jint | java.lang.Integer, /) -> None: ...

    class MediaPlayerControl(java.lang.Object):
        def canPause(self) -> bool: ...
        def canSeekBackward(self) -> bool: ...
        def canSeekForward(self) -> bool: ...
        def getAudioSessionId(self) -> int: ...
        def getBufferPercentage(self) -> int: ...
        def getCurrentPosition(self) -> int: ...
        def getDuration(self) -> int: ...
        def isPlaying(self) -> bool: ...
        def pause(self) -> None: ...
        def seekTo(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
        def start(self) -> None: ...

class MultiAutoCompleteTextView(AutoCompleteTextView):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def enoughToFilter(self) -> bool: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    @typing.overload
    def performFiltering(self, text: java.lang.CharSequence, keyCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def performFiltering(self, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, keyCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def performValidation(self) -> None: ...
    def replaceText(self, text: java.lang.CharSequence, /) -> None: ...
    def setTokenizer(self, t: MultiAutoCompleteTextView.Tokenizer, /) -> None: ...

    class Tokenizer(java.lang.Object):
        def findTokenEnd(self, arg1: java.lang.CharSequence, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
        def findTokenStart(self, arg1: java.lang.CharSequence, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
        def terminateToken(self, arg1: java.lang.CharSequence, /) -> java.lang.CharSequence: ...

    class CommaTokenizer(MultiAutoCompleteTextView.Tokenizer):
        def __init__(self) -> None: ...
        def findTokenEnd(self, text: java.lang.CharSequence, cursor: int | java.jint | java.lang.Integer, /) -> int: ...
        def findTokenStart(self, text: java.lang.CharSequence, cursor: int | java.jint | java.lang.Integer, /) -> int: ...
        def terminateToken(self, text: java.lang.CharSequence, /) -> java.lang.CharSequence: ...

class NumberPicker(LinearLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def computeScroll(self) -> None: ...
    def computeVerticalScrollExtent(self) -> int: ...
    def computeVerticalScrollOffset(self) -> int: ...
    def computeVerticalScrollRange(self) -> int: ...
    def dispatchHoverEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def dispatchKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def dispatchTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def dispatchTrackballEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def drawableStateChanged(self) -> None: ...
    def getAccessibilityNodeProvider(self) -> android.view.accessibility.AccessibilityNodeProvider: ...
    def getBottomFadingEdgeStrength(self) -> float: ...
    def getDisplayedValues(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getMaxValue(self) -> int: ...
    def getMinValue(self) -> int: ...
    def getSelectionDividerHeight(self) -> int: ...
    def getSolidColor(self) -> int: ...
    def getTextColor(self) -> int: ...
    def getTextSize(self) -> float: ...
    def getTopFadingEdgeStrength(self) -> float: ...
    def getValue(self) -> int: ...
    def getWrapSelectorWheel(self) -> bool: ...
    def jumpDrawablesToCurrentState(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onInterceptTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def performClick(self) -> bool: ...
    def performLongClick(self) -> bool: ...
    def scrollBy(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDisplayedValues(self, displayedValues: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFormatter(self, formatter: NumberPicker.Formatter, /) -> None: ...
    def setMaxValue(self, maxValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinValue(self, minValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOnLongPressUpdateInterval(self, intervalMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def setOnScrollListener(self, onScrollListener: NumberPicker.OnScrollListener, /) -> None: ...
    def setOnValueChangedListener(self, onValueChangedListener: NumberPicker.OnValueChangeListener, /) -> None: ...
    def setSelectionDividerHeight(self, height: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTextColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTextSize(self, size: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setValue(self, value: int | java.jint | java.lang.Integer, /) -> None: ...
    def setWrapSelectorWheel(self, wrapSelectorWheel: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class OnValueChangeListener(java.lang.Object):
        def onValueChange(self, arg1: NumberPicker, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnScrollListener(java.lang.Object):
        SCROLL_STATE_FLING: typing.ClassVar[int] = ...
        SCROLL_STATE_IDLE: typing.ClassVar[int] = ...
        SCROLL_STATE_TOUCH_SCROLL: typing.ClassVar[int] = ...
        def onScrollStateChange(self, arg1: NumberPicker, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

    class Formatter(java.lang.Object):
        def format(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...

class OverScroller(java.lang.Object):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, interpolator: android.view.animation.Interpolator, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, interpolator: android.view.animation.Interpolator, bounceCoefficientX: float | java.jfloat | java.lang.Float, bounceCoefficientY: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, interpolator: android.view.animation.Interpolator, bounceCoefficientX: float | java.jfloat | java.lang.Float, bounceCoefficientY: float | java.jfloat | java.lang.Float, flywheel: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def abortAnimation(self) -> None: ...
    def computeScrollOffset(self) -> bool: ...
    @typing.overload
    def fling(self, startX: int | java.jint | java.lang.Integer, startY: int | java.jint | java.lang.Integer, velocityX: int | java.jint | java.lang.Integer, velocityY: int | java.jint | java.lang.Integer, minX: int | java.jint | java.lang.Integer, maxX: int | java.jint | java.lang.Integer, minY: int | java.jint | java.lang.Integer, maxY: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def fling(self, startX: int | java.jint | java.lang.Integer, startY: int | java.jint | java.lang.Integer, velocityX: int | java.jint | java.lang.Integer, velocityY: int | java.jint | java.lang.Integer, minX: int | java.jint | java.lang.Integer, maxX: int | java.jint | java.lang.Integer, minY: int | java.jint | java.lang.Integer, maxY: int | java.jint | java.lang.Integer, overX: int | java.jint | java.lang.Integer, overY: int | java.jint | java.lang.Integer, /) -> None: ...
    def forceFinished(self, finished: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def getCurrVelocity(self) -> float: ...
    def getCurrX(self) -> int: ...
    def getCurrY(self) -> int: ...
    def getFinalX(self) -> int: ...
    def getFinalY(self) -> int: ...
    def getStartX(self) -> int: ...
    def getStartY(self) -> int: ...
    def isFinished(self) -> bool: ...
    def isOverScrolled(self) -> bool: ...
    def notifyHorizontalEdgeReached(self, startX: int | java.jint | java.lang.Integer, finalX: int | java.jint | java.lang.Integer, overX: int | java.jint | java.lang.Integer, /) -> None: ...
    def notifyVerticalEdgeReached(self, startY: int | java.jint | java.lang.Integer, finalY: int | java.jint | java.lang.Integer, overY: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFriction(self, friction: float | java.jfloat | java.lang.Float, /) -> None: ...
    def springBack(self, startX: int | java.jint | java.lang.Integer, startY: int | java.jint | java.lang.Integer, minX: int | java.jint | java.lang.Integer, maxX: int | java.jint | java.lang.Integer, minY: int | java.jint | java.lang.Integer, maxY: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def startScroll(self, startX: int | java.jint | java.lang.Integer, startY: int | java.jint | java.lang.Integer, dx: int | java.jint | java.lang.Integer, dy: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startScroll(self, startX: int | java.jint | java.lang.Integer, startY: int | java.jint | java.lang.Integer, dx: int | java.jint | java.lang.Integer, dy: int | java.jint | java.lang.Integer, duration: int | java.jint | java.lang.Integer, /) -> None: ...

class PopupMenu(java.lang.Object):
    @typing.overload
    def __init__(self, context: android.content.Context, anchor: android.view.View, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, anchor: android.view.View, gravity: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, anchor: android.view.View, gravity: int | java.jint | java.lang.Integer, popupStyleAttr: int | java.jint | java.lang.Integer, popupStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def dismiss(self) -> None: ...
    def getDragToOpenListener(self) -> android.view.View.OnTouchListener: ...
    def getGravity(self) -> int: ...
    def getMenu(self) -> android.view.Menu: ...
    def getMenuInflater(self) -> android.view.MenuInflater: ...
    def inflate(self, menuRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def setForceShowIcon(self, forceShowIcon: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setGravity(self, gravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOnDismissListener(self, listener: PopupMenu.OnDismissListener, /) -> None: ...
    def setOnMenuItemClickListener(self, listener: PopupMenu.OnMenuItemClickListener, /) -> None: ...
    def show(self) -> None: ...

    class OnMenuItemClickListener(java.lang.Object):
        def onMenuItemClick(self, arg1: android.view.MenuItem, /) -> bool: ...

    class OnDismissListener(java.lang.Object):
        def onDismiss(self, arg1: PopupMenu, /) -> None: ...

class PopupWindow(java.lang.Object):
    INPUT_METHOD_FROM_FOCUSABLE: typing.ClassVar[int] = ...
    INPUT_METHOD_NEEDED: typing.ClassVar[int] = ...
    INPUT_METHOD_NOT_NEEDED: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, contentView: android.view.View, /) -> None: ...
    @typing.overload
    def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, contentView: android.view.View, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, contentView: android.view.View, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, focusable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dismiss(self) -> None: ...
    def getAnimationStyle(self) -> int: ...
    def getBackground(self) -> android.graphics.drawable.Drawable: ...
    def getContentView(self) -> android.view.View: ...
    def getElevation(self) -> float: ...
    def getEnterTransition(self) -> android.transition.Transition | None: ...
    def getEpicenterBounds(self) -> android.graphics.Rect | None: ...
    def getExitTransition(self) -> android.transition.Transition | None: ...
    def getHeight(self) -> int: ...
    def getInputMethodMode(self) -> int: ...
    @typing.overload
    def getMaxAvailableHeight(self, anchor: android.view.View, /) -> int: ...
    @typing.overload
    def getMaxAvailableHeight(self, anchor: android.view.View, yOffset: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getMaxAvailableHeight(self, anchor: android.view.View, yOffset: int | java.jint | java.lang.Integer, ignoreBottomDecorations: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    def getOverlapAnchor(self) -> bool: ...
    def getSoftInputMode(self) -> int: ...
    def getWidth(self) -> int: ...
    def getWindowLayoutType(self) -> int: ...
    def isAboveAnchor(self) -> bool: ...
    def isAttachedInDecor(self) -> bool: ...
    def isClippedToScreen(self) -> bool: ...
    def isClippingEnabled(self) -> bool: ...
    def isFocusable(self) -> bool: ...
    def isLaidOutInScreen(self) -> bool: ...
    def isOutsideTouchable(self) -> bool: ...
    def isShowing(self) -> bool: ...
    def isSplitTouchEnabled(self) -> bool: ...
    def isTouchModal(self) -> bool: ...
    def isTouchable(self) -> bool: ...
    def setAnimationStyle(self, animationStyle: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAttachedInDecor(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setBackgroundDrawable(self, background: android.graphics.drawable.Drawable, /) -> None: ...
    def setClippingEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setContentView(self, contentView: android.view.View, /) -> None: ...
    def setElevation(self, elevation: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setEnterTransition(self, enterTransition: android.transition.Transition, /) -> None: ...
    def setEpicenterBounds(self, bounds: android.graphics.Rect, /) -> None: ...
    def setExitTransition(self, exitTransition: android.transition.Transition, /) -> None: ...
    def setFocusable(self, focusable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setHeight(self, height: int | java.jint | java.lang.Integer, /) -> None: ...
    def setIgnoreCheekPress(self) -> None: ...
    def setInputMethodMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setIsClippedToScreen(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setIsLaidOutInScreen(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOnDismissListener(self, onDismissListener: PopupWindow.OnDismissListener, /) -> None: ...
    def setOutsideTouchable(self, touchable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOverlapAnchor(self, overlapAnchor: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSoftInputMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSplitTouchEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTouchInterceptor(self, l: android.view.View.OnTouchListener, /) -> None: ...
    def setTouchModal(self, touchModal: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTouchable(self, touchable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setWidth(self, width: int | java.jint | java.lang.Integer, /) -> None: ...
    def setWindowLayoutMode(self, widthSpec: int | java.jint | java.lang.Integer, heightSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def setWindowLayoutType(self, layoutType: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def showAsDropDown(self, anchor: android.view.View, /) -> None: ...
    @typing.overload
    def showAsDropDown(self, anchor: android.view.View, xoff: int | java.jint | java.lang.Integer, yoff: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def showAsDropDown(self, anchor: android.view.View, xoff: int | java.jint | java.lang.Integer, yoff: int | java.jint | java.lang.Integer, gravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def showAtLocation(self, parent: android.view.View, gravity: int | java.jint | java.lang.Integer, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def update(self) -> None: ...
    @typing.overload
    def update(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def update(self, anchor: android.view.View, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def update(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def update(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, force: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def update(self, anchor: android.view.View, xoff: int | java.jint | java.lang.Integer, yoff: int | java.jint | java.lang.Integer, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnDismissListener(java.lang.Object):
        def onDismiss(self) -> None: ...

class ProgressBar(android.view.View):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def drawableHotspotChanged(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> None: ...
    def drawableStateChanged(self) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getCurrentDrawable(self) -> android.graphics.drawable.Drawable | None: ...
    def getIndeterminateDrawable(self) -> android.graphics.drawable.Drawable: ...
    def getIndeterminateTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getIndeterminateTintList(self) -> android.content.res.ColorStateList | None: ...
    def getIndeterminateTintMode(self) -> android.graphics.PorterDuff.Mode | None: ...
    def getInterpolator(self) -> android.view.animation.Interpolator: ...
    def getMax(self) -> int: ...
    def getMaxHeight(self) -> int: ...
    def getMaxWidth(self) -> int: ...
    def getMin(self) -> int: ...
    def getMinHeight(self) -> int: ...
    def getMinWidth(self) -> int: ...
    def getProgress(self) -> int: ...
    def getProgressBackgroundTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getProgressBackgroundTintList(self) -> android.content.res.ColorStateList | None: ...
    def getProgressBackgroundTintMode(self) -> android.graphics.PorterDuff.Mode | None: ...
    def getProgressDrawable(self) -> android.graphics.drawable.Drawable: ...
    def getProgressTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getProgressTintList(self) -> android.content.res.ColorStateList | None: ...
    def getProgressTintMode(self) -> android.graphics.PorterDuff.Mode | None: ...
    def getSecondaryProgress(self) -> int: ...
    def getSecondaryProgressTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getSecondaryProgressTintList(self) -> android.content.res.ColorStateList | None: ...
    def getSecondaryProgressTintMode(self) -> android.graphics.PorterDuff.Mode | None: ...
    def incrementProgressBy(self, diff: int | java.jint | java.lang.Integer, /) -> None: ...
    def incrementSecondaryProgressBy(self, diff: int | java.jint | java.lang.Integer, /) -> None: ...
    def invalidateDrawable(self, dr: android.graphics.drawable.Drawable, /) -> None: ...
    def isAnimating(self) -> bool: ...
    def isIndeterminate(self) -> bool: ...
    def jumpDrawablesToCurrentState(self) -> None: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onSizeChanged(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, oldw: int | java.jint | java.lang.Integer, oldh: int | java.jint | java.lang.Integer, /) -> None: ...
    def onVisibilityAggregated(self, isVisible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def postInvalidate(self) -> None: ...
    def setIndeterminate(self, indeterminate: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setIndeterminateDrawable(self, d: android.graphics.drawable.Drawable, /) -> None: ...
    def setIndeterminateDrawableTiled(self, d: android.graphics.drawable.Drawable, /) -> None: ...
    def setIndeterminateTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setIndeterminateTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setIndeterminateTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> None: ...
    @typing.overload
    def setInterpolator(self, interpolator: android.view.animation.Interpolator, /) -> None: ...
    @typing.overload
    def setInterpolator(self, context: android.content.Context, resID: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMax(self, max: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaxHeight(self, maxHeight: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaxWidth(self, maxWidth: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMin(self, min: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinHeight(self, minHeight: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinWidth(self, minWidth: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setProgress(self, progress: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setProgress(self, progress: int | java.jint | java.lang.Integer, animate: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setProgressBackgroundTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setProgressBackgroundTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setProgressBackgroundTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> None: ...
    def setProgressDrawable(self, d: android.graphics.drawable.Drawable, /) -> None: ...
    def setProgressDrawableTiled(self, d: android.graphics.drawable.Drawable, /) -> None: ...
    def setProgressTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setProgressTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setProgressTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> None: ...
    def setSecondaryProgress(self, secondaryProgress: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSecondaryProgressTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setSecondaryProgressTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setSecondaryProgressTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> None: ...
    def setStateDescription(self, stateDescription: java.lang.CharSequence, /) -> None: ...
    def verifyDrawable(self, who: android.graphics.drawable.Drawable, /) -> bool: ...

class QuickContactBadge(android.view.View.OnClickListener, ImageView):
    mExcludeMimes: java.chaquopy.JavaArray[java.lang.String] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def assignContactFromEmail(self, emailAddress: str | java.lang.String, lazyLookup: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def assignContactFromEmail(self, emailAddress: str | java.lang.String, lazyLookup: bool | java.jboolean | java.lang.Boolean, extras: android.os.Bundle, /) -> None: ...
    @typing.overload
    def assignContactFromPhone(self, phoneNumber: str | java.lang.String, lazyLookup: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def assignContactFromPhone(self, phoneNumber: str | java.lang.String, lazyLookup: bool | java.jboolean | java.lang.Boolean, extras: android.os.Bundle, /) -> None: ...
    def assignContactUri(self, contactUri: android.net.Uri, /) -> None: ...
    def drawableHotspotChanged(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> None: ...
    def drawableStateChanged(self) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def onAttachedToWindow(self) -> None: ...
    def onClick(self, v: android.view.View, /) -> None: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def setExcludeMimes(self, excludeMimes: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setImageToDefault(self) -> None: ...
    def setMode(self, size: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOverlay(self, overlay: android.graphics.drawable.Drawable, /) -> None: ...
    def setPrioritizedMimeType(self, prioritizedMimeType: str | java.lang.String, /) -> None: ...

class RadioButton(CompoundButton):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def onInitializeAccessibilityNodeInfo(self, info: android.view.accessibility.AccessibilityNodeInfo, /) -> None: ...
    def toggle(self) -> None: ...

class RadioGroup(LinearLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def addView(self, child: android.view.View, index: int | java.jint | java.lang.Integer, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def autofill(self, value: android.view.autofill.AutofillValue, /) -> None: ...
    def check(self, id: int | java.jint | java.lang.Integer, /) -> None: ...
    def checkLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> bool: ...
    def clearCheck(self) -> None: ...
    def generateDefaultLayoutParams(self) -> LinearLayout.LayoutParams: ...
    def generateLayoutParams(self, attrs: android.util.AttributeSet, /) -> RadioGroup.LayoutParams: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAutofillType(self) -> int: ...
    def getAutofillValue(self) -> android.view.autofill.AutofillValue: ...
    def getCheckedRadioButtonId(self) -> int: ...
    def onFinishInflate(self) -> None: ...
    def onInitializeAccessibilityNodeInfo(self, info: android.view.accessibility.AccessibilityNodeInfo, /) -> None: ...
    def setOnCheckedChangeListener(self, listener: RadioGroup.OnCheckedChangeListener, /) -> None: ...
    def setOnHierarchyChangeListener(self, listener: android.view.ViewGroup.OnHierarchyChangeListener, /) -> None: ...

    class LayoutParams(LinearLayout.LayoutParams):
        @typing.overload
        def __init__(self, p: android.view.ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: android.view.ViewGroup.MarginLayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, c: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
        @typing.overload
        def __init__(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, initWeight: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setBaseAttributes(self, a: android.content.res.TypedArray, widthAttr: int | java.jint | java.lang.Integer, heightAttr: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnCheckedChangeListener(java.lang.Object):
        def onCheckedChanged(self, arg1: RadioGroup, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

class RatingBar(AbsSeekBar):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getNumStars(self) -> int: ...
    def getOnRatingBarChangeListener(self) -> RatingBar.OnRatingBarChangeListener | None: ...
    def getRating(self) -> float: ...
    def getStepSize(self) -> float: ...
    def isIndicator(self) -> bool: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def setIsIndicator(self, isIndicator: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMax(self, max: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNumStars(self, numStars: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOnRatingBarChangeListener(self, listener: RatingBar.OnRatingBarChangeListener, /) -> None: ...
    def setRating(self, rating: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setStepSize(self, stepSize: float | java.jfloat | java.lang.Float, /) -> None: ...

    class OnRatingBarChangeListener(java.lang.Object):
        def onRatingChanged(self, arg1: RatingBar, arg2: float | java.jfloat | java.lang.Float, arg3: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class RelativeLayout(android.view.ViewGroup):
    ABOVE: typing.ClassVar[int] = ...
    ALIGN_BASELINE: typing.ClassVar[int] = ...
    ALIGN_BOTTOM: typing.ClassVar[int] = ...
    ALIGN_END: typing.ClassVar[int] = ...
    ALIGN_LEFT: typing.ClassVar[int] = ...
    ALIGN_PARENT_BOTTOM: typing.ClassVar[int] = ...
    ALIGN_PARENT_END: typing.ClassVar[int] = ...
    ALIGN_PARENT_LEFT: typing.ClassVar[int] = ...
    ALIGN_PARENT_RIGHT: typing.ClassVar[int] = ...
    ALIGN_PARENT_START: typing.ClassVar[int] = ...
    ALIGN_PARENT_TOP: typing.ClassVar[int] = ...
    ALIGN_RIGHT: typing.ClassVar[int] = ...
    ALIGN_START: typing.ClassVar[int] = ...
    ALIGN_TOP: typing.ClassVar[int] = ...
    BELOW: typing.ClassVar[int] = ...
    CENTER_HORIZONTAL: typing.ClassVar[int] = ...
    CENTER_IN_PARENT: typing.ClassVar[int] = ...
    CENTER_VERTICAL: typing.ClassVar[int] = ...
    END_OF: typing.ClassVar[int] = ...
    LEFT_OF: typing.ClassVar[int] = ...
    RIGHT_OF: typing.ClassVar[int] = ...
    START_OF: typing.ClassVar[int] = ...
    TRUE: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def checkLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> bool: ...
    def generateDefaultLayoutParams(self) -> android.view.ViewGroup.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, attrs: android.util.AttributeSet, /) -> RelativeLayout.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, lp: android.view.ViewGroup.LayoutParams, /) -> android.view.ViewGroup.LayoutParams: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getBaseline(self) -> int: ...
    def getGravity(self) -> int: ...
    def getIgnoreGravity(self) -> int: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def requestLayout(self) -> None: ...
    def setGravity(self, gravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setHorizontalGravity(self, horizontalGravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setIgnoreGravity(self, viewId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setVerticalGravity(self, verticalGravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def shouldDelayChildPressedState(self) -> bool: ...

    class LayoutParams(android.view.ViewGroup.MarginLayoutParams):
        alignWithParent: bool = ...
        @typing.overload
        def __init__(self, source: android.view.ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: android.view.ViewGroup.MarginLayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: RelativeLayout.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, c: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
        @typing.overload
        def addRule(self, verb: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def addRule(self, verb: int | java.jint | java.lang.Integer, subject: int | java.jint | java.lang.Integer, /) -> None: ...
        def debug(self, output: str | java.lang.String, /) -> str: ...
        def getRule(self, verb: int | java.jint | java.lang.Integer, /) -> int: ...
        def getRules(self) -> java.chaquopy.JavaArrayJInt: ...
        def removeRule(self, verb: int | java.jint | java.lang.Integer, /) -> None: ...
        def resolveLayoutDirection(self, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...

class RemoteViews(android.os.Parcelable, android.view.LayoutInflater.Filter):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RemoteViews]] = ...
    EXTRA_CHECKED: typing.ClassVar[str] = ...
    EXTRA_SHARED_ELEMENT_BOUNDS: typing.ClassVar[str] = ...
    MARGIN_BOTTOM: typing.ClassVar[int] = ...
    MARGIN_END: typing.ClassVar[int] = ...
    MARGIN_LEFT: typing.ClassVar[int] = ...
    MARGIN_RIGHT: typing.ClassVar[int] = ...
    MARGIN_START: typing.ClassVar[int] = ...
    MARGIN_TOP: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, parcel: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, drawInstructions: RemoteViews.DrawInstructions, /) -> None: ...
    @typing.overload
    def __init__(self, src: RemoteViews, /) -> None: ...
    @typing.overload
    def __init__(self, remoteViews: java.util.Map[android.util.SizeF, RemoteViews], /) -> None: ...
    @typing.overload
    def __init__(self, landscape: RemoteViews, portrait: RemoteViews, /) -> None: ...
    @typing.overload
    def __init__(self, packageName: str | java.lang.String, layoutId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, packageName: str | java.lang.String, layoutId: int | java.jint | java.lang.Integer, viewId: int | java.jint | java.lang.Integer, /) -> None: ...
    def addStableView(self, viewId: int | java.jint | java.lang.Integer, nestedView: RemoteViews, stableId: int | java.jint | java.lang.Integer, /) -> None: ...
    def addView(self, viewId: int | java.jint | java.lang.Integer, nestedView: RemoteViews, /) -> None: ...
    def apply(self, context: android.content.Context, parent: android.view.ViewGroup, /) -> android.view.View | None: ...
    def clone(self) -> RemoteViews: ...
    def describeContents(self) -> int: ...
    def getLayoutId(self) -> int: ...
    def getPackage(self) -> str: ...
    def getViewId(self) -> int: ...
    def onLoadClass(self, clazz: typing.Type, /) -> bool: ...
    def reapply(self, context: android.content.Context, v: android.view.View, /) -> None: ...
    def removeAllViews(self, viewId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAccessibilityTraversalAfter(self, viewId: int | java.jint | java.lang.Integer, nextId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAccessibilityTraversalBefore(self, viewId: int | java.jint | java.lang.Integer, nextId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBitmap(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: android.graphics.Bitmap, /) -> None: ...
    def setBlendMode(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: android.graphics.BlendMode, /) -> None: ...
    def setBoolean(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setBundle(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: android.os.Bundle, /) -> None: ...
    def setByte(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: int | java.jbyte | java.lang.Byte, /) -> None: ...
    def setChar(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: str | java.jchar | java.lang.Character, /) -> None: ...
    @typing.overload
    def setCharSequence(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, stringResource: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setCharSequence(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: java.lang.CharSequence, /) -> None: ...
    def setCharSequenceAttr(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, stringAttribute: int | java.jint | java.lang.Integer, /) -> None: ...
    def setChronometer(self, viewId: int | java.jint | java.lang.Integer, base: int | java.jlong | java.lang.Long, format: str | java.lang.String, started: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setChronometerCountDown(self, viewId: int | java.jint | java.lang.Integer, isCountDown: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setColor(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, colorResource: int | java.jint | java.lang.Integer, /) -> None: ...
    def setColorAttr(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, colorAttribute: int | java.jint | java.lang.Integer, /) -> None: ...
    def setColorInt(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, notNight: int | java.jint | java.lang.Integer, night: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setColorStateList(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, colorResource: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setColorStateList(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: android.content.res.ColorStateList, /) -> None: ...
    @typing.overload
    def setColorStateList(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, notNight: android.content.res.ColorStateList, night: android.content.res.ColorStateList, /) -> None: ...
    def setColorStateListAttr(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, colorAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCompoundButtonChecked(self, viewId: int | java.jint | java.lang.Integer, checked: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setContentDescription(self, viewId: int | java.jint | java.lang.Integer, contentDescription: java.lang.CharSequence, /) -> None: ...
    def setDisplayedChild(self, viewId: int | java.jint | java.lang.Integer, childIndex: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDouble(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: float | java.jdouble | java.lang.Double, /) -> None: ...
    def setEmptyView(self, viewId: int | java.jint | java.lang.Integer, emptyViewId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFloat(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def setFloatDimen(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, dimenResource: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setFloatDimen(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: float | java.jfloat | java.lang.Float, unit: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFloatDimenAttr(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, dimenAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setIcon(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: android.graphics.drawable.Icon, /) -> None: ...
    @typing.overload
    def setIcon(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, notNight: android.graphics.drawable.Icon, night: android.graphics.drawable.Icon, /) -> None: ...
    def setImageViewBitmap(self, viewId: int | java.jint | java.lang.Integer, bitmap: android.graphics.Bitmap, /) -> None: ...
    def setImageViewIcon(self, viewId: int | java.jint | java.lang.Integer, icon: android.graphics.drawable.Icon, /) -> None: ...
    def setImageViewResource(self, viewId: int | java.jint | java.lang.Integer, srcId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setImageViewUri(self, viewId: int | java.jint | java.lang.Integer, uri: android.net.Uri, /) -> None: ...
    def setInt(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setIntDimen(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, dimenResource: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setIntDimen(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: float | java.jfloat | java.lang.Float, unit: int | java.jint | java.lang.Integer, /) -> None: ...
    def setIntDimenAttr(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, dimenAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    def setIntent(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: android.content.Intent, /) -> None: ...
    def setLabelFor(self, viewId: int | java.jint | java.lang.Integer, labeledId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLightBackgroundLayoutId(self, layoutId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLong(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: int | java.jlong | java.lang.Long, /) -> None: ...
    def setOnCheckedChangeResponse(self, viewId: int | java.jint | java.lang.Integer, response: RemoteViews.RemoteResponse, /) -> None: ...
    def setOnClickFillInIntent(self, viewId: int | java.jint | java.lang.Integer, fillInIntent: android.content.Intent, /) -> None: ...
    def setOnClickPendingIntent(self, viewId: int | java.jint | java.lang.Integer, pendingIntent: android.app.PendingIntent, /) -> None: ...
    def setOnClickResponse(self, viewId: int | java.jint | java.lang.Integer, response: RemoteViews.RemoteResponse, /) -> None: ...
    def setOnStylusHandwritingPendingIntent(self, viewId: int | java.jint | java.lang.Integer, pendingIntent: android.app.PendingIntent, /) -> None: ...
    def setPendingIntentTemplate(self, viewId: int | java.jint | java.lang.Integer, pendingIntentTemplate: android.app.PendingIntent, /) -> None: ...
    def setProgressBar(self, viewId: int | java.jint | java.lang.Integer, max: int | java.jint | java.lang.Integer, progress: int | java.jint | java.lang.Integer, indeterminate: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setRadioGroupChecked(self, viewId: int | java.jint | java.lang.Integer, checkedId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRelativeScrollPosition(self, viewId: int | java.jint | java.lang.Integer, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setRemoteAdapter(self, viewId: int | java.jint | java.lang.Integer, intent: android.content.Intent, /) -> None: ...
    @typing.overload
    def setRemoteAdapter(self, viewId: int | java.jint | java.lang.Integer, items: RemoteViews.RemoteCollectionItems, /) -> None: ...
    @typing.overload
    def setRemoteAdapter(self, appWidgetId: int | java.jint | java.lang.Integer, viewId: int | java.jint | java.lang.Integer, intent: android.content.Intent, /) -> None: ...
    def setScrollPosition(self, viewId: int | java.jint | java.lang.Integer, position: int | java.jint | java.lang.Integer, /) -> None: ...
    def setShort(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: int | java.jshort | java.lang.Short, /) -> None: ...
    def setString(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
    def setTextColor(self, viewId: int | java.jint | java.lang.Integer, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTextViewCompoundDrawables(self, viewId: int | java.jint | java.lang.Integer, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTextViewCompoundDrawablesRelative(self, viewId: int | java.jint | java.lang.Integer, start: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTextViewText(self, viewId: int | java.jint | java.lang.Integer, text: java.lang.CharSequence, /) -> None: ...
    def setTextViewTextSize(self, viewId: int | java.jint | java.lang.Integer, units: int | java.jint | java.lang.Integer, size: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setUri(self, viewId: int | java.jint | java.lang.Integer, methodName: str | java.lang.String, value: android.net.Uri, /) -> None: ...
    def setViewLayoutHeight(self, viewId: int | java.jint | java.lang.Integer, height: float | java.jfloat | java.lang.Float, units: int | java.jint | java.lang.Integer, /) -> None: ...
    def setViewLayoutHeightAttr(self, viewId: int | java.jint | java.lang.Integer, heightAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    def setViewLayoutHeightDimen(self, viewId: int | java.jint | java.lang.Integer, heightDimen: int | java.jint | java.lang.Integer, /) -> None: ...
    def setViewLayoutMargin(self, viewId: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, value: float | java.jfloat | java.lang.Float, units: int | java.jint | java.lang.Integer, /) -> None: ...
    def setViewLayoutMarginAttr(self, viewId: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, attr: int | java.jint | java.lang.Integer, /) -> None: ...
    def setViewLayoutMarginDimen(self, viewId: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, dimen: int | java.jint | java.lang.Integer, /) -> None: ...
    def setViewLayoutWidth(self, viewId: int | java.jint | java.lang.Integer, width: float | java.jfloat | java.lang.Float, units: int | java.jint | java.lang.Integer, /) -> None: ...
    def setViewLayoutWidthAttr(self, viewId: int | java.jint | java.lang.Integer, widthAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    def setViewLayoutWidthDimen(self, viewId: int | java.jint | java.lang.Integer, widthDimen: int | java.jint | java.lang.Integer, /) -> None: ...
    def setViewOutlinePreferredRadius(self, viewId: int | java.jint | java.lang.Integer, radius: float | java.jfloat | java.lang.Float, units: int | java.jint | java.lang.Integer, /) -> None: ...
    def setViewOutlinePreferredRadiusAttr(self, viewId: int | java.jint | java.lang.Integer, attrId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setViewOutlinePreferredRadiusDimen(self, viewId: int | java.jint | java.lang.Integer, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setViewPadding(self, viewId: int | java.jint | java.lang.Integer, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def setViewVisibility(self, viewId: int | java.jint | java.lang.Integer, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def showNext(self, viewId: int | java.jint | java.lang.Integer, /) -> None: ...
    def showPrevious(self, viewId: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class RemoteViewOutlineProvider(android.view.ViewOutlineProvider):
        def __init__(self, radius: float | java.jfloat | java.lang.Float, /) -> None: ...
        def getOutline(self, view: android.view.View, outline: android.graphics.Outline, /) -> None: ...
        def getRadius(self) -> float: ...

    class RemoteView(java.lang.annotation.Annotation): ...

    class RemoteResponse(java.lang.Object):
        def __init__(self) -> None: ...
        def addSharedElement(self, viewId: int | java.jint | java.lang.Integer, sharedElementName: str | java.lang.String, /) -> RemoteViews.RemoteResponse: ...
        @staticmethod
        def fromFillInIntent(fillIntent: android.content.Intent, /) -> RemoteViews.RemoteResponse: ...
        @staticmethod
        def fromPendingIntent(pendingIntent: android.app.PendingIntent, /) -> RemoteViews.RemoteResponse: ...

    class RemoteCollectionItems(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RemoteViews.RemoteCollectionItems]] = ...
        def describeContents(self) -> int: ...
        def getItemCount(self) -> int: ...
        def getItemId(self, position: int | java.jint | java.lang.Integer, /) -> int: ...
        def getItemView(self, position: int | java.jint | java.lang.Integer, /) -> RemoteViews: ...
        def getViewTypeCount(self) -> int: ...
        def hasStableIds(self) -> bool: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

        class Builder(java.lang.Object):
            def __init__(self) -> None: ...
            def addItem(self, id: int | java.jlong | java.lang.Long, view: RemoteViews, /) -> RemoteViews.RemoteCollectionItems.Builder: ...
            def build(self) -> RemoteViews.RemoteCollectionItems: ...
            def setHasStableIds(self, hasStableIds: bool | java.jboolean | java.lang.Boolean, /) -> RemoteViews.RemoteCollectionItems.Builder: ...
            def setViewTypeCount(self, viewTypeCount: int | java.jint | java.lang.Integer, /) -> RemoteViews.RemoteCollectionItems.Builder: ...

    class DrawInstructions(java.lang.Object):
        @staticmethod
        def getSupportedVersion() -> int: ...

        class Builder(java.lang.Object):
            def __init__(self, instructions: java.util.List[java.chaquopy.JavaArrayJByte], /) -> None: ...
            def build(self) -> RemoteViews.DrawInstructions: ...

    class ActionException(java.lang.RuntimeException):
        @typing.overload
        def __init__(self, ex: java.lang.Exception, /) -> None: ...
        @typing.overload
        def __init__(self, message: str | java.lang.String, /) -> None: ...

class RemoteViewsService(android.app.Service):
    def __init__(self) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onGetViewFactory(self, arg1: android.content.Intent, /) -> RemoteViewsService.RemoteViewsFactory: ...

    class RemoteViewsFactory(java.lang.Object):
        def getCount(self) -> int: ...
        def getItemId(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
        def getLoadingView(self) -> RemoteViews: ...
        def getViewAt(self, arg1: int | java.jint | java.lang.Integer, /) -> RemoteViews: ...
        def getViewTypeCount(self) -> int: ...
        def hasStableIds(self) -> bool: ...
        def onCreate(self) -> None: ...
        def onDataSetChanged(self) -> None: ...
        def onDestroy(self) -> None: ...

class ResourceCursorAdapter(CursorAdapter):
    @typing.overload
    def __init__(self, context: android.content.Context, layout: int | java.jint | java.lang.Integer, c: android.database.Cursor, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, layout: int | java.jint | java.lang.Integer, c: android.database.Cursor, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, layout: int | java.jint | java.lang.Integer, c: android.database.Cursor, autoRequery: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def newDropDownView(self, context: android.content.Context, cursor: android.database.Cursor, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def newView(self, context: android.content.Context, cursor: android.database.Cursor, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def setDropDownViewResource(self, dropDownLayout: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDropDownViewTheme(self, theme: android.content.res.Resources.Theme, /) -> None: ...
    def setViewResource(self, layout: int | java.jint | java.lang.Integer, /) -> None: ...

class ResourceCursorTreeAdapter(CursorTreeAdapter):
    @typing.overload
    def __init__(self, context: android.content.Context, cursor: android.database.Cursor, groupLayout: int | java.jint | java.lang.Integer, childLayout: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, cursor: android.database.Cursor, collapsedGroupLayout: int | java.jint | java.lang.Integer, expandedGroupLayout: int | java.jint | java.lang.Integer, childLayout: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, cursor: android.database.Cursor, collapsedGroupLayout: int | java.jint | java.lang.Integer, expandedGroupLayout: int | java.jint | java.lang.Integer, childLayout: int | java.jint | java.lang.Integer, lastChildLayout: int | java.jint | java.lang.Integer, /) -> None: ...
    def newChildView(self, context: android.content.Context, cursor: android.database.Cursor, isLastChild: bool | java.jboolean | java.lang.Boolean, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def newGroupView(self, context: android.content.Context, cursor: android.database.Cursor, isExpanded: bool | java.jboolean | java.lang.Boolean, parent: android.view.ViewGroup, /) -> android.view.View: ...

class ScrollView(FrameLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, index: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, index: int | java.jint | java.lang.Integer, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def arrowScroll(self, direction: int | java.jint | java.lang.Integer, /) -> bool: ...
    def computeScroll(self) -> None: ...
    def computeScrollDeltaToGetChildRectOnScreen(self, rect: android.graphics.Rect, /) -> int: ...
    def computeVerticalScrollOffset(self) -> int: ...
    def computeVerticalScrollRange(self) -> int: ...
    def dispatchKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def draw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def executeKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def fling(self, velocityY: int | java.jint | java.lang.Integer, /) -> None: ...
    def fullScroll(self, direction: int | java.jint | java.lang.Integer, /) -> bool: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getBottomEdgeEffectColor(self) -> int: ...
    def getBottomFadingEdgeStrength(self) -> float: ...
    def getMaxScrollAmount(self) -> int: ...
    def getTopEdgeEffectColor(self) -> int: ...
    def getTopFadingEdgeStrength(self) -> float: ...
    def isFillViewport(self) -> bool: ...
    def isSmoothScrollingEnabled(self) -> bool: ...
    def measureChild(self, child: android.view.View, parentWidthMeasureSpec: int | java.jint | java.lang.Integer, parentHeightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def measureChildWithMargins(self, child: android.view.View, parentWidthMeasureSpec: int | java.jint | java.lang.Integer, widthUsed: int | java.jint | java.lang.Integer, parentHeightMeasureSpec: int | java.jint | java.lang.Integer, heightUsed: int | java.jint | java.lang.Integer, /) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onGenericMotionEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onInterceptTouchEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onNestedFling(self, target: android.view.View, velocityX: float | java.jfloat | java.lang.Float, velocityY: float | java.jfloat | java.lang.Float, consumed: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def onNestedScroll(self, target: android.view.View, dxConsumed: int | java.jint | java.lang.Integer, dyConsumed: int | java.jint | java.lang.Integer, dxUnconsumed: int | java.jint | java.lang.Integer, dyUnconsumed: int | java.jint | java.lang.Integer, /) -> None: ...
    def onNestedScrollAccepted(self, child: android.view.View, target: android.view.View, axes: int | java.jint | java.lang.Integer, /) -> None: ...
    def onOverScrolled(self, scrollX: int | java.jint | java.lang.Integer, scrollY: int | java.jint | java.lang.Integer, clampedX: bool | java.jboolean | java.lang.Boolean, clampedY: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onRequestFocusInDescendants(self, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> bool: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onSizeChanged(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, oldw: int | java.jint | java.lang.Integer, oldh: int | java.jint | java.lang.Integer, /) -> None: ...
    def onStartNestedScroll(self, child: android.view.View, target: android.view.View, nestedScrollAxes: int | java.jint | java.lang.Integer, /) -> bool: ...
    def onStopNestedScroll(self, target: android.view.View, /) -> None: ...
    def onTouchEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def pageScroll(self, direction: int | java.jint | java.lang.Integer, /) -> bool: ...
    def requestChildFocus(self, child: android.view.View, focused: android.view.View, /) -> None: ...
    def requestChildRectangleOnScreen(self, child: android.view.View, rectangle: android.graphics.Rect, immediate: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def requestDisallowInterceptTouchEvent(self, disallowIntercept: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def requestLayout(self) -> None: ...
    def scrollTo(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> None: ...
    def scrollToDescendant(self, child: android.view.View, /) -> None: ...
    def setBottomEdgeEffectColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setEdgeEffectColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFillViewport(self, fillViewport: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSmoothScrollingEnabled(self, smoothScrollingEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTopEdgeEffectColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def shouldDelayChildPressedState(self) -> bool: ...
    def smoothScrollBy(self, dx: int | java.jint | java.lang.Integer, dy: int | java.jint | java.lang.Integer, /) -> None: ...
    def smoothScrollTo(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> None: ...

class Scroller(java.lang.Object):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, interpolator: android.view.animation.Interpolator, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, interpolator: android.view.animation.Interpolator, flywheel: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def abortAnimation(self) -> None: ...
    def computeScrollOffset(self) -> bool: ...
    def extendDuration(self, extend: int | java.jint | java.lang.Integer, /) -> None: ...
    def fling(self, startX: int | java.jint | java.lang.Integer, startY: int | java.jint | java.lang.Integer, velocityX: int | java.jint | java.lang.Integer, velocityY: int | java.jint | java.lang.Integer, minX: int | java.jint | java.lang.Integer, maxX: int | java.jint | java.lang.Integer, minY: int | java.jint | java.lang.Integer, maxY: int | java.jint | java.lang.Integer, /) -> None: ...
    def forceFinished(self, finished: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def getCurrVelocity(self) -> float: ...
    def getCurrX(self) -> int: ...
    def getCurrY(self) -> int: ...
    def getDuration(self) -> int: ...
    def getFinalX(self) -> int: ...
    def getFinalY(self) -> int: ...
    def getStartX(self) -> int: ...
    def getStartY(self) -> int: ...
    def isFinished(self) -> bool: ...
    def setFinalX(self, newX: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFinalY(self, newY: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFriction(self, friction: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def startScroll(self, startX: int | java.jint | java.lang.Integer, startY: int | java.jint | java.lang.Integer, dx: int | java.jint | java.lang.Integer, dy: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startScroll(self, startX: int | java.jint | java.lang.Integer, startY: int | java.jint | java.lang.Integer, dx: int | java.jint | java.lang.Integer, dy: int | java.jint | java.lang.Integer, duration: int | java.jint | java.lang.Integer, /) -> None: ...
    def timePassed(self) -> int: ...

class SearchView(android.view.CollapsibleActionView, LinearLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def clearFocus(self) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getImeOptions(self) -> int: ...
    def getInputType(self) -> int: ...
    def getMaxWidth(self) -> int: ...
    def getQuery(self) -> java.lang.CharSequence: ...
    def getQueryHint(self) -> java.lang.CharSequence | None: ...
    def getSuggestionsAdapter(self) -> CursorAdapter: ...
    def isIconfiedByDefault(self) -> bool: ...
    def isIconified(self) -> bool: ...
    def isIconifiedByDefault(self) -> bool: ...
    def isQueryRefinementEnabled(self) -> bool: ...
    def isSubmitButtonEnabled(self) -> bool: ...
    def onActionViewCollapsed(self) -> None: ...
    def onActionViewExpanded(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onWindowFocusChanged(self, hasWindowFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def requestFocus(self, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> bool: ...
    def setIconified(self, iconify: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setIconifiedByDefault(self, iconified: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setImeOptions(self, imeOptions: int | java.jint | java.lang.Integer, /) -> None: ...
    def setInputType(self, inputType: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaxWidth(self, maxpixels: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOnCloseListener(self, listener: SearchView.OnCloseListener, /) -> None: ...
    def setOnQueryTextFocusChangeListener(self, listener: android.view.View.OnFocusChangeListener, /) -> None: ...
    def setOnQueryTextListener(self, listener: SearchView.OnQueryTextListener, /) -> None: ...
    def setOnSearchClickListener(self, listener: android.view.View.OnClickListener, /) -> None: ...
    def setOnSuggestionListener(self, listener: SearchView.OnSuggestionListener, /) -> None: ...
    def setQuery(self, query: java.lang.CharSequence, submit: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setQueryHint(self, hint: java.lang.CharSequence, /) -> None: ...
    def setQueryRefinementEnabled(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSearchableInfo(self, searchable: android.app.SearchableInfo, /) -> None: ...
    def setSubmitButtonEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSuggestionsAdapter(self, adapter: CursorAdapter, /) -> None: ...

    class OnSuggestionListener(java.lang.Object):
        def onSuggestionClick(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
        def onSuggestionSelect(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...

    class OnQueryTextListener(java.lang.Object):
        def onQueryTextChange(self, arg1: str | java.lang.String, /) -> bool: ...
        def onQueryTextSubmit(self, arg1: str | java.lang.String, /) -> bool: ...

    class OnCloseListener(java.lang.Object):
        def onClose(self) -> bool: ...

class SectionIndexer(java.lang.Object):
    def getPositionForSection(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getSectionForPosition(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getSections(self) -> java.chaquopy.JavaArray[java.lang.Object]: ...

class SeekBar(AbsSeekBar):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def setOnSeekBarChangeListener(self, l: SeekBar.OnSeekBarChangeListener, /) -> None: ...

    class OnSeekBarChangeListener(java.lang.Object):
        def onProgressChanged(self, arg1: SeekBar, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onStartTrackingTouch(self, arg1: SeekBar, /) -> None: ...
        def onStopTrackingTouch(self, arg1: SeekBar, /) -> None: ...

class ShareActionProvider(android.view.ActionProvider):
    DEFAULT_SHARE_HISTORY_FILE_NAME: typing.ClassVar[str] = ...
    def __init__(self, context: android.content.Context, /) -> None: ...
    def hasSubMenu(self) -> bool: ...
    def onCreateActionView(self) -> android.view.View: ...
    def onPrepareSubMenu(self, subMenu: android.view.SubMenu, /) -> None: ...
    def setOnShareTargetSelectedListener(self, listener: ShareActionProvider.OnShareTargetSelectedListener, /) -> None: ...
    def setShareHistoryFileName(self, shareHistoryFile: str | java.lang.String, /) -> None: ...
    def setShareIntent(self, shareIntent: android.content.Intent, /) -> None: ...

    class OnShareTargetSelectedListener(java.lang.Object):
        def onShareTargetSelected(self, arg1: ShareActionProvider, arg2: android.content.Intent, /) -> bool: ...

class SimpleAdapter(BaseAdapter, Filterable, ThemedSpinnerAdapter):
    def __init__(self, context: android.content.Context, data: java.util.List[java.util.Map[java.lang.String, java.lang.Object]], resource: int | java.jint | java.lang.Integer, from_: java.chaquopy.JavaArray[java.lang.String], to: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def getCount(self) -> int: ...
    def getDropDownView(self, position: int | java.jint | java.lang.Integer, convertView: android.view.View, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def getDropDownViewTheme(self) -> android.content.res.Resources.Theme: ...
    def getFilter(self) -> Filter: ...
    def getItem(self, position: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def getItemId(self, position: int | java.jint | java.lang.Integer, /) -> int: ...
    def getView(self, position: int | java.jint | java.lang.Integer, convertView: android.view.View, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def getViewBinder(self) -> SimpleAdapter.ViewBinder | None: ...
    def setDropDownViewResource(self, resource: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDropDownViewTheme(self, theme: android.content.res.Resources.Theme, /) -> None: ...
    def setViewBinder(self, viewBinder: SimpleAdapter.ViewBinder, /) -> None: ...
    @typing.overload
    def setViewImage(self, v: ImageView, value: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setViewImage(self, v: ImageView, value: str | java.lang.String, /) -> None: ...
    def setViewText(self, v: TextView, text: str | java.lang.String, /) -> None: ...

    class ViewBinder(java.lang.Object):
        def setViewValue(self, arg1: android.view.View, arg2: java.lang.Object | int | bool | float | str, arg3: str | java.lang.String, /) -> bool: ...

class SimpleCursorAdapter(ResourceCursorAdapter):
    @typing.overload
    def __init__(self, context: android.content.Context, layout: int | java.jint | java.lang.Integer, c: android.database.Cursor, from_: java.chaquopy.JavaArray[java.lang.String], to: java.chaquopy.JavaArrayJInt, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, layout: int | java.jint | java.lang.Integer, c: android.database.Cursor, from_: java.chaquopy.JavaArray[java.lang.String], to: java.chaquopy.JavaArrayJInt, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def bindView(self, view: android.view.View, context: android.content.Context, cursor: android.database.Cursor, /) -> None: ...
    def changeCursorAndColumns(self, c: android.database.Cursor, from_: java.chaquopy.JavaArray[java.lang.String], to: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def convertToString(self, cursor: android.database.Cursor, /) -> java.lang.CharSequence: ...
    def getCursorToStringConverter(self) -> SimpleCursorAdapter.CursorToStringConverter | None: ...
    def getStringConversionColumn(self) -> int: ...
    def getViewBinder(self) -> SimpleCursorAdapter.ViewBinder | None: ...
    def setCursorToStringConverter(self, cursorToStringConverter: SimpleCursorAdapter.CursorToStringConverter, /) -> None: ...
    def setStringConversionColumn(self, stringConversionColumn: int | java.jint | java.lang.Integer, /) -> None: ...
    def setViewBinder(self, viewBinder: SimpleCursorAdapter.ViewBinder, /) -> None: ...
    def setViewImage(self, v: ImageView, value: str | java.lang.String, /) -> None: ...
    def setViewText(self, v: TextView, text: str | java.lang.String, /) -> None: ...
    def swapCursor(self, c: android.database.Cursor, /) -> android.database.Cursor: ...

    class ViewBinder(java.lang.Object):
        def setViewValue(self, arg1: android.view.View, arg2: android.database.Cursor, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...

    class CursorToStringConverter(java.lang.Object):
        def convertToString(self, arg1: android.database.Cursor, /) -> java.lang.CharSequence: ...

class SimpleCursorTreeAdapter(ResourceCursorTreeAdapter):
    @typing.overload
    def __init__(self, context: android.content.Context, cursor: android.database.Cursor, groupLayout: int | java.jint | java.lang.Integer, groupFrom: java.chaquopy.JavaArray[java.lang.String], groupTo: java.chaquopy.JavaArrayJInt, childLayout: int | java.jint | java.lang.Integer, childFrom: java.chaquopy.JavaArray[java.lang.String], childTo: java.chaquopy.JavaArrayJInt, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, cursor: android.database.Cursor, collapsedGroupLayout: int | java.jint | java.lang.Integer, expandedGroupLayout: int | java.jint | java.lang.Integer, groupFrom: java.chaquopy.JavaArray[java.lang.String], groupTo: java.chaquopy.JavaArrayJInt, childLayout: int | java.jint | java.lang.Integer, childFrom: java.chaquopy.JavaArray[java.lang.String], childTo: java.chaquopy.JavaArrayJInt, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, cursor: android.database.Cursor, collapsedGroupLayout: int | java.jint | java.lang.Integer, expandedGroupLayout: int | java.jint | java.lang.Integer, groupFrom: java.chaquopy.JavaArray[java.lang.String], groupTo: java.chaquopy.JavaArrayJInt, childLayout: int | java.jint | java.lang.Integer, lastChildLayout: int | java.jint | java.lang.Integer, childFrom: java.chaquopy.JavaArray[java.lang.String], childTo: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def bindChildView(self, view: android.view.View, context: android.content.Context, cursor: android.database.Cursor, isLastChild: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def bindGroupView(self, view: android.view.View, context: android.content.Context, cursor: android.database.Cursor, isExpanded: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def getViewBinder(self) -> SimpleCursorTreeAdapter.ViewBinder | None: ...
    def setViewBinder(self, viewBinder: SimpleCursorTreeAdapter.ViewBinder, /) -> None: ...
    def setViewImage(self, v: ImageView, value: str | java.lang.String, /) -> None: ...
    def setViewText(self, v: TextView, text: str | java.lang.String, /) -> None: ...

    class ViewBinder(java.lang.Object):
        def setViewValue(self, arg1: android.view.View, arg2: android.database.Cursor, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...

class SimpleExpandableListAdapter(BaseExpandableListAdapter):
    @typing.overload
    def __init__(self, context: android.content.Context, groupData: java.util.List[java.util.Map[java.lang.String, java.lang.Object]], groupLayout: int | java.jint | java.lang.Integer, groupFrom: java.chaquopy.JavaArray[java.lang.String], groupTo: java.chaquopy.JavaArrayJInt, childData: java.util.List[java.util.List[java.util.Map[java.lang.String, java.lang.Object]]], childLayout: int | java.jint | java.lang.Integer, childFrom: java.chaquopy.JavaArray[java.lang.String], childTo: java.chaquopy.JavaArrayJInt, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, groupData: java.util.List[java.util.Map[java.lang.String, java.lang.Object]], expandedGroupLayout: int | java.jint | java.lang.Integer, collapsedGroupLayout: int | java.jint | java.lang.Integer, groupFrom: java.chaquopy.JavaArray[java.lang.String], groupTo: java.chaquopy.JavaArrayJInt, childData: java.util.List[java.util.List[java.util.Map[java.lang.String, java.lang.Object]]], childLayout: int | java.jint | java.lang.Integer, childFrom: java.chaquopy.JavaArray[java.lang.String], childTo: java.chaquopy.JavaArrayJInt, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, groupData: java.util.List[java.util.Map[java.lang.String, java.lang.Object]], expandedGroupLayout: int | java.jint | java.lang.Integer, collapsedGroupLayout: int | java.jint | java.lang.Integer, groupFrom: java.chaquopy.JavaArray[java.lang.String], groupTo: java.chaquopy.JavaArrayJInt, childData: java.util.List[java.util.List[java.util.Map[java.lang.String, java.lang.Object]]], childLayout: int | java.jint | java.lang.Integer, lastChildLayout: int | java.jint | java.lang.Integer, childFrom: java.chaquopy.JavaArray[java.lang.String], childTo: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def getChild(self, groupPosition: int | java.jint | java.lang.Integer, childPosition: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def getChildId(self, groupPosition: int | java.jint | java.lang.Integer, childPosition: int | java.jint | java.lang.Integer, /) -> int: ...
    def getChildView(self, groupPosition: int | java.jint | java.lang.Integer, childPosition: int | java.jint | java.lang.Integer, isLastChild: bool | java.jboolean | java.lang.Boolean, convertView: android.view.View, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def getChildrenCount(self, groupPosition: int | java.jint | java.lang.Integer, /) -> int: ...
    def getGroup(self, groupPosition: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def getGroupCount(self) -> int: ...
    def getGroupId(self, groupPosition: int | java.jint | java.lang.Integer, /) -> int: ...
    def getGroupView(self, groupPosition: int | java.jint | java.lang.Integer, isExpanded: bool | java.jboolean | java.lang.Boolean, convertView: android.view.View, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def hasStableIds(self) -> bool: ...
    def isChildSelectable(self, groupPosition: int | java.jint | java.lang.Integer, childPosition: int | java.jint | java.lang.Integer, /) -> bool: ...
    def newChildView(self, isLastChild: bool | java.jboolean | java.lang.Boolean, parent: android.view.ViewGroup, /) -> android.view.View: ...
    def newGroupView(self, isExpanded: bool | java.jboolean | java.lang.Boolean, parent: android.view.ViewGroup, /) -> android.view.View: ...

class SlidingDrawer(android.view.ViewGroup):
    ORIENTATION_HORIZONTAL: typing.ClassVar[int] = ...
    ORIENTATION_VERTICAL: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def animateClose(self) -> None: ...
    def animateOpen(self) -> None: ...
    def animateToggle(self) -> None: ...
    def close(self) -> None: ...
    def dispatchDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getContent(self) -> android.view.View: ...
    def getHandle(self) -> android.view.View: ...
    def isMoving(self) -> bool: ...
    def isOpened(self) -> bool: ...
    def lock(self) -> None: ...
    def onFinishInflate(self) -> None: ...
    def onInterceptTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def open(self) -> None: ...
    def setOnDrawerCloseListener(self, onDrawerCloseListener: SlidingDrawer.OnDrawerCloseListener, /) -> None: ...
    def setOnDrawerOpenListener(self, onDrawerOpenListener: SlidingDrawer.OnDrawerOpenListener, /) -> None: ...
    def setOnDrawerScrollListener(self, onDrawerScrollListener: SlidingDrawer.OnDrawerScrollListener, /) -> None: ...
    def toggle(self) -> None: ...
    def unlock(self) -> None: ...

    class OnDrawerScrollListener(java.lang.Object):
        def onScrollEnded(self) -> None: ...
        def onScrollStarted(self) -> None: ...

    class OnDrawerOpenListener(java.lang.Object):
        def onDrawerOpened(self) -> None: ...

    class OnDrawerCloseListener(java.lang.Object):
        def onDrawerClosed(self) -> None: ...

class Space(android.view.View):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def draw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...

class Spinner(android.content.DialogInterface.OnClickListener, AbsSpinner):
    MODE_DIALOG: typing.ClassVar[int] = ...
    MODE_DROPDOWN: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, mode: int | java.jint | java.lang.Integer, popupTheme: android.content.res.Resources.Theme, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getBaseline(self) -> int: ...
    def getDropDownHorizontalOffset(self) -> int: ...
    def getDropDownVerticalOffset(self) -> int: ...
    def getDropDownWidth(self) -> int: ...
    def getGravity(self) -> int: ...
    def getPopupBackground(self) -> android.graphics.drawable.Drawable: ...
    def getPopupContext(self) -> android.content.Context: ...
    def getPrompt(self) -> java.lang.CharSequence: ...
    def onClick(self, dialog: android.content.DialogInterface, which: int | java.jint | java.lang.Integer, /) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onResolvePointerIcon(self, event: android.view.MotionEvent, pointerIndex: int | java.jint | java.lang.Integer, /) -> android.view.PointerIcon: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def performClick(self) -> bool: ...
    def setAdapter(self, adapter: SpinnerAdapter, /) -> None: ...
    def setDropDownHorizontalOffset(self, pixels: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDropDownVerticalOffset(self, pixels: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDropDownWidth(self, pixels: int | java.jint | java.lang.Integer, /) -> None: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setGravity(self, gravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOnItemClickListener(self, l: AdapterView.OnItemClickListener, /) -> None: ...
    def setPopupBackgroundDrawable(self, background: android.graphics.drawable.Drawable, /) -> None: ...
    def setPopupBackgroundResource(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPrompt(self, prompt: java.lang.CharSequence, /) -> None: ...
    def setPromptId(self, promptId: int | java.jint | java.lang.Integer, /) -> None: ...

class SpinnerAdapter(Adapter):
    def getDropDownView(self, arg1: int | java.jint | java.lang.Integer, arg2: android.view.View, arg3: android.view.ViewGroup, /) -> android.view.View: ...

class StackView(AdapterViewAnimator):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def advance(self) -> None: ...
    def dispatchDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def onGenericMotionEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onInterceptTouchEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTouchEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def showNext(self) -> None: ...
    def showPrevious(self) -> None: ...

class Switch(CompoundButton):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def draw(self, c: android.graphics.Canvas, /) -> None: ...
    def drawableHotspotChanged(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> None: ...
    def drawableStateChanged(self) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getCompoundPaddingLeft(self) -> int: ...
    def getCompoundPaddingRight(self) -> int: ...
    def getShowText(self) -> bool: ...
    def getSplitTrack(self) -> bool: ...
    def getSwitchMinWidth(self) -> int: ...
    def getSwitchPadding(self) -> int: ...
    def getTextOff(self) -> java.lang.CharSequence: ...
    def getTextOn(self) -> java.lang.CharSequence: ...
    def getThumbDrawable(self) -> android.graphics.drawable.Drawable: ...
    def getThumbTextPadding(self) -> int: ...
    def getThumbTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getThumbTintList(self) -> android.content.res.ColorStateList | None: ...
    def getThumbTintMode(self) -> android.graphics.PorterDuff.Mode | None: ...
    def getTrackDrawable(self) -> android.graphics.drawable.Drawable: ...
    def getTrackTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getTrackTintList(self) -> android.content.res.ColorStateList | None: ...
    def getTrackTintMode(self) -> android.graphics.PorterDuff.Mode | None: ...
    def jumpDrawablesToCurrentState(self) -> None: ...
    def onCreateDrawableState(self, extraSpace: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTouchEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def setChecked(self, checked: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setShowText(self, showText: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSplitTrack(self, splitTrack: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSwitchMinWidth(self, pixels: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSwitchPadding(self, pixels: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSwitchTextAppearance(self, context: android.content.Context, resid: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSwitchTypeface(self, tf: android.graphics.Typeface, /) -> None: ...
    @typing.overload
    def setSwitchTypeface(self, tf: android.graphics.Typeface, style: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTextOff(self, textOff: java.lang.CharSequence, /) -> None: ...
    def setTextOn(self, textOn: java.lang.CharSequence, /) -> None: ...
    def setThumbDrawable(self, thumb: android.graphics.drawable.Drawable, /) -> None: ...
    def setThumbIcon(self, icon: android.graphics.drawable.Icon, /) -> None: ...
    def setThumbResource(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setThumbTextPadding(self, pixels: int | java.jint | java.lang.Integer, /) -> None: ...
    def setThumbTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setThumbTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setThumbTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> None: ...
    def setTrackDrawable(self, track: android.graphics.drawable.Drawable, /) -> None: ...
    def setTrackIcon(self, icon: android.graphics.drawable.Icon, /) -> None: ...
    def setTrackResource(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTrackTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setTrackTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setTrackTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> None: ...
    def toggle(self) -> None: ...
    def verifyDrawable(self, who: android.graphics.drawable.Drawable, /) -> bool: ...

class TabHost(android.view.ViewTreeObserver.OnTouchModeChangeListener, FrameLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def addTab(self, tabSpec: TabHost.TabSpec, /) -> None: ...
    def clearAllTabs(self) -> None: ...
    def dispatchKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def dispatchWindowFocusChanged(self, hasFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getCurrentTab(self) -> int: ...
    def getCurrentTabTag(self) -> str | None: ...
    def getCurrentTabView(self) -> android.view.View | None: ...
    def getCurrentView(self) -> android.view.View: ...
    def getTabContentView(self) -> FrameLayout: ...
    def getTabWidget(self) -> TabWidget: ...
    def newTabSpec(self, tag: str | java.lang.String, /) -> TabHost.TabSpec: ...
    def onTouchModeChanged(self, isInTouchMode: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCurrentTab(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCurrentTabByTag(self, tag: str | java.lang.String, /) -> None: ...
    def setOnTabChangedListener(self, l: TabHost.OnTabChangeListener, /) -> None: ...
    @typing.overload
    def setup(self) -> None: ...
    @typing.overload
    def setup(self, activityGroup: android.app.LocalActivityManager, /) -> None: ...

    class TabSpec(java.lang.Object):
        def getTag(self) -> str: ...
        @typing.overload
        def setContent(self, viewId: int | java.jint | java.lang.Integer, /) -> TabHost.TabSpec: ...
        @typing.overload
        def setContent(self, intent: android.content.Intent, /) -> TabHost.TabSpec: ...
        @typing.overload
        def setContent(self, contentFactory: TabHost.TabContentFactory, /) -> TabHost.TabSpec: ...
        @typing.overload
        def setIndicator(self, view: android.view.View, /) -> TabHost.TabSpec: ...
        @typing.overload
        def setIndicator(self, label: java.lang.CharSequence, /) -> TabHost.TabSpec: ...
        @typing.overload
        def setIndicator(self, label: java.lang.CharSequence, icon: android.graphics.drawable.Drawable, /) -> TabHost.TabSpec: ...

    class TabContentFactory(java.lang.Object):
        def createTabContent(self, arg1: str | java.lang.String, /) -> android.view.View: ...

    class OnTabChangeListener(java.lang.Object):
        def onTabChanged(self, arg1: str | java.lang.String, /) -> None: ...

class TabWidget(android.view.View.OnFocusChangeListener, LinearLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def addView(self, child: android.view.View, /) -> None: ...
    def childDrawableStateChanged(self, child: android.view.View, /) -> None: ...
    def dispatchDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def focusCurrentTab(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getChildDrawingOrder(self, childCount: int | java.jint | java.lang.Integer, i: int | java.jint | java.lang.Integer, /) -> int: ...
    def getChildTabViewAt(self, index: int | java.jint | java.lang.Integer, /) -> android.view.View: ...
    def getLeftStripDrawable(self) -> android.graphics.drawable.Drawable | None: ...
    def getRightStripDrawable(self) -> android.graphics.drawable.Drawable | None: ...
    def getTabCount(self) -> int: ...
    def isStripEnabled(self) -> bool: ...
    def onFocusChange(self, v: android.view.View, hasFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onResolvePointerIcon(self, event: android.view.MotionEvent, pointerIndex: int | java.jint | java.lang.Integer, /) -> android.view.PointerIcon: ...
    def onSizeChanged(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, oldw: int | java.jint | java.lang.Integer, oldh: int | java.jint | java.lang.Integer, /) -> None: ...
    def removeAllViews(self) -> None: ...
    def setCurrentTab(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setDividerDrawable(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setDividerDrawable(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setLeftStripDrawable(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setLeftStripDrawable(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    @typing.overload
    def setRightStripDrawable(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setRightStripDrawable(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def setStripEnabled(self, stripEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class TableLayout(LinearLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, index: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    @typing.overload
    def addView(self, child: android.view.View, index: int | java.jint | java.lang.Integer, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def checkLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> bool: ...
    def generateDefaultLayoutParams(self) -> LinearLayout.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, attrs: android.util.AttributeSet, /) -> TableLayout.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> LinearLayout.LayoutParams: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def isColumnCollapsed(self, columnIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isColumnShrinkable(self, columnIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isColumnStretchable(self, columnIndex: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isShrinkAllColumns(self) -> bool: ...
    def isStretchAllColumns(self) -> bool: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def requestLayout(self) -> None: ...
    def setColumnCollapsed(self, columnIndex: int | java.jint | java.lang.Integer, isCollapsed: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setColumnShrinkable(self, columnIndex: int | java.jint | java.lang.Integer, isShrinkable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setColumnStretchable(self, columnIndex: int | java.jint | java.lang.Integer, isStretchable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOnHierarchyChangeListener(self, listener: android.view.ViewGroup.OnHierarchyChangeListener, /) -> None: ...
    def setShrinkAllColumns(self, shrinkAllColumns: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setStretchAllColumns(self, stretchAllColumns: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class LayoutParams(LinearLayout.LayoutParams):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, p: android.view.ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: android.view.ViewGroup.MarginLayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, c: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
        @typing.overload
        def __init__(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, initWeight: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setBaseAttributes(self, a: android.content.res.TypedArray, widthAttr: int | java.jint | java.lang.Integer, heightAttr: int | java.jint | java.lang.Integer, /) -> None: ...

class TableRow(LinearLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def checkLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> bool: ...
    def generateDefaultLayoutParams(self) -> LinearLayout.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, attrs: android.util.AttributeSet, /) -> TableRow.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> LinearLayout.LayoutParams: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getVirtualChildAt(self, i: int | java.jint | java.lang.Integer, /) -> android.view.View: ...
    def getVirtualChildCount(self) -> int: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOnHierarchyChangeListener(self, listener: android.view.ViewGroup.OnHierarchyChangeListener, /) -> None: ...

    class LayoutParams(LinearLayout.LayoutParams):
        column: int = ...
        span: int = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, column: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, p: android.view.ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: android.view.ViewGroup.MarginLayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, c: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
        @typing.overload
        def __init__(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, initWeight: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setBaseAttributes(self, a: android.content.res.TypedArray, widthAttr: int | java.jint | java.lang.Integer, heightAttr: int | java.jint | java.lang.Integer, /) -> None: ...

class TextClock(TextView):
    DEFAULT_FORMAT_12_HOUR: typing.ClassVar[java.lang.CharSequence] = ...
    DEFAULT_FORMAT_24_HOUR: typing.ClassVar[java.lang.CharSequence] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getFormat12Hour(self) -> java.lang.CharSequence: ...
    def getFormat24Hour(self) -> java.lang.CharSequence: ...
    def getTimeZone(self) -> str | None: ...
    def is24HourModeEnabled(self) -> bool: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onVisibilityAggregated(self, isVisible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def refreshTime(self) -> None: ...
    def setFormat12Hour(self, format: java.lang.CharSequence, /) -> None: ...
    def setFormat24Hour(self, format: java.lang.CharSequence, /) -> None: ...
    def setTimeZone(self, timeZone: str | java.lang.String, /) -> None: ...

class TextSwitcher(ViewSwitcher):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def addView(self, child: android.view.View, index: int | java.jint | java.lang.Integer, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def setCurrentText(self, text: java.lang.CharSequence, /) -> None: ...
    def setText(self, text: java.lang.CharSequence, /) -> None: ...

class TextView(android.view.View, android.view.ViewTreeObserver.OnPreDrawListener):
    AUTO_SIZE_TEXT_TYPE_NONE: typing.ClassVar[int] = ...
    AUTO_SIZE_TEXT_TYPE_UNIFORM: typing.ClassVar[int] = ...
    FOCUSED_SEARCH_RESULT_INDEX_NONE: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def addExtraDataToAccessibilityNodeInfo(self, info: android.view.accessibility.AccessibilityNodeInfo, extraDataKey: str | java.lang.String, arguments: android.os.Bundle, /) -> None: ...
    def addTextChangedListener(self, watcher: android.text.TextWatcher, /) -> None: ...
    @typing.overload
    def append(self, text: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def append(self, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> None: ...
    def autofill(self, value: android.view.autofill.AutofillValue, /) -> None: ...
    def beginBatchEdit(self) -> None: ...
    @typing.overload
    def bringPointIntoView(self, offset: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def bringPointIntoView(self, offset: int | java.jint | java.lang.Integer, requestRectWithoutFocus: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def cancelLongPress(self) -> None: ...
    def clearComposingText(self) -> None: ...
    def computeHorizontalScrollRange(self) -> int: ...
    def computeScroll(self) -> None: ...
    def computeVerticalScrollExtent(self) -> int: ...
    def computeVerticalScrollRange(self) -> int: ...
    def debug(self, depth: int | java.jint | java.lang.Integer, /) -> None: ...
    def didTouchFocusSelect(self) -> bool: ...
    def drawableHotspotChanged(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> None: ...
    def drawableStateChanged(self) -> None: ...
    def endBatchEdit(self) -> None: ...
    def extractText(self, request: android.view.inputmethod.ExtractedTextRequest, outText: android.view.inputmethod.ExtractedText, /) -> bool: ...
    def findViewsWithText(self, outViews: java.util.ArrayList[android.view.View], searched: java.lang.CharSequence, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAutoLinkMask(self) -> int: ...
    def getAutoSizeMaxTextSize(self) -> int: ...
    def getAutoSizeMinTextSize(self) -> int: ...
    def getAutoSizeStepGranularity(self) -> int: ...
    def getAutoSizeTextAvailableSizes(self) -> java.chaquopy.JavaArrayJInt: ...
    def getAutoSizeTextType(self) -> int: ...
    def getAutofillHints(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getAutofillType(self) -> int: ...
    def getAutofillValue(self) -> android.view.autofill.AutofillValue | None: ...
    def getBaseline(self) -> int: ...
    def getBottomPaddingOffset(self) -> int: ...
    def getBreakStrategy(self) -> int: ...
    def getCompoundDrawablePadding(self) -> int: ...
    def getCompoundDrawableTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getCompoundDrawableTintList(self) -> android.content.res.ColorStateList: ...
    def getCompoundDrawableTintMode(self) -> android.graphics.PorterDuff.Mode: ...
    def getCompoundDrawables(self) -> java.chaquopy.JavaArray[android.graphics.drawable.Drawable]: ...
    def getCompoundDrawablesRelative(self) -> java.chaquopy.JavaArray[android.graphics.drawable.Drawable]: ...
    def getCompoundPaddingBottom(self) -> int: ...
    def getCompoundPaddingEnd(self) -> int: ...
    def getCompoundPaddingLeft(self) -> int: ...
    def getCompoundPaddingRight(self) -> int: ...
    def getCompoundPaddingStart(self) -> int: ...
    def getCompoundPaddingTop(self) -> int: ...
    def getCurrentHintTextColor(self) -> int: ...
    def getCurrentTextColor(self) -> int: ...
    def getCustomInsertionActionModeCallback(self) -> android.view.ActionMode.Callback: ...
    def getCustomSelectionActionModeCallback(self) -> android.view.ActionMode.Callback: ...
    def getDefaultEditable(self) -> bool: ...
    def getDefaultMovementMethod(self) -> android.text.method.MovementMethod: ...
    def getEditableText(self) -> android.text.Editable: ...
    def getEllipsize(self) -> android.text.TextUtils.TruncateAt: ...
    def getError(self) -> java.lang.CharSequence: ...
    def getExtendedPaddingBottom(self) -> int: ...
    def getExtendedPaddingTop(self) -> int: ...
    def getFilters(self) -> java.chaquopy.JavaArray[android.text.InputFilter]: ...
    def getFirstBaselineToTopHeight(self) -> int: ...
    def getFocusedRect(self, r: android.graphics.Rect, /) -> None: ...
    def getFocusedSearchResultHighlightColor(self) -> int: ...
    def getFocusedSearchResultIndex(self) -> int: ...
    def getFontFeatureSettings(self) -> str | None: ...
    def getFontVariationSettings(self) -> str | None: ...
    def getFreezesText(self) -> bool: ...
    def getGravity(self) -> int: ...
    def getHighlightColor(self) -> int: ...
    def getHighlights(self) -> android.text.Highlights | None: ...
    def getHint(self) -> java.lang.CharSequence: ...
    def getHintTextColors(self) -> android.content.res.ColorStateList: ...
    def getHyphenationFrequency(self) -> int: ...
    def getImeActionId(self) -> int: ...
    def getImeActionLabel(self) -> java.lang.CharSequence: ...
    def getImeHintLocales(self) -> android.os.LocaleList | None: ...
    def getImeOptions(self) -> int: ...
    def getIncludeFontPadding(self) -> bool: ...
    def getInputExtras(self, create: bool | java.jboolean | java.lang.Boolean, /) -> android.os.Bundle: ...
    def getInputType(self) -> int: ...
    def getJustificationMode(self) -> int: ...
    def getKeyListener(self) -> android.text.method.KeyListener: ...
    def getLastBaselineToBottomHeight(self) -> int: ...
    def getLayout(self) -> android.text.Layout: ...
    def getLeftFadingEdgeStrength(self) -> float: ...
    def getLeftPaddingOffset(self) -> int: ...
    def getLetterSpacing(self) -> float: ...
    def getLineBounds(self, line: int | java.jint | java.lang.Integer, bounds: android.graphics.Rect, /) -> int: ...
    def getLineBreakStyle(self) -> int: ...
    def getLineBreakWordStyle(self) -> int: ...
    def getLineCount(self) -> int: ...
    def getLineHeight(self) -> int: ...
    def getLineSpacingExtra(self) -> float: ...
    def getLineSpacingMultiplier(self) -> float: ...
    def getLinkTextColors(self) -> android.content.res.ColorStateList: ...
    def getLinksClickable(self) -> bool: ...
    def getMarqueeRepeatLimit(self) -> int: ...
    def getMaxEms(self) -> int: ...
    def getMaxHeight(self) -> int: ...
    def getMaxLines(self) -> int: ...
    def getMaxWidth(self) -> int: ...
    def getMinEms(self) -> int: ...
    def getMinHeight(self) -> int: ...
    def getMinLines(self) -> int: ...
    def getMinWidth(self) -> int: ...
    def getMinimumFontMetrics(self) -> android.graphics.Paint.FontMetrics | None: ...
    def getMovementMethod(self) -> android.text.method.MovementMethod: ...
    def getOffsetForPosition(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> int: ...
    def getPaint(self) -> android.text.TextPaint: ...
    def getPaintFlags(self) -> int: ...
    def getPrivateImeOptions(self) -> str: ...
    def getRightFadingEdgeStrength(self) -> float: ...
    def getRightPaddingOffset(self) -> int: ...
    def getSearchResultHighlightColor(self) -> int: ...
    def getSearchResultHighlights(self) -> java.chaquopy.JavaArrayJInt | None: ...
    def getSelectionEnd(self) -> int: ...
    def getSelectionStart(self) -> int: ...
    def getShadowColor(self) -> int: ...
    def getShadowDx(self) -> float: ...
    def getShadowDy(self) -> float: ...
    def getShadowRadius(self) -> float: ...
    def getShiftDrawingOffsetForStartOverhang(self) -> bool: ...
    def getShowSoftInputOnFocus(self) -> bool: ...
    def getText(self) -> java.lang.CharSequence: ...
    def getTextClassifier(self) -> android.view.textclassifier.TextClassifier: ...
    def getTextColors(self) -> android.content.res.ColorStateList: ...
    def getTextCursorDrawable(self) -> android.graphics.drawable.Drawable | None: ...
    def getTextDirectionHeuristic(self) -> android.text.TextDirectionHeuristic: ...
    def getTextLocale(self) -> java.util.Locale: ...
    def getTextLocales(self) -> android.os.LocaleList: ...
    def getTextMetricsParams(self) -> android.text.PrecomputedText.Params: ...
    def getTextScaleX(self) -> float: ...
    def getTextSelectHandle(self) -> android.graphics.drawable.Drawable | None: ...
    def getTextSelectHandleLeft(self) -> android.graphics.drawable.Drawable | None: ...
    def getTextSelectHandleRight(self) -> android.graphics.drawable.Drawable | None: ...
    def getTextSize(self) -> float: ...
    def getTextSizeUnit(self) -> int: ...
    def getTopPaddingOffset(self) -> int: ...
    def getTotalPaddingBottom(self) -> int: ...
    def getTotalPaddingEnd(self) -> int: ...
    def getTotalPaddingLeft(self) -> int: ...
    def getTotalPaddingRight(self) -> int: ...
    def getTotalPaddingStart(self) -> int: ...
    def getTotalPaddingTop(self) -> int: ...
    def getTransformationMethod(self) -> android.text.method.TransformationMethod: ...
    def getTypeface(self) -> android.graphics.Typeface: ...
    def getUrls(self) -> java.chaquopy.JavaArray[android.text.style.URLSpan]: ...
    def getUseBoundsForWidth(self) -> bool: ...
    def hasOverlappingRendering(self) -> bool: ...
    def hasSelection(self) -> bool: ...
    def invalidateDrawable(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def isAllCaps(self) -> bool: ...
    def isAutoHandwritingEnabled(self) -> bool: ...
    def isCursorVisible(self) -> bool: ...
    def isElegantTextHeight(self) -> bool: ...
    def isFallbackLineSpacing(self) -> bool: ...
    def isHorizontallyScrollable(self) -> bool: ...
    def isInputMethodTarget(self) -> bool: ...
    def isLocalePreferredLineHeightForMinimumUsed(self) -> bool: ...
    def isPaddingOffsetRequired(self) -> bool: ...
    def isSingleLine(self) -> bool: ...
    def isSuggestionsEnabled(self) -> bool: ...
    def isTextSelectable(self) -> bool: ...
    def jumpDrawablesToCurrentState(self) -> None: ...
    def length(self) -> int: ...
    def moveCursorToVisibleOffset(self) -> bool: ...
    def onAttachedToWindow(self) -> None: ...
    def onBeginBatchEdit(self) -> None: ...
    def onCheckIsTextEditor(self) -> bool: ...
    def onCommitCompletion(self, text: android.view.inputmethod.CompletionInfo, /) -> None: ...
    def onCommitCorrection(self, info: android.view.inputmethod.CorrectionInfo, /) -> None: ...
    def onConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def onCreateContextMenu(self, menu: android.view.ContextMenu, /) -> None: ...
    def onCreateDrawableState(self, extraSpace: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def onCreateInputConnection(self, outAttrs: android.view.inputmethod.EditorInfo, /) -> android.view.inputmethod.InputConnection: ...
    def onCreateViewTranslationRequest(self, supportedFormats: java.chaquopy.JavaArrayJInt, requestsCollector: java.util.function.Consumer[android.view.translation.ViewTranslationRequest], /) -> None: ...
    def onDragEvent(self, event: android.view.DragEvent, /) -> bool: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onEditorAction(self, actionCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def onEndBatchEdit(self) -> None: ...
    def onFocusChanged(self, focused: bool | java.jboolean | java.lang.Boolean, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> None: ...
    def onGenericMotionEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyMultiple(self, keyCode: int | java.jint | java.lang.Integer, repeatCount: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyPreIme(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyShortcut(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onPreDraw(self) -> bool: ...
    def onPrivateIMECommand(self, action: str | java.lang.String, data: android.os.Bundle, /) -> bool: ...
    def onReceiveContent(self, payload: android.view.ContentInfo, /) -> android.view.ContentInfo | None: ...
    def onResolvePointerIcon(self, event: android.view.MotionEvent, pointerIndex: int | java.jint | java.lang.Integer, /) -> android.view.PointerIcon: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onRtlPropertiesChanged(self, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onScreenStateChanged(self, screenState: int | java.jint | java.lang.Integer, /) -> None: ...
    def onScrollChanged(self, horiz: int | java.jint | java.lang.Integer, vert: int | java.jint | java.lang.Integer, oldHoriz: int | java.jint | java.lang.Integer, oldVert: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSelectionChanged(self, selStart: int | java.jint | java.lang.Integer, selEnd: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTextChanged(self, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, lengthBefore: int | java.jint | java.lang.Integer, lengthAfter: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTextContextMenuItem(self, id: int | java.jint | java.lang.Integer, /) -> bool: ...
    def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onTrackballEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onVisibilityAggregated(self, isVisible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onVisibilityChanged(self, changedView: android.view.View, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def onWindowFocusChanged(self, hasWindowFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def performLongClick(self) -> bool: ...
    def removeTextChangedListener(self, watcher: android.text.TextWatcher, /) -> None: ...
    def sendAccessibilityEventUnchecked(self, event: android.view.accessibility.AccessibilityEvent, /) -> None: ...
    def setAllCaps(self, allCaps: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAutoLinkMask(self, mask: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAutoSizeTextTypeUniformWithConfiguration(self, autoSizeMinTextSize: int | java.jint | java.lang.Integer, autoSizeMaxTextSize: int | java.jint | java.lang.Integer, autoSizeStepGranularity: int | java.jint | java.lang.Integer, unit: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAutoSizeTextTypeUniformWithPresetSizes(self, presetSizes: java.chaquopy.JavaArrayJInt, unit: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAutoSizeTextTypeWithDefaults(self, autoSizeTextType: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBreakStrategy(self, breakStrategy: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCompoundDrawablePadding(self, pad: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCompoundDrawableTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setCompoundDrawableTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setCompoundDrawableTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> None: ...
    def setCompoundDrawables(self, left: android.graphics.drawable.Drawable, top: android.graphics.drawable.Drawable, right: android.graphics.drawable.Drawable, bottom: android.graphics.drawable.Drawable, /) -> None: ...
    def setCompoundDrawablesRelative(self, start: android.graphics.drawable.Drawable, top: android.graphics.drawable.Drawable, end: android.graphics.drawable.Drawable, bottom: android.graphics.drawable.Drawable, /) -> None: ...
    @typing.overload
    def setCompoundDrawablesRelativeWithIntrinsicBounds(self, start: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setCompoundDrawablesRelativeWithIntrinsicBounds(self, start: android.graphics.drawable.Drawable, top: android.graphics.drawable.Drawable, end: android.graphics.drawable.Drawable, bottom: android.graphics.drawable.Drawable, /) -> None: ...
    @typing.overload
    def setCompoundDrawablesWithIntrinsicBounds(self, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setCompoundDrawablesWithIntrinsicBounds(self, left: android.graphics.drawable.Drawable, top: android.graphics.drawable.Drawable, right: android.graphics.drawable.Drawable, bottom: android.graphics.drawable.Drawable, /) -> None: ...
    def setCursorVisible(self, visible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCustomInsertionActionModeCallback(self, actionModeCallback: android.view.ActionMode.Callback, /) -> None: ...
    def setCustomSelectionActionModeCallback(self, actionModeCallback: android.view.ActionMode.Callback, /) -> None: ...
    def setEditableFactory(self, factory: android.text.Editable.Factory, /) -> None: ...
    def setElegantTextHeight(self, elegant: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setEllipsize(self, where: android.text.TextUtils.TruncateAt, /) -> None: ...
    def setEms(self, ems: int | java.jint | java.lang.Integer, /) -> None: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setError(self, error: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setError(self, error: java.lang.CharSequence, icon: android.graphics.drawable.Drawable, /) -> None: ...
    def setExtractedText(self, text: android.view.inputmethod.ExtractedText, /) -> None: ...
    def setFallbackLineSpacing(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFilters(self, filters: java.chaquopy.JavaArray[android.text.InputFilter], /) -> None: ...
    def setFirstBaselineToTopHeight(self, firstBaselineToTopHeight: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFocusedSearchResultHighlightColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFocusedSearchResultIndex(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFontFeatureSettings(self, fontFeatureSettings: str | java.lang.String, /) -> None: ...
    def setFontVariationSettings(self, fontVariationSettings: str | java.lang.String, /) -> bool: ...
    def setFrame(self, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setFreezesText(self, freezesText: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setGravity(self, gravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setHeight(self, pixels: int | java.jint | java.lang.Integer, /) -> None: ...
    def setHighlightColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setHighlights(self, highlights: android.text.Highlights, /) -> None: ...
    @typing.overload
    def setHint(self, resid: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setHint(self, hint: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setHintTextColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setHintTextColor(self, colors: android.content.res.ColorStateList, /) -> None: ...
    def setHorizontallyScrolling(self, whether: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setHyphenationFrequency(self, hyphenationFrequency: int | java.jint | java.lang.Integer, /) -> None: ...
    def setImeActionLabel(self, label: java.lang.CharSequence, actionId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setImeHintLocales(self, hintLocales: android.os.LocaleList, /) -> None: ...
    def setImeOptions(self, imeOptions: int | java.jint | java.lang.Integer, /) -> None: ...
    def setIncludeFontPadding(self, includepad: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setInputExtras(self, xmlResId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setInputType(self, type: int | java.jint | java.lang.Integer, /) -> None: ...
    def setJustificationMode(self, justificationMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setKeyListener(self, input: android.text.method.KeyListener, /) -> None: ...
    def setLastBaselineToBottomHeight(self, lastBaselineToBottomHeight: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLetterSpacing(self, letterSpacing: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setLineBreakStyle(self, lineBreakStyle: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLineBreakWordStyle(self, lineBreakWordStyle: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setLineHeight(self, lineHeight: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setLineHeight(self, unit: int | java.jint | java.lang.Integer, lineHeight: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setLineSpacing(self, add: float | java.jfloat | java.lang.Float, mult: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setLines(self, lines: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setLinkTextColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setLinkTextColor(self, colors: android.content.res.ColorStateList, /) -> None: ...
    def setLinksClickable(self, whether: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setLocalePreferredLineHeightForMinimumUsed(self, flag: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMarqueeRepeatLimit(self, marqueeLimit: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaxEms(self, maxEms: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaxHeight(self, maxPixels: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaxLines(self, maxLines: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaxWidth(self, maxPixels: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinEms(self, minEms: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinHeight(self, minPixels: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinLines(self, minLines: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinWidth(self, minPixels: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinimumFontMetrics(self, minimumFontMetrics: android.graphics.Paint.FontMetrics, /) -> None: ...
    def setMovementMethod(self, movement: android.text.method.MovementMethod, /) -> None: ...
    def setOnEditorActionListener(self, l: TextView.OnEditorActionListener, /) -> None: ...
    def setPadding(self, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPaddingRelative(self, start: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPaintFlags(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPrivateImeOptions(self, type: str | java.lang.String, /) -> None: ...
    def setRawInputType(self, type: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScroller(self, s: Scroller, /) -> None: ...
    def setSearchResultHighlightColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSearchResultHighlights(self, *ranges: java.jint) -> None: ...
    def setSelectAllOnFocus(self, selectAllOnFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSelected(self, selected: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setShadowLayer(self, radius: float | java.jfloat | java.lang.Float, dx: float | java.jfloat | java.lang.Float, dy: float | java.jfloat | java.lang.Float, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setShiftDrawingOffsetForStartOverhang(self, shiftDrawingOffsetForStartOverhang: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setShowSoftInputOnFocus(self, show: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setSingleLine(self) -> None: ...
    @typing.overload
    def setSingleLine(self, singleLine: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSpannableFactory(self, factory: android.text.Spannable.Factory, /) -> None: ...
    @typing.overload
    def setText(self, resid: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setText(self, text: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setText(self, resid: int | java.jint | java.lang.Integer, type: TextView.BufferType, /) -> None: ...
    @typing.overload
    def setText(self, text: java.lang.CharSequence, type: TextView.BufferType, /) -> None: ...
    @typing.overload
    def setText(self, text: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTextAppearance(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTextAppearance(self, context: android.content.Context, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTextClassifier(self, textClassifier: android.view.textclassifier.TextClassifier, /) -> None: ...
    @typing.overload
    def setTextColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTextColor(self, colors: android.content.res.ColorStateList, /) -> None: ...
    @typing.overload
    def setTextCursorDrawable(self, textCursorDrawable: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTextCursorDrawable(self, textCursorDrawable: android.graphics.drawable.Drawable, /) -> None: ...
    def setTextIsSelectable(self, selectable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setTextKeepState(self, text: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setTextKeepState(self, text: java.lang.CharSequence, type: TextView.BufferType, /) -> None: ...
    def setTextLocale(self, locale: java.util.Locale, /) -> None: ...
    def setTextLocales(self, locales: android.os.LocaleList, /) -> None: ...
    def setTextMetricsParams(self, params: android.text.PrecomputedText.Params, /) -> None: ...
    def setTextScaleX(self, size: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def setTextSelectHandle(self, textSelectHandle: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTextSelectHandle(self, textSelectHandle: android.graphics.drawable.Drawable, /) -> None: ...
    @typing.overload
    def setTextSelectHandleLeft(self, textSelectHandleLeft: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTextSelectHandleLeft(self, textSelectHandleLeft: android.graphics.drawable.Drawable, /) -> None: ...
    @typing.overload
    def setTextSelectHandleRight(self, textSelectHandleRight: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTextSelectHandleRight(self, textSelectHandleRight: android.graphics.drawable.Drawable, /) -> None: ...
    @typing.overload
    def setTextSize(self, size: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def setTextSize(self, unit: int | java.jint | java.lang.Integer, size: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setTransformationMethod(self, method: android.text.method.TransformationMethod, /) -> None: ...
    @typing.overload
    def setTypeface(self, tf: android.graphics.Typeface, /) -> None: ...
    @typing.overload
    def setTypeface(self, tf: android.graphics.Typeface, style: int | java.jint | java.lang.Integer, /) -> None: ...
    def setUseBoundsForWidth(self, useBoundsForWidth: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setWidth(self, pixels: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def showContextMenu(self) -> bool: ...
    @typing.overload
    def showContextMenu(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> bool: ...
    def verifyDrawable(self, who: android.graphics.drawable.Drawable, /) -> bool: ...

    class SavedState(android.view.View.BaseSavedState):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TextView.SavedState]] = ...
        def toString(self) -> str: ...
        def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnEditorActionListener(java.lang.Object):
        def onEditorAction(self, arg1: TextView, arg2: int | java.jint | java.lang.Integer, arg3: android.view.KeyEvent, /) -> bool: ...

    class BufferType(java.lang.Enum[TextView.BufferType]):
        EDITABLE: typing.ClassVar[TextView.BufferType] = ...
        NORMAL: typing.ClassVar[TextView.BufferType] = ...
        SPANNABLE: typing.ClassVar[TextView.BufferType] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> TextView.BufferType: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[TextView.BufferType]: ...

class ThemedSpinnerAdapter(SpinnerAdapter):
    def getDropDownViewTheme(self) -> android.content.res.Resources.Theme | None: ...
    def setDropDownViewTheme(self, arg1: android.content.res.Resources.Theme, /) -> None: ...

class TimePicker(FrameLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def autofill(self, value: android.view.autofill.AutofillValue, /) -> None: ...
    def dispatchProvideAutofillStructure(self, structure: android.view.ViewStructure, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAutofillType(self) -> int: ...
    def getAutofillValue(self) -> android.view.autofill.AutofillValue: ...
    def getBaseline(self) -> int: ...
    def getCurrentHour(self) -> int: ...
    def getCurrentMinute(self) -> int: ...
    def getHour(self) -> int: ...
    def getMinute(self) -> int: ...
    def is24HourView(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def setCurrentHour(self, currentHour: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCurrentMinute(self, currentMinute: int | java.jint | java.lang.Integer, /) -> None: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setHour(self, hour: int | java.jint | java.lang.Integer, /) -> None: ...
    def setIs24HourView(self, is24HourView: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMinute(self, minute: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOnTimeChangedListener(self, onTimeChangedListener: TimePicker.OnTimeChangedListener, /) -> None: ...
    def validateInput(self) -> bool: ...

    class OnTimeChangedListener(java.lang.Object):
        def onTimeChanged(self, arg1: TimePicker, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...

class Toast(java.lang.Object):
    LENGTH_LONG: typing.ClassVar[int] = ...
    LENGTH_SHORT: typing.ClassVar[int] = ...
    def __init__(self, context: android.content.Context, /) -> None: ...
    def addCallback(self, callback: Toast.Callback, /) -> None: ...
    def cancel(self) -> None: ...
    def getDuration(self) -> int: ...
    def getGravity(self) -> int: ...
    def getHorizontalMargin(self) -> float: ...
    def getVerticalMargin(self) -> float: ...
    def getView(self) -> android.view.View | None: ...
    def getXOffset(self) -> int: ...
    def getYOffset(self) -> int: ...
    @typing.overload
    @staticmethod
    def makeText(context: android.content.Context, resId: int | java.jint | java.lang.Integer, duration: int | java.jint | java.lang.Integer, /) -> Toast: ...
    @typing.overload
    @staticmethod
    def makeText(context: android.content.Context, text: java.lang.CharSequence, duration: int | java.jint | java.lang.Integer, /) -> Toast: ...
    def removeCallback(self, callback: Toast.Callback, /) -> None: ...
    def setDuration(self, duration: int | java.jint | java.lang.Integer, /) -> None: ...
    def setGravity(self, gravity: int | java.jint | java.lang.Integer, xOffset: int | java.jint | java.lang.Integer, yOffset: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMargin(self, horizontalMargin: float | java.jfloat | java.lang.Float, verticalMargin: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def setText(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setText(self, s: java.lang.CharSequence, /) -> None: ...
    def setView(self, view: android.view.View, /) -> None: ...
    def show(self) -> None: ...

    class Callback(java.lang.Object):
        def __init__(self) -> None: ...
        def onToastHidden(self) -> None: ...
        def onToastShown(self) -> None: ...

class ToggleButton(CompoundButton):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def drawableStateChanged(self) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getDisabledAlpha(self) -> float: ...
    def getTextOff(self) -> java.lang.CharSequence: ...
    def getTextOn(self) -> java.lang.CharSequence: ...
    def onFinishInflate(self) -> None: ...
    def setBackgroundDrawable(self, d: android.graphics.drawable.Drawable, /) -> None: ...
    def setChecked(self, checked: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTextOff(self, textOff: java.lang.CharSequence, /) -> None: ...
    def setTextOn(self, textOn: java.lang.CharSequence, /) -> None: ...

class Toolbar(android.view.ViewGroup):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def checkLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> bool: ...
    def collapseActionView(self) -> None: ...
    def dismissPopupMenus(self) -> None: ...
    def generateDefaultLayoutParams(self) -> Toolbar.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, attrs: android.util.AttributeSet, /) -> Toolbar.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, p: android.view.ViewGroup.LayoutParams, /) -> Toolbar.LayoutParams: ...
    def getCollapseContentDescription(self) -> java.lang.CharSequence | None: ...
    def getCollapseIcon(self) -> android.graphics.drawable.Drawable | None: ...
    def getContentInsetEnd(self) -> int: ...
    def getContentInsetEndWithActions(self) -> int: ...
    def getContentInsetLeft(self) -> int: ...
    def getContentInsetRight(self) -> int: ...
    def getContentInsetStart(self) -> int: ...
    def getContentInsetStartWithNavigation(self) -> int: ...
    def getCurrentContentInsetEnd(self) -> int: ...
    def getCurrentContentInsetLeft(self) -> int: ...
    def getCurrentContentInsetRight(self) -> int: ...
    def getCurrentContentInsetStart(self) -> int: ...
    def getLogo(self) -> android.graphics.drawable.Drawable: ...
    def getLogoDescription(self) -> java.lang.CharSequence: ...
    def getMenu(self) -> android.view.Menu: ...
    def getNavigationContentDescription(self) -> java.lang.CharSequence | None: ...
    def getNavigationIcon(self) -> android.graphics.drawable.Drawable | None: ...
    def getOverflowIcon(self) -> android.graphics.drawable.Drawable | None: ...
    def getPopupTheme(self) -> int: ...
    def getSubtitle(self) -> java.lang.CharSequence: ...
    def getTitle(self) -> java.lang.CharSequence: ...
    def getTitleMarginBottom(self) -> int: ...
    def getTitleMarginEnd(self) -> int: ...
    def getTitleMarginStart(self) -> int: ...
    def getTitleMarginTop(self) -> int: ...
    def hasExpandedActionView(self) -> bool: ...
    def hideOverflowMenu(self) -> bool: ...
    def inflateMenu(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def isOverflowMenuShowing(self) -> bool: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onRtlPropertiesChanged(self, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onTouchEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    @typing.overload
    def setCollapseContentDescription(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setCollapseContentDescription(self, description: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setCollapseIcon(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setCollapseIcon(self, icon: android.graphics.drawable.Drawable, /) -> None: ...
    def setContentInsetEndWithActions(self, insetEndWithActions: int | java.jint | java.lang.Integer, /) -> None: ...
    def setContentInsetStartWithNavigation(self, insetStartWithNavigation: int | java.jint | java.lang.Integer, /) -> None: ...
    def setContentInsetsAbsolute(self, contentInsetLeft: int | java.jint | java.lang.Integer, contentInsetRight: int | java.jint | java.lang.Integer, /) -> None: ...
    def setContentInsetsRelative(self, contentInsetStart: int | java.jint | java.lang.Integer, contentInsetEnd: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setLogo(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setLogo(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    @typing.overload
    def setLogoDescription(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setLogoDescription(self, description: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setNavigationContentDescription(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setNavigationContentDescription(self, description: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setNavigationIcon(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setNavigationIcon(self, icon: android.graphics.drawable.Drawable, /) -> None: ...
    def setNavigationOnClickListener(self, listener: android.view.View.OnClickListener, /) -> None: ...
    def setOnMenuItemClickListener(self, listener: Toolbar.OnMenuItemClickListener, /) -> None: ...
    def setOverflowIcon(self, icon: android.graphics.drawable.Drawable, /) -> None: ...
    def setPopupTheme(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSubtitle(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSubtitle(self, subtitle: java.lang.CharSequence, /) -> None: ...
    def setSubtitleTextAppearance(self, context: android.content.Context, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSubtitleTextColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTitle(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTitle(self, title: java.lang.CharSequence, /) -> None: ...
    def setTitleMargin(self, start: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTitleMarginBottom(self, margin: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTitleMarginEnd(self, margin: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTitleMarginStart(self, margin: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTitleMarginTop(self, margin: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTitleTextAppearance(self, context: android.content.Context, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTitleTextColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def showOverflowMenu(self) -> bool: ...

    class LayoutParams(android.app.ActionBar.LayoutParams):
        @typing.overload
        def __init__(self, gravity: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, source: android.app.ActionBar.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: android.view.ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: android.view.ViewGroup.MarginLayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: Toolbar.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, c: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
        @typing.overload
        def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, gravity: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnMenuItemClickListener(java.lang.Object):
        def onMenuItemClick(self, arg1: android.view.MenuItem, /) -> bool: ...

class TwoLineListItem(RelativeLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getText1(self) -> TextView: ...
    def getText2(self) -> TextView: ...
    def onFinishInflate(self) -> None: ...

class VideoView(android.view.SurfaceView, MediaController.MediaPlayerControl):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def addSubtitleSource(self, is_: java.io.InputStream, format: android.media.MediaFormat, /) -> None: ...
    def canPause(self) -> bool: ...
    def canSeekBackward(self) -> bool: ...
    def canSeekForward(self) -> bool: ...
    def draw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAudioSessionId(self) -> int: ...
    def getBufferPercentage(self) -> int: ...
    def getCurrentPosition(self) -> int: ...
    def getDuration(self) -> int: ...
    def isPlaying(self) -> bool: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTouchEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def onTrackballEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def pause(self) -> None: ...
    def resolveAdjustedSize(self, desiredSize: int | java.jint | java.lang.Integer, measureSpec: int | java.jint | java.lang.Integer, /) -> int: ...
    def resume(self) -> None: ...
    def seekTo(self, msec: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAudioAttributes(self, attributes: android.media.AudioAttributes, /) -> None: ...
    def setAudioFocusRequest(self, focusGain: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMediaController(self, controller: MediaController, /) -> None: ...
    def setOnCompletionListener(self, l: android.media.MediaPlayer.OnCompletionListener, /) -> None: ...
    def setOnErrorListener(self, l: android.media.MediaPlayer.OnErrorListener, /) -> None: ...
    def setOnInfoListener(self, l: android.media.MediaPlayer.OnInfoListener, /) -> None: ...
    def setOnPreparedListener(self, l: android.media.MediaPlayer.OnPreparedListener, /) -> None: ...
    def setVideoPath(self, path: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setVideoURI(self, uri: android.net.Uri, /) -> None: ...
    @typing.overload
    def setVideoURI(self, uri: android.net.Uri, headers: java.util.Map[java.lang.String, java.lang.String], /) -> None: ...
    def start(self) -> None: ...
    def stopPlayback(self) -> None: ...
    def suspend(self) -> None: ...

class ViewAnimator(FrameLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def addView(self, child: android.view.View, index: int | java.jint | java.lang.Integer, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAnimateFirstView(self) -> bool: ...
    def getBaseline(self) -> int: ...
    def getCurrentView(self) -> android.view.View: ...
    def getDisplayedChild(self) -> int: ...
    def getInAnimation(self) -> android.view.animation.Animation | None: ...
    def getOutAnimation(self) -> android.view.animation.Animation | None: ...
    def removeAllViews(self) -> None: ...
    def removeView(self, view: android.view.View, /) -> None: ...
    def removeViewAt(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    def removeViewInLayout(self, view: android.view.View, /) -> None: ...
    def removeViews(self, start: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...
    def removeViewsInLayout(self, start: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAnimateFirstView(self, animate: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDisplayedChild(self, whichChild: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setInAnimation(self, inAnimation: android.view.animation.Animation, /) -> None: ...
    @typing.overload
    def setInAnimation(self, context: android.content.Context, resourceID: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setOutAnimation(self, outAnimation: android.view.animation.Animation, /) -> None: ...
    @typing.overload
    def setOutAnimation(self, context: android.content.Context, resourceID: int | java.jint | java.lang.Integer, /) -> None: ...
    def showNext(self) -> None: ...
    def showPrevious(self) -> None: ...

class ViewFlipper(ViewAnimator):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getFlipInterval(self) -> int: ...
    def isAutoStart(self) -> bool: ...
    def isFlipping(self) -> bool: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onWindowVisibilityChanged(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAutoStart(self, autoStart: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFlipInterval(self, milliseconds: int | java.jint | java.lang.Integer, /) -> None: ...
    def startFlipping(self) -> None: ...
    def stopFlipping(self) -> None: ...

class ViewSwitcher(ViewAnimator):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def addView(self, child: android.view.View, index: int | java.jint | java.lang.Integer, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getNextView(self) -> android.view.View: ...
    def reset(self) -> None: ...
    def setFactory(self, factory: ViewSwitcher.ViewFactory, /) -> None: ...

    class ViewFactory(java.lang.Object):
        def makeView(self) -> android.view.View: ...

class WrapperListAdapter(ListAdapter):
    def getWrappedAdapter(self) -> ListAdapter: ...

class ZoomButton(android.view.View.OnLongClickListener, ImageButton):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchUnhandledMove(self, focused: android.view.View, direction: int | java.jint | java.lang.Integer, /) -> bool: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onLongClick(self, v: android.view.View, /) -> bool: ...
    def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setZoomSpeed(self, speed: int | java.jlong | java.lang.Long, /) -> None: ...

class ZoomButtonsController(android.view.View.OnTouchListener):
    def __init__(self, ownerView: android.view.View, /) -> None: ...
    def getContainer(self) -> android.view.ViewGroup: ...
    def getZoomControls(self) -> android.view.View: ...
    def isAutoDismissed(self) -> bool: ...
    def isVisible(self) -> bool: ...
    def onTouch(self, v: android.view.View, event: android.view.MotionEvent, /) -> bool: ...
    def setAutoDismissed(self, autoDismiss: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFocusable(self, focusable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOnZoomListener(self, listener: ZoomButtonsController.OnZoomListener, /) -> None: ...
    def setVisible(self, visible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setZoomInEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setZoomOutEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setZoomSpeed(self, speed: int | java.jlong | java.lang.Long, /) -> None: ...

    class OnZoomListener(java.lang.Object):
        def onVisibilityChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onZoom(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class ZoomControls(LinearLayout):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def hasFocus(self) -> bool: ...
    def hide(self) -> None: ...
    def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def setIsZoomInEnabled(self, isEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setIsZoomOutEnabled(self, isEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOnZoomInClickListener(self, listener: android.view.View.OnClickListener, /) -> None: ...
    def setOnZoomOutClickListener(self, listener: android.view.View.OnClickListener, /) -> None: ...
    def setZoomSpeed(self, speed: int | java.jlong | java.lang.Long, /) -> None: ...
    def show(self) -> None: ...
