import typing

import android.content
import android.graphics
import android.hardware
import android.util
import android.view
import java
import java.chaquopy
import java.io
import java.lang
import java.nio
import javax.microedition.khronos.egl
import javax.microedition.khronos.opengles

class EGL14(java.lang.Object):
    EGL_ALPHA_MASK_SIZE: typing.ClassVar[int] = ...
    EGL_ALPHA_SIZE: typing.ClassVar[int] = ...
    EGL_BACK_BUFFER: typing.ClassVar[int] = ...
    EGL_BAD_ACCESS: typing.ClassVar[int] = ...
    EGL_BAD_ALLOC: typing.ClassVar[int] = ...
    EGL_BAD_ATTRIBUTE: typing.ClassVar[int] = ...
    EGL_BAD_CONFIG: typing.ClassVar[int] = ...
    EGL_BAD_CONTEXT: typing.ClassVar[int] = ...
    EGL_BAD_CURRENT_SURFACE: typing.ClassVar[int] = ...
    EGL_BAD_DISPLAY: typing.ClassVar[int] = ...
    EGL_BAD_MATCH: typing.ClassVar[int] = ...
    EGL_BAD_NATIVE_PIXMAP: typing.ClassVar[int] = ...
    EGL_BAD_NATIVE_WINDOW: typing.ClassVar[int] = ...
    EGL_BAD_PARAMETER: typing.ClassVar[int] = ...
    EGL_BAD_SURFACE: typing.ClassVar[int] = ...
    EGL_BIND_TO_TEXTURE_RGB: typing.ClassVar[int] = ...
    EGL_BIND_TO_TEXTURE_RGBA: typing.ClassVar[int] = ...
    EGL_BLUE_SIZE: typing.ClassVar[int] = ...
    EGL_BUFFER_DESTROYED: typing.ClassVar[int] = ...
    EGL_BUFFER_PRESERVED: typing.ClassVar[int] = ...
    EGL_BUFFER_SIZE: typing.ClassVar[int] = ...
    EGL_CLIENT_APIS: typing.ClassVar[int] = ...
    EGL_COLOR_BUFFER_TYPE: typing.ClassVar[int] = ...
    EGL_CONFIG_CAVEAT: typing.ClassVar[int] = ...
    EGL_CONFIG_ID: typing.ClassVar[int] = ...
    EGL_CONFORMANT: typing.ClassVar[int] = ...
    EGL_CONTEXT_CLIENT_TYPE: typing.ClassVar[int] = ...
    EGL_CONTEXT_CLIENT_VERSION: typing.ClassVar[int] = ...
    EGL_CONTEXT_LOST: typing.ClassVar[int] = ...
    EGL_CORE_NATIVE_ENGINE: typing.ClassVar[int] = ...
    EGL_DEFAULT_DISPLAY: typing.ClassVar[int] = ...
    EGL_DEPTH_SIZE: typing.ClassVar[int] = ...
    EGL_DISPLAY_SCALING: typing.ClassVar[int] = ...
    EGL_DRAW: typing.ClassVar[int] = ...
    EGL_EXTENSIONS: typing.ClassVar[int] = ...
    EGL_FALSE: typing.ClassVar[int] = ...
    EGL_GREEN_SIZE: typing.ClassVar[int] = ...
    EGL_HEIGHT: typing.ClassVar[int] = ...
    EGL_HORIZONTAL_RESOLUTION: typing.ClassVar[int] = ...
    EGL_LARGEST_PBUFFER: typing.ClassVar[int] = ...
    EGL_LEVEL: typing.ClassVar[int] = ...
    EGL_LUMINANCE_BUFFER: typing.ClassVar[int] = ...
    EGL_LUMINANCE_SIZE: typing.ClassVar[int] = ...
    EGL_MATCH_NATIVE_PIXMAP: typing.ClassVar[int] = ...
    EGL_MAX_PBUFFER_HEIGHT: typing.ClassVar[int] = ...
    EGL_MAX_PBUFFER_PIXELS: typing.ClassVar[int] = ...
    EGL_MAX_PBUFFER_WIDTH: typing.ClassVar[int] = ...
    EGL_MAX_SWAP_INTERVAL: typing.ClassVar[int] = ...
    EGL_MIN_SWAP_INTERVAL: typing.ClassVar[int] = ...
    EGL_MIPMAP_LEVEL: typing.ClassVar[int] = ...
    EGL_MIPMAP_TEXTURE: typing.ClassVar[int] = ...
    EGL_MULTISAMPLE_RESOLVE: typing.ClassVar[int] = ...
    EGL_MULTISAMPLE_RESOLVE_BOX: typing.ClassVar[int] = ...
    EGL_MULTISAMPLE_RESOLVE_BOX_BIT: typing.ClassVar[int] = ...
    EGL_MULTISAMPLE_RESOLVE_DEFAULT: typing.ClassVar[int] = ...
    EGL_NATIVE_RENDERABLE: typing.ClassVar[int] = ...
    EGL_NATIVE_VISUAL_ID: typing.ClassVar[int] = ...
    EGL_NATIVE_VISUAL_TYPE: typing.ClassVar[int] = ...
    EGL_NONE: typing.ClassVar[int] = ...
    EGL_NON_CONFORMANT_CONFIG: typing.ClassVar[int] = ...
    EGL_NOT_INITIALIZED: typing.ClassVar[int] = ...
    EGL_NO_CONTEXT: typing.ClassVar[EGLContext] = ...
    EGL_NO_DISPLAY: typing.ClassVar[EGLDisplay] = ...
    EGL_NO_SURFACE: typing.ClassVar[EGLSurface] = ...
    EGL_NO_TEXTURE: typing.ClassVar[int] = ...
    EGL_OPENGL_API: typing.ClassVar[int] = ...
    EGL_OPENGL_BIT: typing.ClassVar[int] = ...
    EGL_OPENGL_ES2_BIT: typing.ClassVar[int] = ...
    EGL_OPENGL_ES_API: typing.ClassVar[int] = ...
    EGL_OPENGL_ES_BIT: typing.ClassVar[int] = ...
    EGL_OPENVG_API: typing.ClassVar[int] = ...
    EGL_OPENVG_BIT: typing.ClassVar[int] = ...
    EGL_OPENVG_IMAGE: typing.ClassVar[int] = ...
    EGL_PBUFFER_BIT: typing.ClassVar[int] = ...
    EGL_PIXEL_ASPECT_RATIO: typing.ClassVar[int] = ...
    EGL_PIXMAP_BIT: typing.ClassVar[int] = ...
    EGL_READ: typing.ClassVar[int] = ...
    EGL_RED_SIZE: typing.ClassVar[int] = ...
    EGL_RENDERABLE_TYPE: typing.ClassVar[int] = ...
    EGL_RENDER_BUFFER: typing.ClassVar[int] = ...
    EGL_RGB_BUFFER: typing.ClassVar[int] = ...
    EGL_SAMPLES: typing.ClassVar[int] = ...
    EGL_SAMPLE_BUFFERS: typing.ClassVar[int] = ...
    EGL_SINGLE_BUFFER: typing.ClassVar[int] = ...
    EGL_SLOW_CONFIG: typing.ClassVar[int] = ...
    EGL_STENCIL_SIZE: typing.ClassVar[int] = ...
    EGL_SUCCESS: typing.ClassVar[int] = ...
    EGL_SURFACE_TYPE: typing.ClassVar[int] = ...
    EGL_SWAP_BEHAVIOR: typing.ClassVar[int] = ...
    EGL_SWAP_BEHAVIOR_PRESERVED_BIT: typing.ClassVar[int] = ...
    EGL_TEXTURE_2D: typing.ClassVar[int] = ...
    EGL_TEXTURE_FORMAT: typing.ClassVar[int] = ...
    EGL_TEXTURE_RGB: typing.ClassVar[int] = ...
    EGL_TEXTURE_RGBA: typing.ClassVar[int] = ...
    EGL_TEXTURE_TARGET: typing.ClassVar[int] = ...
    EGL_TRANSPARENT_BLUE_VALUE: typing.ClassVar[int] = ...
    EGL_TRANSPARENT_GREEN_VALUE: typing.ClassVar[int] = ...
    EGL_TRANSPARENT_RED_VALUE: typing.ClassVar[int] = ...
    EGL_TRANSPARENT_RGB: typing.ClassVar[int] = ...
    EGL_TRANSPARENT_TYPE: typing.ClassVar[int] = ...
    EGL_TRUE: typing.ClassVar[int] = ...
    EGL_VENDOR: typing.ClassVar[int] = ...
    EGL_VERSION: typing.ClassVar[int] = ...
    EGL_VERTICAL_RESOLUTION: typing.ClassVar[int] = ...
    EGL_VG_ALPHA_FORMAT: typing.ClassVar[int] = ...
    EGL_VG_ALPHA_FORMAT_NONPRE: typing.ClassVar[int] = ...
    EGL_VG_ALPHA_FORMAT_PRE: typing.ClassVar[int] = ...
    EGL_VG_ALPHA_FORMAT_PRE_BIT: typing.ClassVar[int] = ...
    EGL_VG_COLORSPACE: typing.ClassVar[int] = ...
    EGL_VG_COLORSPACE_LINEAR: typing.ClassVar[int] = ...
    EGL_VG_COLORSPACE_LINEAR_BIT: typing.ClassVar[int] = ...
    EGL_VG_COLORSPACE_sRGB: typing.ClassVar[int] = ...
    EGL_WIDTH: typing.ClassVar[int] = ...
    EGL_WINDOW_BIT: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def eglBindAPI(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def eglBindTexImage(arg1: EGLDisplay, arg2: EGLSurface, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def eglChooseConfig(arg1: EGLDisplay, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArray[EGLConfig], arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: java.chaquopy.JavaArrayJInt, arg8: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def eglCopyBuffers(arg1: EGLDisplay, arg2: EGLSurface, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def eglCreateContext(arg1: EGLDisplay, arg2: EGLConfig, arg3: EGLContext, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> EGLContext: ...
    @staticmethod
    def eglCreatePbufferFromClientBuffer(arg1: EGLDisplay, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: EGLConfig, arg5: java.chaquopy.JavaArrayJInt, arg6: int | java.jint | java.lang.Integer, /) -> EGLSurface: ...
    @staticmethod
    def eglCreatePbufferSurface(arg1: EGLDisplay, arg2: EGLConfig, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> EGLSurface: ...
    @staticmethod
    def eglCreatePixmapSurface(arg1: EGLDisplay, arg2: EGLConfig, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> EGLSurface: ...
    @staticmethod
    def eglCreateWindowSurface(dpy: EGLDisplay, config: EGLConfig, win: java.lang.Object | int | bool | float | str, attrib_list: java.chaquopy.JavaArrayJInt, offset: int | java.jint | java.lang.Integer, /) -> EGLSurface: ...
    @staticmethod
    def eglDestroyContext(arg1: EGLDisplay, arg2: EGLContext, /) -> bool: ...
    @staticmethod
    def eglDestroySurface(arg1: EGLDisplay, arg2: EGLSurface, /) -> bool: ...
    @staticmethod
    def eglGetConfigAttrib(arg1: EGLDisplay, arg2: EGLConfig, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def eglGetConfigs(arg1: EGLDisplay, arg2: java.chaquopy.JavaArray[EGLConfig], arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJInt, arg6: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def eglGetCurrentContext() -> EGLContext: ...
    @staticmethod
    def eglGetCurrentDisplay() -> EGLDisplay: ...
    @staticmethod
    def eglGetCurrentSurface(arg1: int | java.jint | java.lang.Integer, /) -> EGLSurface: ...
    @staticmethod
    def eglGetDisplay(arg1: int | java.jint | java.lang.Integer, /) -> EGLDisplay: ...
    @staticmethod
    def eglGetError() -> int: ...
    @staticmethod
    def eglInitialize(arg1: EGLDisplay, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def eglMakeCurrent(arg1: EGLDisplay, arg2: EGLSurface, arg3: EGLSurface, arg4: EGLContext, /) -> bool: ...
    @staticmethod
    def eglQueryAPI() -> int: ...
    @staticmethod
    def eglQueryContext(arg1: EGLDisplay, arg2: EGLContext, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def eglQueryString(arg1: EGLDisplay, arg2: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def eglQuerySurface(arg1: EGLDisplay, arg2: EGLSurface, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def eglReleaseTexImage(arg1: EGLDisplay, arg2: EGLSurface, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def eglReleaseThread() -> bool: ...
    @staticmethod
    def eglSurfaceAttrib(arg1: EGLDisplay, arg2: EGLSurface, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def eglSwapBuffers(arg1: EGLDisplay, arg2: EGLSurface, /) -> bool: ...
    @staticmethod
    def eglSwapInterval(arg1: EGLDisplay, arg2: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def eglTerminate(arg1: EGLDisplay, /) -> bool: ...
    @staticmethod
    def eglWaitClient() -> bool: ...
    @staticmethod
    def eglWaitGL() -> bool: ...
    @staticmethod
    def eglWaitNative(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...

class EGL15(java.lang.Object):
    EGL_CL_EVENT_HANDLE: typing.ClassVar[int] = ...
    EGL_CONDITION_SATISFIED: typing.ClassVar[int] = ...
    EGL_CONTEXT_MAJOR_VERSION: typing.ClassVar[int] = ...
    EGL_CONTEXT_MINOR_VERSION: typing.ClassVar[int] = ...
    EGL_CONTEXT_OPENGL_COMPATIBILITY_PROFILE_BIT: typing.ClassVar[int] = ...
    EGL_CONTEXT_OPENGL_CORE_PROFILE_BIT: typing.ClassVar[int] = ...
    EGL_CONTEXT_OPENGL_DEBUG: typing.ClassVar[int] = ...
    EGL_CONTEXT_OPENGL_FORWARD_COMPATIBLE: typing.ClassVar[int] = ...
    EGL_CONTEXT_OPENGL_PROFILE_MASK: typing.ClassVar[int] = ...
    EGL_CONTEXT_OPENGL_RESET_NOTIFICATION_STRATEGY: typing.ClassVar[int] = ...
    EGL_CONTEXT_OPENGL_ROBUST_ACCESS: typing.ClassVar[int] = ...
    EGL_FOREVER: typing.ClassVar[int] = ...
    EGL_GL_COLORSPACE: typing.ClassVar[int] = ...
    EGL_GL_COLORSPACE_LINEAR: typing.ClassVar[int] = ...
    EGL_GL_COLORSPACE_SRGB: typing.ClassVar[int] = ...
    EGL_GL_RENDERBUFFER: typing.ClassVar[int] = ...
    EGL_GL_TEXTURE_2D: typing.ClassVar[int] = ...
    EGL_GL_TEXTURE_3D: typing.ClassVar[int] = ...
    EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_X: typing.ClassVar[int] = ...
    EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_Y: typing.ClassVar[int] = ...
    EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_Z: typing.ClassVar[int] = ...
    EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_X: typing.ClassVar[int] = ...
    EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_Y: typing.ClassVar[int] = ...
    EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_Z: typing.ClassVar[int] = ...
    EGL_GL_TEXTURE_LEVEL: typing.ClassVar[int] = ...
    EGL_GL_TEXTURE_ZOFFSET: typing.ClassVar[int] = ...
    EGL_IMAGE_PRESERVED: typing.ClassVar[int] = ...
    EGL_LOSE_CONTEXT_ON_RESET: typing.ClassVar[int] = ...
    EGL_NO_CONTEXT: typing.ClassVar[EGLContext] = ...
    EGL_NO_DISPLAY: typing.ClassVar[EGLDisplay] = ...
    EGL_NO_IMAGE: typing.ClassVar[EGLImage] = ...
    EGL_NO_RESET_NOTIFICATION: typing.ClassVar[int] = ...
    EGL_NO_SURFACE: typing.ClassVar[EGLSurface] = ...
    EGL_NO_SYNC: typing.ClassVar[EGLSync] = ...
    EGL_OPENGL_ES3_BIT: typing.ClassVar[int] = ...
    EGL_PLATFORM_ANDROID_KHR: typing.ClassVar[int] = ...
    EGL_SIGNALED: typing.ClassVar[int] = ...
    EGL_SYNC_CL_EVENT: typing.ClassVar[int] = ...
    EGL_SYNC_CL_EVENT_COMPLETE: typing.ClassVar[int] = ...
    EGL_SYNC_CONDITION: typing.ClassVar[int] = ...
    EGL_SYNC_FENCE: typing.ClassVar[int] = ...
    EGL_SYNC_FLUSH_COMMANDS_BIT: typing.ClassVar[int] = ...
    EGL_SYNC_PRIOR_COMMANDS_COMPLETE: typing.ClassVar[int] = ...
    EGL_SYNC_STATUS: typing.ClassVar[int] = ...
    EGL_SYNC_TYPE: typing.ClassVar[int] = ...
    EGL_TIMEOUT_EXPIRED: typing.ClassVar[int] = ...
    EGL_UNSIGNALED: typing.ClassVar[int] = ...
    @staticmethod
    def eglClientWaitSync(arg1: EGLDisplay, arg2: EGLSync, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jlong | java.lang.Long, /) -> int: ...
    @staticmethod
    def eglCreateImage(arg1: EGLDisplay, arg2: EGLContext, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jlong | java.lang.Long, arg5: java.chaquopy.JavaArrayJLong, arg6: int | java.jint | java.lang.Integer, /) -> EGLImage: ...
    @staticmethod
    def eglCreatePlatformPixmapSurface(arg1: EGLDisplay, arg2: EGLConfig, arg3: java.nio.Buffer, arg4: java.chaquopy.JavaArrayJLong, arg5: int | java.jint | java.lang.Integer, /) -> EGLSurface: ...
    @staticmethod
    def eglCreatePlatformWindowSurface(arg1: EGLDisplay, arg2: EGLConfig, arg3: java.nio.Buffer, arg4: java.chaquopy.JavaArrayJLong, arg5: int | java.jint | java.lang.Integer, /) -> EGLSurface: ...
    @staticmethod
    def eglCreateSync(arg1: EGLDisplay, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJLong, arg4: int | java.jint | java.lang.Integer, /) -> EGLSync: ...
    @staticmethod
    def eglDestroyImage(arg1: EGLDisplay, arg2: EGLImage, /) -> bool: ...
    @staticmethod
    def eglDestroySync(arg1: EGLDisplay, arg2: EGLSync, /) -> bool: ...
    @staticmethod
    def eglGetPlatformDisplay(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jlong | java.lang.Long, arg3: java.chaquopy.JavaArrayJLong, arg4: int | java.jint | java.lang.Integer, /) -> EGLDisplay: ...
    @staticmethod
    def eglGetSyncAttrib(arg1: EGLDisplay, arg2: EGLSync, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJLong, arg5: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def eglWaitSync(arg1: EGLDisplay, arg2: EGLSync, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...

class EGLConfig(EGLObjectHandle):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...

class EGLContext(EGLObjectHandle):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...

class EGLDisplay(EGLObjectHandle):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...

class EGLExt(java.lang.Object):
    EGL_CONTEXT_FLAGS_KHR: typing.ClassVar[int] = ...
    EGL_CONTEXT_MAJOR_VERSION_KHR: typing.ClassVar[int] = ...
    EGL_CONTEXT_MINOR_VERSION_KHR: typing.ClassVar[int] = ...
    EGL_NO_NATIVE_FENCE_FD_ANDROID: typing.ClassVar[int] = ...
    EGL_OPENGL_ES3_BIT_KHR: typing.ClassVar[int] = ...
    EGL_RECORDABLE_ANDROID: typing.ClassVar[int] = ...
    EGL_SYNC_NATIVE_FENCE_ANDROID: typing.ClassVar[int] = ...
    EGL_SYNC_NATIVE_FENCE_FD_ANDROID: typing.ClassVar[int] = ...
    EGL_SYNC_NATIVE_FENCE_SIGNALED_ANDROID: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def eglDupNativeFenceFDANDROID(display: EGLDisplay, sync: EGLSync, /) -> android.hardware.SyncFence: ...
    @staticmethod
    def eglPresentationTimeANDROID(arg1: EGLDisplay, arg2: EGLSurface, arg3: int | java.jlong | java.lang.Long, /) -> bool: ...

class EGLImage(EGLObjectHandle):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...

class EGLObjectHandle(java.lang.Object):
    @typing.overload
    def __init__(self, handle: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, handle: int | java.jlong | java.lang.Long, /) -> None: ...
    def getHandle(self) -> int: ...
    def getNativeHandle(self) -> int: ...
    def hashCode(self) -> int: ...

class EGLSurface(EGLObjectHandle):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...

class EGLSync(EGLObjectHandle):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...

class ETC1(java.lang.Object):
    DECODED_BLOCK_SIZE: typing.ClassVar[int] = ...
    ENCODED_BLOCK_SIZE: typing.ClassVar[int] = ...
    ETC1_RGB8_OES: typing.ClassVar[int] = ...
    ETC_PKM_HEADER_SIZE: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def decodeBlock(arg1: java.nio.Buffer, arg2: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def decodeImage(arg1: java.nio.Buffer, arg2: java.nio.Buffer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def encodeBlock(arg1: java.nio.Buffer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def encodeImage(arg1: java.nio.Buffer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def formatHeader(arg1: java.nio.Buffer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def getEncodedDataSize(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getHeight(arg1: java.nio.Buffer, /) -> int: ...
    @staticmethod
    def getWidth(arg1: java.nio.Buffer, /) -> int: ...
    @staticmethod
    def isValid(arg1: java.nio.Buffer, /) -> bool: ...

class ETC1Util(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def compressTexture(input: java.nio.Buffer, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, pixelSize: int | java.jint | java.lang.Integer, stride: int | java.jint | java.lang.Integer, /) -> ETC1Util.ETC1Texture: ...
    @staticmethod
    def createTexture(input: java.io.InputStream, /) -> ETC1Util.ETC1Texture: ...
    @staticmethod
    def isETC1Supported() -> bool: ...
    @typing.overload
    @staticmethod
    def loadTexture(target: int | java.jint | java.lang.Integer, level: int | java.jint | java.lang.Integer, border: int | java.jint | java.lang.Integer, fallbackFormat: int | java.jint | java.lang.Integer, fallbackType: int | java.jint | java.lang.Integer, texture: ETC1Util.ETC1Texture, /) -> None: ...
    @typing.overload
    @staticmethod
    def loadTexture(target: int | java.jint | java.lang.Integer, level: int | java.jint | java.lang.Integer, border: int | java.jint | java.lang.Integer, fallbackFormat: int | java.jint | java.lang.Integer, fallbackType: int | java.jint | java.lang.Integer, input: java.io.InputStream, /) -> None: ...
    @staticmethod
    def writeTexture(texture: ETC1Util.ETC1Texture, output: java.io.OutputStream, /) -> None: ...

    class ETC1Texture(java.lang.Object):
        def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, data: java.nio.ByteBuffer, /) -> None: ...
        def getData(self) -> java.nio.ByteBuffer: ...
        def getHeight(self) -> int: ...
        def getWidth(self) -> int: ...

class GLDebugHelper(java.lang.Object):
    CONFIG_CHECK_GL_ERROR: typing.ClassVar[int] = ...
    CONFIG_CHECK_THREAD: typing.ClassVar[int] = ...
    CONFIG_LOG_ARGUMENT_NAMES: typing.ClassVar[int] = ...
    ERROR_WRONG_THREAD: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @typing.overload
    @staticmethod
    def wrap(egl: javax.microedition.khronos.egl.EGL, configFlags: int | java.jint | java.lang.Integer, log: java.io.Writer, /) -> javax.microedition.khronos.egl.EGL: ...
    @typing.overload
    @staticmethod
    def wrap(gl: javax.microedition.khronos.opengles.GL, configFlags: int | java.jint | java.lang.Integer, log: java.io.Writer, /) -> javax.microedition.khronos.opengles.GL: ...

class GLES10(java.lang.Object):
    GL_ADD: typing.ClassVar[int] = ...
    GL_ALIASED_LINE_WIDTH_RANGE: typing.ClassVar[int] = ...
    GL_ALIASED_POINT_SIZE_RANGE: typing.ClassVar[int] = ...
    GL_ALPHA: typing.ClassVar[int] = ...
    GL_ALPHA_BITS: typing.ClassVar[int] = ...
    GL_ALPHA_TEST: typing.ClassVar[int] = ...
    GL_ALWAYS: typing.ClassVar[int] = ...
    GL_AMBIENT: typing.ClassVar[int] = ...
    GL_AMBIENT_AND_DIFFUSE: typing.ClassVar[int] = ...
    GL_AND: typing.ClassVar[int] = ...
    GL_AND_INVERTED: typing.ClassVar[int] = ...
    GL_AND_REVERSE: typing.ClassVar[int] = ...
    GL_BACK: typing.ClassVar[int] = ...
    GL_BLEND: typing.ClassVar[int] = ...
    GL_BLUE_BITS: typing.ClassVar[int] = ...
    GL_BYTE: typing.ClassVar[int] = ...
    GL_CCW: typing.ClassVar[int] = ...
    GL_CLAMP_TO_EDGE: typing.ClassVar[int] = ...
    GL_CLEAR: typing.ClassVar[int] = ...
    GL_COLOR_ARRAY: typing.ClassVar[int] = ...
    GL_COLOR_BUFFER_BIT: typing.ClassVar[int] = ...
    GL_COLOR_LOGIC_OP: typing.ClassVar[int] = ...
    GL_COLOR_MATERIAL: typing.ClassVar[int] = ...
    GL_COMPRESSED_TEXTURE_FORMATS: typing.ClassVar[int] = ...
    GL_CONSTANT_ATTENUATION: typing.ClassVar[int] = ...
    GL_COPY: typing.ClassVar[int] = ...
    GL_COPY_INVERTED: typing.ClassVar[int] = ...
    GL_CULL_FACE: typing.ClassVar[int] = ...
    GL_CW: typing.ClassVar[int] = ...
    GL_DECAL: typing.ClassVar[int] = ...
    GL_DECR: typing.ClassVar[int] = ...
    GL_DEPTH_BITS: typing.ClassVar[int] = ...
    GL_DEPTH_BUFFER_BIT: typing.ClassVar[int] = ...
    GL_DEPTH_TEST: typing.ClassVar[int] = ...
    GL_DIFFUSE: typing.ClassVar[int] = ...
    GL_DITHER: typing.ClassVar[int] = ...
    GL_DONT_CARE: typing.ClassVar[int] = ...
    GL_DST_ALPHA: typing.ClassVar[int] = ...
    GL_DST_COLOR: typing.ClassVar[int] = ...
    GL_EMISSION: typing.ClassVar[int] = ...
    GL_EQUAL: typing.ClassVar[int] = ...
    GL_EQUIV: typing.ClassVar[int] = ...
    GL_EXP2: typing.ClassVar[int] = ...
    GL_EXP: typing.ClassVar[int] = ...
    GL_EXTENSIONS: typing.ClassVar[int] = ...
    GL_FALSE: typing.ClassVar[int] = ...
    GL_FASTEST: typing.ClassVar[int] = ...
    GL_FIXED: typing.ClassVar[int] = ...
    GL_FLAT: typing.ClassVar[int] = ...
    GL_FLOAT: typing.ClassVar[int] = ...
    GL_FOG: typing.ClassVar[int] = ...
    GL_FOG_COLOR: typing.ClassVar[int] = ...
    GL_FOG_DENSITY: typing.ClassVar[int] = ...
    GL_FOG_END: typing.ClassVar[int] = ...
    GL_FOG_HINT: typing.ClassVar[int] = ...
    GL_FOG_MODE: typing.ClassVar[int] = ...
    GL_FOG_START: typing.ClassVar[int] = ...
    GL_FRONT: typing.ClassVar[int] = ...
    GL_FRONT_AND_BACK: typing.ClassVar[int] = ...
    GL_GEQUAL: typing.ClassVar[int] = ...
    GL_GREATER: typing.ClassVar[int] = ...
    GL_GREEN_BITS: typing.ClassVar[int] = ...
    GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES: typing.ClassVar[int] = ...
    GL_IMPLEMENTATION_COLOR_READ_TYPE_OES: typing.ClassVar[int] = ...
    GL_INCR: typing.ClassVar[int] = ...
    GL_INVALID_ENUM: typing.ClassVar[int] = ...
    GL_INVALID_OPERATION: typing.ClassVar[int] = ...
    GL_INVALID_VALUE: typing.ClassVar[int] = ...
    GL_INVERT: typing.ClassVar[int] = ...
    GL_KEEP: typing.ClassVar[int] = ...
    GL_LEQUAL: typing.ClassVar[int] = ...
    GL_LESS: typing.ClassVar[int] = ...
    GL_LIGHT0: typing.ClassVar[int] = ...
    GL_LIGHT1: typing.ClassVar[int] = ...
    GL_LIGHT2: typing.ClassVar[int] = ...
    GL_LIGHT3: typing.ClassVar[int] = ...
    GL_LIGHT4: typing.ClassVar[int] = ...
    GL_LIGHT5: typing.ClassVar[int] = ...
    GL_LIGHT6: typing.ClassVar[int] = ...
    GL_LIGHT7: typing.ClassVar[int] = ...
    GL_LIGHTING: typing.ClassVar[int] = ...
    GL_LIGHT_MODEL_AMBIENT: typing.ClassVar[int] = ...
    GL_LIGHT_MODEL_TWO_SIDE: typing.ClassVar[int] = ...
    GL_LINEAR: typing.ClassVar[int] = ...
    GL_LINEAR_ATTENUATION: typing.ClassVar[int] = ...
    GL_LINEAR_MIPMAP_LINEAR: typing.ClassVar[int] = ...
    GL_LINEAR_MIPMAP_NEAREST: typing.ClassVar[int] = ...
    GL_LINES: typing.ClassVar[int] = ...
    GL_LINE_LOOP: typing.ClassVar[int] = ...
    GL_LINE_SMOOTH: typing.ClassVar[int] = ...
    GL_LINE_SMOOTH_HINT: typing.ClassVar[int] = ...
    GL_LINE_STRIP: typing.ClassVar[int] = ...
    GL_LUMINANCE: typing.ClassVar[int] = ...
    GL_LUMINANCE_ALPHA: typing.ClassVar[int] = ...
    GL_MAX_ELEMENTS_INDICES: typing.ClassVar[int] = ...
    GL_MAX_ELEMENTS_VERTICES: typing.ClassVar[int] = ...
    GL_MAX_LIGHTS: typing.ClassVar[int] = ...
    GL_MAX_MODELVIEW_STACK_DEPTH: typing.ClassVar[int] = ...
    GL_MAX_PROJECTION_STACK_DEPTH: typing.ClassVar[int] = ...
    GL_MAX_TEXTURE_SIZE: typing.ClassVar[int] = ...
    GL_MAX_TEXTURE_STACK_DEPTH: typing.ClassVar[int] = ...
    GL_MAX_TEXTURE_UNITS: typing.ClassVar[int] = ...
    GL_MAX_VIEWPORT_DIMS: typing.ClassVar[int] = ...
    GL_MODELVIEW: typing.ClassVar[int] = ...
    GL_MODULATE: typing.ClassVar[int] = ...
    GL_MULTISAMPLE: typing.ClassVar[int] = ...
    GL_NAND: typing.ClassVar[int] = ...
    GL_NEAREST: typing.ClassVar[int] = ...
    GL_NEAREST_MIPMAP_LINEAR: typing.ClassVar[int] = ...
    GL_NEAREST_MIPMAP_NEAREST: typing.ClassVar[int] = ...
    GL_NEVER: typing.ClassVar[int] = ...
    GL_NICEST: typing.ClassVar[int] = ...
    GL_NOOP: typing.ClassVar[int] = ...
    GL_NOR: typing.ClassVar[int] = ...
    GL_NORMALIZE: typing.ClassVar[int] = ...
    GL_NORMAL_ARRAY: typing.ClassVar[int] = ...
    GL_NOTEQUAL: typing.ClassVar[int] = ...
    GL_NO_ERROR: typing.ClassVar[int] = ...
    GL_NUM_COMPRESSED_TEXTURE_FORMATS: typing.ClassVar[int] = ...
    GL_ONE: typing.ClassVar[int] = ...
    GL_ONE_MINUS_DST_ALPHA: typing.ClassVar[int] = ...
    GL_ONE_MINUS_DST_COLOR: typing.ClassVar[int] = ...
    GL_ONE_MINUS_SRC_ALPHA: typing.ClassVar[int] = ...
    GL_ONE_MINUS_SRC_COLOR: typing.ClassVar[int] = ...
    GL_OR: typing.ClassVar[int] = ...
    GL_OR_INVERTED: typing.ClassVar[int] = ...
    GL_OR_REVERSE: typing.ClassVar[int] = ...
    GL_OUT_OF_MEMORY: typing.ClassVar[int] = ...
    GL_PACK_ALIGNMENT: typing.ClassVar[int] = ...
    GL_PALETTE4_R5_G6_B5_OES: typing.ClassVar[int] = ...
    GL_PALETTE4_RGB5_A1_OES: typing.ClassVar[int] = ...
    GL_PALETTE4_RGB8_OES: typing.ClassVar[int] = ...
    GL_PALETTE4_RGBA4_OES: typing.ClassVar[int] = ...
    GL_PALETTE4_RGBA8_OES: typing.ClassVar[int] = ...
    GL_PALETTE8_R5_G6_B5_OES: typing.ClassVar[int] = ...
    GL_PALETTE8_RGB5_A1_OES: typing.ClassVar[int] = ...
    GL_PALETTE8_RGB8_OES: typing.ClassVar[int] = ...
    GL_PALETTE8_RGBA4_OES: typing.ClassVar[int] = ...
    GL_PALETTE8_RGBA8_OES: typing.ClassVar[int] = ...
    GL_PERSPECTIVE_CORRECTION_HINT: typing.ClassVar[int] = ...
    GL_POINTS: typing.ClassVar[int] = ...
    GL_POINT_FADE_THRESHOLD_SIZE: typing.ClassVar[int] = ...
    GL_POINT_SIZE: typing.ClassVar[int] = ...
    GL_POINT_SMOOTH: typing.ClassVar[int] = ...
    GL_POINT_SMOOTH_HINT: typing.ClassVar[int] = ...
    GL_POLYGON_OFFSET_FILL: typing.ClassVar[int] = ...
    GL_POLYGON_SMOOTH_HINT: typing.ClassVar[int] = ...
    GL_POSITION: typing.ClassVar[int] = ...
    GL_PROJECTION: typing.ClassVar[int] = ...
    GL_QUADRATIC_ATTENUATION: typing.ClassVar[int] = ...
    GL_RED_BITS: typing.ClassVar[int] = ...
    GL_RENDERER: typing.ClassVar[int] = ...
    GL_REPEAT: typing.ClassVar[int] = ...
    GL_REPLACE: typing.ClassVar[int] = ...
    GL_RESCALE_NORMAL: typing.ClassVar[int] = ...
    GL_RGB: typing.ClassVar[int] = ...
    GL_RGBA: typing.ClassVar[int] = ...
    GL_SAMPLE_ALPHA_TO_COVERAGE: typing.ClassVar[int] = ...
    GL_SAMPLE_ALPHA_TO_ONE: typing.ClassVar[int] = ...
    GL_SAMPLE_COVERAGE: typing.ClassVar[int] = ...
    GL_SCISSOR_TEST: typing.ClassVar[int] = ...
    GL_SET: typing.ClassVar[int] = ...
    GL_SHININESS: typing.ClassVar[int] = ...
    GL_SHORT: typing.ClassVar[int] = ...
    GL_SMOOTH: typing.ClassVar[int] = ...
    GL_SMOOTH_LINE_WIDTH_RANGE: typing.ClassVar[int] = ...
    GL_SMOOTH_POINT_SIZE_RANGE: typing.ClassVar[int] = ...
    GL_SPECULAR: typing.ClassVar[int] = ...
    GL_SPOT_CUTOFF: typing.ClassVar[int] = ...
    GL_SPOT_DIRECTION: typing.ClassVar[int] = ...
    GL_SPOT_EXPONENT: typing.ClassVar[int] = ...
    GL_SRC_ALPHA: typing.ClassVar[int] = ...
    GL_SRC_ALPHA_SATURATE: typing.ClassVar[int] = ...
    GL_SRC_COLOR: typing.ClassVar[int] = ...
    GL_STACK_OVERFLOW: typing.ClassVar[int] = ...
    GL_STACK_UNDERFLOW: typing.ClassVar[int] = ...
    GL_STENCIL_BITS: typing.ClassVar[int] = ...
    GL_STENCIL_BUFFER_BIT: typing.ClassVar[int] = ...
    GL_STENCIL_TEST: typing.ClassVar[int] = ...
    GL_SUBPIXEL_BITS: typing.ClassVar[int] = ...
    GL_TEXTURE0: typing.ClassVar[int] = ...
    GL_TEXTURE10: typing.ClassVar[int] = ...
    GL_TEXTURE11: typing.ClassVar[int] = ...
    GL_TEXTURE12: typing.ClassVar[int] = ...
    GL_TEXTURE13: typing.ClassVar[int] = ...
    GL_TEXTURE14: typing.ClassVar[int] = ...
    GL_TEXTURE15: typing.ClassVar[int] = ...
    GL_TEXTURE16: typing.ClassVar[int] = ...
    GL_TEXTURE17: typing.ClassVar[int] = ...
    GL_TEXTURE18: typing.ClassVar[int] = ...
    GL_TEXTURE19: typing.ClassVar[int] = ...
    GL_TEXTURE1: typing.ClassVar[int] = ...
    GL_TEXTURE20: typing.ClassVar[int] = ...
    GL_TEXTURE21: typing.ClassVar[int] = ...
    GL_TEXTURE22: typing.ClassVar[int] = ...
    GL_TEXTURE23: typing.ClassVar[int] = ...
    GL_TEXTURE24: typing.ClassVar[int] = ...
    GL_TEXTURE25: typing.ClassVar[int] = ...
    GL_TEXTURE26: typing.ClassVar[int] = ...
    GL_TEXTURE27: typing.ClassVar[int] = ...
    GL_TEXTURE28: typing.ClassVar[int] = ...
    GL_TEXTURE29: typing.ClassVar[int] = ...
    GL_TEXTURE2: typing.ClassVar[int] = ...
    GL_TEXTURE30: typing.ClassVar[int] = ...
    GL_TEXTURE31: typing.ClassVar[int] = ...
    GL_TEXTURE3: typing.ClassVar[int] = ...
    GL_TEXTURE4: typing.ClassVar[int] = ...
    GL_TEXTURE5: typing.ClassVar[int] = ...
    GL_TEXTURE6: typing.ClassVar[int] = ...
    GL_TEXTURE7: typing.ClassVar[int] = ...
    GL_TEXTURE8: typing.ClassVar[int] = ...
    GL_TEXTURE9: typing.ClassVar[int] = ...
    GL_TEXTURE: typing.ClassVar[int] = ...
    GL_TEXTURE_2D: typing.ClassVar[int] = ...
    GL_TEXTURE_COORD_ARRAY: typing.ClassVar[int] = ...
    GL_TEXTURE_ENV: typing.ClassVar[int] = ...
    GL_TEXTURE_ENV_COLOR: typing.ClassVar[int] = ...
    GL_TEXTURE_ENV_MODE: typing.ClassVar[int] = ...
    GL_TEXTURE_MAG_FILTER: typing.ClassVar[int] = ...
    GL_TEXTURE_MIN_FILTER: typing.ClassVar[int] = ...
    GL_TEXTURE_WRAP_S: typing.ClassVar[int] = ...
    GL_TEXTURE_WRAP_T: typing.ClassVar[int] = ...
    GL_TRIANGLES: typing.ClassVar[int] = ...
    GL_TRIANGLE_FAN: typing.ClassVar[int] = ...
    GL_TRIANGLE_STRIP: typing.ClassVar[int] = ...
    GL_TRUE: typing.ClassVar[int] = ...
    GL_UNPACK_ALIGNMENT: typing.ClassVar[int] = ...
    GL_UNSIGNED_BYTE: typing.ClassVar[int] = ...
    GL_UNSIGNED_SHORT: typing.ClassVar[int] = ...
    GL_UNSIGNED_SHORT_4_4_4_4: typing.ClassVar[int] = ...
    GL_UNSIGNED_SHORT_5_5_5_1: typing.ClassVar[int] = ...
    GL_UNSIGNED_SHORT_5_6_5: typing.ClassVar[int] = ...
    GL_VENDOR: typing.ClassVar[int] = ...
    GL_VERSION: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY: typing.ClassVar[int] = ...
    GL_XOR: typing.ClassVar[int] = ...
    GL_ZERO: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def glActiveTexture(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glAlphaFunc(arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glAlphaFuncx(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindTexture(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlendFunc(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glClear(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glClearColor(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glClearColorx(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glClearDepthf(arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glClearDepthx(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glClearStencil(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glClientActiveTexture(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glColor4f(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glColor4x(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glColorMask(arg1: bool | java.jboolean | java.lang.Boolean, arg2: bool | java.jboolean | java.lang.Boolean, arg3: bool | java.jboolean | java.lang.Boolean, arg4: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def glColorPointer(size: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, stride: int | java.jint | java.lang.Integer, pointer: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glCompressedTexImage2D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glCompressedTexSubImage2D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glCopyTexImage2D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glCopyTexSubImage2D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glCullFace(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteTextures(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteTextures(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDepthFunc(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDepthMask(arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def glDepthRangef(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glDepthRangex(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDisable(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDisableClientState(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDrawArrays(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDrawElements(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glEnable(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glEnableClientState(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glFinish() -> None: ...
    @staticmethod
    def glFlush() -> None: ...
    @staticmethod
    def glFogf(arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glFogfv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glFogfv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glFogx(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glFogxv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glFogxv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glFrontFace(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glFrustumf(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, arg6: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glFrustumx(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenTextures(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenTextures(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGetError() -> int: ...
    @typing.overload
    @staticmethod
    def glGetIntegerv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetIntegerv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGetString(arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def glHint(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glLightModelf(arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLightModelfv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLightModelfv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glLightModelx(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLightModelxv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLightModelxv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glLightf(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLightfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLightfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glLightx(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLightxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLightxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glLineWidth(arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glLineWidthx(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glLoadIdentity() -> None: ...
    @typing.overload
    @staticmethod
    def glLoadMatrixf(arg1: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLoadMatrixf(arg1: java.chaquopy.JavaArrayJFloat, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLoadMatrixx(arg1: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLoadMatrixx(arg1: java.chaquopy.JavaArrayJInt, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glLogicOp(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glMaterialf(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glMaterialfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glMaterialfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glMaterialx(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glMaterialxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glMaterialxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glMatrixMode(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glMultMatrixf(arg1: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glMultMatrixf(arg1: java.chaquopy.JavaArrayJFloat, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glMultMatrixx(arg1: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glMultMatrixx(arg1: java.chaquopy.JavaArrayJInt, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glMultiTexCoord4f(arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glMultiTexCoord4x(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glNormal3f(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glNormal3x(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glNormalPointer(type: int | java.jint | java.lang.Integer, stride: int | java.jint | java.lang.Integer, pointer: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glOrthof(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, arg6: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glOrthox(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glPixelStorei(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glPointSize(arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glPointSizex(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glPolygonOffset(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glPolygonOffsetx(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glPopMatrix() -> None: ...
    @staticmethod
    def glPushMatrix() -> None: ...
    @staticmethod
    def glReadPixels(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glRotatef(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glRotatex(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glSampleCoverage(arg1: float | java.jfloat | java.lang.Float, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def glSampleCoveragex(arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def glScalef(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glScalex(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glScissor(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glShadeModel(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glStencilFunc(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glStencilMask(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glStencilOp(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexCoordPointer(size: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, stride: int | java.jint | java.lang.Integer, pointer: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glTexEnvf(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexEnvfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexEnvfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexEnvx(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexEnvxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexEnvxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexImage2D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glTexParameterf(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glTexParameterx(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexSubImage2D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glTranslatef(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glTranslatex(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glVertexPointer(size: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, stride: int | java.jint | java.lang.Integer, pointer: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glViewport(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...

class GLES10Ext(java.lang.Object):
    def __init__(self) -> None: ...
    @typing.overload
    @staticmethod
    def glQueryMatrixxOES(arg1: java.nio.IntBuffer, arg2: java.nio.IntBuffer, /) -> int: ...
    @typing.overload
    @staticmethod
    def glQueryMatrixxOES(arg1: java.chaquopy.JavaArrayJInt, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> int: ...

class GLES11(GLES10):
    GL_ACTIVE_TEXTURE: typing.ClassVar[int] = ...
    GL_ADD_SIGNED: typing.ClassVar[int] = ...
    GL_ALPHA_SCALE: typing.ClassVar[int] = ...
    GL_ALPHA_TEST_FUNC: typing.ClassVar[int] = ...
    GL_ALPHA_TEST_REF: typing.ClassVar[int] = ...
    GL_ARRAY_BUFFER: typing.ClassVar[int] = ...
    GL_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_BLEND_DST: typing.ClassVar[int] = ...
    GL_BLEND_SRC: typing.ClassVar[int] = ...
    GL_BUFFER_ACCESS: typing.ClassVar[int] = ...
    GL_BUFFER_SIZE: typing.ClassVar[int] = ...
    GL_BUFFER_USAGE: typing.ClassVar[int] = ...
    GL_CLIENT_ACTIVE_TEXTURE: typing.ClassVar[int] = ...
    GL_CLIP_PLANE0: typing.ClassVar[int] = ...
    GL_CLIP_PLANE1: typing.ClassVar[int] = ...
    GL_CLIP_PLANE2: typing.ClassVar[int] = ...
    GL_CLIP_PLANE3: typing.ClassVar[int] = ...
    GL_CLIP_PLANE4: typing.ClassVar[int] = ...
    GL_CLIP_PLANE5: typing.ClassVar[int] = ...
    GL_COLOR_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_COLOR_ARRAY_POINTER: typing.ClassVar[int] = ...
    GL_COLOR_ARRAY_SIZE: typing.ClassVar[int] = ...
    GL_COLOR_ARRAY_STRIDE: typing.ClassVar[int] = ...
    GL_COLOR_ARRAY_TYPE: typing.ClassVar[int] = ...
    GL_COLOR_CLEAR_VALUE: typing.ClassVar[int] = ...
    GL_COLOR_WRITEMASK: typing.ClassVar[int] = ...
    GL_COMBINE: typing.ClassVar[int] = ...
    GL_COMBINE_ALPHA: typing.ClassVar[int] = ...
    GL_COMBINE_RGB: typing.ClassVar[int] = ...
    GL_CONSTANT: typing.ClassVar[int] = ...
    GL_COORD_REPLACE_OES: typing.ClassVar[int] = ...
    GL_CULL_FACE_MODE: typing.ClassVar[int] = ...
    GL_CURRENT_COLOR: typing.ClassVar[int] = ...
    GL_CURRENT_NORMAL: typing.ClassVar[int] = ...
    GL_CURRENT_TEXTURE_COORDS: typing.ClassVar[int] = ...
    GL_DEPTH_CLEAR_VALUE: typing.ClassVar[int] = ...
    GL_DEPTH_FUNC: typing.ClassVar[int] = ...
    GL_DEPTH_RANGE: typing.ClassVar[int] = ...
    GL_DEPTH_WRITEMASK: typing.ClassVar[int] = ...
    GL_DOT3_RGB: typing.ClassVar[int] = ...
    GL_DOT3_RGBA: typing.ClassVar[int] = ...
    GL_DYNAMIC_DRAW: typing.ClassVar[int] = ...
    GL_ELEMENT_ARRAY_BUFFER: typing.ClassVar[int] = ...
    GL_ELEMENT_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_FRONT_FACE: typing.ClassVar[int] = ...
    GL_GENERATE_MIPMAP: typing.ClassVar[int] = ...
    GL_GENERATE_MIPMAP_HINT: typing.ClassVar[int] = ...
    GL_INTERPOLATE: typing.ClassVar[int] = ...
    GL_LINE_WIDTH: typing.ClassVar[int] = ...
    GL_LOGIC_OP_MODE: typing.ClassVar[int] = ...
    GL_MATRIX_MODE: typing.ClassVar[int] = ...
    GL_MAX_CLIP_PLANES: typing.ClassVar[int] = ...
    GL_MODELVIEW_MATRIX: typing.ClassVar[int] = ...
    GL_MODELVIEW_MATRIX_FLOAT_AS_INT_BITS_OES: typing.ClassVar[int] = ...
    GL_MODELVIEW_STACK_DEPTH: typing.ClassVar[int] = ...
    GL_NORMAL_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_NORMAL_ARRAY_POINTER: typing.ClassVar[int] = ...
    GL_NORMAL_ARRAY_STRIDE: typing.ClassVar[int] = ...
    GL_NORMAL_ARRAY_TYPE: typing.ClassVar[int] = ...
    GL_OPERAND0_ALPHA: typing.ClassVar[int] = ...
    GL_OPERAND0_RGB: typing.ClassVar[int] = ...
    GL_OPERAND1_ALPHA: typing.ClassVar[int] = ...
    GL_OPERAND1_RGB: typing.ClassVar[int] = ...
    GL_OPERAND2_ALPHA: typing.ClassVar[int] = ...
    GL_OPERAND2_RGB: typing.ClassVar[int] = ...
    GL_POINT_DISTANCE_ATTENUATION: typing.ClassVar[int] = ...
    GL_POINT_FADE_THRESHOLD_SIZE: typing.ClassVar[int] = ...
    GL_POINT_SIZE: typing.ClassVar[int] = ...
    GL_POINT_SIZE_ARRAY_BUFFER_BINDING_OES: typing.ClassVar[int] = ...
    GL_POINT_SIZE_ARRAY_OES: typing.ClassVar[int] = ...
    GL_POINT_SIZE_ARRAY_POINTER_OES: typing.ClassVar[int] = ...
    GL_POINT_SIZE_ARRAY_STRIDE_OES: typing.ClassVar[int] = ...
    GL_POINT_SIZE_ARRAY_TYPE_OES: typing.ClassVar[int] = ...
    GL_POINT_SIZE_MAX: typing.ClassVar[int] = ...
    GL_POINT_SIZE_MIN: typing.ClassVar[int] = ...
    GL_POINT_SPRITE_OES: typing.ClassVar[int] = ...
    GL_POLYGON_OFFSET_FACTOR: typing.ClassVar[int] = ...
    GL_POLYGON_OFFSET_UNITS: typing.ClassVar[int] = ...
    GL_PREVIOUS: typing.ClassVar[int] = ...
    GL_PRIMARY_COLOR: typing.ClassVar[int] = ...
    GL_PROJECTION_MATRIX: typing.ClassVar[int] = ...
    GL_PROJECTION_MATRIX_FLOAT_AS_INT_BITS_OES: typing.ClassVar[int] = ...
    GL_PROJECTION_STACK_DEPTH: typing.ClassVar[int] = ...
    GL_RGB_SCALE: typing.ClassVar[int] = ...
    GL_SAMPLES: typing.ClassVar[int] = ...
    GL_SAMPLE_BUFFERS: typing.ClassVar[int] = ...
    GL_SAMPLE_COVERAGE_INVERT: typing.ClassVar[int] = ...
    GL_SAMPLE_COVERAGE_VALUE: typing.ClassVar[int] = ...
    GL_SCISSOR_BOX: typing.ClassVar[int] = ...
    GL_SHADE_MODEL: typing.ClassVar[int] = ...
    GL_SRC0_ALPHA: typing.ClassVar[int] = ...
    GL_SRC0_RGB: typing.ClassVar[int] = ...
    GL_SRC1_ALPHA: typing.ClassVar[int] = ...
    GL_SRC1_RGB: typing.ClassVar[int] = ...
    GL_SRC2_ALPHA: typing.ClassVar[int] = ...
    GL_SRC2_RGB: typing.ClassVar[int] = ...
    GL_STATIC_DRAW: typing.ClassVar[int] = ...
    GL_STENCIL_CLEAR_VALUE: typing.ClassVar[int] = ...
    GL_STENCIL_FAIL: typing.ClassVar[int] = ...
    GL_STENCIL_FUNC: typing.ClassVar[int] = ...
    GL_STENCIL_PASS_DEPTH_FAIL: typing.ClassVar[int] = ...
    GL_STENCIL_PASS_DEPTH_PASS: typing.ClassVar[int] = ...
    GL_STENCIL_REF: typing.ClassVar[int] = ...
    GL_STENCIL_VALUE_MASK: typing.ClassVar[int] = ...
    GL_STENCIL_WRITEMASK: typing.ClassVar[int] = ...
    GL_SUBTRACT: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_2D: typing.ClassVar[int] = ...
    GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_TEXTURE_COORD_ARRAY_POINTER: typing.ClassVar[int] = ...
    GL_TEXTURE_COORD_ARRAY_SIZE: typing.ClassVar[int] = ...
    GL_TEXTURE_COORD_ARRAY_STRIDE: typing.ClassVar[int] = ...
    GL_TEXTURE_COORD_ARRAY_TYPE: typing.ClassVar[int] = ...
    GL_TEXTURE_MATRIX: typing.ClassVar[int] = ...
    GL_TEXTURE_MATRIX_FLOAT_AS_INT_BITS_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_STACK_DEPTH: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY_POINTER: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY_SIZE: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY_STRIDE: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY_TYPE: typing.ClassVar[int] = ...
    GL_VIEWPORT: typing.ClassVar[int] = ...
    GL_WRITE_ONLY: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def glBindBuffer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBufferData(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.Buffer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBufferSubData(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glClipPlanef(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glClipPlanef(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glClipPlanex(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glClipPlanex(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glColor4ub(arg1: int | java.jbyte | java.lang.Byte, arg2: int | java.jbyte | java.lang.Byte, arg3: int | java.jbyte | java.lang.Byte, arg4: int | java.jbyte | java.lang.Byte, /) -> None: ...
    @staticmethod
    def glColorPointer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteBuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteBuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDrawElements(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenBuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenBuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetBooleanv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetBooleanv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJBoolean, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetBufferParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetBufferParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetClipPlanef(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetClipPlanef(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetClipPlanex(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetClipPlanex(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetFixedv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetFixedv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetFloatv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetFloatv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetLightfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetLightfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetLightxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetLightxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetMaterialfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetMaterialfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetMaterialxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetMaterialxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexEnvfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexEnvfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexEnviv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexEnviv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexEnvxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexEnvxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glIsBuffer(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glIsEnabled(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glIsTexture(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glNormalPointer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glPointParameterf(arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glPointParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glPointParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glPointParameterx(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glPointParameterxv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glPointParameterxv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glPointSizePointerOES(type: int | java.jint | java.lang.Integer, stride: int | java.jint | java.lang.Integer, pointer: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glTexCoordPointer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexEnvi(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexEnviv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexEnviv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexParameteri(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterxv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glVertexPointer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...

class GLES11Ext(java.lang.Object):
    GL_3DC_XY_AMD: typing.ClassVar[int] = ...
    GL_3DC_X_AMD: typing.ClassVar[int] = ...
    GL_ATC_RGBA_EXPLICIT_ALPHA_AMD: typing.ClassVar[int] = ...
    GL_ATC_RGBA_INTERPOLATED_ALPHA_AMD: typing.ClassVar[int] = ...
    GL_ATC_RGB_AMD: typing.ClassVar[int] = ...
    GL_BGRA: typing.ClassVar[int] = ...
    GL_BLEND_DST_ALPHA_OES: typing.ClassVar[int] = ...
    GL_BLEND_DST_RGB_OES: typing.ClassVar[int] = ...
    GL_BLEND_EQUATION_ALPHA_OES: typing.ClassVar[int] = ...
    GL_BLEND_EQUATION_OES: typing.ClassVar[int] = ...
    GL_BLEND_EQUATION_RGB_OES: typing.ClassVar[int] = ...
    GL_BLEND_SRC_ALPHA_OES: typing.ClassVar[int] = ...
    GL_BLEND_SRC_RGB_OES: typing.ClassVar[int] = ...
    GL_BUFFER_ACCESS_OES: typing.ClassVar[int] = ...
    GL_BUFFER_MAPPED_OES: typing.ClassVar[int] = ...
    GL_BUFFER_MAP_POINTER_OES: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT0_OES: typing.ClassVar[int] = ...
    GL_CURRENT_PALETTE_MATRIX_OES: typing.ClassVar[int] = ...
    GL_DECR_WRAP_OES: typing.ClassVar[int] = ...
    GL_DEPTH24_STENCIL8_OES: typing.ClassVar[int] = ...
    GL_DEPTH_ATTACHMENT_OES: typing.ClassVar[int] = ...
    GL_DEPTH_COMPONENT16_OES: typing.ClassVar[int] = ...
    GL_DEPTH_COMPONENT24_OES: typing.ClassVar[int] = ...
    GL_DEPTH_COMPONENT32_OES: typing.ClassVar[int] = ...
    GL_DEPTH_STENCIL_OES: typing.ClassVar[int] = ...
    GL_ETC1_RGB8_OES: typing.ClassVar[int] = ...
    GL_FIXED_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_BINDING_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_COMPLETE_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_FORMATS_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_UNSUPPORTED_OES: typing.ClassVar[int] = ...
    GL_FUNC_ADD_OES: typing.ClassVar[int] = ...
    GL_FUNC_REVERSE_SUBTRACT_OES: typing.ClassVar[int] = ...
    GL_FUNC_SUBTRACT_OES: typing.ClassVar[int] = ...
    GL_INCR_WRAP_OES: typing.ClassVar[int] = ...
    GL_INVALID_FRAMEBUFFER_OPERATION_OES: typing.ClassVar[int] = ...
    GL_MATRIX_INDEX_ARRAY_BUFFER_BINDING_OES: typing.ClassVar[int] = ...
    GL_MATRIX_INDEX_ARRAY_OES: typing.ClassVar[int] = ...
    GL_MATRIX_INDEX_ARRAY_POINTER_OES: typing.ClassVar[int] = ...
    GL_MATRIX_INDEX_ARRAY_SIZE_OES: typing.ClassVar[int] = ...
    GL_MATRIX_INDEX_ARRAY_STRIDE_OES: typing.ClassVar[int] = ...
    GL_MATRIX_INDEX_ARRAY_TYPE_OES: typing.ClassVar[int] = ...
    GL_MATRIX_PALETTE_OES: typing.ClassVar[int] = ...
    GL_MAX_CUBE_MAP_TEXTURE_SIZE_OES: typing.ClassVar[int] = ...
    GL_MAX_PALETTE_MATRICES_OES: typing.ClassVar[int] = ...
    GL_MAX_RENDERBUFFER_SIZE_OES: typing.ClassVar[int] = ...
    GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_UNITS_OES: typing.ClassVar[int] = ...
    GL_MIRRORED_REPEAT_OES: typing.ClassVar[int] = ...
    GL_MODELVIEW_MATRIX_FLOAT_AS_INT_BITS_OES: typing.ClassVar[int] = ...
    GL_NONE_OES: typing.ClassVar[int] = ...
    GL_NORMAL_MAP_OES: typing.ClassVar[int] = ...
    GL_PROJECTION_MATRIX_FLOAT_AS_INT_BITS_OES: typing.ClassVar[int] = ...
    GL_REFLECTION_MAP_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_ALPHA_SIZE_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_BINDING_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_BLUE_SIZE_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_DEPTH_SIZE_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_GREEN_SIZE_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_HEIGHT_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_INTERNAL_FORMAT_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_RED_SIZE_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_STENCIL_SIZE_OES: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_WIDTH_OES: typing.ClassVar[int] = ...
    GL_REQUIRED_TEXTURE_IMAGE_UNITS_OES: typing.ClassVar[int] = ...
    GL_RGB565_OES: typing.ClassVar[int] = ...
    GL_RGB5_A1_OES: typing.ClassVar[int] = ...
    GL_RGB8_OES: typing.ClassVar[int] = ...
    GL_RGBA4_OES: typing.ClassVar[int] = ...
    GL_RGBA8_OES: typing.ClassVar[int] = ...
    GL_SAMPLER_EXTERNAL_OES: typing.ClassVar[int] = ...
    GL_STENCIL_ATTACHMENT_OES: typing.ClassVar[int] = ...
    GL_STENCIL_INDEX1_OES: typing.ClassVar[int] = ...
    GL_STENCIL_INDEX4_OES: typing.ClassVar[int] = ...
    GL_STENCIL_INDEX8_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_CUBE_MAP_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_EXTERNAL_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_CROP_RECT_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_NEGATIVE_X_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_POSITIVE_X_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_POSITIVE_Y_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_POSITIVE_Z_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_EXTERNAL_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_GEN_MODE_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_GEN_STR_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_MATRIX_FLOAT_AS_INT_BITS_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_MAX_ANISOTROPY_EXT: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_24_8_OES: typing.ClassVar[int] = ...
    GL_WEIGHT_ARRAY_BUFFER_BINDING_OES: typing.ClassVar[int] = ...
    GL_WEIGHT_ARRAY_OES: typing.ClassVar[int] = ...
    GL_WEIGHT_ARRAY_POINTER_OES: typing.ClassVar[int] = ...
    GL_WEIGHT_ARRAY_SIZE_OES: typing.ClassVar[int] = ...
    GL_WEIGHT_ARRAY_STRIDE_OES: typing.ClassVar[int] = ...
    GL_WEIGHT_ARRAY_TYPE_OES: typing.ClassVar[int] = ...
    GL_WRITE_ONLY_OES: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def glAlphaFuncxOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindFramebufferOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindRenderbufferOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlendEquationOES(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlendEquationSeparateOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlendFuncSeparateOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glCheckFramebufferStatusOES(arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def glClearColorxOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glClearDepthfOES(arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glClearDepthxOES(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glClipPlanefOES(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glClipPlanefOES(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glClipPlanexOES(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glClipPlanexOES(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glColor4xOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glCurrentPaletteMatrixOES(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteFramebuffersOES(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteFramebuffersOES(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteRenderbuffersOES(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteRenderbuffersOES(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDepthRangefOES(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glDepthRangexOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDrawTexfOES(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawTexfvOES(arg1: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawTexfvOES(arg1: java.chaquopy.JavaArrayJFloat, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDrawTexiOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawTexivOES(arg1: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawTexivOES(arg1: java.chaquopy.JavaArrayJInt, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDrawTexsOES(arg1: int | java.jshort | java.lang.Short, arg2: int | java.jshort | java.lang.Short, arg3: int | java.jshort | java.lang.Short, arg4: int | java.jshort | java.lang.Short, arg5: int | java.jshort | java.lang.Short, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawTexsvOES(arg1: java.nio.ShortBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawTexsvOES(arg1: java.chaquopy.JavaArrayJShort, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDrawTexxOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawTexxvOES(arg1: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawTexxvOES(arg1: java.chaquopy.JavaArrayJInt, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glEGLImageTargetRenderbufferStorageOES(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glEGLImageTargetTexture2DOES(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glFogxOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glFogxvOES(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glFogxvOES(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glFramebufferRenderbufferOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glFramebufferTexture2DOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glFrustumfOES(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, arg6: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glFrustumxOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenFramebuffersOES(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenFramebuffersOES(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenRenderbuffersOES(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenRenderbuffersOES(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGenerateMipmapOES(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetClipPlanefOES(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetClipPlanefOES(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetClipPlanexOES(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetClipPlanexOES(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetFixedvOES(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetFixedvOES(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetFramebufferAttachmentParameterivOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetFramebufferAttachmentParameterivOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetLightxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetLightxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetMaterialxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetMaterialxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetRenderbufferParameterivOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetRenderbufferParameterivOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexEnvxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexEnvxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexGenfvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexGenfvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexGenivOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexGenivOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexGenxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexGenxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glIsFramebufferOES(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glIsRenderbufferOES(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glLightModelxOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLightModelxvOES(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLightModelxvOES(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glLightxOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLightxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLightxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glLineWidthxOES(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLoadMatrixxOES(arg1: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glLoadMatrixxOES(arg1: java.chaquopy.JavaArrayJInt, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glLoadPaletteFromModelViewMatrixOES() -> None: ...
    @staticmethod
    def glMaterialxOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glMaterialxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glMaterialxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glMatrixIndexPointerOES(size: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, stride: int | java.jint | java.lang.Integer, pointer: java.nio.Buffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glMultMatrixxOES(arg1: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glMultMatrixxOES(arg1: java.chaquopy.JavaArrayJInt, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glMultiTexCoord4xOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glNormal3xOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glOrthofOES(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, arg6: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glOrthoxOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glPointParameterxOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glPointParameterxvOES(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glPointParameterxvOES(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glPointSizexOES(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glPolygonOffsetxOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glRenderbufferStorageOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glRotatexOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glSampleCoveragexOES(arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def glScalexOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexEnvxOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexEnvxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexEnvxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexGenfOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexGenfvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexGenfvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexGeniOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexGenivOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexGenivOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexGenxOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexGenxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexGenxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexParameterxOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterxvOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTranslatexOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glWeightPointerOES(size: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, stride: int | java.jint | java.lang.Integer, pointer: java.nio.Buffer, /) -> None: ...

class GLES20(java.lang.Object):
    GL_ACTIVE_ATTRIBUTES: typing.ClassVar[int] = ...
    GL_ACTIVE_ATTRIBUTE_MAX_LENGTH: typing.ClassVar[int] = ...
    GL_ACTIVE_TEXTURE: typing.ClassVar[int] = ...
    GL_ACTIVE_UNIFORMS: typing.ClassVar[int] = ...
    GL_ACTIVE_UNIFORM_MAX_LENGTH: typing.ClassVar[int] = ...
    GL_ALIASED_LINE_WIDTH_RANGE: typing.ClassVar[int] = ...
    GL_ALIASED_POINT_SIZE_RANGE: typing.ClassVar[int] = ...
    GL_ALPHA: typing.ClassVar[int] = ...
    GL_ALPHA_BITS: typing.ClassVar[int] = ...
    GL_ALWAYS: typing.ClassVar[int] = ...
    GL_ARRAY_BUFFER: typing.ClassVar[int] = ...
    GL_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_ATTACHED_SHADERS: typing.ClassVar[int] = ...
    GL_BACK: typing.ClassVar[int] = ...
    GL_BLEND: typing.ClassVar[int] = ...
    GL_BLEND_COLOR: typing.ClassVar[int] = ...
    GL_BLEND_DST_ALPHA: typing.ClassVar[int] = ...
    GL_BLEND_DST_RGB: typing.ClassVar[int] = ...
    GL_BLEND_EQUATION: typing.ClassVar[int] = ...
    GL_BLEND_EQUATION_ALPHA: typing.ClassVar[int] = ...
    GL_BLEND_EQUATION_RGB: typing.ClassVar[int] = ...
    GL_BLEND_SRC_ALPHA: typing.ClassVar[int] = ...
    GL_BLEND_SRC_RGB: typing.ClassVar[int] = ...
    GL_BLUE_BITS: typing.ClassVar[int] = ...
    GL_BOOL: typing.ClassVar[int] = ...
    GL_BOOL_VEC2: typing.ClassVar[int] = ...
    GL_BOOL_VEC3: typing.ClassVar[int] = ...
    GL_BOOL_VEC4: typing.ClassVar[int] = ...
    GL_BUFFER_SIZE: typing.ClassVar[int] = ...
    GL_BUFFER_USAGE: typing.ClassVar[int] = ...
    GL_BYTE: typing.ClassVar[int] = ...
    GL_CCW: typing.ClassVar[int] = ...
    GL_CLAMP_TO_EDGE: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT0: typing.ClassVar[int] = ...
    GL_COLOR_BUFFER_BIT: typing.ClassVar[int] = ...
    GL_COLOR_CLEAR_VALUE: typing.ClassVar[int] = ...
    GL_COLOR_WRITEMASK: typing.ClassVar[int] = ...
    GL_COMPILE_STATUS: typing.ClassVar[int] = ...
    GL_COMPRESSED_TEXTURE_FORMATS: typing.ClassVar[int] = ...
    GL_CONSTANT_ALPHA: typing.ClassVar[int] = ...
    GL_CONSTANT_COLOR: typing.ClassVar[int] = ...
    GL_CULL_FACE: typing.ClassVar[int] = ...
    GL_CULL_FACE_MODE: typing.ClassVar[int] = ...
    GL_CURRENT_PROGRAM: typing.ClassVar[int] = ...
    GL_CURRENT_VERTEX_ATTRIB: typing.ClassVar[int] = ...
    GL_CW: typing.ClassVar[int] = ...
    GL_DECR: typing.ClassVar[int] = ...
    GL_DECR_WRAP: typing.ClassVar[int] = ...
    GL_DELETE_STATUS: typing.ClassVar[int] = ...
    GL_DEPTH_ATTACHMENT: typing.ClassVar[int] = ...
    GL_DEPTH_BITS: typing.ClassVar[int] = ...
    GL_DEPTH_BUFFER_BIT: typing.ClassVar[int] = ...
    GL_DEPTH_CLEAR_VALUE: typing.ClassVar[int] = ...
    GL_DEPTH_COMPONENT16: typing.ClassVar[int] = ...
    GL_DEPTH_COMPONENT: typing.ClassVar[int] = ...
    GL_DEPTH_FUNC: typing.ClassVar[int] = ...
    GL_DEPTH_RANGE: typing.ClassVar[int] = ...
    GL_DEPTH_TEST: typing.ClassVar[int] = ...
    GL_DEPTH_WRITEMASK: typing.ClassVar[int] = ...
    GL_DITHER: typing.ClassVar[int] = ...
    GL_DONT_CARE: typing.ClassVar[int] = ...
    GL_DST_ALPHA: typing.ClassVar[int] = ...
    GL_DST_COLOR: typing.ClassVar[int] = ...
    GL_DYNAMIC_DRAW: typing.ClassVar[int] = ...
    GL_ELEMENT_ARRAY_BUFFER: typing.ClassVar[int] = ...
    GL_ELEMENT_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_EQUAL: typing.ClassVar[int] = ...
    GL_EXTENSIONS: typing.ClassVar[int] = ...
    GL_FALSE: typing.ClassVar[int] = ...
    GL_FASTEST: typing.ClassVar[int] = ...
    GL_FIXED: typing.ClassVar[int] = ...
    GL_FLOAT: typing.ClassVar[int] = ...
    GL_FLOAT_MAT2: typing.ClassVar[int] = ...
    GL_FLOAT_MAT3: typing.ClassVar[int] = ...
    GL_FLOAT_MAT4: typing.ClassVar[int] = ...
    GL_FLOAT_VEC2: typing.ClassVar[int] = ...
    GL_FLOAT_VEC3: typing.ClassVar[int] = ...
    GL_FLOAT_VEC4: typing.ClassVar[int] = ...
    GL_FRAGMENT_SHADER: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_BINDING: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_COMPLETE: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_UNSUPPORTED: typing.ClassVar[int] = ...
    GL_FRONT: typing.ClassVar[int] = ...
    GL_FRONT_AND_BACK: typing.ClassVar[int] = ...
    GL_FRONT_FACE: typing.ClassVar[int] = ...
    GL_FUNC_ADD: typing.ClassVar[int] = ...
    GL_FUNC_REVERSE_SUBTRACT: typing.ClassVar[int] = ...
    GL_FUNC_SUBTRACT: typing.ClassVar[int] = ...
    GL_GENERATE_MIPMAP_HINT: typing.ClassVar[int] = ...
    GL_GEQUAL: typing.ClassVar[int] = ...
    GL_GREATER: typing.ClassVar[int] = ...
    GL_GREEN_BITS: typing.ClassVar[int] = ...
    GL_HIGH_FLOAT: typing.ClassVar[int] = ...
    GL_HIGH_INT: typing.ClassVar[int] = ...
    GL_IMPLEMENTATION_COLOR_READ_FORMAT: typing.ClassVar[int] = ...
    GL_IMPLEMENTATION_COLOR_READ_TYPE: typing.ClassVar[int] = ...
    GL_INCR: typing.ClassVar[int] = ...
    GL_INCR_WRAP: typing.ClassVar[int] = ...
    GL_INFO_LOG_LENGTH: typing.ClassVar[int] = ...
    GL_INT: typing.ClassVar[int] = ...
    GL_INT_VEC2: typing.ClassVar[int] = ...
    GL_INT_VEC3: typing.ClassVar[int] = ...
    GL_INT_VEC4: typing.ClassVar[int] = ...
    GL_INVALID_ENUM: typing.ClassVar[int] = ...
    GL_INVALID_FRAMEBUFFER_OPERATION: typing.ClassVar[int] = ...
    GL_INVALID_OPERATION: typing.ClassVar[int] = ...
    GL_INVALID_VALUE: typing.ClassVar[int] = ...
    GL_INVERT: typing.ClassVar[int] = ...
    GL_KEEP: typing.ClassVar[int] = ...
    GL_LEQUAL: typing.ClassVar[int] = ...
    GL_LESS: typing.ClassVar[int] = ...
    GL_LINEAR: typing.ClassVar[int] = ...
    GL_LINEAR_MIPMAP_LINEAR: typing.ClassVar[int] = ...
    GL_LINEAR_MIPMAP_NEAREST: typing.ClassVar[int] = ...
    GL_LINES: typing.ClassVar[int] = ...
    GL_LINE_LOOP: typing.ClassVar[int] = ...
    GL_LINE_STRIP: typing.ClassVar[int] = ...
    GL_LINE_WIDTH: typing.ClassVar[int] = ...
    GL_LINK_STATUS: typing.ClassVar[int] = ...
    GL_LOW_FLOAT: typing.ClassVar[int] = ...
    GL_LOW_INT: typing.ClassVar[int] = ...
    GL_LUMINANCE: typing.ClassVar[int] = ...
    GL_LUMINANCE_ALPHA: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS: typing.ClassVar[int] = ...
    GL_MAX_CUBE_MAP_TEXTURE_SIZE: typing.ClassVar[int] = ...
    GL_MAX_FRAGMENT_UNIFORM_VECTORS: typing.ClassVar[int] = ...
    GL_MAX_RENDERBUFFER_SIZE: typing.ClassVar[int] = ...
    GL_MAX_TEXTURE_IMAGE_UNITS: typing.ClassVar[int] = ...
    GL_MAX_TEXTURE_SIZE: typing.ClassVar[int] = ...
    GL_MAX_VARYING_VECTORS: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_ATTRIBS: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_UNIFORM_VECTORS: typing.ClassVar[int] = ...
    GL_MAX_VIEWPORT_DIMS: typing.ClassVar[int] = ...
    GL_MEDIUM_FLOAT: typing.ClassVar[int] = ...
    GL_MEDIUM_INT: typing.ClassVar[int] = ...
    GL_MIRRORED_REPEAT: typing.ClassVar[int] = ...
    GL_NEAREST: typing.ClassVar[int] = ...
    GL_NEAREST_MIPMAP_LINEAR: typing.ClassVar[int] = ...
    GL_NEAREST_MIPMAP_NEAREST: typing.ClassVar[int] = ...
    GL_NEVER: typing.ClassVar[int] = ...
    GL_NICEST: typing.ClassVar[int] = ...
    GL_NONE: typing.ClassVar[int] = ...
    GL_NOTEQUAL: typing.ClassVar[int] = ...
    GL_NO_ERROR: typing.ClassVar[int] = ...
    GL_NUM_COMPRESSED_TEXTURE_FORMATS: typing.ClassVar[int] = ...
    GL_NUM_SHADER_BINARY_FORMATS: typing.ClassVar[int] = ...
    GL_ONE: typing.ClassVar[int] = ...
    GL_ONE_MINUS_CONSTANT_ALPHA: typing.ClassVar[int] = ...
    GL_ONE_MINUS_CONSTANT_COLOR: typing.ClassVar[int] = ...
    GL_ONE_MINUS_DST_ALPHA: typing.ClassVar[int] = ...
    GL_ONE_MINUS_DST_COLOR: typing.ClassVar[int] = ...
    GL_ONE_MINUS_SRC_ALPHA: typing.ClassVar[int] = ...
    GL_ONE_MINUS_SRC_COLOR: typing.ClassVar[int] = ...
    GL_OUT_OF_MEMORY: typing.ClassVar[int] = ...
    GL_PACK_ALIGNMENT: typing.ClassVar[int] = ...
    GL_POINTS: typing.ClassVar[int] = ...
    GL_POLYGON_OFFSET_FACTOR: typing.ClassVar[int] = ...
    GL_POLYGON_OFFSET_FILL: typing.ClassVar[int] = ...
    GL_POLYGON_OFFSET_UNITS: typing.ClassVar[int] = ...
    GL_RED_BITS: typing.ClassVar[int] = ...
    GL_RENDERBUFFER: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_ALPHA_SIZE: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_BINDING: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_BLUE_SIZE: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_DEPTH_SIZE: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_GREEN_SIZE: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_HEIGHT: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_INTERNAL_FORMAT: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_RED_SIZE: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_STENCIL_SIZE: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_WIDTH: typing.ClassVar[int] = ...
    GL_RENDERER: typing.ClassVar[int] = ...
    GL_REPEAT: typing.ClassVar[int] = ...
    GL_REPLACE: typing.ClassVar[int] = ...
    GL_RGB565: typing.ClassVar[int] = ...
    GL_RGB5_A1: typing.ClassVar[int] = ...
    GL_RGB: typing.ClassVar[int] = ...
    GL_RGBA4: typing.ClassVar[int] = ...
    GL_RGBA: typing.ClassVar[int] = ...
    GL_SAMPLER_2D: typing.ClassVar[int] = ...
    GL_SAMPLER_CUBE: typing.ClassVar[int] = ...
    GL_SAMPLES: typing.ClassVar[int] = ...
    GL_SAMPLE_ALPHA_TO_COVERAGE: typing.ClassVar[int] = ...
    GL_SAMPLE_BUFFERS: typing.ClassVar[int] = ...
    GL_SAMPLE_COVERAGE: typing.ClassVar[int] = ...
    GL_SAMPLE_COVERAGE_INVERT: typing.ClassVar[int] = ...
    GL_SAMPLE_COVERAGE_VALUE: typing.ClassVar[int] = ...
    GL_SCISSOR_BOX: typing.ClassVar[int] = ...
    GL_SCISSOR_TEST: typing.ClassVar[int] = ...
    GL_SHADER_BINARY_FORMATS: typing.ClassVar[int] = ...
    GL_SHADER_COMPILER: typing.ClassVar[int] = ...
    GL_SHADER_SOURCE_LENGTH: typing.ClassVar[int] = ...
    GL_SHADER_TYPE: typing.ClassVar[int] = ...
    GL_SHADING_LANGUAGE_VERSION: typing.ClassVar[int] = ...
    GL_SHORT: typing.ClassVar[int] = ...
    GL_SRC_ALPHA: typing.ClassVar[int] = ...
    GL_SRC_ALPHA_SATURATE: typing.ClassVar[int] = ...
    GL_SRC_COLOR: typing.ClassVar[int] = ...
    GL_STATIC_DRAW: typing.ClassVar[int] = ...
    GL_STENCIL_ATTACHMENT: typing.ClassVar[int] = ...
    GL_STENCIL_BACK_FAIL: typing.ClassVar[int] = ...
    GL_STENCIL_BACK_FUNC: typing.ClassVar[int] = ...
    GL_STENCIL_BACK_PASS_DEPTH_FAIL: typing.ClassVar[int] = ...
    GL_STENCIL_BACK_PASS_DEPTH_PASS: typing.ClassVar[int] = ...
    GL_STENCIL_BACK_REF: typing.ClassVar[int] = ...
    GL_STENCIL_BACK_VALUE_MASK: typing.ClassVar[int] = ...
    GL_STENCIL_BACK_WRITEMASK: typing.ClassVar[int] = ...
    GL_STENCIL_BITS: typing.ClassVar[int] = ...
    GL_STENCIL_BUFFER_BIT: typing.ClassVar[int] = ...
    GL_STENCIL_CLEAR_VALUE: typing.ClassVar[int] = ...
    GL_STENCIL_FAIL: typing.ClassVar[int] = ...
    GL_STENCIL_FUNC: typing.ClassVar[int] = ...
    GL_STENCIL_INDEX8: typing.ClassVar[int] = ...
    GL_STENCIL_INDEX: typing.ClassVar[int] = ...
    GL_STENCIL_PASS_DEPTH_FAIL: typing.ClassVar[int] = ...
    GL_STENCIL_PASS_DEPTH_PASS: typing.ClassVar[int] = ...
    GL_STENCIL_REF: typing.ClassVar[int] = ...
    GL_STENCIL_TEST: typing.ClassVar[int] = ...
    GL_STENCIL_VALUE_MASK: typing.ClassVar[int] = ...
    GL_STENCIL_WRITEMASK: typing.ClassVar[int] = ...
    GL_STREAM_DRAW: typing.ClassVar[int] = ...
    GL_SUBPIXEL_BITS: typing.ClassVar[int] = ...
    GL_TEXTURE0: typing.ClassVar[int] = ...
    GL_TEXTURE10: typing.ClassVar[int] = ...
    GL_TEXTURE11: typing.ClassVar[int] = ...
    GL_TEXTURE12: typing.ClassVar[int] = ...
    GL_TEXTURE13: typing.ClassVar[int] = ...
    GL_TEXTURE14: typing.ClassVar[int] = ...
    GL_TEXTURE15: typing.ClassVar[int] = ...
    GL_TEXTURE16: typing.ClassVar[int] = ...
    GL_TEXTURE17: typing.ClassVar[int] = ...
    GL_TEXTURE18: typing.ClassVar[int] = ...
    GL_TEXTURE19: typing.ClassVar[int] = ...
    GL_TEXTURE1: typing.ClassVar[int] = ...
    GL_TEXTURE20: typing.ClassVar[int] = ...
    GL_TEXTURE21: typing.ClassVar[int] = ...
    GL_TEXTURE22: typing.ClassVar[int] = ...
    GL_TEXTURE23: typing.ClassVar[int] = ...
    GL_TEXTURE24: typing.ClassVar[int] = ...
    GL_TEXTURE25: typing.ClassVar[int] = ...
    GL_TEXTURE26: typing.ClassVar[int] = ...
    GL_TEXTURE27: typing.ClassVar[int] = ...
    GL_TEXTURE28: typing.ClassVar[int] = ...
    GL_TEXTURE29: typing.ClassVar[int] = ...
    GL_TEXTURE2: typing.ClassVar[int] = ...
    GL_TEXTURE30: typing.ClassVar[int] = ...
    GL_TEXTURE31: typing.ClassVar[int] = ...
    GL_TEXTURE3: typing.ClassVar[int] = ...
    GL_TEXTURE4: typing.ClassVar[int] = ...
    GL_TEXTURE5: typing.ClassVar[int] = ...
    GL_TEXTURE6: typing.ClassVar[int] = ...
    GL_TEXTURE7: typing.ClassVar[int] = ...
    GL_TEXTURE8: typing.ClassVar[int] = ...
    GL_TEXTURE9: typing.ClassVar[int] = ...
    GL_TEXTURE: typing.ClassVar[int] = ...
    GL_TEXTURE_2D: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_2D: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_CUBE_MAP: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_NEGATIVE_X: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_NEGATIVE_Y: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_NEGATIVE_Z: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_POSITIVE_X: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_POSITIVE_Y: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_POSITIVE_Z: typing.ClassVar[int] = ...
    GL_TEXTURE_MAG_FILTER: typing.ClassVar[int] = ...
    GL_TEXTURE_MIN_FILTER: typing.ClassVar[int] = ...
    GL_TEXTURE_WRAP_S: typing.ClassVar[int] = ...
    GL_TEXTURE_WRAP_T: typing.ClassVar[int] = ...
    GL_TRIANGLES: typing.ClassVar[int] = ...
    GL_TRIANGLE_FAN: typing.ClassVar[int] = ...
    GL_TRIANGLE_STRIP: typing.ClassVar[int] = ...
    GL_TRUE: typing.ClassVar[int] = ...
    GL_UNPACK_ALIGNMENT: typing.ClassVar[int] = ...
    GL_UNSIGNED_BYTE: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT: typing.ClassVar[int] = ...
    GL_UNSIGNED_SHORT: typing.ClassVar[int] = ...
    GL_UNSIGNED_SHORT_4_4_4_4: typing.ClassVar[int] = ...
    GL_UNSIGNED_SHORT_5_5_5_1: typing.ClassVar[int] = ...
    GL_UNSIGNED_SHORT_5_6_5: typing.ClassVar[int] = ...
    GL_VALIDATE_STATUS: typing.ClassVar[int] = ...
    GL_VENDOR: typing.ClassVar[int] = ...
    GL_VERSION: typing.ClassVar[int] = ...
    GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_VERTEX_ATTRIB_ARRAY_ENABLED: typing.ClassVar[int] = ...
    GL_VERTEX_ATTRIB_ARRAY_NORMALIZED: typing.ClassVar[int] = ...
    GL_VERTEX_ATTRIB_ARRAY_POINTER: typing.ClassVar[int] = ...
    GL_VERTEX_ATTRIB_ARRAY_SIZE: typing.ClassVar[int] = ...
    GL_VERTEX_ATTRIB_ARRAY_STRIDE: typing.ClassVar[int] = ...
    GL_VERTEX_ATTRIB_ARRAY_TYPE: typing.ClassVar[int] = ...
    GL_VERTEX_SHADER: typing.ClassVar[int] = ...
    GL_VIEWPORT: typing.ClassVar[int] = ...
    GL_ZERO: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def glActiveTexture(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glAttachShader(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindAttribLocation(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: str | java.lang.String, /) -> None: ...
    @staticmethod
    def glBindBuffer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindFramebuffer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindRenderbuffer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindTexture(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlendColor(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glBlendEquation(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlendEquationSeparate(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlendFunc(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlendFuncSeparate(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBufferData(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.Buffer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBufferSubData(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glCheckFramebufferStatus(arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def glClear(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glClearColor(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glClearDepthf(arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glClearStencil(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glColorMask(arg1: bool | java.jboolean | java.lang.Boolean, arg2: bool | java.jboolean | java.lang.Boolean, arg3: bool | java.jboolean | java.lang.Boolean, arg4: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def glCompileShader(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glCompressedTexImage2D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glCompressedTexSubImage2D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glCopyTexImage2D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glCopyTexSubImage2D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glCreateProgram() -> int: ...
    @staticmethod
    def glCreateShader(arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def glCullFace(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteBuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteBuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteFramebuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteFramebuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDeleteProgram(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteRenderbuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteRenderbuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDeleteShader(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteTextures(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteTextures(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDepthFunc(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDepthMask(arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def glDepthRangef(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glDetachShader(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDisable(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDisableVertexAttribArray(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDrawArrays(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawElements(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawElements(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glEnable(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glEnableVertexAttribArray(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glFinish() -> None: ...
    @staticmethod
    def glFlush() -> None: ...
    @staticmethod
    def glFramebufferRenderbuffer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glFramebufferTexture2D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glFrontFace(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenBuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenBuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenFramebuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenFramebuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenRenderbuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenRenderbuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenTextures(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenTextures(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGenerateMipmap(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetActiveAttrib(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, arg4: java.nio.IntBuffer, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetActiveAttrib(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJInt, arg6: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetActiveAttrib(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, arg6: java.chaquopy.JavaArrayJInt, arg7: int | java.jint | java.lang.Integer, arg8: java.chaquopy.JavaArrayJInt, arg9: int | java.jint | java.lang.Integer, arg10: java.chaquopy.JavaArrayJByte, arg11: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetActiveUniform(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, arg4: java.nio.IntBuffer, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetActiveUniform(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJInt, arg6: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetActiveUniform(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, arg6: java.chaquopy.JavaArrayJInt, arg7: int | java.jint | java.lang.Integer, arg8: java.chaquopy.JavaArrayJInt, arg9: int | java.jint | java.lang.Integer, arg10: java.chaquopy.JavaArrayJByte, arg11: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetAttachedShaders(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetAttachedShaders(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJInt, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGetAttribLocation(arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, /) -> int: ...
    @typing.overload
    @staticmethod
    def glGetBooleanv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetBooleanv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJBoolean, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetBufferParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetBufferParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGetError() -> int: ...
    @typing.overload
    @staticmethod
    def glGetFloatv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetFloatv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetFramebufferAttachmentParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetFramebufferAttachmentParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetIntegerv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetIntegerv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGetProgramInfoLog(arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetProgramiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetProgramiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetRenderbufferParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetRenderbufferParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGetShaderInfoLog(arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetShaderPrecisionFormat(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetShaderPrecisionFormat(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJInt, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetShaderSource(arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetShaderSource(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJByte, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetShaderiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetShaderiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGetString(arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGetUniformLocation(arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, /) -> int: ...
    @typing.overload
    @staticmethod
    def glGetUniformfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetUniformfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetUniformiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetUniformiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetVertexAttribfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetVertexAttribfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetVertexAttribiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetVertexAttribiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glHint(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glIsBuffer(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glIsEnabled(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glIsFramebuffer(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glIsProgram(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glIsRenderbuffer(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glIsShader(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glIsTexture(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glLineWidth(arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glLinkProgram(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glPixelStorei(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glPolygonOffset(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glReadPixels(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glReleaseShaderCompiler() -> None: ...
    @staticmethod
    def glRenderbufferStorage(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glSampleCoverage(arg1: float | java.jfloat | java.lang.Float, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def glScissor(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glShaderBinary(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glShaderBinary(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: java.nio.Buffer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glShaderSource(arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, /) -> None: ...
    @staticmethod
    def glStencilFunc(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glStencilFuncSeparate(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glStencilMask(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glStencilMaskSeparate(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glStencilOp(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glStencilOpSeparate(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexImage2D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glTexParameterf(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexParameteri(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexSubImage2D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glUniform1f(arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform1fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform1fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glUniform1i(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform1iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform1iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glUniform2f(arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glUniform2i(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform2iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform2iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glUniform3f(arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glUniform3i(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform3iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform3iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glUniform4f(arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glUniform4i(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform4iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform4iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glUseProgram(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glValidateProgram(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glVertexAttrib1f(arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttrib1fv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttrib1fv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glVertexAttrib2f(arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttrib2fv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttrib2fv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glVertexAttrib3f(arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttrib3fv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttrib3fv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glVertexAttrib4f(arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttrib4fv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttrib4fv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttribPointer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttribPointer(indx: int | java.jint | java.lang.Integer, size: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, normalized: bool | java.jboolean | java.lang.Boolean, stride: int | java.jint | java.lang.Integer, ptr: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glViewport(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...

class GLES30(GLES20):
    GL_ACTIVE_UNIFORM_BLOCKS: typing.ClassVar[int] = ...
    GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH: typing.ClassVar[int] = ...
    GL_ALREADY_SIGNALED: typing.ClassVar[int] = ...
    GL_ANY_SAMPLES_PASSED: typing.ClassVar[int] = ...
    GL_ANY_SAMPLES_PASSED_CONSERVATIVE: typing.ClassVar[int] = ...
    GL_BLUE: typing.ClassVar[int] = ...
    GL_BUFFER_ACCESS_FLAGS: typing.ClassVar[int] = ...
    GL_BUFFER_MAPPED: typing.ClassVar[int] = ...
    GL_BUFFER_MAP_LENGTH: typing.ClassVar[int] = ...
    GL_BUFFER_MAP_OFFSET: typing.ClassVar[int] = ...
    GL_BUFFER_MAP_POINTER: typing.ClassVar[int] = ...
    GL_COLOR: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT10: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT11: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT12: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT13: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT14: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT15: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT1: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT2: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT3: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT4: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT5: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT6: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT7: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT8: typing.ClassVar[int] = ...
    GL_COLOR_ATTACHMENT9: typing.ClassVar[int] = ...
    GL_COMPARE_REF_TO_TEXTURE: typing.ClassVar[int] = ...
    GL_COMPRESSED_R11_EAC: typing.ClassVar[int] = ...
    GL_COMPRESSED_RG11_EAC: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGB8_ETC2: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA8_ETC2_EAC: typing.ClassVar[int] = ...
    GL_COMPRESSED_SIGNED_R11_EAC: typing.ClassVar[int] = ...
    GL_COMPRESSED_SIGNED_RG11_EAC: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ETC2: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2: typing.ClassVar[int] = ...
    GL_CONDITION_SATISFIED: typing.ClassVar[int] = ...
    GL_COPY_READ_BUFFER: typing.ClassVar[int] = ...
    GL_COPY_READ_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_COPY_WRITE_BUFFER: typing.ClassVar[int] = ...
    GL_COPY_WRITE_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_CURRENT_QUERY: typing.ClassVar[int] = ...
    GL_DEPTH24_STENCIL8: typing.ClassVar[int] = ...
    GL_DEPTH32F_STENCIL8: typing.ClassVar[int] = ...
    GL_DEPTH: typing.ClassVar[int] = ...
    GL_DEPTH_COMPONENT24: typing.ClassVar[int] = ...
    GL_DEPTH_COMPONENT32F: typing.ClassVar[int] = ...
    GL_DEPTH_STENCIL: typing.ClassVar[int] = ...
    GL_DEPTH_STENCIL_ATTACHMENT: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER0: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER10: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER11: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER12: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER13: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER14: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER15: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER1: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER2: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER3: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER4: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER5: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER6: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER7: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER8: typing.ClassVar[int] = ...
    GL_DRAW_BUFFER9: typing.ClassVar[int] = ...
    GL_DRAW_FRAMEBUFFER: typing.ClassVar[int] = ...
    GL_DRAW_FRAMEBUFFER_BINDING: typing.ClassVar[int] = ...
    GL_DYNAMIC_COPY: typing.ClassVar[int] = ...
    GL_DYNAMIC_READ: typing.ClassVar[int] = ...
    GL_FLOAT_32_UNSIGNED_INT_24_8_REV: typing.ClassVar[int] = ...
    GL_FLOAT_MAT2x3: typing.ClassVar[int] = ...
    GL_FLOAT_MAT2x4: typing.ClassVar[int] = ...
    GL_FLOAT_MAT3x2: typing.ClassVar[int] = ...
    GL_FLOAT_MAT3x4: typing.ClassVar[int] = ...
    GL_FLOAT_MAT4x2: typing.ClassVar[int] = ...
    GL_FLOAT_MAT4x3: typing.ClassVar[int] = ...
    GL_FRAGMENT_SHADER_DERIVATIVE_HINT: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_DEFAULT: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_UNDEFINED: typing.ClassVar[int] = ...
    GL_GREEN: typing.ClassVar[int] = ...
    GL_HALF_FLOAT: typing.ClassVar[int] = ...
    GL_INTERLEAVED_ATTRIBS: typing.ClassVar[int] = ...
    GL_INT_2_10_10_10_REV: typing.ClassVar[int] = ...
    GL_INT_SAMPLER_2D: typing.ClassVar[int] = ...
    GL_INT_SAMPLER_2D_ARRAY: typing.ClassVar[int] = ...
    GL_INT_SAMPLER_3D: typing.ClassVar[int] = ...
    GL_INT_SAMPLER_CUBE: typing.ClassVar[int] = ...
    GL_INVALID_INDEX: typing.ClassVar[int] = ...
    GL_MAJOR_VERSION: typing.ClassVar[int] = ...
    GL_MAP_FLUSH_EXPLICIT_BIT: typing.ClassVar[int] = ...
    GL_MAP_INVALIDATE_BUFFER_BIT: typing.ClassVar[int] = ...
    GL_MAP_INVALIDATE_RANGE_BIT: typing.ClassVar[int] = ...
    GL_MAP_READ_BIT: typing.ClassVar[int] = ...
    GL_MAP_UNSYNCHRONIZED_BIT: typing.ClassVar[int] = ...
    GL_MAP_WRITE_BIT: typing.ClassVar[int] = ...
    GL_MAX: typing.ClassVar[int] = ...
    GL_MAX_3D_TEXTURE_SIZE: typing.ClassVar[int] = ...
    GL_MAX_ARRAY_TEXTURE_LAYERS: typing.ClassVar[int] = ...
    GL_MAX_COLOR_ATTACHMENTS: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_UNIFORM_BLOCKS: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_DRAW_BUFFERS: typing.ClassVar[int] = ...
    GL_MAX_ELEMENTS_INDICES: typing.ClassVar[int] = ...
    GL_MAX_ELEMENTS_VERTICES: typing.ClassVar[int] = ...
    GL_MAX_ELEMENT_INDEX: typing.ClassVar[int] = ...
    GL_MAX_FRAGMENT_INPUT_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_FRAGMENT_UNIFORM_BLOCKS: typing.ClassVar[int] = ...
    GL_MAX_FRAGMENT_UNIFORM_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_PROGRAM_TEXEL_OFFSET: typing.ClassVar[int] = ...
    GL_MAX_SAMPLES: typing.ClassVar[int] = ...
    GL_MAX_SERVER_WAIT_TIMEOUT: typing.ClassVar[int] = ...
    GL_MAX_TEXTURE_LOD_BIAS: typing.ClassVar[int] = ...
    GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS: typing.ClassVar[int] = ...
    GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_UNIFORM_BLOCK_SIZE: typing.ClassVar[int] = ...
    GL_MAX_UNIFORM_BUFFER_BINDINGS: typing.ClassVar[int] = ...
    GL_MAX_VARYING_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_OUTPUT_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_UNIFORM_BLOCKS: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_UNIFORM_COMPONENTS: typing.ClassVar[int] = ...
    GL_MIN: typing.ClassVar[int] = ...
    GL_MINOR_VERSION: typing.ClassVar[int] = ...
    GL_MIN_PROGRAM_TEXEL_OFFSET: typing.ClassVar[int] = ...
    GL_NUM_EXTENSIONS: typing.ClassVar[int] = ...
    GL_NUM_PROGRAM_BINARY_FORMATS: typing.ClassVar[int] = ...
    GL_NUM_SAMPLE_COUNTS: typing.ClassVar[int] = ...
    GL_OBJECT_TYPE: typing.ClassVar[int] = ...
    GL_PACK_ROW_LENGTH: typing.ClassVar[int] = ...
    GL_PACK_SKIP_PIXELS: typing.ClassVar[int] = ...
    GL_PACK_SKIP_ROWS: typing.ClassVar[int] = ...
    GL_PIXEL_PACK_BUFFER: typing.ClassVar[int] = ...
    GL_PIXEL_PACK_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_PIXEL_UNPACK_BUFFER: typing.ClassVar[int] = ...
    GL_PIXEL_UNPACK_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_PRIMITIVE_RESTART_FIXED_INDEX: typing.ClassVar[int] = ...
    GL_PROGRAM_BINARY_FORMATS: typing.ClassVar[int] = ...
    GL_PROGRAM_BINARY_LENGTH: typing.ClassVar[int] = ...
    GL_PROGRAM_BINARY_RETRIEVABLE_HINT: typing.ClassVar[int] = ...
    GL_QUERY_RESULT: typing.ClassVar[int] = ...
    GL_QUERY_RESULT_AVAILABLE: typing.ClassVar[int] = ...
    GL_R11F_G11F_B10F: typing.ClassVar[int] = ...
    GL_R16F: typing.ClassVar[int] = ...
    GL_R16I: typing.ClassVar[int] = ...
    GL_R16UI: typing.ClassVar[int] = ...
    GL_R32F: typing.ClassVar[int] = ...
    GL_R32I: typing.ClassVar[int] = ...
    GL_R32UI: typing.ClassVar[int] = ...
    GL_R8: typing.ClassVar[int] = ...
    GL_R8I: typing.ClassVar[int] = ...
    GL_R8UI: typing.ClassVar[int] = ...
    GL_R8_SNORM: typing.ClassVar[int] = ...
    GL_RASTERIZER_DISCARD: typing.ClassVar[int] = ...
    GL_READ_BUFFER: typing.ClassVar[int] = ...
    GL_READ_FRAMEBUFFER: typing.ClassVar[int] = ...
    GL_READ_FRAMEBUFFER_BINDING: typing.ClassVar[int] = ...
    GL_RED: typing.ClassVar[int] = ...
    GL_RED_INTEGER: typing.ClassVar[int] = ...
    GL_RENDERBUFFER_SAMPLES: typing.ClassVar[int] = ...
    GL_RG16F: typing.ClassVar[int] = ...
    GL_RG16I: typing.ClassVar[int] = ...
    GL_RG16UI: typing.ClassVar[int] = ...
    GL_RG32F: typing.ClassVar[int] = ...
    GL_RG32I: typing.ClassVar[int] = ...
    GL_RG32UI: typing.ClassVar[int] = ...
    GL_RG8: typing.ClassVar[int] = ...
    GL_RG8I: typing.ClassVar[int] = ...
    GL_RG8UI: typing.ClassVar[int] = ...
    GL_RG8_SNORM: typing.ClassVar[int] = ...
    GL_RG: typing.ClassVar[int] = ...
    GL_RGB10_A2: typing.ClassVar[int] = ...
    GL_RGB10_A2UI: typing.ClassVar[int] = ...
    GL_RGB16F: typing.ClassVar[int] = ...
    GL_RGB16I: typing.ClassVar[int] = ...
    GL_RGB16UI: typing.ClassVar[int] = ...
    GL_RGB32F: typing.ClassVar[int] = ...
    GL_RGB32I: typing.ClassVar[int] = ...
    GL_RGB32UI: typing.ClassVar[int] = ...
    GL_RGB8: typing.ClassVar[int] = ...
    GL_RGB8I: typing.ClassVar[int] = ...
    GL_RGB8UI: typing.ClassVar[int] = ...
    GL_RGB8_SNORM: typing.ClassVar[int] = ...
    GL_RGB9_E5: typing.ClassVar[int] = ...
    GL_RGBA16F: typing.ClassVar[int] = ...
    GL_RGBA16I: typing.ClassVar[int] = ...
    GL_RGBA16UI: typing.ClassVar[int] = ...
    GL_RGBA32F: typing.ClassVar[int] = ...
    GL_RGBA32I: typing.ClassVar[int] = ...
    GL_RGBA32UI: typing.ClassVar[int] = ...
    GL_RGBA8: typing.ClassVar[int] = ...
    GL_RGBA8I: typing.ClassVar[int] = ...
    GL_RGBA8UI: typing.ClassVar[int] = ...
    GL_RGBA8_SNORM: typing.ClassVar[int] = ...
    GL_RGBA_INTEGER: typing.ClassVar[int] = ...
    GL_RGB_INTEGER: typing.ClassVar[int] = ...
    GL_RG_INTEGER: typing.ClassVar[int] = ...
    GL_SAMPLER_2D_ARRAY: typing.ClassVar[int] = ...
    GL_SAMPLER_2D_ARRAY_SHADOW: typing.ClassVar[int] = ...
    GL_SAMPLER_2D_SHADOW: typing.ClassVar[int] = ...
    GL_SAMPLER_3D: typing.ClassVar[int] = ...
    GL_SAMPLER_BINDING: typing.ClassVar[int] = ...
    GL_SAMPLER_CUBE_SHADOW: typing.ClassVar[int] = ...
    GL_SEPARATE_ATTRIBS: typing.ClassVar[int] = ...
    GL_SIGNALED: typing.ClassVar[int] = ...
    GL_SIGNED_NORMALIZED: typing.ClassVar[int] = ...
    GL_SRGB8: typing.ClassVar[int] = ...
    GL_SRGB8_ALPHA8: typing.ClassVar[int] = ...
    GL_SRGB: typing.ClassVar[int] = ...
    GL_STATIC_COPY: typing.ClassVar[int] = ...
    GL_STATIC_READ: typing.ClassVar[int] = ...
    GL_STENCIL: typing.ClassVar[int] = ...
    GL_STREAM_COPY: typing.ClassVar[int] = ...
    GL_STREAM_READ: typing.ClassVar[int] = ...
    GL_SYNC_CONDITION: typing.ClassVar[int] = ...
    GL_SYNC_FENCE: typing.ClassVar[int] = ...
    GL_SYNC_FLAGS: typing.ClassVar[int] = ...
    GL_SYNC_FLUSH_COMMANDS_BIT: typing.ClassVar[int] = ...
    GL_SYNC_GPU_COMMANDS_COMPLETE: typing.ClassVar[int] = ...
    GL_SYNC_STATUS: typing.ClassVar[int] = ...
    GL_TEXTURE_2D_ARRAY: typing.ClassVar[int] = ...
    GL_TEXTURE_3D: typing.ClassVar[int] = ...
    GL_TEXTURE_BASE_LEVEL: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_2D_ARRAY: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_3D: typing.ClassVar[int] = ...
    GL_TEXTURE_COMPARE_FUNC: typing.ClassVar[int] = ...
    GL_TEXTURE_COMPARE_MODE: typing.ClassVar[int] = ...
    GL_TEXTURE_IMMUTABLE_FORMAT: typing.ClassVar[int] = ...
    GL_TEXTURE_IMMUTABLE_LEVELS: typing.ClassVar[int] = ...
    GL_TEXTURE_MAX_LEVEL: typing.ClassVar[int] = ...
    GL_TEXTURE_MAX_LOD: typing.ClassVar[int] = ...
    GL_TEXTURE_MIN_LOD: typing.ClassVar[int] = ...
    GL_TEXTURE_SWIZZLE_A: typing.ClassVar[int] = ...
    GL_TEXTURE_SWIZZLE_B: typing.ClassVar[int] = ...
    GL_TEXTURE_SWIZZLE_G: typing.ClassVar[int] = ...
    GL_TEXTURE_SWIZZLE_R: typing.ClassVar[int] = ...
    GL_TEXTURE_WRAP_R: typing.ClassVar[int] = ...
    GL_TIMEOUT_EXPIRED: typing.ClassVar[int] = ...
    GL_TIMEOUT_IGNORED: typing.ClassVar[int] = ...
    GL_TRANSFORM_FEEDBACK: typing.ClassVar[int] = ...
    GL_TRANSFORM_FEEDBACK_ACTIVE: typing.ClassVar[int] = ...
    GL_TRANSFORM_FEEDBACK_BINDING: typing.ClassVar[int] = ...
    GL_TRANSFORM_FEEDBACK_BUFFER: typing.ClassVar[int] = ...
    GL_TRANSFORM_FEEDBACK_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_TRANSFORM_FEEDBACK_BUFFER_MODE: typing.ClassVar[int] = ...
    GL_TRANSFORM_FEEDBACK_BUFFER_SIZE: typing.ClassVar[int] = ...
    GL_TRANSFORM_FEEDBACK_BUFFER_START: typing.ClassVar[int] = ...
    GL_TRANSFORM_FEEDBACK_PAUSED: typing.ClassVar[int] = ...
    GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN: typing.ClassVar[int] = ...
    GL_TRANSFORM_FEEDBACK_VARYINGS: typing.ClassVar[int] = ...
    GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH: typing.ClassVar[int] = ...
    GL_UNIFORM_ARRAY_STRIDE: typing.ClassVar[int] = ...
    GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS: typing.ClassVar[int] = ...
    GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES: typing.ClassVar[int] = ...
    GL_UNIFORM_BLOCK_BINDING: typing.ClassVar[int] = ...
    GL_UNIFORM_BLOCK_DATA_SIZE: typing.ClassVar[int] = ...
    GL_UNIFORM_BLOCK_INDEX: typing.ClassVar[int] = ...
    GL_UNIFORM_BLOCK_NAME_LENGTH: typing.ClassVar[int] = ...
    GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER: typing.ClassVar[int] = ...
    GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER: typing.ClassVar[int] = ...
    GL_UNIFORM_BUFFER: typing.ClassVar[int] = ...
    GL_UNIFORM_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT: typing.ClassVar[int] = ...
    GL_UNIFORM_BUFFER_SIZE: typing.ClassVar[int] = ...
    GL_UNIFORM_BUFFER_START: typing.ClassVar[int] = ...
    GL_UNIFORM_IS_ROW_MAJOR: typing.ClassVar[int] = ...
    GL_UNIFORM_MATRIX_STRIDE: typing.ClassVar[int] = ...
    GL_UNIFORM_NAME_LENGTH: typing.ClassVar[int] = ...
    GL_UNIFORM_OFFSET: typing.ClassVar[int] = ...
    GL_UNIFORM_SIZE: typing.ClassVar[int] = ...
    GL_UNIFORM_TYPE: typing.ClassVar[int] = ...
    GL_UNPACK_IMAGE_HEIGHT: typing.ClassVar[int] = ...
    GL_UNPACK_ROW_LENGTH: typing.ClassVar[int] = ...
    GL_UNPACK_SKIP_IMAGES: typing.ClassVar[int] = ...
    GL_UNPACK_SKIP_PIXELS: typing.ClassVar[int] = ...
    GL_UNPACK_SKIP_ROWS: typing.ClassVar[int] = ...
    GL_UNSIGNALED: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_10F_11F_11F_REV: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_24_8: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_2_10_10_10_REV: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_5_9_9_9_REV: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_SAMPLER_2D: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_SAMPLER_2D_ARRAY: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_SAMPLER_3D: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_SAMPLER_CUBE: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_VEC2: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_VEC3: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_VEC4: typing.ClassVar[int] = ...
    GL_UNSIGNED_NORMALIZED: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY_BINDING: typing.ClassVar[int] = ...
    GL_VERTEX_ATTRIB_ARRAY_DIVISOR: typing.ClassVar[int] = ...
    GL_VERTEX_ATTRIB_ARRAY_INTEGER: typing.ClassVar[int] = ...
    GL_WAIT_FAILED: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def glBeginQuery(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBeginTransformFeedback(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindBufferBase(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindBufferRange(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindSampler(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindTransformFeedback(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindVertexArray(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlitFramebuffer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: int | java.jint | java.lang.Integer, arg10: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glClearBufferfi(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glClearBufferfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glClearBufferfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glClearBufferiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glClearBufferiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glClearBufferuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glClearBufferuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glClientWaitSync(arg1: int | java.jlong | java.lang.Long, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jlong | java.lang.Long, /) -> int: ...
    @typing.overload
    @staticmethod
    def glCompressedTexImage3D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glCompressedTexImage3D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: java.nio.Buffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glCompressedTexSubImage3D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: int | java.jint | java.lang.Integer, arg10: int | java.jint | java.lang.Integer, arg11: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glCompressedTexSubImage3D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: int | java.jint | java.lang.Integer, arg10: int | java.jint | java.lang.Integer, arg11: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glCopyBufferSubData(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glCopyTexSubImage3D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteQueries(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteQueries(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteSamplers(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteSamplers(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDeleteSync(arg1: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteTransformFeedbacks(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteTransformFeedbacks(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteVertexArrays(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteVertexArrays(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDrawArraysInstanced(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawBuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawBuffers(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawElementsInstanced(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawElementsInstanced(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawRangeElements(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawRangeElements(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glEndQuery(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glEndTransformFeedback() -> None: ...
    @staticmethod
    def glFenceSync(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def glFlushMappedBufferRange(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glFramebufferTextureLayer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenQueries(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenQueries(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenSamplers(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenSamplers(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenTransformFeedbacks(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenTransformFeedbacks(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenVertexArrays(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenVertexArrays(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetActiveUniformBlockName(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetActiveUniformBlockName(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.Buffer, arg4: java.nio.Buffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetActiveUniformBlockName(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, arg6: java.chaquopy.JavaArrayJByte, arg7: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetActiveUniformBlockiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetActiveUniformBlockiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetActiveUniformsiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, arg4: int | java.jint | java.lang.Integer, arg5: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetActiveUniformsiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: java.chaquopy.JavaArrayJInt, arg7: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetBufferParameteri64v(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.LongBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetBufferParameteri64v(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJLong, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGetBufferPointerv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> java.nio.Buffer: ...
    @staticmethod
    def glGetFragDataLocation(arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, /) -> int: ...
    @typing.overload
    @staticmethod
    def glGetInteger64i_v(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.LongBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetInteger64i_v(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJLong, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetInteger64v(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.LongBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetInteger64v(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJLong, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetIntegeri_v(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetIntegeri_v(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetInternalformativ(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetInternalformativ(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJInt, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetProgramBinary(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, arg4: java.nio.IntBuffer, arg5: java.nio.Buffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetProgramBinary(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJInt, arg6: int | java.jint | java.lang.Integer, arg7: java.nio.Buffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetQueryObjectuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetQueryObjectuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetQueryiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetQueryiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetSamplerParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetSamplerParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetSamplerParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetSamplerParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGetStringi(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetSynciv(arg1: int | java.jlong | java.lang.Long, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, arg5: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetSynciv(arg1: int | java.jlong | java.lang.Long, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, arg6: java.chaquopy.JavaArrayJInt, arg7: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTransformFeedbackVarying(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, arg4: java.nio.IntBuffer, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetTransformFeedbackVarying(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJInt, arg6: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetTransformFeedbackVarying(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, arg5: java.nio.IntBuffer, arg6: java.nio.IntBuffer, arg7: int | java.jbyte | java.lang.Byte, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTransformFeedbackVarying(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, arg5: java.nio.IntBuffer, arg6: java.nio.IntBuffer, arg7: java.nio.ByteBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTransformFeedbackVarying(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, arg6: java.chaquopy.JavaArrayJInt, arg7: int | java.jint | java.lang.Integer, arg8: java.chaquopy.JavaArrayJInt, arg9: int | java.jint | java.lang.Integer, arg10: java.chaquopy.JavaArrayJByte, arg11: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGetUniformBlockIndex(arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, /) -> int: ...
    @typing.overload
    @staticmethod
    def glGetUniformIndices(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArray[java.lang.String], arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetUniformIndices(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArray[java.lang.String], arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetUniformuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetUniformuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetVertexAttribIiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetVertexAttribIiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetVertexAttribIuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetVertexAttribIuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glInvalidateFramebuffer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glInvalidateFramebuffer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glInvalidateSubFramebuffer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glInvalidateSubFramebuffer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glIsQuery(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glIsSampler(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glIsSync(arg1: int | java.jlong | java.lang.Long, /) -> bool: ...
    @staticmethod
    def glIsTransformFeedback(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glIsVertexArray(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glMapBufferRange(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> java.nio.Buffer: ...
    @staticmethod
    def glPauseTransformFeedback() -> None: ...
    @staticmethod
    def glProgramBinary(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.Buffer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glProgramParameteri(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glReadBuffer(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glReadPixels(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glRenderbufferStorageMultisample(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glResumeTransformFeedback() -> None: ...
    @staticmethod
    def glSamplerParameterf(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glSamplerParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glSamplerParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glSamplerParameteri(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glSamplerParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glSamplerParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexImage3D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: int | java.jint | java.lang.Integer, arg10: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexImage3D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: int | java.jint | java.lang.Integer, arg10: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glTexStorage2D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexStorage3D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexSubImage3D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: int | java.jint | java.lang.Integer, arg10: int | java.jint | java.lang.Integer, arg11: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexSubImage3D(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: int | java.jint | java.lang.Integer, arg10: int | java.jint | java.lang.Integer, arg11: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glTransformFeedbackVaryings(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArray[java.lang.String], arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glUniform1ui(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform1uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform1uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glUniform2ui(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform2uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform2uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glUniform3ui(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform3uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform3uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glUniform4ui(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform4uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniform4uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glUniformBlockBinding(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix2x3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix2x3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix2x4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix2x4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix3x2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix3x2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix3x4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix3x4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix4x2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix4x2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix4x3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glUniformMatrix4x3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glUnmapBuffer(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glVertexAttribDivisor(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glVertexAttribI4i(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttribI4iv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttribI4iv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glVertexAttribI4ui(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttribI4uiv(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttribI4uiv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttribIPointer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glVertexAttribIPointer(index: int | java.jint | java.lang.Integer, size: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, stride: int | java.jint | java.lang.Integer, pointer: java.nio.Buffer, /) -> None: ...
    @staticmethod
    def glWaitSync(arg1: int | java.jlong | java.lang.Long, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jlong | java.lang.Long, /) -> None: ...

class GLES31(GLES30):
    GL_ACTIVE_ATOMIC_COUNTER_BUFFERS: typing.ClassVar[int] = ...
    GL_ACTIVE_PROGRAM: typing.ClassVar[int] = ...
    GL_ACTIVE_RESOURCES: typing.ClassVar[int] = ...
    GL_ACTIVE_VARIABLES: typing.ClassVar[int] = ...
    GL_ALL_BARRIER_BITS: typing.ClassVar[int] = ...
    GL_ALL_SHADER_BITS: typing.ClassVar[int] = ...
    GL_ARRAY_SIZE: typing.ClassVar[int] = ...
    GL_ARRAY_STRIDE: typing.ClassVar[int] = ...
    GL_ATOMIC_COUNTER_BARRIER_BIT: typing.ClassVar[int] = ...
    GL_ATOMIC_COUNTER_BUFFER: typing.ClassVar[int] = ...
    GL_ATOMIC_COUNTER_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_ATOMIC_COUNTER_BUFFER_INDEX: typing.ClassVar[int] = ...
    GL_ATOMIC_COUNTER_BUFFER_SIZE: typing.ClassVar[int] = ...
    GL_ATOMIC_COUNTER_BUFFER_START: typing.ClassVar[int] = ...
    GL_BLOCK_INDEX: typing.ClassVar[int] = ...
    GL_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_BUFFER_DATA_SIZE: typing.ClassVar[int] = ...
    GL_BUFFER_UPDATE_BARRIER_BIT: typing.ClassVar[int] = ...
    GL_BUFFER_VARIABLE: typing.ClassVar[int] = ...
    GL_COMMAND_BARRIER_BIT: typing.ClassVar[int] = ...
    GL_COMPUTE_SHADER: typing.ClassVar[int] = ...
    GL_COMPUTE_SHADER_BIT: typing.ClassVar[int] = ...
    GL_COMPUTE_WORK_GROUP_SIZE: typing.ClassVar[int] = ...
    GL_DEPTH_STENCIL_TEXTURE_MODE: typing.ClassVar[int] = ...
    GL_DISPATCH_INDIRECT_BUFFER: typing.ClassVar[int] = ...
    GL_DISPATCH_INDIRECT_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_DRAW_INDIRECT_BUFFER: typing.ClassVar[int] = ...
    GL_DRAW_INDIRECT_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_ELEMENT_ARRAY_BARRIER_BIT: typing.ClassVar[int] = ...
    GL_FRAGMENT_SHADER_BIT: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_BARRIER_BIT: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_DEFAULT_HEIGHT: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_DEFAULT_SAMPLES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_DEFAULT_WIDTH: typing.ClassVar[int] = ...
    GL_IMAGE_2D: typing.ClassVar[int] = ...
    GL_IMAGE_2D_ARRAY: typing.ClassVar[int] = ...
    GL_IMAGE_3D: typing.ClassVar[int] = ...
    GL_IMAGE_BINDING_ACCESS: typing.ClassVar[int] = ...
    GL_IMAGE_BINDING_FORMAT: typing.ClassVar[int] = ...
    GL_IMAGE_BINDING_LAYER: typing.ClassVar[int] = ...
    GL_IMAGE_BINDING_LAYERED: typing.ClassVar[int] = ...
    GL_IMAGE_BINDING_LEVEL: typing.ClassVar[int] = ...
    GL_IMAGE_BINDING_NAME: typing.ClassVar[int] = ...
    GL_IMAGE_CUBE: typing.ClassVar[int] = ...
    GL_IMAGE_FORMAT_COMPATIBILITY_BY_CLASS: typing.ClassVar[int] = ...
    GL_IMAGE_FORMAT_COMPATIBILITY_BY_SIZE: typing.ClassVar[int] = ...
    GL_IMAGE_FORMAT_COMPATIBILITY_TYPE: typing.ClassVar[int] = ...
    GL_INT_IMAGE_2D: typing.ClassVar[int] = ...
    GL_INT_IMAGE_2D_ARRAY: typing.ClassVar[int] = ...
    GL_INT_IMAGE_3D: typing.ClassVar[int] = ...
    GL_INT_IMAGE_CUBE: typing.ClassVar[int] = ...
    GL_INT_SAMPLER_2D_MULTISAMPLE: typing.ClassVar[int] = ...
    GL_IS_ROW_MAJOR: typing.ClassVar[int] = ...
    GL_LOCATION: typing.ClassVar[int] = ...
    GL_MATRIX_STRIDE: typing.ClassVar[int] = ...
    GL_MAX_ATOMIC_COUNTER_BUFFER_BINDINGS: typing.ClassVar[int] = ...
    GL_MAX_ATOMIC_COUNTER_BUFFER_SIZE: typing.ClassVar[int] = ...
    GL_MAX_COLOR_TEXTURE_SAMPLES: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_ATOMIC_COUNTERS: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_ATOMIC_COUNTER_BUFFERS: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_COMPUTE_UNIFORM_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_IMAGE_UNIFORMS: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_SHADER_OUTPUT_RESOURCES: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_SHADER_STORAGE_BLOCKS: typing.ClassVar[int] = ...
    GL_MAX_COMPUTE_ATOMIC_COUNTERS: typing.ClassVar[int] = ...
    GL_MAX_COMPUTE_ATOMIC_COUNTER_BUFFERS: typing.ClassVar[int] = ...
    GL_MAX_COMPUTE_IMAGE_UNIFORMS: typing.ClassVar[int] = ...
    GL_MAX_COMPUTE_SHADER_STORAGE_BLOCKS: typing.ClassVar[int] = ...
    GL_MAX_COMPUTE_SHARED_MEMORY_SIZE: typing.ClassVar[int] = ...
    GL_MAX_COMPUTE_TEXTURE_IMAGE_UNITS: typing.ClassVar[int] = ...
    GL_MAX_COMPUTE_UNIFORM_BLOCKS: typing.ClassVar[int] = ...
    GL_MAX_COMPUTE_UNIFORM_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_COMPUTE_WORK_GROUP_COUNT: typing.ClassVar[int] = ...
    GL_MAX_COMPUTE_WORK_GROUP_INVOCATIONS: typing.ClassVar[int] = ...
    GL_MAX_COMPUTE_WORK_GROUP_SIZE: typing.ClassVar[int] = ...
    GL_MAX_DEPTH_TEXTURE_SAMPLES: typing.ClassVar[int] = ...
    GL_MAX_FRAGMENT_ATOMIC_COUNTERS: typing.ClassVar[int] = ...
    GL_MAX_FRAGMENT_ATOMIC_COUNTER_BUFFERS: typing.ClassVar[int] = ...
    GL_MAX_FRAGMENT_IMAGE_UNIFORMS: typing.ClassVar[int] = ...
    GL_MAX_FRAGMENT_SHADER_STORAGE_BLOCKS: typing.ClassVar[int] = ...
    GL_MAX_FRAMEBUFFER_HEIGHT: typing.ClassVar[int] = ...
    GL_MAX_FRAMEBUFFER_SAMPLES: typing.ClassVar[int] = ...
    GL_MAX_FRAMEBUFFER_WIDTH: typing.ClassVar[int] = ...
    GL_MAX_IMAGE_UNITS: typing.ClassVar[int] = ...
    GL_MAX_INTEGER_SAMPLES: typing.ClassVar[int] = ...
    GL_MAX_NAME_LENGTH: typing.ClassVar[int] = ...
    GL_MAX_NUM_ACTIVE_VARIABLES: typing.ClassVar[int] = ...
    GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET: typing.ClassVar[int] = ...
    GL_MAX_SAMPLE_MASK_WORDS: typing.ClassVar[int] = ...
    GL_MAX_SHADER_STORAGE_BLOCK_SIZE: typing.ClassVar[int] = ...
    GL_MAX_SHADER_STORAGE_BUFFER_BINDINGS: typing.ClassVar[int] = ...
    GL_MAX_UNIFORM_LOCATIONS: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_ATOMIC_COUNTERS: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_ATOMIC_COUNTER_BUFFERS: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_ATTRIB_BINDINGS: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_ATTRIB_RELATIVE_OFFSET: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_ATTRIB_STRIDE: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_IMAGE_UNIFORMS: typing.ClassVar[int] = ...
    GL_MAX_VERTEX_SHADER_STORAGE_BLOCKS: typing.ClassVar[int] = ...
    GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET: typing.ClassVar[int] = ...
    GL_NAME_LENGTH: typing.ClassVar[int] = ...
    GL_NUM_ACTIVE_VARIABLES: typing.ClassVar[int] = ...
    GL_OFFSET: typing.ClassVar[int] = ...
    GL_PIXEL_BUFFER_BARRIER_BIT: typing.ClassVar[int] = ...
    GL_PROGRAM_INPUT: typing.ClassVar[int] = ...
    GL_PROGRAM_OUTPUT: typing.ClassVar[int] = ...
    GL_PROGRAM_PIPELINE_BINDING: typing.ClassVar[int] = ...
    GL_PROGRAM_SEPARABLE: typing.ClassVar[int] = ...
    GL_READ_ONLY: typing.ClassVar[int] = ...
    GL_READ_WRITE: typing.ClassVar[int] = ...
    GL_REFERENCED_BY_COMPUTE_SHADER: typing.ClassVar[int] = ...
    GL_REFERENCED_BY_FRAGMENT_SHADER: typing.ClassVar[int] = ...
    GL_REFERENCED_BY_VERTEX_SHADER: typing.ClassVar[int] = ...
    GL_SAMPLER_2D_MULTISAMPLE: typing.ClassVar[int] = ...
    GL_SAMPLE_MASK: typing.ClassVar[int] = ...
    GL_SAMPLE_MASK_VALUE: typing.ClassVar[int] = ...
    GL_SAMPLE_POSITION: typing.ClassVar[int] = ...
    GL_SHADER_IMAGE_ACCESS_BARRIER_BIT: typing.ClassVar[int] = ...
    GL_SHADER_STORAGE_BARRIER_BIT: typing.ClassVar[int] = ...
    GL_SHADER_STORAGE_BLOCK: typing.ClassVar[int] = ...
    GL_SHADER_STORAGE_BUFFER: typing.ClassVar[int] = ...
    GL_SHADER_STORAGE_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_SHADER_STORAGE_BUFFER_OFFSET_ALIGNMENT: typing.ClassVar[int] = ...
    GL_SHADER_STORAGE_BUFFER_SIZE: typing.ClassVar[int] = ...
    GL_SHADER_STORAGE_BUFFER_START: typing.ClassVar[int] = ...
    GL_STENCIL_INDEX: typing.ClassVar[int] = ...
    GL_TEXTURE_2D_MULTISAMPLE: typing.ClassVar[int] = ...
    GL_TEXTURE_ALPHA_SIZE: typing.ClassVar[int] = ...
    GL_TEXTURE_ALPHA_TYPE: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_2D_MULTISAMPLE: typing.ClassVar[int] = ...
    GL_TEXTURE_BLUE_SIZE: typing.ClassVar[int] = ...
    GL_TEXTURE_BLUE_TYPE: typing.ClassVar[int] = ...
    GL_TEXTURE_COMPRESSED: typing.ClassVar[int] = ...
    GL_TEXTURE_DEPTH: typing.ClassVar[int] = ...
    GL_TEXTURE_DEPTH_SIZE: typing.ClassVar[int] = ...
    GL_TEXTURE_DEPTH_TYPE: typing.ClassVar[int] = ...
    GL_TEXTURE_FETCH_BARRIER_BIT: typing.ClassVar[int] = ...
    GL_TEXTURE_FIXED_SAMPLE_LOCATIONS: typing.ClassVar[int] = ...
    GL_TEXTURE_GREEN_SIZE: typing.ClassVar[int] = ...
    GL_TEXTURE_GREEN_TYPE: typing.ClassVar[int] = ...
    GL_TEXTURE_HEIGHT: typing.ClassVar[int] = ...
    GL_TEXTURE_INTERNAL_FORMAT: typing.ClassVar[int] = ...
    GL_TEXTURE_RED_SIZE: typing.ClassVar[int] = ...
    GL_TEXTURE_RED_TYPE: typing.ClassVar[int] = ...
    GL_TEXTURE_SAMPLES: typing.ClassVar[int] = ...
    GL_TEXTURE_SHARED_SIZE: typing.ClassVar[int] = ...
    GL_TEXTURE_STENCIL_SIZE: typing.ClassVar[int] = ...
    GL_TEXTURE_UPDATE_BARRIER_BIT: typing.ClassVar[int] = ...
    GL_TEXTURE_WIDTH: typing.ClassVar[int] = ...
    GL_TOP_LEVEL_ARRAY_SIZE: typing.ClassVar[int] = ...
    GL_TOP_LEVEL_ARRAY_STRIDE: typing.ClassVar[int] = ...
    GL_TRANSFORM_FEEDBACK_BARRIER_BIT: typing.ClassVar[int] = ...
    GL_TRANSFORM_FEEDBACK_VARYING: typing.ClassVar[int] = ...
    GL_TYPE: typing.ClassVar[int] = ...
    GL_UNIFORM: typing.ClassVar[int] = ...
    GL_UNIFORM_BARRIER_BIT: typing.ClassVar[int] = ...
    GL_UNIFORM_BLOCK: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_ATOMIC_COUNTER: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_IMAGE_2D: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_IMAGE_2D_ARRAY: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_IMAGE_3D: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_IMAGE_CUBE: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE: typing.ClassVar[int] = ...
    GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT: typing.ClassVar[int] = ...
    GL_VERTEX_ATTRIB_BINDING: typing.ClassVar[int] = ...
    GL_VERTEX_ATTRIB_RELATIVE_OFFSET: typing.ClassVar[int] = ...
    GL_VERTEX_BINDING_BUFFER: typing.ClassVar[int] = ...
    GL_VERTEX_BINDING_DIVISOR: typing.ClassVar[int] = ...
    GL_VERTEX_BINDING_OFFSET: typing.ClassVar[int] = ...
    GL_VERTEX_BINDING_STRIDE: typing.ClassVar[int] = ...
    GL_VERTEX_SHADER_BIT: typing.ClassVar[int] = ...
    GL_WRITE_ONLY: typing.ClassVar[int] = ...
    @staticmethod
    def glActiveShaderProgram(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindImageTexture(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindProgramPipeline(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBindVertexBuffer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jlong | java.lang.Long, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glCreateShaderProgramv(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    @typing.overload
    @staticmethod
    def glDeleteProgramPipelines(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDeleteProgramPipelines(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDispatchCompute(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDispatchComputeIndirect(arg1: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def glDrawArraysIndirect(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def glDrawElementsIndirect(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def glFramebufferParameteri(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenProgramPipelines(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGenProgramPipelines(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetBooleani_v(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetBooleani_v(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJBoolean, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetFramebufferParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetFramebufferParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetMultisamplefv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetMultisamplefv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetProgramInterfaceiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetProgramInterfaceiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGetProgramPipelineInfoLog(arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetProgramPipelineiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetProgramPipelineiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGetProgramResourceIndex(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: str | java.lang.String, /) -> int: ...
    @staticmethod
    def glGetProgramResourceLocation(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: str | java.lang.String, /) -> int: ...
    @staticmethod
    def glGetProgramResourceName(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetProgramResourceiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: java.nio.IntBuffer, arg6: int | java.jint | java.lang.Integer, arg7: java.nio.IntBuffer, arg8: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetProgramResourceiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJInt, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: java.chaquopy.JavaArrayJInt, arg9: int | java.jint | java.lang.Integer, arg10: java.chaquopy.JavaArrayJInt, arg11: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexLevelParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexLevelParameterfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexLevelParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexLevelParameteriv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glIsProgramPipeline(arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glMemoryBarrier(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glMemoryBarrierByRegion(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glProgramUniform1f(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform1fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform1fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glProgramUniform1i(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform1iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform1iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glProgramUniform1ui(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform1uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform1uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glProgramUniform2f(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glProgramUniform2i(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform2iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform2iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glProgramUniform2ui(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform2uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform2uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glProgramUniform3f(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glProgramUniform3i(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform3iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform3iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glProgramUniform3ui(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform3uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform3uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glProgramUniform4f(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, arg6: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glProgramUniform4i(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform4iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform4iv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glProgramUniform4ui(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform4uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniform4uiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.chaquopy.JavaArrayJFloat, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix2x3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix2x3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.chaquopy.JavaArrayJFloat, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix2x4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix2x4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.chaquopy.JavaArrayJFloat, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.chaquopy.JavaArrayJFloat, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix3x2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix3x2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.chaquopy.JavaArrayJFloat, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix3x4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix3x4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.chaquopy.JavaArrayJFloat, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix4fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.chaquopy.JavaArrayJFloat, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix4x2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix4x2fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.chaquopy.JavaArrayJFloat, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix4x3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glProgramUniformMatrix4x3fv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: java.chaquopy.JavaArrayJFloat, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glSampleMaski(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexStorage2DMultisample(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def glUseProgramStages(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glValidateProgramPipeline(arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glVertexAttribBinding(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glVertexAttribFormat(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glVertexAttribIFormat(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glVertexBindingDivisor(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

class GLES31Ext(java.lang.Object):
    GL_BLEND_ADVANCED_COHERENT_KHR: typing.ClassVar[int] = ...
    GL_BUFFER_KHR: typing.ClassVar[int] = ...
    GL_CLAMP_TO_BORDER_EXT: typing.ClassVar[int] = ...
    GL_COLORBURN_KHR: typing.ClassVar[int] = ...
    GL_COLORDODGE_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_10x10_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_10x5_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_10x6_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_10x8_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_12x10_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_12x12_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_4x4_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_5x4_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_5x5_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_6x5_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_6x6_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_8x5_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_8x6_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_8x8_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR: typing.ClassVar[int] = ...
    GL_CONTEXT_FLAG_DEBUG_BIT_KHR: typing.ClassVar[int] = ...
    GL_DARKEN_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_CALLBACK_FUNCTION_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_CALLBACK_USER_PARAM_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_GROUP_STACK_DEPTH_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_LOGGED_MESSAGES_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_OUTPUT_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_OUTPUT_SYNCHRONOUS_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_SEVERITY_HIGH_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_SEVERITY_LOW_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_SEVERITY_MEDIUM_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_SEVERITY_NOTIFICATION_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_SOURCE_API_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_SOURCE_APPLICATION_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_SOURCE_OTHER_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_SOURCE_SHADER_COMPILER_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_SOURCE_THIRD_PARTY_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_SOURCE_WINDOW_SYSTEM_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_ERROR_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_MARKER_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_OTHER_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_PERFORMANCE_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_POP_GROUP_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_PORTABILITY_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_PUSH_GROUP_KHR: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR_KHR: typing.ClassVar[int] = ...
    GL_DECODE_EXT: typing.ClassVar[int] = ...
    GL_DIFFERENCE_KHR: typing.ClassVar[int] = ...
    GL_EXCLUSION_KHR: typing.ClassVar[int] = ...
    GL_FIRST_VERTEX_CONVENTION_EXT: typing.ClassVar[int] = ...
    GL_FRACTIONAL_EVEN_EXT: typing.ClassVar[int] = ...
    GL_FRACTIONAL_ODD_EXT: typing.ClassVar[int] = ...
    GL_FRAGMENT_INTERPOLATION_OFFSET_BITS_OES: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_LAYERED_EXT: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_DEFAULT_LAYERS_EXT: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_EXT: typing.ClassVar[int] = ...
    GL_GEOMETRY_LINKED_INPUT_TYPE_EXT: typing.ClassVar[int] = ...
    GL_GEOMETRY_LINKED_OUTPUT_TYPE_EXT: typing.ClassVar[int] = ...
    GL_GEOMETRY_LINKED_VERTICES_OUT_EXT: typing.ClassVar[int] = ...
    GL_GEOMETRY_SHADER_BIT_EXT: typing.ClassVar[int] = ...
    GL_GEOMETRY_SHADER_EXT: typing.ClassVar[int] = ...
    GL_GEOMETRY_SHADER_INVOCATIONS_EXT: typing.ClassVar[int] = ...
    GL_HARDLIGHT_KHR: typing.ClassVar[int] = ...
    GL_HSL_COLOR_KHR: typing.ClassVar[int] = ...
    GL_HSL_HUE_KHR: typing.ClassVar[int] = ...
    GL_HSL_LUMINOSITY_KHR: typing.ClassVar[int] = ...
    GL_HSL_SATURATION_KHR: typing.ClassVar[int] = ...
    GL_IMAGE_BUFFER_EXT: typing.ClassVar[int] = ...
    GL_IMAGE_CUBE_MAP_ARRAY_EXT: typing.ClassVar[int] = ...
    GL_INT_IMAGE_BUFFER_EXT: typing.ClassVar[int] = ...
    GL_INT_IMAGE_CUBE_MAP_ARRAY_EXT: typing.ClassVar[int] = ...
    GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY_OES: typing.ClassVar[int] = ...
    GL_INT_SAMPLER_BUFFER_EXT: typing.ClassVar[int] = ...
    GL_INT_SAMPLER_CUBE_MAP_ARRAY_EXT: typing.ClassVar[int] = ...
    GL_ISOLINES_EXT: typing.ClassVar[int] = ...
    GL_IS_PER_PATCH_EXT: typing.ClassVar[int] = ...
    GL_LAST_VERTEX_CONVENTION_EXT: typing.ClassVar[int] = ...
    GL_LAYER_PROVOKING_VERTEX_EXT: typing.ClassVar[int] = ...
    GL_LIGHTEN_KHR: typing.ClassVar[int] = ...
    GL_LINES_ADJACENCY_EXT: typing.ClassVar[int] = ...
    GL_LINE_STRIP_ADJACENCY_EXT: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_TESS_CONTROL_UNIFORM_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_TESS_EVALUATION_UNIFORM_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_DEBUG_GROUP_STACK_DEPTH_KHR: typing.ClassVar[int] = ...
    GL_MAX_DEBUG_LOGGED_MESSAGES_KHR: typing.ClassVar[int] = ...
    GL_MAX_DEBUG_MESSAGE_LENGTH_KHR: typing.ClassVar[int] = ...
    GL_MAX_FRAGMENT_INTERPOLATION_OFFSET_OES: typing.ClassVar[int] = ...
    GL_MAX_FRAMEBUFFER_LAYERS_EXT: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_ATOMIC_COUNTERS_EXT: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_ATOMIC_COUNTER_BUFFERS_EXT: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_IMAGE_UNIFORMS_EXT: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_INPUT_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_OUTPUT_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_OUTPUT_VERTICES_EXT: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_SHADER_INVOCATIONS_EXT: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS_EXT: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_EXT: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_UNIFORM_BLOCKS_EXT: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_LABEL_LENGTH_KHR: typing.ClassVar[int] = ...
    GL_MAX_PATCH_VERTICES_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_IMAGE_UNIFORMS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_INPUT_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_OUTPUT_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_TEXTURE_IMAGE_UNITS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_TOTAL_OUTPUT_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_UNIFORM_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_IMAGE_UNIFORMS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_INPUT_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_OUTPUT_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_TEXTURE_IMAGE_UNITS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_UNIFORM_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_GEN_LEVEL_EXT: typing.ClassVar[int] = ...
    GL_MAX_TESS_PATCH_COMPONENTS_EXT: typing.ClassVar[int] = ...
    GL_MAX_TEXTURE_BUFFER_SIZE_EXT: typing.ClassVar[int] = ...
    GL_MIN_FRAGMENT_INTERPOLATION_OFFSET_OES: typing.ClassVar[int] = ...
    GL_MIN_SAMPLE_SHADING_VALUE_OES: typing.ClassVar[int] = ...
    GL_MULTIPLY_KHR: typing.ClassVar[int] = ...
    GL_OVERLAY_KHR: typing.ClassVar[int] = ...
    GL_PATCHES_EXT: typing.ClassVar[int] = ...
    GL_PATCH_VERTICES_EXT: typing.ClassVar[int] = ...
    GL_PRIMITIVES_GENERATED_EXT: typing.ClassVar[int] = ...
    GL_PRIMITIVE_BOUNDING_BOX_EXT: typing.ClassVar[int] = ...
    GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED: typing.ClassVar[int] = ...
    GL_PROGRAM_KHR: typing.ClassVar[int] = ...
    GL_QUADS_EXT: typing.ClassVar[int] = ...
    GL_QUERY_KHR: typing.ClassVar[int] = ...
    GL_REFERENCED_BY_GEOMETRY_SHADER_EXT: typing.ClassVar[int] = ...
    GL_REFERENCED_BY_TESS_CONTROL_SHADER_EXT: typing.ClassVar[int] = ...
    GL_REFERENCED_BY_TESS_EVALUATION_SHADER_EXT: typing.ClassVar[int] = ...
    GL_SAMPLER_2D_MULTISAMPLE_ARRAY_OES: typing.ClassVar[int] = ...
    GL_SAMPLER_BUFFER_EXT: typing.ClassVar[int] = ...
    GL_SAMPLER_CUBE_MAP_ARRAY_EXT: typing.ClassVar[int] = ...
    GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW_EXT: typing.ClassVar[int] = ...
    GL_SAMPLER_KHR: typing.ClassVar[int] = ...
    GL_SAMPLE_SHADING_OES: typing.ClassVar[int] = ...
    GL_SCREEN_KHR: typing.ClassVar[int] = ...
    GL_SHADER_KHR: typing.ClassVar[int] = ...
    GL_SKIP_DECODE_EXT: typing.ClassVar[int] = ...
    GL_SOFTLIGHT_KHR: typing.ClassVar[int] = ...
    GL_STACK_OVERFLOW_KHR: typing.ClassVar[int] = ...
    GL_STACK_UNDERFLOW_KHR: typing.ClassVar[int] = ...
    GL_STENCIL_INDEX8_OES: typing.ClassVar[int] = ...
    GL_STENCIL_INDEX_OES: typing.ClassVar[int] = ...
    GL_TESS_CONTROL_OUTPUT_VERTICES_EXT: typing.ClassVar[int] = ...
    GL_TESS_CONTROL_SHADER_BIT_EXT: typing.ClassVar[int] = ...
    GL_TESS_CONTROL_SHADER_EXT: typing.ClassVar[int] = ...
    GL_TESS_EVALUATION_SHADER_BIT_EXT: typing.ClassVar[int] = ...
    GL_TESS_EVALUATION_SHADER_EXT: typing.ClassVar[int] = ...
    GL_TESS_GEN_MODE_EXT: typing.ClassVar[int] = ...
    GL_TESS_GEN_POINT_MODE_EXT: typing.ClassVar[int] = ...
    GL_TESS_GEN_SPACING_EXT: typing.ClassVar[int] = ...
    GL_TESS_GEN_VERTEX_ORDER_EXT: typing.ClassVar[int] = ...
    GL_TEXTURE_2D_MULTISAMPLE_ARRAY_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY_OES: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_BUFFER_EXT: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_CUBE_MAP_ARRAY_EXT: typing.ClassVar[int] = ...
    GL_TEXTURE_BORDER_COLOR_EXT: typing.ClassVar[int] = ...
    GL_TEXTURE_BUFFER_BINDING_EXT: typing.ClassVar[int] = ...
    GL_TEXTURE_BUFFER_DATA_STORE_BINDING_EXT: typing.ClassVar[int] = ...
    GL_TEXTURE_BUFFER_EXT: typing.ClassVar[int] = ...
    GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT_EXT: typing.ClassVar[int] = ...
    GL_TEXTURE_BUFFER_OFFSET_EXT: typing.ClassVar[int] = ...
    GL_TEXTURE_BUFFER_SIZE_EXT: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_ARRAY_EXT: typing.ClassVar[int] = ...
    GL_TEXTURE_SRGB_DECODE_EXT: typing.ClassVar[int] = ...
    GL_TRIANGLES_ADJACENCY_EXT: typing.ClassVar[int] = ...
    GL_TRIANGLE_STRIP_ADJACENCY_EXT: typing.ClassVar[int] = ...
    GL_UNDEFINED_VERTEX_EXT: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_IMAGE_BUFFER_EXT: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY_EXT: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY_OES: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_SAMPLER_BUFFER_EXT: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY_EXT: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY_KHR: typing.ClassVar[int] = ...
    @staticmethod
    def glBlendBarrierKHR() -> None: ...
    @staticmethod
    def glBlendEquationSeparateiEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlendEquationiEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlendFuncSeparateiEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlendFunciEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glColorMaskiEXT(arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, arg3: bool | java.jboolean | java.lang.Boolean, arg4: bool | java.jboolean | java.lang.Boolean, arg5: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def glCopyImageSubDataEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: int | java.jint | java.lang.Integer, arg10: int | java.jint | java.lang.Integer, arg11: int | java.jint | java.lang.Integer, arg12: int | java.jint | java.lang.Integer, arg13: int | java.jint | java.lang.Integer, arg14: int | java.jint | java.lang.Integer, arg15: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDebugMessageCallbackKHR(arg1: GLES31Ext.DebugProcKHR, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDebugMessageControlKHR(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: java.nio.IntBuffer, arg6: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDebugMessageControlKHR(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJInt, arg6: int | java.jint | java.lang.Integer, arg7: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def glDebugMessageInsertKHR(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: str | java.lang.String, /) -> None: ...
    @staticmethod
    def glDisableiEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glEnableiEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glFramebufferTextureEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glGetDebugMessageCallbackKHR() -> GLES31Ext.DebugProcKHR: ...
    @typing.overload
    @staticmethod
    def glGetDebugMessageLogKHR(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, arg3: java.nio.IntBuffer, arg4: java.nio.IntBuffer, arg5: java.nio.IntBuffer, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @typing.overload
    @staticmethod
    def glGetDebugMessageLogKHR(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, arg3: java.nio.IntBuffer, arg4: java.nio.IntBuffer, arg5: java.nio.IntBuffer, arg6: java.nio.IntBuffer, arg7: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    @staticmethod
    def glGetDebugMessageLogKHR(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, arg6: java.chaquopy.JavaArrayJInt, arg7: int | java.jint | java.lang.Integer, arg8: java.chaquopy.JavaArrayJInt, arg9: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @typing.overload
    @staticmethod
    def glGetDebugMessageLogKHR(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJInt, arg6: int | java.jint | java.lang.Integer, arg7: java.chaquopy.JavaArrayJInt, arg8: int | java.jint | java.lang.Integer, arg9: java.chaquopy.JavaArrayJInt, arg10: int | java.jint | java.lang.Integer, arg11: java.chaquopy.JavaArrayJInt, arg12: int | java.jint | java.lang.Integer, arg13: java.chaquopy.JavaArrayJByte, arg14: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def glGetObjectLabelKHR(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def glGetObjectPtrLabelKHR(arg1: int | java.jlong | java.lang.Long, /) -> str: ...
    @typing.overload
    @staticmethod
    def glGetSamplerParameterIivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetSamplerParameterIivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetSamplerParameterIuivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetSamplerParameterIuivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterIivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterIivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterIuivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterIuivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glIsEnablediEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glMinSampleShadingOES(arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glObjectLabelKHR(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: str | java.lang.String, /) -> None: ...
    @staticmethod
    def glObjectPtrLabelKHR(arg1: int | java.jlong | java.lang.Long, arg2: str | java.lang.String, /) -> None: ...
    @staticmethod
    def glPatchParameteriEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glPopDebugGroupKHR() -> None: ...
    @staticmethod
    def glPrimitiveBoundingBoxEXT(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, arg6: float | java.jfloat | java.lang.Float, arg7: float | java.jfloat | java.lang.Float, arg8: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glPushDebugGroupKHR(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: str | java.lang.String, /) -> None: ...
    @typing.overload
    @staticmethod
    def glSamplerParameterIivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glSamplerParameterIivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glSamplerParameterIuivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glSamplerParameterIuivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexBufferEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexBufferRangeEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterIivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterIivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterIuivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterIuivEXT(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexStorage3DMultisampleOES(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class DebugProcKHR(java.lang.Object):
        def onMessage(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: str | java.lang.String, /) -> None: ...

class GLES32(GLES31):
    GL_BUFFER: typing.ClassVar[int] = ...
    GL_CLAMP_TO_BORDER: typing.ClassVar[int] = ...
    GL_COLORBURN: typing.ClassVar[int] = ...
    GL_COLORDODGE: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_10x10: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_10x5: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_10x6: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_10x8: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_12x10: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_12x12: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_4x4: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_5x4: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_5x5: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_6x5: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_6x6: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_8x5: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_8x6: typing.ClassVar[int] = ...
    GL_COMPRESSED_RGBA_ASTC_8x8: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6: typing.ClassVar[int] = ...
    GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8: typing.ClassVar[int] = ...
    GL_CONTEXT_FLAGS: typing.ClassVar[int] = ...
    GL_CONTEXT_FLAG_DEBUG_BIT: typing.ClassVar[int] = ...
    GL_CONTEXT_FLAG_ROBUST_ACCESS_BIT: typing.ClassVar[int] = ...
    GL_CONTEXT_LOST: typing.ClassVar[int] = ...
    GL_DARKEN: typing.ClassVar[int] = ...
    GL_DEBUG_CALLBACK_FUNCTION: typing.ClassVar[int] = ...
    GL_DEBUG_CALLBACK_USER_PARAM: typing.ClassVar[int] = ...
    GL_DEBUG_GROUP_STACK_DEPTH: typing.ClassVar[int] = ...
    GL_DEBUG_LOGGED_MESSAGES: typing.ClassVar[int] = ...
    GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH: typing.ClassVar[int] = ...
    GL_DEBUG_OUTPUT: typing.ClassVar[int] = ...
    GL_DEBUG_OUTPUT_SYNCHRONOUS: typing.ClassVar[int] = ...
    GL_DEBUG_SEVERITY_HIGH: typing.ClassVar[int] = ...
    GL_DEBUG_SEVERITY_LOW: typing.ClassVar[int] = ...
    GL_DEBUG_SEVERITY_MEDIUM: typing.ClassVar[int] = ...
    GL_DEBUG_SEVERITY_NOTIFICATION: typing.ClassVar[int] = ...
    GL_DEBUG_SOURCE_API: typing.ClassVar[int] = ...
    GL_DEBUG_SOURCE_APPLICATION: typing.ClassVar[int] = ...
    GL_DEBUG_SOURCE_OTHER: typing.ClassVar[int] = ...
    GL_DEBUG_SOURCE_SHADER_COMPILER: typing.ClassVar[int] = ...
    GL_DEBUG_SOURCE_THIRD_PARTY: typing.ClassVar[int] = ...
    GL_DEBUG_SOURCE_WINDOW_SYSTEM: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_ERROR: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_MARKER: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_OTHER: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_PERFORMANCE: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_POP_GROUP: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_PORTABILITY: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_PUSH_GROUP: typing.ClassVar[int] = ...
    GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR: typing.ClassVar[int] = ...
    GL_DIFFERENCE: typing.ClassVar[int] = ...
    GL_EXCLUSION: typing.ClassVar[int] = ...
    GL_FIRST_VERTEX_CONVENTION: typing.ClassVar[int] = ...
    GL_FRACTIONAL_EVEN: typing.ClassVar[int] = ...
    GL_FRACTIONAL_ODD: typing.ClassVar[int] = ...
    GL_FRAGMENT_INTERPOLATION_OFFSET_BITS: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_ATTACHMENT_LAYERED: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_DEFAULT_LAYERS: typing.ClassVar[int] = ...
    GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS: typing.ClassVar[int] = ...
    GL_GEOMETRY_INPUT_TYPE: typing.ClassVar[int] = ...
    GL_GEOMETRY_OUTPUT_TYPE: typing.ClassVar[int] = ...
    GL_GEOMETRY_SHADER: typing.ClassVar[int] = ...
    GL_GEOMETRY_SHADER_BIT: typing.ClassVar[int] = ...
    GL_GEOMETRY_SHADER_INVOCATIONS: typing.ClassVar[int] = ...
    GL_GEOMETRY_VERTICES_OUT: typing.ClassVar[int] = ...
    GL_GUILTY_CONTEXT_RESET: typing.ClassVar[int] = ...
    GL_HARDLIGHT: typing.ClassVar[int] = ...
    GL_HSL_COLOR: typing.ClassVar[int] = ...
    GL_HSL_HUE: typing.ClassVar[int] = ...
    GL_HSL_LUMINOSITY: typing.ClassVar[int] = ...
    GL_HSL_SATURATION: typing.ClassVar[int] = ...
    GL_IMAGE_BUFFER: typing.ClassVar[int] = ...
    GL_IMAGE_CUBE_MAP_ARRAY: typing.ClassVar[int] = ...
    GL_INNOCENT_CONTEXT_RESET: typing.ClassVar[int] = ...
    GL_INT_IMAGE_BUFFER: typing.ClassVar[int] = ...
    GL_INT_IMAGE_CUBE_MAP_ARRAY: typing.ClassVar[int] = ...
    GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY: typing.ClassVar[int] = ...
    GL_INT_SAMPLER_BUFFER: typing.ClassVar[int] = ...
    GL_INT_SAMPLER_CUBE_MAP_ARRAY: typing.ClassVar[int] = ...
    GL_ISOLINES: typing.ClassVar[int] = ...
    GL_IS_PER_PATCH: typing.ClassVar[int] = ...
    GL_LAST_VERTEX_CONVENTION: typing.ClassVar[int] = ...
    GL_LAYER_PROVOKING_VERTEX: typing.ClassVar[int] = ...
    GL_LIGHTEN: typing.ClassVar[int] = ...
    GL_LINES_ADJACENCY: typing.ClassVar[int] = ...
    GL_LINE_STRIP_ADJACENCY: typing.ClassVar[int] = ...
    GL_LOSE_CONTEXT_ON_RESET: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_TESS_CONTROL_UNIFORM_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_COMBINED_TESS_EVALUATION_UNIFORM_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_DEBUG_GROUP_STACK_DEPTH: typing.ClassVar[int] = ...
    GL_MAX_DEBUG_LOGGED_MESSAGES: typing.ClassVar[int] = ...
    GL_MAX_DEBUG_MESSAGE_LENGTH: typing.ClassVar[int] = ...
    GL_MAX_FRAGMENT_INTERPOLATION_OFFSET: typing.ClassVar[int] = ...
    GL_MAX_FRAMEBUFFER_LAYERS: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_ATOMIC_COUNTERS: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_ATOMIC_COUNTER_BUFFERS: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_IMAGE_UNIFORMS: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_INPUT_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_OUTPUT_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_OUTPUT_VERTICES: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_SHADER_INVOCATIONS: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_UNIFORM_BLOCKS: typing.ClassVar[int] = ...
    GL_MAX_GEOMETRY_UNIFORM_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_LABEL_LENGTH: typing.ClassVar[int] = ...
    GL_MAX_PATCH_VERTICES: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_IMAGE_UNIFORMS: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_INPUT_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_OUTPUT_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_TEXTURE_IMAGE_UNITS: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_TOTAL_OUTPUT_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS: typing.ClassVar[int] = ...
    GL_MAX_TESS_CONTROL_UNIFORM_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_IMAGE_UNIFORMS: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_INPUT_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_OUTPUT_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_TEXTURE_IMAGE_UNITS: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS: typing.ClassVar[int] = ...
    GL_MAX_TESS_EVALUATION_UNIFORM_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_TESS_GEN_LEVEL: typing.ClassVar[int] = ...
    GL_MAX_TESS_PATCH_COMPONENTS: typing.ClassVar[int] = ...
    GL_MAX_TEXTURE_BUFFER_SIZE: typing.ClassVar[int] = ...
    GL_MIN_FRAGMENT_INTERPOLATION_OFFSET: typing.ClassVar[int] = ...
    GL_MIN_SAMPLE_SHADING_VALUE: typing.ClassVar[int] = ...
    GL_MULTIPLY: typing.ClassVar[int] = ...
    GL_MULTISAMPLE_LINE_WIDTH_GRANULARITY: typing.ClassVar[int] = ...
    GL_MULTISAMPLE_LINE_WIDTH_RANGE: typing.ClassVar[int] = ...
    GL_NO_RESET_NOTIFICATION: typing.ClassVar[int] = ...
    GL_OVERLAY: typing.ClassVar[int] = ...
    GL_PATCHES: typing.ClassVar[int] = ...
    GL_PATCH_VERTICES: typing.ClassVar[int] = ...
    GL_PRIMITIVES_GENERATED: typing.ClassVar[int] = ...
    GL_PRIMITIVE_BOUNDING_BOX: typing.ClassVar[int] = ...
    GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED: typing.ClassVar[int] = ...
    GL_PROGRAM: typing.ClassVar[int] = ...
    GL_PROGRAM_PIPELINE: typing.ClassVar[int] = ...
    GL_QUADS: typing.ClassVar[int] = ...
    GL_QUERY: typing.ClassVar[int] = ...
    GL_REFERENCED_BY_GEOMETRY_SHADER: typing.ClassVar[int] = ...
    GL_REFERENCED_BY_TESS_CONTROL_SHADER: typing.ClassVar[int] = ...
    GL_REFERENCED_BY_TESS_EVALUATION_SHADER: typing.ClassVar[int] = ...
    GL_RESET_NOTIFICATION_STRATEGY: typing.ClassVar[int] = ...
    GL_SAMPLER: typing.ClassVar[int] = ...
    GL_SAMPLER_2D_MULTISAMPLE_ARRAY: typing.ClassVar[int] = ...
    GL_SAMPLER_BUFFER: typing.ClassVar[int] = ...
    GL_SAMPLER_CUBE_MAP_ARRAY: typing.ClassVar[int] = ...
    GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW: typing.ClassVar[int] = ...
    GL_SAMPLE_SHADING: typing.ClassVar[int] = ...
    GL_SCREEN: typing.ClassVar[int] = ...
    GL_SHADER: typing.ClassVar[int] = ...
    GL_SOFTLIGHT: typing.ClassVar[int] = ...
    GL_STACK_OVERFLOW: typing.ClassVar[int] = ...
    GL_STACK_UNDERFLOW: typing.ClassVar[int] = ...
    GL_TESS_CONTROL_OUTPUT_VERTICES: typing.ClassVar[int] = ...
    GL_TESS_CONTROL_SHADER: typing.ClassVar[int] = ...
    GL_TESS_CONTROL_SHADER_BIT: typing.ClassVar[int] = ...
    GL_TESS_EVALUATION_SHADER: typing.ClassVar[int] = ...
    GL_TESS_EVALUATION_SHADER_BIT: typing.ClassVar[int] = ...
    GL_TESS_GEN_MODE: typing.ClassVar[int] = ...
    GL_TESS_GEN_POINT_MODE: typing.ClassVar[int] = ...
    GL_TESS_GEN_SPACING: typing.ClassVar[int] = ...
    GL_TESS_GEN_VERTEX_ORDER: typing.ClassVar[int] = ...
    GL_TEXTURE_2D_MULTISAMPLE_ARRAY: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_BUFFER: typing.ClassVar[int] = ...
    GL_TEXTURE_BINDING_CUBE_MAP_ARRAY: typing.ClassVar[int] = ...
    GL_TEXTURE_BORDER_COLOR: typing.ClassVar[int] = ...
    GL_TEXTURE_BUFFER: typing.ClassVar[int] = ...
    GL_TEXTURE_BUFFER_BINDING: typing.ClassVar[int] = ...
    GL_TEXTURE_BUFFER_DATA_STORE_BINDING: typing.ClassVar[int] = ...
    GL_TEXTURE_BUFFER_OFFSET: typing.ClassVar[int] = ...
    GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT: typing.ClassVar[int] = ...
    GL_TEXTURE_BUFFER_SIZE: typing.ClassVar[int] = ...
    GL_TEXTURE_CUBE_MAP_ARRAY: typing.ClassVar[int] = ...
    GL_TRIANGLES_ADJACENCY: typing.ClassVar[int] = ...
    GL_TRIANGLE_STRIP_ADJACENCY: typing.ClassVar[int] = ...
    GL_UNDEFINED_VERTEX: typing.ClassVar[int] = ...
    GL_UNKNOWN_CONTEXT_RESET: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_IMAGE_BUFFER: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_SAMPLER_BUFFER: typing.ClassVar[int] = ...
    GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY: typing.ClassVar[int] = ...
    GL_VERTEX_ARRAY: typing.ClassVar[int] = ...
    @staticmethod
    def glBlendBarrier() -> None: ...
    @staticmethod
    def glBlendEquationSeparatei(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlendEquationi(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlendFuncSeparatei(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glBlendFunci(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glColorMaski(arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, arg3: bool | java.jboolean | java.lang.Boolean, arg4: bool | java.jboolean | java.lang.Boolean, arg5: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def glCopyImageSubData(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: int | java.jint | java.lang.Integer, arg10: int | java.jint | java.lang.Integer, arg11: int | java.jint | java.lang.Integer, arg12: int | java.jint | java.lang.Integer, arg13: int | java.jint | java.lang.Integer, arg14: int | java.jint | java.lang.Integer, arg15: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDebugMessageCallback(arg1: GLES32.DebugProc, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDebugMessageControl(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: java.nio.IntBuffer, arg6: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDebugMessageControl(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJInt, arg6: int | java.jint | java.lang.Integer, arg7: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def glDebugMessageInsert(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: str | java.lang.String, /) -> None: ...
    @staticmethod
    def glDisablei(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDrawElementsBaseVertex(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawElementsInstancedBaseVertex(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glDrawElementsInstancedBaseVertex(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.Buffer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glDrawRangeElementsBaseVertex(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: java.nio.Buffer, arg7: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glEnablei(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glFramebufferTexture(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetDebugMessageLog(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, arg3: java.nio.IntBuffer, arg4: java.nio.IntBuffer, arg5: java.nio.IntBuffer, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @typing.overload
    @staticmethod
    def glGetDebugMessageLog(arg1: int | java.jint | java.lang.Integer, arg2: java.nio.IntBuffer, arg3: java.nio.IntBuffer, arg4: java.nio.IntBuffer, arg5: java.nio.IntBuffer, arg6: java.nio.IntBuffer, arg7: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    @staticmethod
    def glGetDebugMessageLog(arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJInt, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, arg6: java.chaquopy.JavaArrayJInt, arg7: int | java.jint | java.lang.Integer, arg8: java.chaquopy.JavaArrayJInt, arg9: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @typing.overload
    @staticmethod
    def glGetDebugMessageLog(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJInt, arg6: int | java.jint | java.lang.Integer, arg7: java.chaquopy.JavaArrayJInt, arg8: int | java.jint | java.lang.Integer, arg9: java.chaquopy.JavaArrayJInt, arg10: int | java.jint | java.lang.Integer, arg11: java.chaquopy.JavaArrayJInt, arg12: int | java.jint | java.lang.Integer, arg13: java.chaquopy.JavaArrayJByte, arg14: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def glGetGraphicsResetStatus() -> int: ...
    @staticmethod
    def glGetObjectLabel(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def glGetObjectPtrLabel(arg1: int | java.jlong | java.lang.Long, /) -> str: ...
    @staticmethod
    def glGetPointerv(arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def glGetSamplerParameterIiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetSamplerParameterIiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetSamplerParameterIuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetSamplerParameterIuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterIiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterIiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterIuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetTexParameterIuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetnUniformfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.FloatBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetnUniformfv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetnUniformiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetnUniformiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetnUniformuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glGetnUniformuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glIsEnabledi(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def glMinSampleShading(arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glObjectLabel(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: str | java.lang.String, /) -> None: ...
    @staticmethod
    def glObjectPtrLabel(arg1: int | java.jlong | java.lang.Long, arg2: str | java.lang.String, /) -> None: ...
    @staticmethod
    def glPatchParameteri(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glPopDebugGroup() -> None: ...
    @staticmethod
    def glPrimitiveBoundingBox(arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, arg5: float | java.jfloat | java.lang.Float, arg6: float | java.jfloat | java.lang.Float, arg7: float | java.jfloat | java.lang.Float, arg8: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def glPushDebugGroup(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: str | java.lang.String, /) -> None: ...
    @staticmethod
    def glReadnPixels(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: java.nio.Buffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glSamplerParameterIiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glSamplerParameterIiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glSamplerParameterIuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glSamplerParameterIuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexBuffer(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexBufferRange(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterIiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterIiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterIuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.nio.IntBuffer, /) -> None: ...
    @typing.overload
    @staticmethod
    def glTexParameterIuiv(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJInt, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def glTexStorage3DMultisample(arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class DebugProc(java.lang.Object):
        def onMessage(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: str | java.lang.String, /) -> None: ...

class GLException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self, error: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, error: int | java.jint | java.lang.Integer, string: str | java.lang.String, /) -> None: ...

class GLSurfaceView(android.view.SurfaceHolder.Callback2, android.view.SurfaceView):
    DEBUG_CHECK_GL_ERROR: typing.ClassVar[int] = ...
    DEBUG_LOG_GL_CALLS: typing.ClassVar[int] = ...
    RENDERMODE_CONTINUOUSLY: typing.ClassVar[int] = ...
    RENDERMODE_WHEN_DIRTY: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def finalize(self) -> None: ...
    def getDebugFlags(self) -> int: ...
    def getPreserveEGLContextOnPause(self) -> bool: ...
    def getRenderMode(self) -> int: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onPause(self) -> None: ...
    def onResume(self) -> None: ...
    def queueEvent(self, r: java.lang.Runnable, /) -> None: ...
    def requestRender(self) -> None: ...
    def setDebugFlags(self, debugFlags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setEGLConfigChooser(self, configChooser: GLSurfaceView.EGLConfigChooser, /) -> None: ...
    @typing.overload
    def setEGLConfigChooser(self, needDepth: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setEGLConfigChooser(self, redSize: int | java.jint | java.lang.Integer, greenSize: int | java.jint | java.lang.Integer, blueSize: int | java.jint | java.lang.Integer, alphaSize: int | java.jint | java.lang.Integer, depthSize: int | java.jint | java.lang.Integer, stencilSize: int | java.jint | java.lang.Integer, /) -> None: ...
    def setEGLContextClientVersion(self, version: int | java.jint | java.lang.Integer, /) -> None: ...
    def setEGLContextFactory(self, factory: GLSurfaceView.EGLContextFactory, /) -> None: ...
    def setEGLWindowSurfaceFactory(self, factory: GLSurfaceView.EGLWindowSurfaceFactory, /) -> None: ...
    def setGLWrapper(self, glWrapper: GLSurfaceView.GLWrapper, /) -> None: ...
    def setPreserveEGLContextOnPause(self, preserveOnPause: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setRenderMode(self, renderMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRenderer(self, renderer: GLSurfaceView.Renderer, /) -> None: ...
    def surfaceChanged(self, holder: android.view.SurfaceHolder, format: int | java.jint | java.lang.Integer, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, /) -> None: ...
    def surfaceCreated(self, holder: android.view.SurfaceHolder, /) -> None: ...
    def surfaceDestroyed(self, holder: android.view.SurfaceHolder, /) -> None: ...
    def surfaceRedrawNeeded(self, holder: android.view.SurfaceHolder, /) -> None: ...
    def surfaceRedrawNeededAsync(self, holder: android.view.SurfaceHolder, finishDrawing: java.lang.Runnable, /) -> None: ...

    class Renderer(java.lang.Object):
        def onDrawFrame(self, arg1: javax.microedition.khronos.opengles.GL10, /) -> None: ...
        def onSurfaceChanged(self, arg1: javax.microedition.khronos.opengles.GL10, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
        def onSurfaceCreated(self, arg1: javax.microedition.khronos.opengles.GL10, arg2: javax.microedition.khronos.egl.EGLConfig, /) -> None: ...

    class GLWrapper(java.lang.Object):
        def wrap(self, arg1: javax.microedition.khronos.opengles.GL, /) -> javax.microedition.khronos.opengles.GL: ...

    class EGLWindowSurfaceFactory(java.lang.Object):
        def createWindowSurface(self, arg1: javax.microedition.khronos.egl.EGL10, arg2: javax.microedition.khronos.egl.EGLDisplay, arg3: javax.microedition.khronos.egl.EGLConfig, arg4: java.lang.Object | int | bool | float | str, /) -> javax.microedition.khronos.egl.EGLSurface: ...
        def destroySurface(self, arg1: javax.microedition.khronos.egl.EGL10, arg2: javax.microedition.khronos.egl.EGLDisplay, arg3: javax.microedition.khronos.egl.EGLSurface, /) -> None: ...

    class EGLContextFactory(java.lang.Object):
        def createContext(self, arg1: javax.microedition.khronos.egl.EGL10, arg2: javax.microedition.khronos.egl.EGLDisplay, arg3: javax.microedition.khronos.egl.EGLConfig, /) -> javax.microedition.khronos.egl.EGLContext: ...
        def destroyContext(self, arg1: javax.microedition.khronos.egl.EGL10, arg2: javax.microedition.khronos.egl.EGLDisplay, arg3: javax.microedition.khronos.egl.EGLContext, /) -> None: ...

    class EGLConfigChooser(java.lang.Object):
        def chooseConfig(self, arg1: javax.microedition.khronos.egl.EGL10, arg2: javax.microedition.khronos.egl.EGLDisplay, /) -> javax.microedition.khronos.egl.EGLConfig: ...

class GLU(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def gluErrorString(error: int | java.jint | java.lang.Integer, /) -> str | None: ...
    @staticmethod
    def gluLookAt(gl: javax.microedition.khronos.opengles.GL10, eyeX: float | java.jfloat | java.lang.Float, eyeY: float | java.jfloat | java.lang.Float, eyeZ: float | java.jfloat | java.lang.Float, centerX: float | java.jfloat | java.lang.Float, centerY: float | java.jfloat | java.lang.Float, centerZ: float | java.jfloat | java.lang.Float, upX: float | java.jfloat | java.lang.Float, upY: float | java.jfloat | java.lang.Float, upZ: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def gluOrtho2D(gl: javax.microedition.khronos.opengles.GL10, left: float | java.jfloat | java.lang.Float, right: float | java.jfloat | java.lang.Float, bottom: float | java.jfloat | java.lang.Float, top: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def gluPerspective(gl: javax.microedition.khronos.opengles.GL10, fovy: float | java.jfloat | java.lang.Float, aspect: float | java.jfloat | java.lang.Float, zNear: float | java.jfloat | java.lang.Float, zFar: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def gluProject(objX: float | java.jfloat | java.lang.Float, objY: float | java.jfloat | java.lang.Float, objZ: float | java.jfloat | java.lang.Float, model: java.chaquopy.JavaArrayJFloat, modelOffset: int | java.jint | java.lang.Integer, project: java.chaquopy.JavaArrayJFloat, projectOffset: int | java.jint | java.lang.Integer, view: java.chaquopy.JavaArrayJInt, viewOffset: int | java.jint | java.lang.Integer, win: java.chaquopy.JavaArrayJFloat, winOffset: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def gluUnProject(winX: float | java.jfloat | java.lang.Float, winY: float | java.jfloat | java.lang.Float, winZ: float | java.jfloat | java.lang.Float, model: java.chaquopy.JavaArrayJFloat, modelOffset: int | java.jint | java.lang.Integer, project: java.chaquopy.JavaArrayJFloat, projectOffset: int | java.jint | java.lang.Integer, view: java.chaquopy.JavaArrayJInt, viewOffset: int | java.jint | java.lang.Integer, obj: java.chaquopy.JavaArrayJFloat, objOffset: int | java.jint | java.lang.Integer, /) -> int: ...

class GLUtils(java.lang.Object):
    @staticmethod
    def getEGLErrorString(error: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def getInternalFormat(bitmap: android.graphics.Bitmap, /) -> int: ...
    @staticmethod
    def getType(bitmap: android.graphics.Bitmap, /) -> int: ...
    @typing.overload
    @staticmethod
    def texImage2D(target: int | java.jint | java.lang.Integer, level: int | java.jint | java.lang.Integer, bitmap: android.graphics.Bitmap, border: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def texImage2D(target: int | java.jint | java.lang.Integer, level: int | java.jint | java.lang.Integer, internalformat: int | java.jint | java.lang.Integer, bitmap: android.graphics.Bitmap, border: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def texImage2D(target: int | java.jint | java.lang.Integer, level: int | java.jint | java.lang.Integer, internalformat: int | java.jint | java.lang.Integer, bitmap: android.graphics.Bitmap, type: int | java.jint | java.lang.Integer, border: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def texSubImage2D(target: int | java.jint | java.lang.Integer, level: int | java.jint | java.lang.Integer, xoffset: int | java.jint | java.lang.Integer, yoffset: int | java.jint | java.lang.Integer, bitmap: android.graphics.Bitmap, /) -> None: ...
    @typing.overload
    @staticmethod
    def texSubImage2D(target: int | java.jint | java.lang.Integer, level: int | java.jint | java.lang.Integer, xoffset: int | java.jint | java.lang.Integer, yoffset: int | java.jint | java.lang.Integer, bitmap: android.graphics.Bitmap, format: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, /) -> None: ...

class Matrix(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def frustumM(m: java.chaquopy.JavaArrayJFloat, offset: int | java.jint | java.lang.Integer, left: float | java.jfloat | java.lang.Float, right: float | java.jfloat | java.lang.Float, bottom: float | java.jfloat | java.lang.Float, top: float | java.jfloat | java.lang.Float, near: float | java.jfloat | java.lang.Float, far: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def invertM(mInv: java.chaquopy.JavaArrayJFloat, mInvOffset: int | java.jint | java.lang.Integer, m: java.chaquopy.JavaArrayJFloat, mOffset: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def length(x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, z: float | java.jfloat | java.lang.Float, /) -> float: ...
    @staticmethod
    def multiplyMM(result: java.chaquopy.JavaArrayJFloat, resultOffset: int | java.jint | java.lang.Integer, lhs: java.chaquopy.JavaArrayJFloat, lhsOffset: int | java.jint | java.lang.Integer, rhs: java.chaquopy.JavaArrayJFloat, rhsOffset: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def multiplyMV(resultVec: java.chaquopy.JavaArrayJFloat, resultVecOffset: int | java.jint | java.lang.Integer, lhsMat: java.chaquopy.JavaArrayJFloat, lhsMatOffset: int | java.jint | java.lang.Integer, rhsVec: java.chaquopy.JavaArrayJFloat, rhsVecOffset: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def orthoM(m: java.chaquopy.JavaArrayJFloat, mOffset: int | java.jint | java.lang.Integer, left: float | java.jfloat | java.lang.Float, right: float | java.jfloat | java.lang.Float, bottom: float | java.jfloat | java.lang.Float, top: float | java.jfloat | java.lang.Float, near: float | java.jfloat | java.lang.Float, far: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def perspectiveM(m: java.chaquopy.JavaArrayJFloat, offset: int | java.jint | java.lang.Integer, fovy: float | java.jfloat | java.lang.Float, aspect: float | java.jfloat | java.lang.Float, zNear: float | java.jfloat | java.lang.Float, zFar: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def rotateM(m: java.chaquopy.JavaArrayJFloat, mOffset: int | java.jint | java.lang.Integer, a: float | java.jfloat | java.lang.Float, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, z: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def rotateM(rm: java.chaquopy.JavaArrayJFloat, rmOffset: int | java.jint | java.lang.Integer, m: java.chaquopy.JavaArrayJFloat, mOffset: int | java.jint | java.lang.Integer, a: float | java.jfloat | java.lang.Float, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, z: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def scaleM(m: java.chaquopy.JavaArrayJFloat, mOffset: int | java.jint | java.lang.Integer, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, z: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def scaleM(sm: java.chaquopy.JavaArrayJFloat, smOffset: int | java.jint | java.lang.Integer, m: java.chaquopy.JavaArrayJFloat, mOffset: int | java.jint | java.lang.Integer, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, z: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def setIdentityM(sm: java.chaquopy.JavaArrayJFloat, smOffset: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def setLookAtM(rm: java.chaquopy.JavaArrayJFloat, rmOffset: int | java.jint | java.lang.Integer, eyeX: float | java.jfloat | java.lang.Float, eyeY: float | java.jfloat | java.lang.Float, eyeZ: float | java.jfloat | java.lang.Float, centerX: float | java.jfloat | java.lang.Float, centerY: float | java.jfloat | java.lang.Float, centerZ: float | java.jfloat | java.lang.Float, upX: float | java.jfloat | java.lang.Float, upY: float | java.jfloat | java.lang.Float, upZ: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def setRotateEulerM(rm: java.chaquopy.JavaArrayJFloat, rmOffset: int | java.jint | java.lang.Integer, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, z: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def setRotateEulerM2(rm: java.chaquopy.JavaArrayJFloat, rmOffset: int | java.jint | java.lang.Integer, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, z: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def setRotateM(rm: java.chaquopy.JavaArrayJFloat, rmOffset: int | java.jint | java.lang.Integer, a: float | java.jfloat | java.lang.Float, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, z: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def translateM(m: java.chaquopy.JavaArrayJFloat, mOffset: int | java.jint | java.lang.Integer, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, z: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    @staticmethod
    def translateM(tm: java.chaquopy.JavaArrayJFloat, tmOffset: int | java.jint | java.lang.Integer, m: java.chaquopy.JavaArrayJFloat, mOffset: int | java.jint | java.lang.Integer, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, z: float | java.jfloat | java.lang.Float, /) -> None: ...
    @staticmethod
    def transposeM(mTrans: java.chaquopy.JavaArrayJFloat, mTransOffset: int | java.jint | java.lang.Integer, m: java.chaquopy.JavaArrayJFloat, mOffset: int | java.jint | java.lang.Integer, /) -> None: ...

class Visibility(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def computeBoundingSphere(arg1: java.chaquopy.JavaArrayJFloat, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJFloat, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def frustumCullSpheres(arg1: java.chaquopy.JavaArrayJFloat, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: java.chaquopy.JavaArrayJInt, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def visibilityTest(arg1: java.chaquopy.JavaArrayJFloat, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJFloat, arg4: int | java.jint | java.lang.Integer, arg5: java.chaquopy.JavaArrayJChar, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, /) -> int: ...
