import typing

import android.animation
import android.app.jank
import android.content
import android.content.res
import android.credentials
import android.graphics
import android.graphics.drawable
import android.hardware
import android.hardware.display
import android.hardware.lights
import android.media.session
import android.net
import android.os
import android.transition
import android.util
import android.view.accessibility
import android.view.animation
import android.view.autofill
import android.view.contentcapture
import android.view.displayhash
import android.view.inputmethod
import android.view.translation
import android.window
import java
import java.chaquopy
import java.io
import java.lang
import java.lang.annotation
import java.util
import java.util.concurrent
import java.util.function
import org.xmlpull.v1

class AbsSavedState(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AbsSavedState]] = ...
    EMPTY_STATE: typing.ClassVar[AbsSavedState] = ...
    @typing.overload
    def __init__(self, source: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, superState: android.os.Parcelable, /) -> None: ...
    @typing.overload
    def __init__(self, source: android.os.Parcel, loader: java.lang.ClassLoader, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSuperState(self) -> android.os.Parcelable: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ActionMode(java.lang.Object):
    DEFAULT_HIDE_DURATION: typing.ClassVar[int] = ...
    TYPE_FLOATING: typing.ClassVar[int] = ...
    TYPE_PRIMARY: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def finish(self) -> None: ...
    def getCustomView(self) -> View: ...
    def getMenu(self) -> Menu: ...
    def getMenuInflater(self) -> MenuInflater: ...
    def getSubtitle(self) -> java.lang.CharSequence: ...
    def getTag(self) -> java.lang.Object: ...
    def getTitle(self) -> java.lang.CharSequence: ...
    def getTitleOptionalHint(self) -> bool: ...
    def getType(self) -> int: ...
    def hide(self, duration: int | java.jlong | java.lang.Long, /) -> None: ...
    def invalidate(self) -> None: ...
    def invalidateContentRect(self) -> None: ...
    def isTitleOptional(self) -> bool: ...
    def onWindowFocusChanged(self, hasWindowFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCustomView(self, arg1: View, /) -> None: ...
    @typing.overload
    def setSubtitle(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSubtitle(self, arg1: java.lang.CharSequence, /) -> None: ...
    def setTag(self, tag: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def setTitle(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTitle(self, arg1: java.lang.CharSequence, /) -> None: ...
    def setTitleOptionalHint(self, titleOptional: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setType(self, type: int | java.jint | java.lang.Integer, /) -> None: ...

    class Callback2(ActionMode.Callback):
        def __init__(self) -> None: ...
        def onGetContentRect(self, mode: ActionMode, view: View, outRect: android.graphics.Rect, /) -> None: ...

    class Callback(java.lang.Object):
        def onActionItemClicked(self, arg1: ActionMode, arg2: MenuItem, /) -> bool: ...
        def onCreateActionMode(self, arg1: ActionMode, arg2: Menu, /) -> bool: ...
        def onDestroyActionMode(self, arg1: ActionMode, /) -> None: ...
        def onPrepareActionMode(self, arg1: ActionMode, arg2: Menu, /) -> bool: ...

class ActionProvider(java.lang.Object):
    def __init__(self, context: android.content.Context, /) -> None: ...
    def hasSubMenu(self) -> bool: ...
    def isVisible(self) -> bool: ...
    @typing.overload
    def onCreateActionView(self) -> View: ...
    @typing.overload
    def onCreateActionView(self, forItem: MenuItem, /) -> View: ...
    def onPerformDefaultAction(self) -> bool: ...
    def onPrepareSubMenu(self, subMenu: SubMenu, /) -> None: ...
    def overridesItemVisibility(self) -> bool: ...
    def refreshVisibility(self) -> None: ...
    def setVisibilityListener(self, listener: ActionProvider.VisibilityListener, /) -> None: ...

    class VisibilityListener(java.lang.Object):
        def onActionProviderVisibilityChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class AttachedSurfaceControl(java.lang.Object):
    def addOnBufferTransformHintChangedListener(self, listener: AttachedSurfaceControl.OnBufferTransformHintChangedListener, /) -> None: ...
    def applyTransactionOnDraw(self, arg1: SurfaceControl.Transaction, /) -> bool: ...
    def buildReparentTransaction(self, arg1: SurfaceControl, /) -> SurfaceControl.Transaction: ...
    def getBufferTransformHint(self) -> int: ...
    def getInputTransferToken(self) -> android.window.InputTransferToken: ...
    def registerOnJankDataListener(self, executor: java.util.concurrent.Executor, listener: SurfaceControl.OnJankDataListener, /) -> SurfaceControl.OnJankDataListenerRegistration: ...
    def removeOnBufferTransformHintChangedListener(self, listener: AttachedSurfaceControl.OnBufferTransformHintChangedListener, /) -> None: ...
    def setChildBoundingInsets(self, insets: android.graphics.Rect, /) -> None: ...
    def setTouchableRegion(self, r: android.graphics.Region, /) -> None: ...

    class OnBufferTransformHintChangedListener(java.lang.Object):
        def onBufferTransformHintChanged(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class Choreographer(java.lang.Object):
    @staticmethod
    def getInstance() -> Choreographer: ...
    def postFrameCallback(self, callback: Choreographer.FrameCallback, /) -> None: ...
    def postFrameCallbackDelayed(self, callback: Choreographer.FrameCallback, delayMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def postVsyncCallback(self, callback: Choreographer.VsyncCallback, /) -> None: ...
    def removeFrameCallback(self, callback: Choreographer.FrameCallback, /) -> None: ...
    def removeVsyncCallback(self, callback: Choreographer.VsyncCallback, /) -> None: ...

    class VsyncCallback(java.lang.Object):
        def onVsync(self, arg1: Choreographer.FrameData, /) -> None: ...

    class FrameTimeline(java.lang.Object):
        def getDeadlineNanos(self) -> int: ...
        def getExpectedPresentationTimeNanos(self) -> int: ...
        def getVsyncId(self) -> int: ...

    class FrameData(java.lang.Object):
        def getFrameTimeNanos(self) -> int: ...
        def getFrameTimelines(self) -> java.chaquopy.JavaArray[Choreographer.FrameTimeline]: ...
        def getPreferredFrameTimeline(self) -> Choreographer.FrameTimeline: ...

    class FrameCallback(java.lang.Object):
        def doFrame(self, arg1: int | java.jlong | java.lang.Long, /) -> None: ...

class CollapsibleActionView(java.lang.Object):
    def onActionViewCollapsed(self) -> None: ...
    def onActionViewExpanded(self) -> None: ...

class ContentInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ContentInfo]] = ...
    FLAG_CONVERT_TO_PLAIN_TEXT: typing.ClassVar[int] = ...
    SOURCE_APP: typing.ClassVar[int] = ...
    SOURCE_AUTOFILL: typing.ClassVar[int] = ...
    SOURCE_CLIPBOARD: typing.ClassVar[int] = ...
    SOURCE_DRAG_AND_DROP: typing.ClassVar[int] = ...
    SOURCE_INPUT_METHOD: typing.ClassVar[int] = ...
    SOURCE_PROCESS_TEXT: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getClip(self) -> android.content.ClipData: ...
    def getExtras(self) -> android.os.Bundle | None: ...
    def getFlags(self) -> int: ...
    def getLinkUri(self) -> android.net.Uri | None: ...
    def getSource(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, other: ContentInfo, /) -> None: ...
        @typing.overload
        def __init__(self, clip: android.content.ClipData, source: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> ContentInfo: ...
        def setClip(self, clip: android.content.ClipData, /) -> ContentInfo.Builder: ...
        def setExtras(self, extras: android.os.Bundle, /) -> ContentInfo.Builder: ...
        def setFlags(self, flags: int | java.jint | java.lang.Integer, /) -> ContentInfo.Builder: ...
        def setLinkUri(self, linkUri: android.net.Uri, /) -> ContentInfo.Builder: ...
        def setSource(self, source: int | java.jint | java.lang.Integer, /) -> ContentInfo.Builder: ...

class ContextMenu(Menu):
    def clearHeader(self) -> None: ...
    @typing.overload
    def setHeaderIcon(self, arg1: int | java.jint | java.lang.Integer, /) -> ContextMenu: ...
    @typing.overload
    def setHeaderIcon(self, arg1: android.graphics.drawable.Drawable, /) -> ContextMenu: ...
    @typing.overload
    def setHeaderTitle(self, arg1: int | java.jint | java.lang.Integer, /) -> ContextMenu: ...
    @typing.overload
    def setHeaderTitle(self, arg1: java.lang.CharSequence, /) -> ContextMenu: ...
    def setHeaderView(self, arg1: View, /) -> ContextMenu: ...

    class ContextMenuInfo(java.lang.Object): ...

class ContextThemeWrapper(android.content.ContextWrapper):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, base: android.content.Context, themeResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, base: android.content.Context, theme: android.content.res.Resources.Theme, /) -> None: ...
    def applyOverrideConfiguration(self, overrideConfiguration: android.content.res.Configuration, /) -> None: ...
    def attachBaseContext(self, newBase: android.content.Context, /) -> None: ...
    def getAssets(self) -> android.content.res.AssetManager: ...
    def getResources(self) -> android.content.res.Resources: ...
    def getSystemService(self, name: str | java.lang.String, /) -> java.lang.Object: ...
    def getTheme(self) -> android.content.res.Resources.Theme: ...
    def onApplyThemeResource(self, theme: android.content.res.Resources.Theme, resId: int | java.jint | java.lang.Integer, first: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setTheme(self, resid: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTheme(self, theme: android.content.res.Resources.Theme, /) -> None: ...

class Display(java.lang.Object):
    DEFAULT_DISPLAY: typing.ClassVar[int] = ...
    FLAG_PRESENTATION: typing.ClassVar[int] = ...
    FLAG_PRIVATE: typing.ClassVar[int] = ...
    FLAG_ROUND: typing.ClassVar[int] = ...
    FLAG_SECURE: typing.ClassVar[int] = ...
    FLAG_SUPPORTS_PROTECTED_BUFFERS: typing.ClassVar[int] = ...
    FRAME_RATE_CATEGORY_HIGH: typing.ClassVar[int] = ...
    FRAME_RATE_CATEGORY_NORMAL: typing.ClassVar[int] = ...
    INVALID_DISPLAY: typing.ClassVar[int] = ...
    STATE_DOZE: typing.ClassVar[int] = ...
    STATE_DOZE_SUSPEND: typing.ClassVar[int] = ...
    STATE_OFF: typing.ClassVar[int] = ...
    STATE_ON: typing.ClassVar[int] = ...
    STATE_ON_SUSPEND: typing.ClassVar[int] = ...
    STATE_UNKNOWN: typing.ClassVar[int] = ...
    STATE_VR: typing.ClassVar[int] = ...
    def getAppVsyncOffsetNanos(self) -> int: ...
    def getCurrentSizeRange(self, outSmallestSize: android.graphics.Point, outLargestSize: android.graphics.Point, /) -> None: ...
    def getCutout(self) -> DisplayCutout | None: ...
    def getDeviceProductInfo(self) -> android.hardware.display.DeviceProductInfo | None: ...
    def getDisplayId(self) -> int: ...
    def getFlags(self) -> int: ...
    def getHdrCapabilities(self) -> Display.HdrCapabilities: ...
    def getHdrSdrRatio(self) -> float: ...
    def getHeight(self) -> int: ...
    def getHighestHdrSdrRatio(self) -> float: ...
    def getMetrics(self, outMetrics: android.util.DisplayMetrics, /) -> None: ...
    def getMode(self) -> Display.Mode: ...
    def getName(self) -> str: ...
    def getOrientation(self) -> int: ...
    def getOverlaySupport(self) -> android.hardware.OverlayProperties: ...
    def getPixelFormat(self) -> int: ...
    def getPreferredWideGamutColorSpace(self) -> android.graphics.ColorSpace | None: ...
    def getPresentationDeadlineNanos(self) -> int: ...
    def getRealMetrics(self, outMetrics: android.util.DisplayMetrics, /) -> None: ...
    def getRealSize(self, outSize: android.graphics.Point, /) -> None: ...
    def getRectSize(self, outSize: android.graphics.Rect, /) -> None: ...
    def getRefreshRate(self) -> float: ...
    def getRotation(self) -> int: ...
    def getRoundedCorner(self, position: int | java.jint | java.lang.Integer, /) -> RoundedCorner | None: ...
    def getShape(self) -> DisplayShape: ...
    def getSize(self, outSize: android.graphics.Point, /) -> None: ...
    def getState(self) -> int: ...
    def getSuggestedFrameRate(self, category: int | java.jint | java.lang.Integer, /) -> float: ...
    def getSupportedModes(self) -> java.chaquopy.JavaArray[Display.Mode]: ...
    def getSupportedRefreshRates(self) -> java.chaquopy.JavaArrayJFloat: ...
    def getWidth(self) -> int: ...
    def hasArrSupport(self) -> bool: ...
    def isHdr(self) -> bool: ...
    def isHdrSdrRatioAvailable(self) -> bool: ...
    def isMinimalPostProcessingSupported(self) -> bool: ...
    def isValid(self) -> bool: ...
    def isWideColorGamut(self) -> bool: ...
    def registerHdrSdrRatioChangedListener(self, executor: java.util.concurrent.Executor, listener: java.util.function.Consumer[Display], /) -> None: ...
    def toString(self) -> str: ...
    def unregisterHdrSdrRatioChangedListener(self, listener: java.util.function.Consumer[Display], /) -> None: ...

    class Mode(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Display.Mode]] = ...
        def describeContents(self) -> int: ...
        def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getAlternativeRefreshRates(self) -> java.chaquopy.JavaArrayJFloat: ...
        def getModeId(self) -> int: ...
        def getPhysicalHeight(self) -> int: ...
        def getPhysicalWidth(self) -> int: ...
        def getRefreshRate(self) -> float: ...
        def getSupportedHdrTypes(self) -> java.chaquopy.JavaArrayJInt: ...
        def hashCode(self) -> int: ...
        def toString(self) -> str: ...
        def writeToParcel(self, out: android.os.Parcel, parcelableFlags: int | java.jint | java.lang.Integer, /) -> None: ...

    class HdrCapabilities(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Display.HdrCapabilities]] = ...
        HDR_TYPE_DOLBY_VISION: typing.ClassVar[int] = ...
        HDR_TYPE_HDR10: typing.ClassVar[int] = ...
        HDR_TYPE_HDR10_PLUS: typing.ClassVar[int] = ...
        HDR_TYPE_HLG: typing.ClassVar[int] = ...
        HDR_TYPE_INVALID: typing.ClassVar[int] = ...
        INVALID_LUMINANCE: typing.ClassVar[float] = ...
        def describeContents(self) -> int: ...
        def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getDesiredMaxAverageLuminance(self) -> float: ...
        def getDesiredMaxLuminance(self) -> float: ...
        def getDesiredMinLuminance(self) -> float: ...
        def getSupportedHdrTypes(self) -> java.chaquopy.JavaArrayJInt: ...
        def hashCode(self) -> int: ...
        def toString(self) -> str: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class DisplayCutout(java.lang.Object):
    @typing.overload
    def __init__(self, safeInsets: android.graphics.Rect, boundingRects: java.util.List[android.graphics.Rect], /) -> None: ...
    @typing.overload
    def __init__(self, safeInsets: android.graphics.Insets, boundLeft: android.graphics.Rect, boundTop: android.graphics.Rect, boundRight: android.graphics.Rect, boundBottom: android.graphics.Rect, /) -> None: ...
    @typing.overload
    def __init__(self, safeInsets: android.graphics.Insets, boundLeft: android.graphics.Rect, boundTop: android.graphics.Rect, boundRight: android.graphics.Rect, boundBottom: android.graphics.Rect, waterfallInsets: android.graphics.Insets, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBoundingRectBottom(self) -> android.graphics.Rect: ...
    def getBoundingRectLeft(self) -> android.graphics.Rect: ...
    def getBoundingRectRight(self) -> android.graphics.Rect: ...
    def getBoundingRectTop(self) -> android.graphics.Rect: ...
    def getBoundingRects(self) -> java.util.List[android.graphics.Rect]: ...
    def getCutoutPath(self) -> android.graphics.Path | None: ...
    def getSafeInsetBottom(self) -> int: ...
    def getSafeInsetLeft(self) -> int: ...
    def getSafeInsetRight(self) -> int: ...
    def getSafeInsetTop(self) -> int: ...
    def getWaterfallInsets(self) -> android.graphics.Insets: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> DisplayCutout: ...
        def setBoundingRectBottom(self, boundingRectBottom: android.graphics.Rect, /) -> DisplayCutout.Builder: ...
        def setBoundingRectLeft(self, boundingRectLeft: android.graphics.Rect, /) -> DisplayCutout.Builder: ...
        def setBoundingRectRight(self, boundingRectRight: android.graphics.Rect, /) -> DisplayCutout.Builder: ...
        def setBoundingRectTop(self, boundingRectTop: android.graphics.Rect, /) -> DisplayCutout.Builder: ...
        def setCutoutPath(self, cutoutPath: android.graphics.Path, /) -> DisplayCutout.Builder: ...
        def setSafeInsets(self, safeInsets: android.graphics.Insets, /) -> DisplayCutout.Builder: ...
        def setWaterfallInsets(self, waterfallInsets: android.graphics.Insets, /) -> DisplayCutout.Builder: ...

class DisplayShape(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DisplayShape]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPath(self) -> android.graphics.Path: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class DragAndDropPermissions(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DragAndDropPermissions]] = ...
    def describeContents(self) -> int: ...
    def release(self) -> None: ...
    def writeToParcel(self, destination: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class DragEvent(android.os.Parcelable):
    ACTION_DRAG_ENDED: typing.ClassVar[int] = ...
    ACTION_DRAG_ENTERED: typing.ClassVar[int] = ...
    ACTION_DRAG_EXITED: typing.ClassVar[int] = ...
    ACTION_DRAG_LOCATION: typing.ClassVar[int] = ...
    ACTION_DRAG_STARTED: typing.ClassVar[int] = ...
    ACTION_DROP: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DragEvent]] = ...
    def describeContents(self) -> int: ...
    def getAction(self) -> int: ...
    def getClipData(self) -> android.content.ClipData: ...
    def getClipDescription(self) -> android.content.ClipDescription: ...
    def getLocalState(self) -> java.lang.Object: ...
    def getResult(self) -> bool: ...
    def getX(self) -> float: ...
    def getY(self) -> float: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class FocusFinder(java.lang.Object):
    def findNearestTouchable(self, root: ViewGroup, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, direction: int | java.jint | java.lang.Integer, deltas: java.chaquopy.JavaArrayJInt, /) -> View | None: ...
    def findNextFocus(self, root: ViewGroup, focused: View, direction: int | java.jint | java.lang.Integer, /) -> View | None: ...
    def findNextFocusFromRect(self, root: ViewGroup, focusedRect: android.graphics.Rect, direction: int | java.jint | java.lang.Integer, /) -> View | None: ...
    def findNextKeyboardNavigationCluster(self, root: View, currentCluster: View, direction: int | java.jint | java.lang.Integer, /) -> View | None: ...
    @staticmethod
    def getInstance() -> FocusFinder: ...

class FrameMetrics(java.lang.Object):
    ANIMATION_DURATION: typing.ClassVar[int] = ...
    COMMAND_ISSUE_DURATION: typing.ClassVar[int] = ...
    DEADLINE: typing.ClassVar[int] = ...
    DRAW_DURATION: typing.ClassVar[int] = ...
    FIRST_DRAW_FRAME: typing.ClassVar[int] = ...
    FRAME_TIMELINE_VSYNC_ID: typing.ClassVar[int] = ...
    GPU_DURATION: typing.ClassVar[int] = ...
    INPUT_HANDLING_DURATION: typing.ClassVar[int] = ...
    INTENDED_VSYNC_TIMESTAMP: typing.ClassVar[int] = ...
    LAYOUT_MEASURE_DURATION: typing.ClassVar[int] = ...
    SWAP_BUFFERS_DURATION: typing.ClassVar[int] = ...
    SYNC_DURATION: typing.ClassVar[int] = ...
    TOTAL_DURATION: typing.ClassVar[int] = ...
    UNKNOWN_DELAY_DURATION: typing.ClassVar[int] = ...
    VSYNC_TIMESTAMP: typing.ClassVar[int] = ...
    def __init__(self, other: FrameMetrics, /) -> None: ...
    def getMetric(self, id: int | java.jint | java.lang.Integer, /) -> int: ...

class FrameStats(java.lang.Object):
    UNDEFINED_TIME_NANO: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def getEndTimeNano(self) -> int: ...
    def getFrameCount(self) -> int: ...
    def getFramePresentedTimeNano(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    def getRefreshPeriodNano(self) -> int: ...
    def getStartTimeNano(self) -> int: ...

class GestureDetector(java.lang.Object):
    @typing.overload
    def __init__(self, listener: GestureDetector.OnGestureListener, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, listener: GestureDetector.OnGestureListener, /) -> None: ...
    @typing.overload
    def __init__(self, listener: GestureDetector.OnGestureListener, handler: android.os.Handler, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, listener: GestureDetector.OnGestureListener, handler: android.os.Handler, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, listener: GestureDetector.OnGestureListener, handler: android.os.Handler, unused: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def isLongpressEnabled(self) -> bool: ...
    def onGenericMotionEvent(self, ev: MotionEvent, /) -> bool: ...
    def onTouchEvent(self, ev: MotionEvent, /) -> bool: ...
    def setContextClickListener(self, onContextClickListener: GestureDetector.OnContextClickListener, /) -> None: ...
    def setIsLongpressEnabled(self, isLongpressEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOnDoubleTapListener(self, onDoubleTapListener: GestureDetector.OnDoubleTapListener, /) -> None: ...

    class SimpleOnGestureListener(GestureDetector.OnContextClickListener, GestureDetector.OnDoubleTapListener, GestureDetector.OnGestureListener):
        def __init__(self) -> None: ...
        def onContextClick(self, e: MotionEvent, /) -> bool: ...
        def onDoubleTap(self, e: MotionEvent, /) -> bool: ...
        def onDoubleTapEvent(self, e: MotionEvent, /) -> bool: ...
        def onDown(self, e: MotionEvent, /) -> bool: ...
        def onFling(self, e1: MotionEvent, e2: MotionEvent, velocityX: float | java.jfloat | java.lang.Float, velocityY: float | java.jfloat | java.lang.Float, /) -> bool: ...
        def onLongPress(self, e: MotionEvent, /) -> None: ...
        def onScroll(self, e1: MotionEvent, e2: MotionEvent, distanceX: float | java.jfloat | java.lang.Float, distanceY: float | java.jfloat | java.lang.Float, /) -> bool: ...
        def onShowPress(self, e: MotionEvent, /) -> None: ...
        def onSingleTapConfirmed(self, e: MotionEvent, /) -> bool: ...
        def onSingleTapUp(self, e: MotionEvent, /) -> bool: ...

    class OnGestureListener(java.lang.Object):
        def onDown(self, arg1: MotionEvent, /) -> bool: ...
        def onFling(self, arg1: MotionEvent, arg2: MotionEvent, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, /) -> bool: ...
        def onLongPress(self, arg1: MotionEvent, /) -> None: ...
        def onScroll(self, arg1: MotionEvent, arg2: MotionEvent, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, /) -> bool: ...
        def onShowPress(self, arg1: MotionEvent, /) -> None: ...
        def onSingleTapUp(self, arg1: MotionEvent, /) -> bool: ...

    class OnDoubleTapListener(java.lang.Object):
        def onDoubleTap(self, arg1: MotionEvent, /) -> bool: ...
        def onDoubleTapEvent(self, arg1: MotionEvent, /) -> bool: ...
        def onSingleTapConfirmed(self, arg1: MotionEvent, /) -> bool: ...

    class OnContextClickListener(java.lang.Object):
        def onContextClick(self, arg1: MotionEvent, /) -> bool: ...

class Gravity(java.lang.Object):
    AXIS_CLIP: typing.ClassVar[int] = ...
    AXIS_PULL_AFTER: typing.ClassVar[int] = ...
    AXIS_PULL_BEFORE: typing.ClassVar[int] = ...
    AXIS_SPECIFIED: typing.ClassVar[int] = ...
    AXIS_X_SHIFT: typing.ClassVar[int] = ...
    AXIS_Y_SHIFT: typing.ClassVar[int] = ...
    BOTTOM: typing.ClassVar[int] = ...
    CENTER: typing.ClassVar[int] = ...
    CENTER_HORIZONTAL: typing.ClassVar[int] = ...
    CENTER_VERTICAL: typing.ClassVar[int] = ...
    CLIP_HORIZONTAL: typing.ClassVar[int] = ...
    CLIP_VERTICAL: typing.ClassVar[int] = ...
    DISPLAY_CLIP_HORIZONTAL: typing.ClassVar[int] = ...
    DISPLAY_CLIP_VERTICAL: typing.ClassVar[int] = ...
    END: typing.ClassVar[int] = ...
    FILL: typing.ClassVar[int] = ...
    FILL_HORIZONTAL: typing.ClassVar[int] = ...
    FILL_VERTICAL: typing.ClassVar[int] = ...
    HORIZONTAL_GRAVITY_MASK: typing.ClassVar[int] = ...
    LEFT: typing.ClassVar[int] = ...
    NO_GRAVITY: typing.ClassVar[int] = ...
    RELATIVE_HORIZONTAL_GRAVITY_MASK: typing.ClassVar[int] = ...
    RELATIVE_LAYOUT_DIRECTION: typing.ClassVar[int] = ...
    RIGHT: typing.ClassVar[int] = ...
    START: typing.ClassVar[int] = ...
    TOP: typing.ClassVar[int] = ...
    VERTICAL_GRAVITY_MASK: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @typing.overload
    @staticmethod
    def apply(gravity: int | java.jint | java.lang.Integer, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, container: android.graphics.Rect, outRect: android.graphics.Rect, /) -> None: ...
    @typing.overload
    @staticmethod
    def apply(gravity: int | java.jint | java.lang.Integer, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, container: android.graphics.Rect, outRect: android.graphics.Rect, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def apply(gravity: int | java.jint | java.lang.Integer, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, container: android.graphics.Rect, xAdj: int | java.jint | java.lang.Integer, yAdj: int | java.jint | java.lang.Integer, outRect: android.graphics.Rect, /) -> None: ...
    @typing.overload
    @staticmethod
    def apply(gravity: int | java.jint | java.lang.Integer, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, container: android.graphics.Rect, xAdj: int | java.jint | java.lang.Integer, yAdj: int | java.jint | java.lang.Integer, outRect: android.graphics.Rect, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def applyDisplay(gravity: int | java.jint | java.lang.Integer, display: android.graphics.Rect, inoutObj: android.graphics.Rect, /) -> None: ...
    @typing.overload
    @staticmethod
    def applyDisplay(gravity: int | java.jint | java.lang.Integer, display: android.graphics.Rect, inoutObj: android.graphics.Rect, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def getAbsoluteGravity(gravity: int | java.jint | java.lang.Integer, layoutDirection: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def isHorizontal(gravity: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def isVertical(gravity: int | java.jint | java.lang.Integer, /) -> bool: ...

class HapticFeedbackConstants(java.lang.Object):
    CLOCK_TICK: typing.ClassVar[int] = ...
    CONFIRM: typing.ClassVar[int] = ...
    CONTEXT_CLICK: typing.ClassVar[int] = ...
    DRAG_START: typing.ClassVar[int] = ...
    FLAG_IGNORE_GLOBAL_SETTING: typing.ClassVar[int] = ...
    FLAG_IGNORE_VIEW_SETTING: typing.ClassVar[int] = ...
    GESTURE_END: typing.ClassVar[int] = ...
    GESTURE_START: typing.ClassVar[int] = ...
    GESTURE_THRESHOLD_ACTIVATE: typing.ClassVar[int] = ...
    GESTURE_THRESHOLD_DEACTIVATE: typing.ClassVar[int] = ...
    KEYBOARD_PRESS: typing.ClassVar[int] = ...
    KEYBOARD_RELEASE: typing.ClassVar[int] = ...
    KEYBOARD_TAP: typing.ClassVar[int] = ...
    LONG_PRESS: typing.ClassVar[int] = ...
    NO_HAPTICS: typing.ClassVar[int] = ...
    REJECT: typing.ClassVar[int] = ...
    SEGMENT_FREQUENT_TICK: typing.ClassVar[int] = ...
    SEGMENT_TICK: typing.ClassVar[int] = ...
    TEXT_HANDLE_MOVE: typing.ClassVar[int] = ...
    TOGGLE_OFF: typing.ClassVar[int] = ...
    TOGGLE_ON: typing.ClassVar[int] = ...
    VIRTUAL_KEY: typing.ClassVar[int] = ...
    VIRTUAL_KEY_RELEASE: typing.ClassVar[int] = ...

class InflateException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, detailMessage: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, detailMessage: str | java.lang.String, throwable: java.lang.Throwable, /) -> None: ...

class InputDevice(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[InputDevice]] = ...
    KEYBOARD_TYPE_ALPHABETIC: typing.ClassVar[int] = ...
    KEYBOARD_TYPE_NONE: typing.ClassVar[int] = ...
    KEYBOARD_TYPE_NON_ALPHABETIC: typing.ClassVar[int] = ...
    MOTION_RANGE_ORIENTATION: typing.ClassVar[int] = ...
    MOTION_RANGE_PRESSURE: typing.ClassVar[int] = ...
    MOTION_RANGE_SIZE: typing.ClassVar[int] = ...
    MOTION_RANGE_TOOL_MAJOR: typing.ClassVar[int] = ...
    MOTION_RANGE_TOOL_MINOR: typing.ClassVar[int] = ...
    MOTION_RANGE_TOUCH_MAJOR: typing.ClassVar[int] = ...
    MOTION_RANGE_TOUCH_MINOR: typing.ClassVar[int] = ...
    MOTION_RANGE_X: typing.ClassVar[int] = ...
    MOTION_RANGE_Y: typing.ClassVar[int] = ...
    SOURCE_ANY: typing.ClassVar[int] = ...
    SOURCE_BLUETOOTH_STYLUS: typing.ClassVar[int] = ...
    SOURCE_CLASS_BUTTON: typing.ClassVar[int] = ...
    SOURCE_CLASS_JOYSTICK: typing.ClassVar[int] = ...
    SOURCE_CLASS_MASK: typing.ClassVar[int] = ...
    SOURCE_CLASS_NONE: typing.ClassVar[int] = ...
    SOURCE_CLASS_POINTER: typing.ClassVar[int] = ...
    SOURCE_CLASS_POSITION: typing.ClassVar[int] = ...
    SOURCE_CLASS_TRACKBALL: typing.ClassVar[int] = ...
    SOURCE_DPAD: typing.ClassVar[int] = ...
    SOURCE_GAMEPAD: typing.ClassVar[int] = ...
    SOURCE_HDMI: typing.ClassVar[int] = ...
    SOURCE_JOYSTICK: typing.ClassVar[int] = ...
    SOURCE_KEYBOARD: typing.ClassVar[int] = ...
    SOURCE_MOUSE: typing.ClassVar[int] = ...
    SOURCE_MOUSE_RELATIVE: typing.ClassVar[int] = ...
    SOURCE_ROTARY_ENCODER: typing.ClassVar[int] = ...
    SOURCE_SENSOR: typing.ClassVar[int] = ...
    SOURCE_STYLUS: typing.ClassVar[int] = ...
    SOURCE_TOUCHPAD: typing.ClassVar[int] = ...
    SOURCE_TOUCHSCREEN: typing.ClassVar[int] = ...
    SOURCE_TOUCH_NAVIGATION: typing.ClassVar[int] = ...
    SOURCE_TRACKBALL: typing.ClassVar[int] = ...
    SOURCE_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getBatteryState(self) -> android.hardware.BatteryState: ...
    def getControllerNumber(self) -> int: ...
    def getDescriptor(self) -> str: ...
    @staticmethod
    def getDevice(id: int | java.jint | java.lang.Integer, /) -> InputDevice | None: ...
    @staticmethod
    def getDeviceIds() -> java.chaquopy.JavaArrayJInt: ...
    def getId(self) -> int: ...
    def getKeyCharacterMap(self) -> KeyCharacterMap: ...
    def getKeyCodeForKeyLocation(self, locationKeyCode: int | java.jint | java.lang.Integer, /) -> int: ...
    def getKeyboardType(self) -> int: ...
    def getLightsManager(self) -> android.hardware.lights.LightsManager: ...
    @typing.overload
    def getMotionRange(self, axis: int | java.jint | java.lang.Integer, /) -> InputDevice.MotionRange | None: ...
    @typing.overload
    def getMotionRange(self, axis: int | java.jint | java.lang.Integer, source: int | java.jint | java.lang.Integer, /) -> InputDevice.MotionRange | None: ...
    def getMotionRanges(self) -> java.util.List[InputDevice.MotionRange]: ...
    def getName(self) -> str: ...
    def getProductId(self) -> int: ...
    def getSensorManager(self) -> android.hardware.SensorManager: ...
    def getSources(self) -> int: ...
    def getVendorId(self) -> int: ...
    def getVibrator(self) -> android.os.Vibrator: ...
    def getVibratorManager(self) -> android.os.VibratorManager: ...
    def hasKeys(self, *keys: java.jint) -> java.chaquopy.JavaArrayJBoolean: ...
    def hasMicrophone(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isExternal(self) -> bool: ...
    def isVirtual(self) -> bool: ...
    def supportsSource(self, source: int | java.jint | java.lang.Integer, /) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class ViewBehavior(java.lang.Object):
        def shouldSmoothScroll(self, axis: int | java.jint | java.lang.Integer, source: int | java.jint | java.lang.Integer, /) -> bool: ...

    class MotionRange(java.lang.Object):
        def getAxis(self) -> int: ...
        def getFlat(self) -> float: ...
        def getFuzz(self) -> float: ...
        def getMax(self) -> float: ...
        def getMin(self) -> float: ...
        def getRange(self) -> float: ...
        def getResolution(self) -> float: ...
        def getSource(self) -> int: ...
        def isFromSource(self, source: int | java.jint | java.lang.Integer, /) -> bool: ...

class InputEvent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[InputEvent]] = ...
    def describeContents(self) -> int: ...
    def getDevice(self) -> InputDevice | None: ...
    def getDeviceId(self) -> int: ...
    def getEventTime(self) -> int: ...
    def getSource(self) -> int: ...
    def isFromSource(self, source: int | java.jint | java.lang.Integer, /) -> bool: ...

class InputQueue(java.lang.Object):
    def finalize(self) -> None: ...

    class Callback(java.lang.Object):
        def onInputQueueCreated(self, arg1: InputQueue, /) -> None: ...
        def onInputQueueDestroyed(self, arg1: InputQueue, /) -> None: ...

class KeyCharacterMap(android.os.Parcelable):
    ALPHA: typing.ClassVar[int] = ...
    BUILT_IN_KEYBOARD: typing.ClassVar[int] = ...
    COMBINING_ACCENT: typing.ClassVar[int] = ...
    COMBINING_ACCENT_MASK: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[KeyCharacterMap]] = ...
    FULL: typing.ClassVar[int] = ...
    HEX_INPUT: typing.ClassVar[str] = ...
    MODIFIER_BEHAVIOR_CHORDED: typing.ClassVar[int] = ...
    MODIFIER_BEHAVIOR_CHORDED_OR_TOGGLED: typing.ClassVar[int] = ...
    NUMERIC: typing.ClassVar[int] = ...
    PICKER_DIALOG_INPUT: typing.ClassVar[str] = ...
    PREDICTIVE: typing.ClassVar[int] = ...
    SPECIAL_FUNCTION: typing.ClassVar[int] = ...
    VIRTUAL_KEYBOARD: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    @staticmethod
    def deviceHasKey(keyCode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def deviceHasKeys(keyCodes: java.chaquopy.JavaArrayJInt, /) -> java.chaquopy.JavaArrayJBoolean: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def finalize(self) -> None: ...
    def get(self, keyCode: int | java.jint | java.lang.Integer, metaState: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getDeadChar(accent: int | java.jint | java.lang.Integer, c: int | java.jint | java.lang.Integer, /) -> int: ...
    def getDisplayLabel(self, keyCode: int | java.jint | java.lang.Integer, /) -> str: ...
    def getEvents(self, chars: java.chaquopy.JavaArrayJChar, /) -> java.chaquopy.JavaArray[KeyEvent]: ...
    def getKeyData(self, keyCode: int | java.jint | java.lang.Integer, results: KeyCharacterMap.KeyData, /) -> bool: ...
    def getKeyboardType(self) -> int: ...
    @typing.overload
    def getMatch(self, keyCode: int | java.jint | java.lang.Integer, chars: java.chaquopy.JavaArrayJChar, /) -> str: ...
    @typing.overload
    def getMatch(self, keyCode: int | java.jint | java.lang.Integer, chars: java.chaquopy.JavaArrayJChar, metaState: int | java.jint | java.lang.Integer, /) -> str: ...
    def getModifierBehavior(self) -> int: ...
    def getNumber(self, keyCode: int | java.jint | java.lang.Integer, /) -> str: ...
    def isPrintingKey(self, keyCode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def load(deviceId: int | java.jint | java.lang.Integer, /) -> KeyCharacterMap: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class UnavailableException(android.util.AndroidRuntimeException):
        def __init__(self, msg: str | java.lang.String, /) -> None: ...

    class KeyData(java.lang.Object):
        META_LENGTH: typing.ClassVar[int] = ...
        displayLabel: str = ...
        meta: java.chaquopy.JavaArrayJChar = ...
        number: str = ...
        def __init__(self) -> None: ...

class KeyEvent(InputEvent, android.os.Parcelable):
    ACTION_DOWN: typing.ClassVar[int] = ...
    ACTION_MULTIPLE: typing.ClassVar[int] = ...
    ACTION_UP: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[KeyEvent]] = ...
    FLAG_CANCELED: typing.ClassVar[int] = ...
    FLAG_CANCELED_LONG_PRESS: typing.ClassVar[int] = ...
    FLAG_EDITOR_ACTION: typing.ClassVar[int] = ...
    FLAG_FALLBACK: typing.ClassVar[int] = ...
    FLAG_FROM_SYSTEM: typing.ClassVar[int] = ...
    FLAG_KEEP_TOUCH_MODE: typing.ClassVar[int] = ...
    FLAG_LONG_PRESS: typing.ClassVar[int] = ...
    FLAG_SOFT_KEYBOARD: typing.ClassVar[int] = ...
    FLAG_TRACKING: typing.ClassVar[int] = ...
    FLAG_VIRTUAL_HARD_KEY: typing.ClassVar[int] = ...
    FLAG_WOKE_HERE: typing.ClassVar[int] = ...
    KEYCODE_0: typing.ClassVar[int] = ...
    KEYCODE_11: typing.ClassVar[int] = ...
    KEYCODE_12: typing.ClassVar[int] = ...
    KEYCODE_1: typing.ClassVar[int] = ...
    KEYCODE_2: typing.ClassVar[int] = ...
    KEYCODE_3: typing.ClassVar[int] = ...
    KEYCODE_3D_MODE: typing.ClassVar[int] = ...
    KEYCODE_4: typing.ClassVar[int] = ...
    KEYCODE_5: typing.ClassVar[int] = ...
    KEYCODE_6: typing.ClassVar[int] = ...
    KEYCODE_7: typing.ClassVar[int] = ...
    KEYCODE_8: typing.ClassVar[int] = ...
    KEYCODE_9: typing.ClassVar[int] = ...
    KEYCODE_A: typing.ClassVar[int] = ...
    KEYCODE_ALL_APPS: typing.ClassVar[int] = ...
    KEYCODE_ALT_LEFT: typing.ClassVar[int] = ...
    KEYCODE_ALT_RIGHT: typing.ClassVar[int] = ...
    KEYCODE_APOSTROPHE: typing.ClassVar[int] = ...
    KEYCODE_APP_SWITCH: typing.ClassVar[int] = ...
    KEYCODE_ASSIST: typing.ClassVar[int] = ...
    KEYCODE_AT: typing.ClassVar[int] = ...
    KEYCODE_AVR_INPUT: typing.ClassVar[int] = ...
    KEYCODE_AVR_POWER: typing.ClassVar[int] = ...
    KEYCODE_B: typing.ClassVar[int] = ...
    KEYCODE_BACK: typing.ClassVar[int] = ...
    KEYCODE_BACKSLASH: typing.ClassVar[int] = ...
    KEYCODE_BOOKMARK: typing.ClassVar[int] = ...
    KEYCODE_BREAK: typing.ClassVar[int] = ...
    KEYCODE_BRIGHTNESS_DOWN: typing.ClassVar[int] = ...
    KEYCODE_BRIGHTNESS_UP: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_10: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_11: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_12: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_13: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_14: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_15: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_16: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_1: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_2: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_3: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_4: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_5: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_6: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_7: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_8: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_9: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_A: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_B: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_C: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_L1: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_L2: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_MODE: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_R1: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_R2: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_SELECT: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_START: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_THUMBL: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_THUMBR: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_X: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_Y: typing.ClassVar[int] = ...
    KEYCODE_BUTTON_Z: typing.ClassVar[int] = ...
    KEYCODE_C: typing.ClassVar[int] = ...
    KEYCODE_CALCULATOR: typing.ClassVar[int] = ...
    KEYCODE_CALENDAR: typing.ClassVar[int] = ...
    KEYCODE_CALL: typing.ClassVar[int] = ...
    KEYCODE_CAMERA: typing.ClassVar[int] = ...
    KEYCODE_CAPS_LOCK: typing.ClassVar[int] = ...
    KEYCODE_CAPTIONS: typing.ClassVar[int] = ...
    KEYCODE_CHANNEL_DOWN: typing.ClassVar[int] = ...
    KEYCODE_CHANNEL_UP: typing.ClassVar[int] = ...
    KEYCODE_CLEAR: typing.ClassVar[int] = ...
    KEYCODE_CLOSE: typing.ClassVar[int] = ...
    KEYCODE_COMMA: typing.ClassVar[int] = ...
    KEYCODE_CONTACTS: typing.ClassVar[int] = ...
    KEYCODE_COPY: typing.ClassVar[int] = ...
    KEYCODE_CTRL_LEFT: typing.ClassVar[int] = ...
    KEYCODE_CTRL_RIGHT: typing.ClassVar[int] = ...
    KEYCODE_CUT: typing.ClassVar[int] = ...
    KEYCODE_D: typing.ClassVar[int] = ...
    KEYCODE_DEL: typing.ClassVar[int] = ...
    KEYCODE_DEMO_APP_1: typing.ClassVar[int] = ...
    KEYCODE_DEMO_APP_2: typing.ClassVar[int] = ...
    KEYCODE_DEMO_APP_3: typing.ClassVar[int] = ...
    KEYCODE_DEMO_APP_4: typing.ClassVar[int] = ...
    KEYCODE_DICTATE: typing.ClassVar[int] = ...
    KEYCODE_DO_NOT_DISTURB: typing.ClassVar[int] = ...
    KEYCODE_DPAD_CENTER: typing.ClassVar[int] = ...
    KEYCODE_DPAD_DOWN: typing.ClassVar[int] = ...
    KEYCODE_DPAD_DOWN_LEFT: typing.ClassVar[int] = ...
    KEYCODE_DPAD_DOWN_RIGHT: typing.ClassVar[int] = ...
    KEYCODE_DPAD_LEFT: typing.ClassVar[int] = ...
    KEYCODE_DPAD_RIGHT: typing.ClassVar[int] = ...
    KEYCODE_DPAD_UP: typing.ClassVar[int] = ...
    KEYCODE_DPAD_UP_LEFT: typing.ClassVar[int] = ...
    KEYCODE_DPAD_UP_RIGHT: typing.ClassVar[int] = ...
    KEYCODE_DVR: typing.ClassVar[int] = ...
    KEYCODE_E: typing.ClassVar[int] = ...
    KEYCODE_EISU: typing.ClassVar[int] = ...
    KEYCODE_EMOJI_PICKER: typing.ClassVar[int] = ...
    KEYCODE_ENDCALL: typing.ClassVar[int] = ...
    KEYCODE_ENTER: typing.ClassVar[int] = ...
    KEYCODE_ENVELOPE: typing.ClassVar[int] = ...
    KEYCODE_EQUALS: typing.ClassVar[int] = ...
    KEYCODE_ESCAPE: typing.ClassVar[int] = ...
    KEYCODE_EXPLORER: typing.ClassVar[int] = ...
    KEYCODE_F10: typing.ClassVar[int] = ...
    KEYCODE_F11: typing.ClassVar[int] = ...
    KEYCODE_F12: typing.ClassVar[int] = ...
    KEYCODE_F13: typing.ClassVar[int] = ...
    KEYCODE_F14: typing.ClassVar[int] = ...
    KEYCODE_F15: typing.ClassVar[int] = ...
    KEYCODE_F16: typing.ClassVar[int] = ...
    KEYCODE_F17: typing.ClassVar[int] = ...
    KEYCODE_F18: typing.ClassVar[int] = ...
    KEYCODE_F19: typing.ClassVar[int] = ...
    KEYCODE_F1: typing.ClassVar[int] = ...
    KEYCODE_F20: typing.ClassVar[int] = ...
    KEYCODE_F21: typing.ClassVar[int] = ...
    KEYCODE_F22: typing.ClassVar[int] = ...
    KEYCODE_F23: typing.ClassVar[int] = ...
    KEYCODE_F24: typing.ClassVar[int] = ...
    KEYCODE_F2: typing.ClassVar[int] = ...
    KEYCODE_F3: typing.ClassVar[int] = ...
    KEYCODE_F4: typing.ClassVar[int] = ...
    KEYCODE_F5: typing.ClassVar[int] = ...
    KEYCODE_F6: typing.ClassVar[int] = ...
    KEYCODE_F7: typing.ClassVar[int] = ...
    KEYCODE_F8: typing.ClassVar[int] = ...
    KEYCODE_F9: typing.ClassVar[int] = ...
    KEYCODE_F: typing.ClassVar[int] = ...
    KEYCODE_FEATURED_APP_1: typing.ClassVar[int] = ...
    KEYCODE_FEATURED_APP_2: typing.ClassVar[int] = ...
    KEYCODE_FEATURED_APP_3: typing.ClassVar[int] = ...
    KEYCODE_FEATURED_APP_4: typing.ClassVar[int] = ...
    KEYCODE_FOCUS: typing.ClassVar[int] = ...
    KEYCODE_FORWARD: typing.ClassVar[int] = ...
    KEYCODE_FORWARD_DEL: typing.ClassVar[int] = ...
    KEYCODE_FULLSCREEN: typing.ClassVar[int] = ...
    KEYCODE_FUNCTION: typing.ClassVar[int] = ...
    KEYCODE_G: typing.ClassVar[int] = ...
    KEYCODE_GRAVE: typing.ClassVar[int] = ...
    KEYCODE_GUIDE: typing.ClassVar[int] = ...
    KEYCODE_H: typing.ClassVar[int] = ...
    KEYCODE_HEADSETHOOK: typing.ClassVar[int] = ...
    KEYCODE_HELP: typing.ClassVar[int] = ...
    KEYCODE_HENKAN: typing.ClassVar[int] = ...
    KEYCODE_HOME: typing.ClassVar[int] = ...
    KEYCODE_I: typing.ClassVar[int] = ...
    KEYCODE_INFO: typing.ClassVar[int] = ...
    KEYCODE_INSERT: typing.ClassVar[int] = ...
    KEYCODE_J: typing.ClassVar[int] = ...
    KEYCODE_K: typing.ClassVar[int] = ...
    KEYCODE_KANA: typing.ClassVar[int] = ...
    KEYCODE_KATAKANA_HIRAGANA: typing.ClassVar[int] = ...
    KEYCODE_KEYBOARD_BACKLIGHT_DOWN: typing.ClassVar[int] = ...
    KEYCODE_KEYBOARD_BACKLIGHT_TOGGLE: typing.ClassVar[int] = ...
    KEYCODE_KEYBOARD_BACKLIGHT_UP: typing.ClassVar[int] = ...
    KEYCODE_L: typing.ClassVar[int] = ...
    KEYCODE_LANGUAGE_SWITCH: typing.ClassVar[int] = ...
    KEYCODE_LAST_CHANNEL: typing.ClassVar[int] = ...
    KEYCODE_LEFT_BRACKET: typing.ClassVar[int] = ...
    KEYCODE_LOCK: typing.ClassVar[int] = ...
    KEYCODE_M: typing.ClassVar[int] = ...
    KEYCODE_MACRO_1: typing.ClassVar[int] = ...
    KEYCODE_MACRO_2: typing.ClassVar[int] = ...
    KEYCODE_MACRO_3: typing.ClassVar[int] = ...
    KEYCODE_MACRO_4: typing.ClassVar[int] = ...
    KEYCODE_MANNER_MODE: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_AUDIO_TRACK: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_CLOSE: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_EJECT: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_FAST_FORWARD: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_NEXT: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_PAUSE: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_PLAY: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_PLAY_PAUSE: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_PREVIOUS: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_RECORD: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_REWIND: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_SKIP_BACKWARD: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_SKIP_FORWARD: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_STEP_BACKWARD: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_STEP_FORWARD: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_STOP: typing.ClassVar[int] = ...
    KEYCODE_MEDIA_TOP_MENU: typing.ClassVar[int] = ...
    KEYCODE_MENU: typing.ClassVar[int] = ...
    KEYCODE_META_LEFT: typing.ClassVar[int] = ...
    KEYCODE_META_RIGHT: typing.ClassVar[int] = ...
    KEYCODE_MINUS: typing.ClassVar[int] = ...
    KEYCODE_MOVE_END: typing.ClassVar[int] = ...
    KEYCODE_MOVE_HOME: typing.ClassVar[int] = ...
    KEYCODE_MUHENKAN: typing.ClassVar[int] = ...
    KEYCODE_MUSIC: typing.ClassVar[int] = ...
    KEYCODE_MUTE: typing.ClassVar[int] = ...
    KEYCODE_N: typing.ClassVar[int] = ...
    KEYCODE_NAVIGATE_IN: typing.ClassVar[int] = ...
    KEYCODE_NAVIGATE_NEXT: typing.ClassVar[int] = ...
    KEYCODE_NAVIGATE_OUT: typing.ClassVar[int] = ...
    KEYCODE_NAVIGATE_PREVIOUS: typing.ClassVar[int] = ...
    KEYCODE_NEW: typing.ClassVar[int] = ...
    KEYCODE_NOTIFICATION: typing.ClassVar[int] = ...
    KEYCODE_NUM: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_0: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_1: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_2: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_3: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_4: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_5: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_6: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_7: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_8: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_9: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_ADD: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_COMMA: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_DIVIDE: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_DOT: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_ENTER: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_EQUALS: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_LEFT_PAREN: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_MULTIPLY: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_RIGHT_PAREN: typing.ClassVar[int] = ...
    KEYCODE_NUMPAD_SUBTRACT: typing.ClassVar[int] = ...
    KEYCODE_NUM_LOCK: typing.ClassVar[int] = ...
    KEYCODE_O: typing.ClassVar[int] = ...
    KEYCODE_P: typing.ClassVar[int] = ...
    KEYCODE_PAGE_DOWN: typing.ClassVar[int] = ...
    KEYCODE_PAGE_UP: typing.ClassVar[int] = ...
    KEYCODE_PAIRING: typing.ClassVar[int] = ...
    KEYCODE_PASTE: typing.ClassVar[int] = ...
    KEYCODE_PERIOD: typing.ClassVar[int] = ...
    KEYCODE_PICTSYMBOLS: typing.ClassVar[int] = ...
    KEYCODE_PLUS: typing.ClassVar[int] = ...
    KEYCODE_POUND: typing.ClassVar[int] = ...
    KEYCODE_POWER: typing.ClassVar[int] = ...
    KEYCODE_PRINT: typing.ClassVar[int] = ...
    KEYCODE_PROFILE_SWITCH: typing.ClassVar[int] = ...
    KEYCODE_PROG_BLUE: typing.ClassVar[int] = ...
    KEYCODE_PROG_GREEN: typing.ClassVar[int] = ...
    KEYCODE_PROG_RED: typing.ClassVar[int] = ...
    KEYCODE_PROG_YELLOW: typing.ClassVar[int] = ...
    KEYCODE_Q: typing.ClassVar[int] = ...
    KEYCODE_R: typing.ClassVar[int] = ...
    KEYCODE_RECENT_APPS: typing.ClassVar[int] = ...
    KEYCODE_REFRESH: typing.ClassVar[int] = ...
    KEYCODE_RIGHT_BRACKET: typing.ClassVar[int] = ...
    KEYCODE_RO: typing.ClassVar[int] = ...
    KEYCODE_S: typing.ClassVar[int] = ...
    KEYCODE_SCREENSHOT: typing.ClassVar[int] = ...
    KEYCODE_SCROLL_LOCK: typing.ClassVar[int] = ...
    KEYCODE_SEARCH: typing.ClassVar[int] = ...
    KEYCODE_SEMICOLON: typing.ClassVar[int] = ...
    KEYCODE_SETTINGS: typing.ClassVar[int] = ...
    KEYCODE_SHIFT_LEFT: typing.ClassVar[int] = ...
    KEYCODE_SHIFT_RIGHT: typing.ClassVar[int] = ...
    KEYCODE_SLASH: typing.ClassVar[int] = ...
    KEYCODE_SLEEP: typing.ClassVar[int] = ...
    KEYCODE_SOFT_LEFT: typing.ClassVar[int] = ...
    KEYCODE_SOFT_RIGHT: typing.ClassVar[int] = ...
    KEYCODE_SOFT_SLEEP: typing.ClassVar[int] = ...
    KEYCODE_SPACE: typing.ClassVar[int] = ...
    KEYCODE_STAR: typing.ClassVar[int] = ...
    KEYCODE_STB_INPUT: typing.ClassVar[int] = ...
    KEYCODE_STB_POWER: typing.ClassVar[int] = ...
    KEYCODE_STEM_1: typing.ClassVar[int] = ...
    KEYCODE_STEM_2: typing.ClassVar[int] = ...
    KEYCODE_STEM_3: typing.ClassVar[int] = ...
    KEYCODE_STEM_PRIMARY: typing.ClassVar[int] = ...
    KEYCODE_STYLUS_BUTTON_PRIMARY: typing.ClassVar[int] = ...
    KEYCODE_STYLUS_BUTTON_SECONDARY: typing.ClassVar[int] = ...
    KEYCODE_STYLUS_BUTTON_TAIL: typing.ClassVar[int] = ...
    KEYCODE_STYLUS_BUTTON_TERTIARY: typing.ClassVar[int] = ...
    KEYCODE_SWITCH_CHARSET: typing.ClassVar[int] = ...
    KEYCODE_SYM: typing.ClassVar[int] = ...
    KEYCODE_SYSRQ: typing.ClassVar[int] = ...
    KEYCODE_SYSTEM_NAVIGATION_DOWN: typing.ClassVar[int] = ...
    KEYCODE_SYSTEM_NAVIGATION_LEFT: typing.ClassVar[int] = ...
    KEYCODE_SYSTEM_NAVIGATION_RIGHT: typing.ClassVar[int] = ...
    KEYCODE_SYSTEM_NAVIGATION_UP: typing.ClassVar[int] = ...
    KEYCODE_T: typing.ClassVar[int] = ...
    KEYCODE_TAB: typing.ClassVar[int] = ...
    KEYCODE_THUMBS_DOWN: typing.ClassVar[int] = ...
    KEYCODE_THUMBS_UP: typing.ClassVar[int] = ...
    KEYCODE_TV: typing.ClassVar[int] = ...
    KEYCODE_TV_ANTENNA_CABLE: typing.ClassVar[int] = ...
    KEYCODE_TV_AUDIO_DESCRIPTION: typing.ClassVar[int] = ...
    KEYCODE_TV_AUDIO_DESCRIPTION_MIX_DOWN: typing.ClassVar[int] = ...
    KEYCODE_TV_AUDIO_DESCRIPTION_MIX_UP: typing.ClassVar[int] = ...
    KEYCODE_TV_CONTENTS_MENU: typing.ClassVar[int] = ...
    KEYCODE_TV_DATA_SERVICE: typing.ClassVar[int] = ...
    KEYCODE_TV_INPUT: typing.ClassVar[int] = ...
    KEYCODE_TV_INPUT_COMPONENT_1: typing.ClassVar[int] = ...
    KEYCODE_TV_INPUT_COMPONENT_2: typing.ClassVar[int] = ...
    KEYCODE_TV_INPUT_COMPOSITE_1: typing.ClassVar[int] = ...
    KEYCODE_TV_INPUT_COMPOSITE_2: typing.ClassVar[int] = ...
    KEYCODE_TV_INPUT_HDMI_1: typing.ClassVar[int] = ...
    KEYCODE_TV_INPUT_HDMI_2: typing.ClassVar[int] = ...
    KEYCODE_TV_INPUT_HDMI_3: typing.ClassVar[int] = ...
    KEYCODE_TV_INPUT_HDMI_4: typing.ClassVar[int] = ...
    KEYCODE_TV_INPUT_VGA_1: typing.ClassVar[int] = ...
    KEYCODE_TV_MEDIA_CONTEXT_MENU: typing.ClassVar[int] = ...
    KEYCODE_TV_NETWORK: typing.ClassVar[int] = ...
    KEYCODE_TV_NUMBER_ENTRY: typing.ClassVar[int] = ...
    KEYCODE_TV_POWER: typing.ClassVar[int] = ...
    KEYCODE_TV_RADIO_SERVICE: typing.ClassVar[int] = ...
    KEYCODE_TV_SATELLITE: typing.ClassVar[int] = ...
    KEYCODE_TV_SATELLITE_BS: typing.ClassVar[int] = ...
    KEYCODE_TV_SATELLITE_CS: typing.ClassVar[int] = ...
    KEYCODE_TV_SATELLITE_SERVICE: typing.ClassVar[int] = ...
    KEYCODE_TV_TELETEXT: typing.ClassVar[int] = ...
    KEYCODE_TV_TERRESTRIAL_ANALOG: typing.ClassVar[int] = ...
    KEYCODE_TV_TERRESTRIAL_DIGITAL: typing.ClassVar[int] = ...
    KEYCODE_TV_TIMER_PROGRAMMING: typing.ClassVar[int] = ...
    KEYCODE_TV_ZOOM_MODE: typing.ClassVar[int] = ...
    KEYCODE_U: typing.ClassVar[int] = ...
    KEYCODE_UNKNOWN: typing.ClassVar[int] = ...
    KEYCODE_V: typing.ClassVar[int] = ...
    KEYCODE_VIDEO_APP_1: typing.ClassVar[int] = ...
    KEYCODE_VIDEO_APP_2: typing.ClassVar[int] = ...
    KEYCODE_VIDEO_APP_3: typing.ClassVar[int] = ...
    KEYCODE_VIDEO_APP_4: typing.ClassVar[int] = ...
    KEYCODE_VIDEO_APP_5: typing.ClassVar[int] = ...
    KEYCODE_VIDEO_APP_6: typing.ClassVar[int] = ...
    KEYCODE_VIDEO_APP_7: typing.ClassVar[int] = ...
    KEYCODE_VIDEO_APP_8: typing.ClassVar[int] = ...
    KEYCODE_VOICE_ASSIST: typing.ClassVar[int] = ...
    KEYCODE_VOLUME_DOWN: typing.ClassVar[int] = ...
    KEYCODE_VOLUME_MUTE: typing.ClassVar[int] = ...
    KEYCODE_VOLUME_UP: typing.ClassVar[int] = ...
    KEYCODE_W: typing.ClassVar[int] = ...
    KEYCODE_WAKEUP: typing.ClassVar[int] = ...
    KEYCODE_WINDOW: typing.ClassVar[int] = ...
    KEYCODE_X: typing.ClassVar[int] = ...
    KEYCODE_Y: typing.ClassVar[int] = ...
    KEYCODE_YEN: typing.ClassVar[int] = ...
    KEYCODE_Z: typing.ClassVar[int] = ...
    KEYCODE_ZENKAKU_HANKAKU: typing.ClassVar[int] = ...
    KEYCODE_ZOOM_IN: typing.ClassVar[int] = ...
    KEYCODE_ZOOM_OUT: typing.ClassVar[int] = ...
    MAX_KEYCODE: typing.ClassVar[int] = ...
    META_ALT_LEFT_ON: typing.ClassVar[int] = ...
    META_ALT_MASK: typing.ClassVar[int] = ...
    META_ALT_ON: typing.ClassVar[int] = ...
    META_ALT_RIGHT_ON: typing.ClassVar[int] = ...
    META_CAPS_LOCK_ON: typing.ClassVar[int] = ...
    META_CTRL_LEFT_ON: typing.ClassVar[int] = ...
    META_CTRL_MASK: typing.ClassVar[int] = ...
    META_CTRL_ON: typing.ClassVar[int] = ...
    META_CTRL_RIGHT_ON: typing.ClassVar[int] = ...
    META_FUNCTION_ON: typing.ClassVar[int] = ...
    META_META_LEFT_ON: typing.ClassVar[int] = ...
    META_META_MASK: typing.ClassVar[int] = ...
    META_META_ON: typing.ClassVar[int] = ...
    META_META_RIGHT_ON: typing.ClassVar[int] = ...
    META_NUM_LOCK_ON: typing.ClassVar[int] = ...
    META_SCROLL_LOCK_ON: typing.ClassVar[int] = ...
    META_SHIFT_LEFT_ON: typing.ClassVar[int] = ...
    META_SHIFT_MASK: typing.ClassVar[int] = ...
    META_SHIFT_ON: typing.ClassVar[int] = ...
    META_SHIFT_RIGHT_ON: typing.ClassVar[int] = ...
    META_SYM_ON: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, origEvent: KeyEvent, /) -> None: ...
    @typing.overload
    def __init__(self, action: int | java.jint | java.lang.Integer, code: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, origEvent: KeyEvent, eventTime: int | java.jlong | java.lang.Long, newRepeat: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, time: int | java.jlong | java.lang.Long, characters: str | java.lang.String, deviceId: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, downTime: int | java.jlong | java.lang.Long, eventTime: int | java.jlong | java.lang.Long, action: int | java.jint | java.lang.Integer, code: int | java.jint | java.lang.Integer, repeat: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, downTime: int | java.jlong | java.lang.Long, eventTime: int | java.jlong | java.lang.Long, action: int | java.jint | java.lang.Integer, code: int | java.jint | java.lang.Integer, repeat: int | java.jint | java.lang.Integer, metaState: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, downTime: int | java.jlong | java.lang.Long, eventTime: int | java.jlong | java.lang.Long, action: int | java.jint | java.lang.Integer, code: int | java.jint | java.lang.Integer, repeat: int | java.jint | java.lang.Integer, metaState: int | java.jint | java.lang.Integer, deviceId: int | java.jint | java.lang.Integer, scancode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, downTime: int | java.jlong | java.lang.Long, eventTime: int | java.jlong | java.lang.Long, action: int | java.jint | java.lang.Integer, code: int | java.jint | java.lang.Integer, repeat: int | java.jint | java.lang.Integer, metaState: int | java.jint | java.lang.Integer, deviceId: int | java.jint | java.lang.Integer, scancode: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, downTime: int | java.jlong | java.lang.Long, eventTime: int | java.jlong | java.lang.Long, action: int | java.jint | java.lang.Integer, code: int | java.jint | java.lang.Integer, repeat: int | java.jint | java.lang.Integer, metaState: int | java.jint | java.lang.Integer, deviceId: int | java.jint | java.lang.Integer, scancode: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, source: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def changeAction(event: KeyEvent, action: int | java.jint | java.lang.Integer, /) -> KeyEvent: ...
    @staticmethod
    def changeFlags(event: KeyEvent, flags: int | java.jint | java.lang.Integer, /) -> KeyEvent: ...
    @typing.overload
    @staticmethod
    def changeTimeRepeat(event: KeyEvent, eventTime: int | java.jlong | java.lang.Long, newRepeat: int | java.jint | java.lang.Integer, /) -> KeyEvent: ...
    @typing.overload
    @staticmethod
    def changeTimeRepeat(event: KeyEvent, eventTime: int | java.jlong | java.lang.Long, newRepeat: int | java.jint | java.lang.Integer, newFlags: int | java.jint | java.lang.Integer, /) -> KeyEvent: ...
    @typing.overload
    def dispatch(self, receiver: KeyEvent.Callback, /) -> bool: ...
    @typing.overload
    def dispatch(self, receiver: KeyEvent.Callback, state: KeyEvent.DispatcherState, target: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAction(self) -> int: ...
    def getCharacters(self) -> str: ...
    @staticmethod
    def getDeadChar(accent: int | java.jint | java.lang.Integer, c: int | java.jint | java.lang.Integer, /) -> int: ...
    def getDeviceId(self) -> int: ...
    def getDisplayLabel(self) -> str: ...
    def getDownTime(self) -> int: ...
    def getEventTime(self) -> int: ...
    def getFlags(self) -> int: ...
    def getKeyCharacterMap(self) -> KeyCharacterMap: ...
    def getKeyCode(self) -> int: ...
    def getKeyData(self, results: KeyCharacterMap.KeyData, /) -> bool: ...
    @typing.overload
    def getMatch(self, chars: java.chaquopy.JavaArrayJChar, /) -> str: ...
    @typing.overload
    def getMatch(self, chars: java.chaquopy.JavaArrayJChar, metaState: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def getMaxKeyCode() -> int: ...
    def getMetaState(self) -> int: ...
    @staticmethod
    def getModifierMetaStateMask() -> int: ...
    def getModifiers(self) -> int: ...
    def getNumber(self) -> str: ...
    def getRepeatCount(self) -> int: ...
    def getScanCode(self) -> int: ...
    def getSource(self) -> int: ...
    @typing.overload
    def getUnicodeChar(self) -> int: ...
    @typing.overload
    def getUnicodeChar(self, metaState: int | java.jint | java.lang.Integer, /) -> int: ...
    def hasModifiers(self, modifiers: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hasNoModifiers(self) -> bool: ...
    def isAltPressed(self) -> bool: ...
    def isCanceled(self) -> bool: ...
    def isCapsLockOn(self) -> bool: ...
    def isCtrlPressed(self) -> bool: ...
    def isFunctionPressed(self) -> bool: ...
    @staticmethod
    def isGamepadButton(keyCode: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isLongPress(self) -> bool: ...
    @staticmethod
    def isMediaSessionKey(keyCode: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isMetaPressed(self) -> bool: ...
    @staticmethod
    def isModifierKey(keyCode: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isNumLockOn(self) -> bool: ...
    def isPrintingKey(self) -> bool: ...
    def isScrollLockOn(self) -> bool: ...
    def isShiftPressed(self) -> bool: ...
    def isSymPressed(self) -> bool: ...
    def isSystem(self) -> bool: ...
    def isTracking(self) -> bool: ...
    @staticmethod
    def keyCodeFromString(symbolicName: str | java.lang.String, /) -> int: ...
    @staticmethod
    def keyCodeToString(keyCode: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def metaStateHasModifiers(metaState: int | java.jint | java.lang.Integer, modifiers: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def metaStateHasNoModifiers(metaState: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def normalizeMetaState(metaState: int | java.jint | java.lang.Integer, /) -> int: ...
    def setSource(self, source: int | java.jint | java.lang.Integer, /) -> None: ...
    def startTracking(self) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class DispatcherState(java.lang.Object):
        def __init__(self) -> None: ...
        def handleUpEvent(self, event: KeyEvent, /) -> None: ...
        def isTracking(self, event: KeyEvent, /) -> bool: ...
        def performedLongPress(self, event: KeyEvent, /) -> None: ...
        @typing.overload
        def reset(self) -> None: ...
        @typing.overload
        def reset(self, target: java.lang.Object | int | bool | float | str, /) -> None: ...
        def startTracking(self, event: KeyEvent, target: java.lang.Object | int | bool | float | str, /) -> None: ...

    class Callback(java.lang.Object):
        def onKeyDown(self, arg1: int | java.jint | java.lang.Integer, arg2: KeyEvent, /) -> bool: ...
        def onKeyLongPress(self, arg1: int | java.jint | java.lang.Integer, arg2: KeyEvent, /) -> bool: ...
        def onKeyMultiple(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: KeyEvent, /) -> bool: ...
        def onKeyUp(self, arg1: int | java.jint | java.lang.Integer, arg2: KeyEvent, /) -> bool: ...

class KeyboardShortcutGroup(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[KeyboardShortcutGroup]] = ...
    @typing.overload
    def __init__(self, label: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def __init__(self, label: java.lang.CharSequence, items: java.util.List[KeyboardShortcutInfo], /) -> None: ...
    def addItem(self, item: KeyboardShortcutInfo, /) -> None: ...
    def describeContents(self) -> int: ...
    def getItems(self) -> java.util.List[KeyboardShortcutInfo]: ...
    def getLabel(self) -> java.lang.CharSequence: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class KeyboardShortcutInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[KeyboardShortcutInfo]] = ...
    @typing.overload
    def __init__(self, label: java.lang.CharSequence, baseCharacter: str | java.jchar | java.lang.Character, modifiers: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, label: java.lang.CharSequence, keycode: int | java.jint | java.lang.Integer, modifiers: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getBaseCharacter(self) -> str: ...
    def getKeycode(self) -> int: ...
    def getLabel(self) -> java.lang.CharSequence | None: ...
    def getModifiers(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class LayoutInflater(java.lang.Object):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, original: LayoutInflater, newContext: android.content.Context, /) -> None: ...
    def cloneInContext(self, arg1: android.content.Context, /) -> LayoutInflater: ...
    @typing.overload
    def createView(self, name: str | java.lang.String, prefix: str | java.lang.String, attrs: android.util.AttributeSet, /) -> View | None: ...
    @typing.overload
    def createView(self, viewContext: android.content.Context, name: str | java.lang.String, prefix: str | java.lang.String, attrs: android.util.AttributeSet, /) -> View | None: ...
    @staticmethod
    def from_(context: android.content.Context, /) -> LayoutInflater: ...
    def getContext(self) -> android.content.Context: ...
    def getFactory(self) -> LayoutInflater.Factory: ...
    def getFactory2(self) -> LayoutInflater.Factory2: ...
    def getFilter(self) -> LayoutInflater.Filter: ...
    @typing.overload
    def inflate(self, resource: int | java.jint | java.lang.Integer, root: ViewGroup, /) -> View: ...
    @typing.overload
    def inflate(self, parser: org.xmlpull.v1.XmlPullParser, root: ViewGroup, /) -> View: ...
    @typing.overload
    def inflate(self, resource: int | java.jint | java.lang.Integer, root: ViewGroup, attachToRoot: bool | java.jboolean | java.lang.Boolean, /) -> View: ...
    @typing.overload
    def inflate(self, parser: org.xmlpull.v1.XmlPullParser, root: ViewGroup, attachToRoot: bool | java.jboolean | java.lang.Boolean, /) -> View: ...
    @typing.overload
    def onCreateView(self, name: str | java.lang.String, attrs: android.util.AttributeSet, /) -> View: ...
    @typing.overload
    def onCreateView(self, parent: View, name: str | java.lang.String, attrs: android.util.AttributeSet, /) -> View: ...
    @typing.overload
    def onCreateView(self, viewContext: android.content.Context, parent: View, name: str | java.lang.String, attrs: android.util.AttributeSet, /) -> View | None: ...
    def setFactory(self, factory: LayoutInflater.Factory, /) -> None: ...
    def setFactory2(self, factory: LayoutInflater.Factory2, /) -> None: ...
    def setFilter(self, filter: LayoutInflater.Filter, /) -> None: ...

    class Filter(java.lang.Object):
        def onLoadClass(self, arg1: typing.Type, /) -> bool: ...

    class Factory2(LayoutInflater.Factory):
        def onCreateView(self, arg1: View, arg2: str | java.lang.String, arg3: android.content.Context, arg4: android.util.AttributeSet, /) -> View: ...

    class Factory(java.lang.Object):
        def onCreateView(self, arg1: str | java.lang.String, arg2: android.content.Context, arg3: android.util.AttributeSet, /) -> View: ...

class Menu(java.lang.Object):
    CATEGORY_ALTERNATIVE: typing.ClassVar[int] = ...
    CATEGORY_CONTAINER: typing.ClassVar[int] = ...
    CATEGORY_SECONDARY: typing.ClassVar[int] = ...
    CATEGORY_SYSTEM: typing.ClassVar[int] = ...
    FIRST: typing.ClassVar[int] = ...
    FLAG_ALWAYS_PERFORM_CLOSE: typing.ClassVar[int] = ...
    FLAG_APPEND_TO_GROUP: typing.ClassVar[int] = ...
    FLAG_PERFORM_NO_CLOSE: typing.ClassVar[int] = ...
    NONE: typing.ClassVar[int] = ...
    SUPPORTED_MODIFIERS_MASK: typing.ClassVar[int] = ...
    @typing.overload
    def add(self, arg1: int | java.jint | java.lang.Integer, /) -> MenuItem: ...
    @typing.overload
    def add(self, arg1: java.lang.CharSequence, /) -> MenuItem: ...
    @typing.overload
    def add(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> MenuItem: ...
    @typing.overload
    def add(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.lang.CharSequence, /) -> MenuItem: ...
    def addIntentOptions(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: android.content.ComponentName, arg5: java.chaquopy.JavaArray[android.content.Intent], arg6: android.content.Intent, arg7: int | java.jint | java.lang.Integer, arg8: java.chaquopy.JavaArray[MenuItem], /) -> int: ...
    @typing.overload
    def addSubMenu(self, arg1: int | java.jint | java.lang.Integer, /) -> SubMenu: ...
    @typing.overload
    def addSubMenu(self, arg1: java.lang.CharSequence, /) -> SubMenu: ...
    @typing.overload
    def addSubMenu(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> SubMenu: ...
    @typing.overload
    def addSubMenu(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.lang.CharSequence, /) -> SubMenu: ...
    def clear(self) -> None: ...
    def close(self) -> None: ...
    def findItem(self, arg1: int | java.jint | java.lang.Integer, /) -> MenuItem | None: ...
    def getItem(self, arg1: int | java.jint | java.lang.Integer, /) -> MenuItem: ...
    def hasVisibleItems(self) -> bool: ...
    def isShortcutKey(self, arg1: int | java.jint | java.lang.Integer, arg2: KeyEvent, /) -> bool: ...
    def performIdentifierAction(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> bool: ...
    def performShortcut(self, arg1: int | java.jint | java.lang.Integer, arg2: KeyEvent, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...
    def removeGroup(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def removeItem(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setGroupCheckable(self, arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, arg3: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setGroupDividerEnabled(self, groupDividerEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setGroupEnabled(self, arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setGroupVisible(self, arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setQwertyMode(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def size(self) -> int: ...

class MenuInflater(java.lang.Object):
    def __init__(self, context: android.content.Context, /) -> None: ...
    def inflate(self, menuRes: int | java.jint | java.lang.Integer, menu: Menu, /) -> None: ...

class MenuItem(java.lang.Object):
    SHOW_AS_ACTION_ALWAYS: typing.ClassVar[int] = ...
    SHOW_AS_ACTION_COLLAPSE_ACTION_VIEW: typing.ClassVar[int] = ...
    SHOW_AS_ACTION_IF_ROOM: typing.ClassVar[int] = ...
    SHOW_AS_ACTION_NEVER: typing.ClassVar[int] = ...
    SHOW_AS_ACTION_WITH_TEXT: typing.ClassVar[int] = ...
    def collapseActionView(self) -> bool: ...
    def expandActionView(self) -> bool: ...
    def getActionProvider(self) -> ActionProvider | None: ...
    def getActionView(self) -> View | None: ...
    def getAlphabeticModifiers(self) -> int: ...
    def getAlphabeticShortcut(self) -> str: ...
    def getContentDescription(self) -> java.lang.CharSequence | None: ...
    def getGroupId(self) -> int: ...
    def getIcon(self) -> android.graphics.drawable.Drawable | None: ...
    def getIconTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getIconTintList(self) -> android.content.res.ColorStateList | None: ...
    def getIconTintMode(self) -> android.graphics.PorterDuff.Mode | None: ...
    def getIntent(self) -> android.content.Intent | None: ...
    def getItemId(self) -> int: ...
    def getMenuInfo(self) -> ContextMenu.ContextMenuInfo | None: ...
    def getNumericModifiers(self) -> int: ...
    def getNumericShortcut(self) -> str: ...
    def getOrder(self) -> int: ...
    def getSubMenu(self) -> SubMenu | None: ...
    def getTitle(self) -> java.lang.CharSequence | None: ...
    def getTitleCondensed(self) -> java.lang.CharSequence | None: ...
    def getTooltipText(self) -> java.lang.CharSequence | None: ...
    def hasSubMenu(self) -> bool: ...
    def isActionViewExpanded(self) -> bool: ...
    def isCheckable(self) -> bool: ...
    def isChecked(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isVisible(self) -> bool: ...
    def setActionProvider(self, arg1: ActionProvider, /) -> MenuItem: ...
    @typing.overload
    def setActionView(self, arg1: int | java.jint | java.lang.Integer, /) -> MenuItem: ...
    @typing.overload
    def setActionView(self, arg1: View, /) -> MenuItem: ...
    @typing.overload
    def setAlphabeticShortcut(self, arg1: str | java.jchar | java.lang.Character, /) -> MenuItem: ...
    @typing.overload
    def setAlphabeticShortcut(self, alphaChar: str | java.jchar | java.lang.Character, alphaModifiers: int | java.jint | java.lang.Integer, /) -> MenuItem: ...
    def setCheckable(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> MenuItem: ...
    def setChecked(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> MenuItem: ...
    def setContentDescription(self, contentDescription: java.lang.CharSequence, /) -> MenuItem: ...
    def setEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> MenuItem: ...
    @typing.overload
    def setIcon(self, arg1: int | java.jint | java.lang.Integer, /) -> MenuItem: ...
    @typing.overload
    def setIcon(self, arg1: android.graphics.drawable.Drawable, /) -> MenuItem: ...
    def setIconTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> MenuItem: ...
    def setIconTintList(self, tint: android.content.res.ColorStateList, /) -> MenuItem: ...
    def setIconTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> MenuItem: ...
    def setIntent(self, arg1: android.content.Intent, /) -> MenuItem: ...
    @typing.overload
    def setNumericShortcut(self, arg1: str | java.jchar | java.lang.Character, /) -> MenuItem: ...
    @typing.overload
    def setNumericShortcut(self, numericChar: str | java.jchar | java.lang.Character, numericModifiers: int | java.jint | java.lang.Integer, /) -> MenuItem: ...
    def setOnActionExpandListener(self, arg1: MenuItem.OnActionExpandListener, /) -> MenuItem: ...
    def setOnMenuItemClickListener(self, arg1: MenuItem.OnMenuItemClickListener, /) -> MenuItem: ...
    @typing.overload
    def setShortcut(self, arg1: str | java.jchar | java.lang.Character, arg2: str | java.jchar | java.lang.Character, /) -> MenuItem: ...
    @typing.overload
    def setShortcut(self, numericChar: str | java.jchar | java.lang.Character, alphaChar: str | java.jchar | java.lang.Character, numericModifiers: int | java.jint | java.lang.Integer, alphaModifiers: int | java.jint | java.lang.Integer, /) -> MenuItem: ...
    def setShowAsAction(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setShowAsActionFlags(self, arg1: int | java.jint | java.lang.Integer, /) -> MenuItem: ...
    @typing.overload
    def setTitle(self, arg1: int | java.jint | java.lang.Integer, /) -> MenuItem: ...
    @typing.overload
    def setTitle(self, arg1: java.lang.CharSequence, /) -> MenuItem: ...
    def setTitleCondensed(self, arg1: java.lang.CharSequence, /) -> MenuItem: ...
    def setTooltipText(self, tooltipText: java.lang.CharSequence, /) -> MenuItem: ...
    def setVisible(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> MenuItem: ...

    class OnMenuItemClickListener(java.lang.Object):
        def onMenuItemClick(self, arg1: MenuItem, /) -> bool: ...

    class OnActionExpandListener(java.lang.Object):
        def onMenuItemActionCollapse(self, arg1: MenuItem, /) -> bool: ...
        def onMenuItemActionExpand(self, arg1: MenuItem, /) -> bool: ...

class MotionEvent(InputEvent, android.os.Parcelable):
    ACTION_BUTTON_PRESS: typing.ClassVar[int] = ...
    ACTION_BUTTON_RELEASE: typing.ClassVar[int] = ...
    ACTION_CANCEL: typing.ClassVar[int] = ...
    ACTION_DOWN: typing.ClassVar[int] = ...
    ACTION_HOVER_ENTER: typing.ClassVar[int] = ...
    ACTION_HOVER_EXIT: typing.ClassVar[int] = ...
    ACTION_HOVER_MOVE: typing.ClassVar[int] = ...
    ACTION_MASK: typing.ClassVar[int] = ...
    ACTION_MOVE: typing.ClassVar[int] = ...
    ACTION_OUTSIDE: typing.ClassVar[int] = ...
    ACTION_POINTER_1_DOWN: typing.ClassVar[int] = ...
    ACTION_POINTER_1_UP: typing.ClassVar[int] = ...
    ACTION_POINTER_2_DOWN: typing.ClassVar[int] = ...
    ACTION_POINTER_2_UP: typing.ClassVar[int] = ...
    ACTION_POINTER_3_DOWN: typing.ClassVar[int] = ...
    ACTION_POINTER_3_UP: typing.ClassVar[int] = ...
    ACTION_POINTER_DOWN: typing.ClassVar[int] = ...
    ACTION_POINTER_ID_MASK: typing.ClassVar[int] = ...
    ACTION_POINTER_ID_SHIFT: typing.ClassVar[int] = ...
    ACTION_POINTER_INDEX_MASK: typing.ClassVar[int] = ...
    ACTION_POINTER_INDEX_SHIFT: typing.ClassVar[int] = ...
    ACTION_POINTER_UP: typing.ClassVar[int] = ...
    ACTION_SCROLL: typing.ClassVar[int] = ...
    ACTION_UP: typing.ClassVar[int] = ...
    AXIS_BRAKE: typing.ClassVar[int] = ...
    AXIS_DISTANCE: typing.ClassVar[int] = ...
    AXIS_GAS: typing.ClassVar[int] = ...
    AXIS_GENERIC_10: typing.ClassVar[int] = ...
    AXIS_GENERIC_11: typing.ClassVar[int] = ...
    AXIS_GENERIC_12: typing.ClassVar[int] = ...
    AXIS_GENERIC_13: typing.ClassVar[int] = ...
    AXIS_GENERIC_14: typing.ClassVar[int] = ...
    AXIS_GENERIC_15: typing.ClassVar[int] = ...
    AXIS_GENERIC_16: typing.ClassVar[int] = ...
    AXIS_GENERIC_1: typing.ClassVar[int] = ...
    AXIS_GENERIC_2: typing.ClassVar[int] = ...
    AXIS_GENERIC_3: typing.ClassVar[int] = ...
    AXIS_GENERIC_4: typing.ClassVar[int] = ...
    AXIS_GENERIC_5: typing.ClassVar[int] = ...
    AXIS_GENERIC_6: typing.ClassVar[int] = ...
    AXIS_GENERIC_7: typing.ClassVar[int] = ...
    AXIS_GENERIC_8: typing.ClassVar[int] = ...
    AXIS_GENERIC_9: typing.ClassVar[int] = ...
    AXIS_GESTURE_PINCH_SCALE_FACTOR: typing.ClassVar[int] = ...
    AXIS_GESTURE_SCROLL_X_DISTANCE: typing.ClassVar[int] = ...
    AXIS_GESTURE_SCROLL_Y_DISTANCE: typing.ClassVar[int] = ...
    AXIS_GESTURE_X_OFFSET: typing.ClassVar[int] = ...
    AXIS_GESTURE_Y_OFFSET: typing.ClassVar[int] = ...
    AXIS_HAT_X: typing.ClassVar[int] = ...
    AXIS_HAT_Y: typing.ClassVar[int] = ...
    AXIS_HSCROLL: typing.ClassVar[int] = ...
    AXIS_LTRIGGER: typing.ClassVar[int] = ...
    AXIS_ORIENTATION: typing.ClassVar[int] = ...
    AXIS_PRESSURE: typing.ClassVar[int] = ...
    AXIS_RELATIVE_X: typing.ClassVar[int] = ...
    AXIS_RELATIVE_Y: typing.ClassVar[int] = ...
    AXIS_RTRIGGER: typing.ClassVar[int] = ...
    AXIS_RUDDER: typing.ClassVar[int] = ...
    AXIS_RX: typing.ClassVar[int] = ...
    AXIS_RY: typing.ClassVar[int] = ...
    AXIS_RZ: typing.ClassVar[int] = ...
    AXIS_SCROLL: typing.ClassVar[int] = ...
    AXIS_SIZE: typing.ClassVar[int] = ...
    AXIS_THROTTLE: typing.ClassVar[int] = ...
    AXIS_TILT: typing.ClassVar[int] = ...
    AXIS_TOOL_MAJOR: typing.ClassVar[int] = ...
    AXIS_TOOL_MINOR: typing.ClassVar[int] = ...
    AXIS_TOUCH_MAJOR: typing.ClassVar[int] = ...
    AXIS_TOUCH_MINOR: typing.ClassVar[int] = ...
    AXIS_VSCROLL: typing.ClassVar[int] = ...
    AXIS_WHEEL: typing.ClassVar[int] = ...
    AXIS_X: typing.ClassVar[int] = ...
    AXIS_Y: typing.ClassVar[int] = ...
    AXIS_Z: typing.ClassVar[int] = ...
    BUTTON_BACK: typing.ClassVar[int] = ...
    BUTTON_FORWARD: typing.ClassVar[int] = ...
    BUTTON_PRIMARY: typing.ClassVar[int] = ...
    BUTTON_SECONDARY: typing.ClassVar[int] = ...
    BUTTON_STYLUS_PRIMARY: typing.ClassVar[int] = ...
    BUTTON_STYLUS_SECONDARY: typing.ClassVar[int] = ...
    BUTTON_TERTIARY: typing.ClassVar[int] = ...
    CLASSIFICATION_AMBIGUOUS_GESTURE: typing.ClassVar[int] = ...
    CLASSIFICATION_DEEP_PRESS: typing.ClassVar[int] = ...
    CLASSIFICATION_NONE: typing.ClassVar[int] = ...
    CLASSIFICATION_PINCH: typing.ClassVar[int] = ...
    CLASSIFICATION_TWO_FINGER_SWIPE: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MotionEvent]] = ...
    EDGE_BOTTOM: typing.ClassVar[int] = ...
    EDGE_LEFT: typing.ClassVar[int] = ...
    EDGE_RIGHT: typing.ClassVar[int] = ...
    EDGE_TOP: typing.ClassVar[int] = ...
    FLAG_CANCELED: typing.ClassVar[int] = ...
    FLAG_WINDOW_IS_OBSCURED: typing.ClassVar[int] = ...
    FLAG_WINDOW_IS_PARTIALLY_OBSCURED: typing.ClassVar[int] = ...
    INVALID_POINTER_ID: typing.ClassVar[int] = ...
    TOOL_TYPE_ERASER: typing.ClassVar[int] = ...
    TOOL_TYPE_FINGER: typing.ClassVar[int] = ...
    TOOL_TYPE_MOUSE: typing.ClassVar[int] = ...
    TOOL_TYPE_STYLUS: typing.ClassVar[int] = ...
    TOOL_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    @staticmethod
    def actionToString(action: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def addBatch(self, eventTime: int | java.jlong | java.lang.Long, pointerCoords: java.chaquopy.JavaArray[MotionEvent.PointerCoords], metaState: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addBatch(self, eventTime: int | java.jlong | java.lang.Long, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, pressure: float | java.jfloat | java.lang.Float, size: float | java.jfloat | java.lang.Float, metaState: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def axisFromString(symbolicName: str | java.lang.String, /) -> int: ...
    @staticmethod
    def axisToString(axis: int | java.jint | java.lang.Integer, /) -> str: ...
    def finalize(self) -> None: ...
    def findPointerIndex(self, pointerId: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAction(self) -> int: ...
    def getActionButton(self) -> int: ...
    def getActionIndex(self) -> int: ...
    def getActionMasked(self) -> int: ...
    @typing.overload
    def getAxisValue(self, axis: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getAxisValue(self, axis: int | java.jint | java.lang.Integer, pointerIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getButtonState(self) -> int: ...
    def getClassification(self) -> int: ...
    def getDeviceId(self) -> int: ...
    def getDownTime(self) -> int: ...
    def getEdgeFlags(self) -> int: ...
    def getEventTime(self) -> int: ...
    def getEventTimeNanos(self) -> int: ...
    def getFlags(self) -> int: ...
    @typing.overload
    def getHistoricalAxisValue(self, axis: int | java.jint | java.lang.Integer, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalAxisValue(self, axis: int | java.jint | java.lang.Integer, pointerIndex: int | java.jint | java.lang.Integer, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    def getHistoricalEventTime(self, pos: int | java.jint | java.lang.Integer, /) -> int: ...
    def getHistoricalEventTimeNanos(self, pos: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getHistoricalOrientation(self, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalOrientation(self, pointerIndex: int | java.jint | java.lang.Integer, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    def getHistoricalPointerCoords(self, pointerIndex: int | java.jint | java.lang.Integer, pos: int | java.jint | java.lang.Integer, outPointerCoords: MotionEvent.PointerCoords, /) -> None: ...
    @typing.overload
    def getHistoricalPressure(self, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalPressure(self, pointerIndex: int | java.jint | java.lang.Integer, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalSize(self, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalSize(self, pointerIndex: int | java.jint | java.lang.Integer, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalToolMajor(self, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalToolMajor(self, pointerIndex: int | java.jint | java.lang.Integer, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalToolMinor(self, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalToolMinor(self, pointerIndex: int | java.jint | java.lang.Integer, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalTouchMajor(self, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalTouchMajor(self, pointerIndex: int | java.jint | java.lang.Integer, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalTouchMinor(self, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalTouchMinor(self, pointerIndex: int | java.jint | java.lang.Integer, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalX(self, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalX(self, pointerIndex: int | java.jint | java.lang.Integer, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalY(self, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getHistoricalY(self, pointerIndex: int | java.jint | java.lang.Integer, pos: int | java.jint | java.lang.Integer, /) -> float: ...
    def getHistorySize(self) -> int: ...
    def getMetaState(self) -> int: ...
    @typing.overload
    def getOrientation(self) -> float: ...
    @typing.overload
    def getOrientation(self, pointerIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getPointerCoords(self, pointerIndex: int | java.jint | java.lang.Integer, outPointerCoords: MotionEvent.PointerCoords, /) -> None: ...
    def getPointerCount(self) -> int: ...
    def getPointerId(self, pointerIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getPointerProperties(self, pointerIndex: int | java.jint | java.lang.Integer, outPointerProperties: MotionEvent.PointerProperties, /) -> None: ...
    @typing.overload
    def getPressure(self) -> float: ...
    @typing.overload
    def getPressure(self, pointerIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getRawX(self) -> float: ...
    @typing.overload
    def getRawX(self, pointerIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getRawY(self) -> float: ...
    @typing.overload
    def getRawY(self, pointerIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getSize(self) -> float: ...
    @typing.overload
    def getSize(self, pointerIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getSource(self) -> int: ...
    @typing.overload
    def getToolMajor(self) -> float: ...
    @typing.overload
    def getToolMajor(self, pointerIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getToolMinor(self) -> float: ...
    @typing.overload
    def getToolMinor(self, pointerIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getToolType(self, pointerIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getTouchMajor(self) -> float: ...
    @typing.overload
    def getTouchMajor(self, pointerIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getTouchMinor(self) -> float: ...
    @typing.overload
    def getTouchMinor(self, pointerIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getX(self) -> float: ...
    @typing.overload
    def getX(self, pointerIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getXPrecision(self) -> float: ...
    @typing.overload
    def getY(self) -> float: ...
    @typing.overload
    def getY(self, pointerIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getYPrecision(self) -> float: ...
    def isButtonPressed(self, button: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    @staticmethod
    def obtain(other: MotionEvent, /) -> MotionEvent | None: ...
    @typing.overload
    @staticmethod
    def obtain(downTime: int | java.jlong | java.lang.Long, eventTime: int | java.jlong | java.lang.Long, action: int | java.jint | java.lang.Integer, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, metaState: int | java.jint | java.lang.Integer, /) -> MotionEvent | None: ...
    @typing.overload
    @staticmethod
    def obtain(downTime: int | java.jlong | java.lang.Long, eventTime: int | java.jlong | java.lang.Long, action: int | java.jint | java.lang.Integer, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, pressure: float | java.jfloat | java.lang.Float, size: float | java.jfloat | java.lang.Float, metaState: int | java.jint | java.lang.Integer, xPrecision: float | java.jfloat | java.lang.Float, yPrecision: float | java.jfloat | java.lang.Float, deviceId: int | java.jint | java.lang.Integer, edgeFlags: int | java.jint | java.lang.Integer, /) -> MotionEvent | None: ...
    @typing.overload
    @staticmethod
    def obtain(downTime: int | java.jlong | java.lang.Long, eventTime: int | java.jlong | java.lang.Long, action: int | java.jint | java.lang.Integer, pointerCount: int | java.jint | java.lang.Integer, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, pressure: float | java.jfloat | java.lang.Float, size: float | java.jfloat | java.lang.Float, metaState: int | java.jint | java.lang.Integer, xPrecision: float | java.jfloat | java.lang.Float, yPrecision: float | java.jfloat | java.lang.Float, deviceId: int | java.jint | java.lang.Integer, edgeFlags: int | java.jint | java.lang.Integer, /) -> MotionEvent | None: ...
    @typing.overload
    @staticmethod
    def obtain(downTime: int | java.jlong | java.lang.Long, eventTime: int | java.jlong | java.lang.Long, action: int | java.jint | java.lang.Integer, pointerCount: int | java.jint | java.lang.Integer, pointerIds: java.chaquopy.JavaArrayJInt, pointerCoords: java.chaquopy.JavaArray[MotionEvent.PointerCoords], metaState: int | java.jint | java.lang.Integer, xPrecision: float | java.jfloat | java.lang.Float, yPrecision: float | java.jfloat | java.lang.Float, deviceId: int | java.jint | java.lang.Integer, edgeFlags: int | java.jint | java.lang.Integer, source: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> MotionEvent | None: ...
    @typing.overload
    @staticmethod
    def obtain(downTime: int | java.jlong | java.lang.Long, eventTime: int | java.jlong | java.lang.Long, action: int | java.jint | java.lang.Integer, pointerCount: int | java.jint | java.lang.Integer, pointerProperties: java.chaquopy.JavaArray[MotionEvent.PointerProperties], pointerCoords: java.chaquopy.JavaArray[MotionEvent.PointerCoords], metaState: int | java.jint | java.lang.Integer, buttonState: int | java.jint | java.lang.Integer, xPrecision: float | java.jfloat | java.lang.Float, yPrecision: float | java.jfloat | java.lang.Float, deviceId: int | java.jint | java.lang.Integer, edgeFlags: int | java.jint | java.lang.Integer, source: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> MotionEvent | None: ...
    @typing.overload
    @staticmethod
    def obtain(downTime: int | java.jlong | java.lang.Long, eventTime: int | java.jlong | java.lang.Long, action: int | java.jint | java.lang.Integer, pointerCount: int | java.jint | java.lang.Integer, pointerProperties: java.chaquopy.JavaArray[MotionEvent.PointerProperties], pointerCoords: java.chaquopy.JavaArray[MotionEvent.PointerCoords], metaState: int | java.jint | java.lang.Integer, buttonState: int | java.jint | java.lang.Integer, xPrecision: float | java.jfloat | java.lang.Float, yPrecision: float | java.jfloat | java.lang.Float, deviceId: int | java.jint | java.lang.Integer, edgeFlags: int | java.jint | java.lang.Integer, source: int | java.jint | java.lang.Integer, displayId: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, classification: int | java.jint | java.lang.Integer, /) -> MotionEvent | None: ...
    @staticmethod
    def obtainNoHistory(other: MotionEvent, /) -> MotionEvent: ...
    def offsetLocation(self, deltaX: float | java.jfloat | java.lang.Float, deltaY: float | java.jfloat | java.lang.Float, /) -> None: ...
    def recycle(self) -> None: ...
    def setAction(self, action: int | java.jint | java.lang.Integer, /) -> None: ...
    def setEdgeFlags(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLocation(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setSource(self, source: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...
    def transform(self, matrix: android.graphics.Matrix, /) -> None: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class PointerProperties(java.lang.Object):
        id: int = ...
        toolType: int = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, other: MotionEvent.PointerProperties, /) -> None: ...
        def clear(self) -> None: ...
        def copyFrom(self, other: MotionEvent.PointerProperties, /) -> None: ...
        def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def hashCode(self) -> int: ...

    class PointerCoords(java.lang.Object):
        orientation: float = ...
        pressure: float = ...
        size: float = ...
        toolMajor: float = ...
        toolMinor: float = ...
        touchMajor: float = ...
        touchMinor: float = ...
        x: float = ...
        y: float = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, other: MotionEvent.PointerCoords, /) -> None: ...
        def clear(self) -> None: ...
        def copyFrom(self, other: MotionEvent.PointerCoords, /) -> None: ...
        def getAxisValue(self, axis: int | java.jint | java.lang.Integer, /) -> float: ...
        def isResampled(self) -> bool: ...
        def setAxisValue(self, axis: int | java.jint | java.lang.Integer, value: float | java.jfloat | java.lang.Float, /) -> None: ...

class MotionPredictor(java.lang.Object):
    def __init__(self, context: android.content.Context, /) -> None: ...
    def isPredictionAvailable(self, deviceId: int | java.jint | java.lang.Integer, source: int | java.jint | java.lang.Integer, /) -> bool: ...
    def predict(self, predictionTimeNanos: int | java.jlong | java.lang.Long, /) -> MotionEvent | None: ...
    def record(self, event: MotionEvent, /) -> None: ...

class OnReceiveContentListener(java.lang.Object):
    def onReceiveContent(self, arg1: View, arg2: ContentInfo, /) -> ContentInfo | None: ...

class OrientationEventListener(java.lang.Object):
    ORIENTATION_UNKNOWN: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, rate: int | java.jint | java.lang.Integer, /) -> None: ...
    def canDetectOrientation(self) -> bool: ...
    def disable(self) -> None: ...
    def enable(self) -> None: ...
    def onOrientationChanged(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class OrientationListener(android.hardware.SensorListener):
    ORIENTATION_UNKNOWN: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, rate: int | java.jint | java.lang.Integer, /) -> None: ...
    def disable(self) -> None: ...
    def enable(self) -> None: ...
    def onAccuracyChanged(self, sensor: int | java.jint | java.lang.Integer, accuracy: int | java.jint | java.lang.Integer, /) -> None: ...
    def onOrientationChanged(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSensorChanged(self, sensor: int | java.jint | java.lang.Integer, values: java.chaquopy.JavaArrayJFloat, /) -> None: ...

class PixelCopy(java.lang.Object):
    ERROR_DESTINATION_INVALID: typing.ClassVar[int] = ...
    ERROR_SOURCE_INVALID: typing.ClassVar[int] = ...
    ERROR_SOURCE_NO_DATA: typing.ClassVar[int] = ...
    ERROR_TIMEOUT: typing.ClassVar[int] = ...
    ERROR_UNKNOWN: typing.ClassVar[int] = ...
    SUCCESS: typing.ClassVar[int] = ...
    @typing.overload
    @staticmethod
    def request(request: PixelCopy.Request, callbackExecutor: java.util.concurrent.Executor, listener: java.util.function.Consumer[PixelCopy.Result], /) -> None: ...
    @typing.overload
    @staticmethod
    def request(source: Surface, dest: android.graphics.Bitmap, listener: PixelCopy.OnPixelCopyFinishedListener, listenerThread: android.os.Handler, /) -> None: ...
    @typing.overload
    @staticmethod
    def request(source: SurfaceView, dest: android.graphics.Bitmap, listener: PixelCopy.OnPixelCopyFinishedListener, listenerThread: android.os.Handler, /) -> None: ...
    @typing.overload
    @staticmethod
    def request(source: Window, dest: android.graphics.Bitmap, listener: PixelCopy.OnPixelCopyFinishedListener, listenerThread: android.os.Handler, /) -> None: ...
    @typing.overload
    @staticmethod
    def request(source: Surface, srcRect: android.graphics.Rect, dest: android.graphics.Bitmap, listener: PixelCopy.OnPixelCopyFinishedListener, listenerThread: android.os.Handler, /) -> None: ...
    @typing.overload
    @staticmethod
    def request(source: SurfaceView, srcRect: android.graphics.Rect, dest: android.graphics.Bitmap, listener: PixelCopy.OnPixelCopyFinishedListener, listenerThread: android.os.Handler, /) -> None: ...
    @typing.overload
    @staticmethod
    def request(source: Window, srcRect: android.graphics.Rect, dest: android.graphics.Bitmap, listener: PixelCopy.OnPixelCopyFinishedListener, listenerThread: android.os.Handler, /) -> None: ...

    class Result(java.lang.Object):
        def getBitmap(self) -> android.graphics.Bitmap: ...
        def getStatus(self) -> int: ...

    class Request(java.lang.Object):
        def getDestinationBitmap(self) -> android.graphics.Bitmap: ...
        def getSourceRect(self) -> android.graphics.Rect: ...

        class Builder(java.lang.Object):
            def build(self) -> PixelCopy.Request: ...
            @typing.overload
            @staticmethod
            def ofSurface(source: Surface, /) -> PixelCopy.Request.Builder: ...
            @typing.overload
            @staticmethod
            def ofSurface(source: SurfaceView, /) -> PixelCopy.Request.Builder: ...
            @typing.overload
            @staticmethod
            def ofWindow(source: View, /) -> PixelCopy.Request.Builder: ...
            @typing.overload
            @staticmethod
            def ofWindow(source: Window, /) -> PixelCopy.Request.Builder: ...
            def setDestinationBitmap(self, destination: android.graphics.Bitmap, /) -> PixelCopy.Request.Builder: ...
            def setSourceRect(self, srcRect: android.graphics.Rect, /) -> PixelCopy.Request.Builder: ...

    class OnPixelCopyFinishedListener(java.lang.Object):
        def onPixelCopyFinished(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class PointerIcon(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PointerIcon]] = ...
    TYPE_ALIAS: typing.ClassVar[int] = ...
    TYPE_ALL_SCROLL: typing.ClassVar[int] = ...
    TYPE_ARROW: typing.ClassVar[int] = ...
    TYPE_CELL: typing.ClassVar[int] = ...
    TYPE_CONTEXT_MENU: typing.ClassVar[int] = ...
    TYPE_COPY: typing.ClassVar[int] = ...
    TYPE_CROSSHAIR: typing.ClassVar[int] = ...
    TYPE_DEFAULT: typing.ClassVar[int] = ...
    TYPE_GRAB: typing.ClassVar[int] = ...
    TYPE_GRABBING: typing.ClassVar[int] = ...
    TYPE_HAND: typing.ClassVar[int] = ...
    TYPE_HANDWRITING: typing.ClassVar[int] = ...
    TYPE_HELP: typing.ClassVar[int] = ...
    TYPE_HORIZONTAL_DOUBLE_ARROW: typing.ClassVar[int] = ...
    TYPE_NO_DROP: typing.ClassVar[int] = ...
    TYPE_NULL: typing.ClassVar[int] = ...
    TYPE_TEXT: typing.ClassVar[int] = ...
    TYPE_TOP_LEFT_DIAGONAL_DOUBLE_ARROW: typing.ClassVar[int] = ...
    TYPE_TOP_RIGHT_DIAGONAL_DOUBLE_ARROW: typing.ClassVar[int] = ...
    TYPE_VERTICAL_DOUBLE_ARROW: typing.ClassVar[int] = ...
    TYPE_VERTICAL_TEXT: typing.ClassVar[int] = ...
    TYPE_WAIT: typing.ClassVar[int] = ...
    TYPE_ZOOM_IN: typing.ClassVar[int] = ...
    TYPE_ZOOM_OUT: typing.ClassVar[int] = ...
    @staticmethod
    def create(bitmap: android.graphics.Bitmap, hotSpotX: float | java.jfloat | java.lang.Float, hotSpotY: float | java.jfloat | java.lang.Float, /) -> PointerIcon: ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def getSystemIcon(context: android.content.Context, type: int | java.jint | java.lang.Integer, /) -> PointerIcon: ...
    @staticmethod
    def load(resources: android.content.res.Resources, resourceId: int | java.jint | java.lang.Integer, /) -> PointerIcon: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class RoundedCorner(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RoundedCorner]] = ...
    POSITION_BOTTOM_LEFT: typing.ClassVar[int] = ...
    POSITION_BOTTOM_RIGHT: typing.ClassVar[int] = ...
    POSITION_TOP_LEFT: typing.ClassVar[int] = ...
    POSITION_TOP_RIGHT: typing.ClassVar[int] = ...
    def __init__(self, position: int | java.jint | java.lang.Integer, radius: int | java.jint | java.lang.Integer, centerX: int | java.jint | java.lang.Integer, centerY: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCenter(self) -> android.graphics.Point: ...
    def getPosition(self) -> int: ...
    def getRadius(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ScaleGestureDetector(java.lang.Object):
    @typing.overload
    def __init__(self, context: android.content.Context, listener: ScaleGestureDetector.OnScaleGestureListener, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, listener: ScaleGestureDetector.OnScaleGestureListener, handler: android.os.Handler, /) -> None: ...
    def getCurrentSpan(self) -> float: ...
    def getCurrentSpanX(self) -> float: ...
    def getCurrentSpanY(self) -> float: ...
    def getEventTime(self) -> int: ...
    def getFocusX(self) -> float: ...
    def getFocusY(self) -> float: ...
    def getPreviousSpan(self) -> float: ...
    def getPreviousSpanX(self) -> float: ...
    def getPreviousSpanY(self) -> float: ...
    def getScaleFactor(self) -> float: ...
    def getTimeDelta(self) -> int: ...
    def isInProgress(self) -> bool: ...
    def isQuickScaleEnabled(self) -> bool: ...
    def isStylusScaleEnabled(self) -> bool: ...
    def onTouchEvent(self, event: MotionEvent, /) -> bool: ...
    def setQuickScaleEnabled(self, scales: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setStylusScaleEnabled(self, scales: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class SimpleOnScaleGestureListener(ScaleGestureDetector.OnScaleGestureListener):
        def __init__(self) -> None: ...
        def onScale(self, detector: ScaleGestureDetector, /) -> bool: ...
        def onScaleBegin(self, detector: ScaleGestureDetector, /) -> bool: ...
        def onScaleEnd(self, detector: ScaleGestureDetector, /) -> None: ...

    class OnScaleGestureListener(java.lang.Object):
        def onScale(self, arg1: ScaleGestureDetector, /) -> bool: ...
        def onScaleBegin(self, arg1: ScaleGestureDetector, /) -> bool: ...
        def onScaleEnd(self, arg1: ScaleGestureDetector, /) -> None: ...

class ScrollCaptureCallback(java.lang.Object):
    def onScrollCaptureEnd(self, arg1: java.lang.Runnable, /) -> None: ...
    def onScrollCaptureImageRequest(self, arg1: ScrollCaptureSession, arg2: android.os.CancellationSignal, arg3: android.graphics.Rect, arg4: java.util.function.Consumer[android.graphics.Rect], /) -> None: ...
    def onScrollCaptureSearch(self, arg1: android.os.CancellationSignal, arg2: java.util.function.Consumer[android.graphics.Rect], /) -> None: ...
    def onScrollCaptureStart(self, arg1: ScrollCaptureSession, arg2: android.os.CancellationSignal, arg3: java.lang.Runnable, /) -> None: ...

class ScrollCaptureSession(java.lang.Object):
    def __init__(self, surface: Surface, scrollBounds: android.graphics.Rect, positionInWindow: android.graphics.Point, /) -> None: ...
    def getPositionInWindow(self) -> android.graphics.Point: ...
    def getScrollBounds(self) -> android.graphics.Rect: ...
    def getSurface(self) -> Surface: ...

class ScrollCaptureTarget(java.lang.Object):
    def __init__(self, scrollTarget: View, localVisibleRect: android.graphics.Rect, positionInWindow: android.graphics.Point, callback: ScrollCaptureCallback, /) -> None: ...
    def getCallback(self) -> ScrollCaptureCallback: ...
    def getContainingView(self) -> View: ...
    def getHint(self) -> int: ...
    def getLocalVisibleRect(self) -> android.graphics.Rect: ...
    def getPositionInWindow(self) -> android.graphics.Point: ...
    def getScrollBounds(self) -> android.graphics.Rect | None: ...
    def setScrollBounds(self, scrollBounds: android.graphics.Rect, /) -> None: ...
    def toString(self) -> str: ...
    def updatePositionInWindow(self) -> None: ...

class ScrollFeedbackProvider(java.lang.Object):
    @staticmethod
    def createProvider(view: View, /) -> ScrollFeedbackProvider: ...
    def onScrollLimit(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onScrollProgress(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSnapToItem(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...

class SearchEvent(java.lang.Object):
    def __init__(self, inputDevice: InputDevice, /) -> None: ...
    def getInputDevice(self) -> InputDevice: ...

class SoundEffectConstants(java.lang.Object):
    CLICK: typing.ClassVar[int] = ...
    NAVIGATION_DOWN: typing.ClassVar[int] = ...
    NAVIGATION_LEFT: typing.ClassVar[int] = ...
    NAVIGATION_REPEAT_DOWN: typing.ClassVar[int] = ...
    NAVIGATION_REPEAT_LEFT: typing.ClassVar[int] = ...
    NAVIGATION_REPEAT_RIGHT: typing.ClassVar[int] = ...
    NAVIGATION_REPEAT_UP: typing.ClassVar[int] = ...
    NAVIGATION_RIGHT: typing.ClassVar[int] = ...
    NAVIGATION_UP: typing.ClassVar[int] = ...
    @staticmethod
    def getConstantForFocusDirection(direction: int | java.jint | java.lang.Integer, repeating: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    @staticmethod
    def getContantForFocusDirection(direction: int | java.jint | java.lang.Integer, /) -> int: ...

class SubMenu(Menu):
    def clearHeader(self) -> None: ...
    def getItem(self) -> MenuItem: ...
    @typing.overload
    def setHeaderIcon(self, arg1: int | java.jint | java.lang.Integer, /) -> SubMenu: ...
    @typing.overload
    def setHeaderIcon(self, arg1: android.graphics.drawable.Drawable, /) -> SubMenu: ...
    @typing.overload
    def setHeaderTitle(self, arg1: int | java.jint | java.lang.Integer, /) -> SubMenu: ...
    @typing.overload
    def setHeaderTitle(self, arg1: java.lang.CharSequence, /) -> SubMenu: ...
    def setHeaderView(self, arg1: View, /) -> SubMenu: ...
    @typing.overload
    def setIcon(self, arg1: int | java.jint | java.lang.Integer, /) -> SubMenu: ...
    @typing.overload
    def setIcon(self, arg1: android.graphics.drawable.Drawable, /) -> SubMenu: ...

class Surface(android.os.Parcelable):
    CHANGE_FRAME_RATE_ALWAYS: typing.ClassVar[int] = ...
    CHANGE_FRAME_RATE_ONLY_IF_SEAMLESS: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Surface]] = ...
    FRAME_RATE_COMPATIBILITY_AT_LEAST: typing.ClassVar[int] = ...
    FRAME_RATE_COMPATIBILITY_DEFAULT: typing.ClassVar[int] = ...
    FRAME_RATE_COMPATIBILITY_FIXED_SOURCE: typing.ClassVar[int] = ...
    ROTATION_0: typing.ClassVar[int] = ...
    ROTATION_180: typing.ClassVar[int] = ...
    ROTATION_270: typing.ClassVar[int] = ...
    ROTATION_90: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, surfaceTexture: android.graphics.SurfaceTexture, /) -> None: ...
    @typing.overload
    def __init__(self, from_: SurfaceControl, /) -> None: ...
    def clearFrameRate(self) -> None: ...
    def describeContents(self) -> int: ...
    def finalize(self) -> None: ...
    def isValid(self) -> bool: ...
    def lockCanvas(self, inOutDirty: android.graphics.Rect, /) -> android.graphics.Canvas: ...
    def lockHardwareCanvas(self) -> android.graphics.Canvas: ...
    def readFromParcel(self, source: android.os.Parcel, /) -> None: ...
    def release(self) -> None: ...
    @typing.overload
    def setFrameRate(self, frameRate: float | java.jfloat | java.lang.Float, compatibility: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setFrameRate(self, frameRate: float | java.jfloat | java.lang.Float, compatibility: int | java.jint | java.lang.Integer, changeFrameRateStrategy: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...
    def unlockCanvas(self, canvas: android.graphics.Canvas, /) -> None: ...
    def unlockCanvasAndPost(self, canvas: android.graphics.Canvas, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class OutOfResourcesException(java.lang.RuntimeException):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, name: str | java.lang.String, /) -> None: ...

class SurfaceControl(android.os.Parcelable):
    BUFFER_TRANSFORM_IDENTITY: typing.ClassVar[int] = ...
    BUFFER_TRANSFORM_MIRROR_HORIZONTAL: typing.ClassVar[int] = ...
    BUFFER_TRANSFORM_MIRROR_VERTICAL: typing.ClassVar[int] = ...
    BUFFER_TRANSFORM_ROTATE_180: typing.ClassVar[int] = ...
    BUFFER_TRANSFORM_ROTATE_270: typing.ClassVar[int] = ...
    BUFFER_TRANSFORM_ROTATE_90: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SurfaceControl]] = ...
    def describeContents(self) -> int: ...
    def finalize(self) -> None: ...
    def isValid(self) -> bool: ...
    def readFromParcel(self, in_: android.os.Parcel, /) -> None: ...
    def release(self) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class TrustedPresentationThresholds(java.lang.Object):
        def __init__(self, minAlpha: float | java.jfloat | java.lang.Float, minFractionRendered: float | java.jfloat | java.lang.Float, stabilityRequirementMs: int | java.jint | java.lang.Integer, /) -> None: ...

    class TransactionStats(java.lang.Object):
        def getLatchTimeNanos(self) -> int: ...
        def getPresentFence(self) -> android.hardware.SyncFence: ...

    class TransactionCommittedListener(java.lang.Object):
        def onTransactionCommitted(self) -> None: ...

    class Transaction(android.os.Parcelable, java.io.Closeable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SurfaceControl.Transaction]] = ...
        def __init__(self) -> None: ...
        def addTransactionCommittedListener(self, executor: java.util.concurrent.Executor, listener: SurfaceControl.TransactionCommittedListener, /) -> SurfaceControl.Transaction: ...
        def addTransactionCompletedListener(self, executor: java.util.concurrent.Executor, listener: java.util.function.Consumer[SurfaceControl.TransactionStats], /) -> SurfaceControl.Transaction: ...
        def apply(self) -> None: ...
        def clearFrameRate(self, sc: SurfaceControl, /) -> SurfaceControl.Transaction: ...
        def clearTrustedPresentationCallback(self, sc: SurfaceControl, /) -> SurfaceControl.Transaction: ...
        def close(self) -> None: ...
        def describeContents(self) -> int: ...
        def merge(self, other: SurfaceControl.Transaction, /) -> SurfaceControl.Transaction: ...
        def reparent(self, sc: SurfaceControl, newParent: SurfaceControl, /) -> SurfaceControl.Transaction: ...
        def setAlpha(self, sc: SurfaceControl, alpha: float | java.jfloat | java.lang.Float, /) -> SurfaceControl.Transaction: ...
        @typing.overload
        def setBuffer(self, sc: SurfaceControl, buffer: android.hardware.HardwareBuffer, /) -> SurfaceControl.Transaction: ...
        @typing.overload
        def setBuffer(self, sc: SurfaceControl, buffer: android.hardware.HardwareBuffer, fence: android.hardware.SyncFence, /) -> SurfaceControl.Transaction: ...
        @typing.overload
        def setBuffer(self, sc: SurfaceControl, buffer: android.hardware.HardwareBuffer, fence: android.hardware.SyncFence, releaseCallback: java.util.function.Consumer[android.hardware.SyncFence], /) -> SurfaceControl.Transaction: ...
        def setBufferSize(self, sc: SurfaceControl, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, /) -> SurfaceControl.Transaction: ...
        def setBufferTransform(self, sc: SurfaceControl, transform: int | java.jint | java.lang.Integer, /) -> SurfaceControl.Transaction: ...
        def setContentPriority(self, sc: SurfaceControl, priority: int | java.jint | java.lang.Integer, /) -> SurfaceControl.Transaction: ...
        def setCrop(self, sc: SurfaceControl, crop: android.graphics.Rect, /) -> SurfaceControl.Transaction: ...
        def setDamageRegion(self, sc: SurfaceControl, region: android.graphics.Region, /) -> SurfaceControl.Transaction: ...
        def setDataSpace(self, sc: SurfaceControl, dataspace: int | java.jint | java.lang.Integer, /) -> SurfaceControl.Transaction: ...
        def setDesiredHdrHeadroom(self, sc: SurfaceControl, desiredRatio: float | java.jfloat | java.lang.Float, /) -> SurfaceControl.Transaction: ...
        def setDesiredPresentTimeNanos(self, desiredPresentTimeNanos: int | java.jlong | java.lang.Long, /) -> SurfaceControl.Transaction: ...
        def setExtendedRangeBrightness(self, sc: SurfaceControl, currentBufferRatio: float | java.jfloat | java.lang.Float, desiredRatio: float | java.jfloat | java.lang.Float, /) -> SurfaceControl.Transaction: ...
        @typing.overload
        def setFrameRate(self, sc: SurfaceControl, frameRate: float | java.jfloat | java.lang.Float, compatibility: int | java.jint | java.lang.Integer, /) -> SurfaceControl.Transaction: ...
        @typing.overload
        def setFrameRate(self, sc: SurfaceControl, frameRate: float | java.jfloat | java.lang.Float, compatibility: int | java.jint | java.lang.Integer, changeFrameRateStrategy: int | java.jint | java.lang.Integer, /) -> SurfaceControl.Transaction: ...
        def setFrameTimeline(self, vsyncId: int | java.jlong | java.lang.Long, /) -> SurfaceControl.Transaction: ...
        def setGeometry(self, sc: SurfaceControl, sourceCrop: android.graphics.Rect, destFrame: android.graphics.Rect, orientation: int | java.jint | java.lang.Integer, /) -> SurfaceControl.Transaction: ...
        def setLayer(self, sc: SurfaceControl, z: int | java.jint | java.lang.Integer, /) -> SurfaceControl.Transaction: ...
        def setLuts(self, sc: SurfaceControl, displayLuts: android.hardware.DisplayLuts, /) -> SurfaceControl.Transaction: ...
        def setOpaque(self, sc: SurfaceControl, isOpaque: bool | java.jboolean | java.lang.Boolean, /) -> SurfaceControl.Transaction: ...
        def setPosition(self, sc: SurfaceControl, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> SurfaceControl.Transaction: ...
        def setScale(self, sc: SurfaceControl, scaleX: float | java.jfloat | java.lang.Float, scaleY: float | java.jfloat | java.lang.Float, /) -> SurfaceControl.Transaction: ...
        def setTrustedPresentationCallback(self, sc: SurfaceControl, thresholds: SurfaceControl.TrustedPresentationThresholds, executor: java.util.concurrent.Executor, listener: java.util.function.Consumer[java.lang.Boolean], /) -> SurfaceControl.Transaction: ...
        def setVisibility(self, sc: SurfaceControl, visible: bool | java.jboolean | java.lang.Boolean, /) -> SurfaceControl.Transaction: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnJankDataListenerRegistration(java.lang.Object):
        def flush(self) -> None: ...
        def removeAfter(self, afterVsync: int | java.jlong | java.lang.Long, /) -> None: ...

    class OnJankDataListener(java.lang.Object):
        def onJankDataAvailable(self, arg1: java.util.List[SurfaceControl.JankData], /) -> None: ...

    class JankData(java.lang.Object):
        JANK_APPLICATION: typing.ClassVar[int] = ...
        JANK_COMPOSER: typing.ClassVar[int] = ...
        JANK_NONE: typing.ClassVar[int] = ...
        JANK_OTHER: typing.ClassVar[int] = ...
        def getActualAppFrameTimeNanos(self) -> int: ...
        def getJankType(self) -> int: ...
        def getScheduledAppFrameTimeNanos(self) -> int: ...
        def getVsyncId(self) -> int: ...
        def toString(self) -> str: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> SurfaceControl: ...
        def setBufferSize(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> SurfaceControl.Builder: ...
        def setFormat(self, format: int | java.jint | java.lang.Integer, /) -> SurfaceControl.Builder: ...
        def setHidden(self, hidden: bool | java.jboolean | java.lang.Boolean, /) -> SurfaceControl.Builder: ...
        def setName(self, name: str | java.lang.String, /) -> SurfaceControl.Builder: ...
        def setOpaque(self, opaque: bool | java.jboolean | java.lang.Boolean, /) -> SurfaceControl.Builder: ...
        def setParent(self, parent: SurfaceControl, /) -> SurfaceControl.Builder: ...

class SurfaceControlInputReceiver(java.lang.Object):
    def onInputEvent(self, arg1: InputEvent, /) -> bool: ...

class SurfaceControlViewHost(java.lang.Object):
    @typing.overload
    def __init__(self, context: android.content.Context, display: Display, hostToken: android.os.IBinder, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, display: Display, hostInputTransferToken: android.window.InputTransferToken, /) -> None: ...
    def finalize(self) -> None: ...
    def getSurfacePackage(self) -> SurfaceControlViewHost.SurfacePackage | None: ...
    def getView(self) -> View | None: ...
    def relayout(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
    def release(self) -> None: ...
    def setView(self, view: View, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
    def transferTouchGestureToHost(self) -> bool: ...

    class SurfacePackage(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SurfaceControlViewHost.SurfacePackage]] = ...
        def __init__(self, other: SurfaceControlViewHost.SurfacePackage, /) -> None: ...
        def describeContents(self) -> int: ...
        def getInputTransferToken(self) -> android.window.InputTransferToken: ...
        def getSurfaceControl(self) -> SurfaceControl: ...
        def notifyConfigurationChanged(self, c: android.content.res.Configuration, /) -> None: ...
        def notifyDetachedFromWindow(self) -> None: ...
        def release(self) -> None: ...
        def toString(self) -> str: ...
        def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SurfaceHolder(java.lang.Object):
    SURFACE_TYPE_GPU: typing.ClassVar[int] = ...
    SURFACE_TYPE_HARDWARE: typing.ClassVar[int] = ...
    SURFACE_TYPE_NORMAL: typing.ClassVar[int] = ...
    SURFACE_TYPE_PUSH_BUFFERS: typing.ClassVar[int] = ...
    def addCallback(self, arg1: SurfaceHolder.Callback, /) -> None: ...
    def getSurface(self) -> Surface: ...
    def getSurfaceFrame(self) -> android.graphics.Rect: ...
    def isCreating(self) -> bool: ...
    @typing.overload
    def lockCanvas(self) -> android.graphics.Canvas: ...
    @typing.overload
    def lockCanvas(self, arg1: android.graphics.Rect, /) -> android.graphics.Canvas: ...
    def lockHardwareCanvas(self) -> android.graphics.Canvas: ...
    def removeCallback(self, arg1: SurfaceHolder.Callback, /) -> None: ...
    def setFixedSize(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFormat(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setKeepScreenOn(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSizeFromLayout(self) -> None: ...
    def setType(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def unlockCanvasAndPost(self, arg1: android.graphics.Canvas, /) -> None: ...

    class Callback2(SurfaceHolder.Callback):
        def surfaceRedrawNeeded(self, arg1: SurfaceHolder, /) -> None: ...
        def surfaceRedrawNeededAsync(self, holder: SurfaceHolder, drawingFinished: java.lang.Runnable, /) -> None: ...

    class Callback(java.lang.Object):
        def surfaceChanged(self, arg1: SurfaceHolder, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
        def surfaceCreated(self, arg1: SurfaceHolder, /) -> None: ...
        def surfaceDestroyed(self, arg1: SurfaceHolder, /) -> None: ...

    class BadSurfaceTypeException(java.lang.RuntimeException):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, name: str | java.lang.String, /) -> None: ...

class SurfaceView(View):
    SURFACE_LIFECYCLE_DEFAULT: typing.ClassVar[int] = ...
    SURFACE_LIFECYCLE_FOLLOWS_ATTACHMENT: typing.ClassVar[int] = ...
    SURFACE_LIFECYCLE_FOLLOWS_VISIBILITY: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def applyTransactionToFrame(self, transaction: SurfaceControl.Transaction, /) -> None: ...
    def clearChildSurfacePackage(self) -> None: ...
    def dispatchDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def draw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def gatherTransparentRegion(self, region: android.graphics.Region, /) -> bool: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getChildSurfacePackage(self) -> SurfaceControlViewHost.SurfacePackage: ...
    def getCompositionOrder(self) -> int: ...
    def getHolder(self) -> SurfaceHolder: ...
    def getHostToken(self) -> android.os.IBinder | None: ...
    def getImportantForAccessibility(self) -> int: ...
    def getSurfaceControl(self) -> SurfaceControl: ...
    def hasOverlappingRendering(self) -> bool: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onFocusChanged(self, gainFocus: bool | java.jboolean | java.lang.Boolean, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSetAlpha(self, alpha: int | java.jint | java.lang.Integer, /) -> bool: ...
    def onWindowVisibilityChanged(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAlpha(self, alpha: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setChildSurfacePackage(self, p: SurfaceControlViewHost.SurfacePackage, /) -> None: ...
    def setClipBounds(self, clipBounds: android.graphics.Rect, /) -> None: ...
    def setCompositionOrder(self, compositionOrder: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDesiredHdrHeadroom(self, desiredHeadroom: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setSecure(self, isSecure: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSurfaceLifecycle(self, lifecycleStrategy: int | java.jint | java.lang.Integer, /) -> None: ...
    def setVisibility(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def setZOrderMediaOverlay(self, isMediaOverlay: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setZOrderOnTop(self, onTop: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class TextureView(View):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def buildLayer(self) -> None: ...
    def draw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    @typing.overload
    def getBitmap(self) -> android.graphics.Bitmap | None: ...
    @typing.overload
    def getBitmap(self, bitmap: android.graphics.Bitmap, /) -> android.graphics.Bitmap | None: ...
    @typing.overload
    def getBitmap(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> android.graphics.Bitmap | None: ...
    def getLayerType(self) -> int: ...
    def getSurfaceTexture(self) -> android.graphics.SurfaceTexture | None: ...
    def getSurfaceTextureListener(self) -> TextureView.SurfaceTextureListener | None: ...
    def getTransform(self, transform: android.graphics.Matrix, /) -> android.graphics.Matrix: ...
    def isAvailable(self) -> bool: ...
    def isOpaque(self) -> bool: ...
    @typing.overload
    def lockCanvas(self) -> android.graphics.Canvas | None: ...
    @typing.overload
    def lockCanvas(self, dirty: android.graphics.Rect, /) -> android.graphics.Canvas | None: ...
    def onAttachedToWindow(self) -> None: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onSizeChanged(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, oldw: int | java.jint | java.lang.Integer, oldh: int | java.jint | java.lang.Integer, /) -> None: ...
    def onVisibilityChanged(self, changedView: View, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBackgroundDrawable(self, background: android.graphics.drawable.Drawable, /) -> None: ...
    def setForeground(self, foreground: android.graphics.drawable.Drawable, /) -> None: ...
    def setLayerPaint(self, paint: android.graphics.Paint, /) -> None: ...
    def setLayerType(self, layerType: int | java.jint | java.lang.Integer, paint: android.graphics.Paint, /) -> None: ...
    def setOpaque(self, opaque: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSurfaceTexture(self, surfaceTexture: android.graphics.SurfaceTexture, /) -> None: ...
    def setSurfaceTextureListener(self, listener: TextureView.SurfaceTextureListener, /) -> None: ...
    def setTransform(self, transform: android.graphics.Matrix, /) -> None: ...
    def unlockCanvasAndPost(self, canvas: android.graphics.Canvas, /) -> None: ...

    class SurfaceTextureListener(java.lang.Object):
        def onSurfaceTextureAvailable(self, arg1: android.graphics.SurfaceTexture, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
        def onSurfaceTextureDestroyed(self, arg1: android.graphics.SurfaceTexture, /) -> bool: ...
        def onSurfaceTextureSizeChanged(self, arg1: android.graphics.SurfaceTexture, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
        def onSurfaceTextureUpdated(self, arg1: android.graphics.SurfaceTexture, /) -> None: ...

class TouchDelegate(java.lang.Object):
    ABOVE: typing.ClassVar[int] = ...
    BELOW: typing.ClassVar[int] = ...
    TO_LEFT: typing.ClassVar[int] = ...
    TO_RIGHT: typing.ClassVar[int] = ...
    def __init__(self, bounds: android.graphics.Rect, delegateView: View, /) -> None: ...
    def getTouchDelegateInfo(self) -> android.view.accessibility.AccessibilityNodeInfo.TouchDelegateInfo: ...
    def onTouchEvent(self, event: MotionEvent, /) -> bool: ...
    def onTouchExplorationHoverEvent(self, event: MotionEvent, /) -> bool: ...

class VelocityTracker(java.lang.Object):
    def addMovement(self, event: MotionEvent, /) -> None: ...
    def clear(self) -> None: ...
    @typing.overload
    def computeCurrentVelocity(self, units: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def computeCurrentVelocity(self, units: int | java.jint | java.lang.Integer, maxVelocity: float | java.jfloat | java.lang.Float, /) -> None: ...
    def finalize(self) -> None: ...
    @typing.overload
    def getAxisVelocity(self, axis: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getAxisVelocity(self, axis: int | java.jint | java.lang.Integer, id: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getXVelocity(self) -> float: ...
    @typing.overload
    def getXVelocity(self, id: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getYVelocity(self) -> float: ...
    @typing.overload
    def getYVelocity(self, id: int | java.jint | java.lang.Integer, /) -> float: ...
    def isAxisSupported(self, axis: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def obtain() -> VelocityTracker: ...
    def recycle(self) -> None: ...

class VerifiedInputEvent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[VerifiedInputEvent]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDeviceId(self) -> int: ...
    def getDisplayId(self) -> int: ...
    def getEventTimeNanos(self) -> int: ...
    def getSource(self) -> int: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class VerifiedKeyEvent(VerifiedInputEvent, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[VerifiedKeyEvent]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAction(self) -> int: ...
    def getDownTimeNanos(self) -> int: ...
    def getFlag(self, flag: int | java.jint | java.lang.Integer, /) -> bool | None: ...
    def getKeyCode(self) -> int: ...
    def getMetaState(self) -> int: ...
    def getRepeatCount(self) -> int: ...
    def getScanCode(self) -> int: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class VerifiedMotionEvent(VerifiedInputEvent, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[VerifiedMotionEvent]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getActionMasked(self) -> int: ...
    def getButtonState(self) -> int: ...
    def getDownTimeNanos(self) -> int: ...
    def getFlag(self, flag: int | java.jint | java.lang.Integer, /) -> bool | None: ...
    def getMetaState(self) -> int: ...
    def getRawX(self) -> float: ...
    def getRawY(self) -> float: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class View(KeyEvent.Callback, android.graphics.drawable.Drawable.Callback, android.view.accessibility.AccessibilityEventSource):
    ACCESSIBILITY_DATA_SENSITIVE_AUTO: typing.ClassVar[int] = ...
    ACCESSIBILITY_DATA_SENSITIVE_NO: typing.ClassVar[int] = ...
    ACCESSIBILITY_DATA_SENSITIVE_YES: typing.ClassVar[int] = ...
    ACCESSIBILITY_LIVE_REGION_ASSERTIVE: typing.ClassVar[int] = ...
    ACCESSIBILITY_LIVE_REGION_NONE: typing.ClassVar[int] = ...
    ACCESSIBILITY_LIVE_REGION_POLITE: typing.ClassVar[int] = ...
    ALPHA: typing.ClassVar[android.util.Property[View, java.lang.Float]] = ...
    AUTOFILL_FLAG_INCLUDE_NOT_IMPORTANT_VIEWS: typing.ClassVar[int] = ...
    AUTOFILL_HINT_CREDIT_CARD_EXPIRATION_DATE: typing.ClassVar[str] = ...
    AUTOFILL_HINT_CREDIT_CARD_EXPIRATION_DAY: typing.ClassVar[str] = ...
    AUTOFILL_HINT_CREDIT_CARD_EXPIRATION_MONTH: typing.ClassVar[str] = ...
    AUTOFILL_HINT_CREDIT_CARD_EXPIRATION_YEAR: typing.ClassVar[str] = ...
    AUTOFILL_HINT_CREDIT_CARD_NUMBER: typing.ClassVar[str] = ...
    AUTOFILL_HINT_CREDIT_CARD_SECURITY_CODE: typing.ClassVar[str] = ...
    AUTOFILL_HINT_EMAIL_ADDRESS: typing.ClassVar[str] = ...
    AUTOFILL_HINT_NAME: typing.ClassVar[str] = ...
    AUTOFILL_HINT_PASSWORD: typing.ClassVar[str] = ...
    AUTOFILL_HINT_PHONE: typing.ClassVar[str] = ...
    AUTOFILL_HINT_POSTAL_ADDRESS: typing.ClassVar[str] = ...
    AUTOFILL_HINT_POSTAL_CODE: typing.ClassVar[str] = ...
    AUTOFILL_HINT_USERNAME: typing.ClassVar[str] = ...
    AUTOFILL_TYPE_DATE: typing.ClassVar[int] = ...
    AUTOFILL_TYPE_LIST: typing.ClassVar[int] = ...
    AUTOFILL_TYPE_NONE: typing.ClassVar[int] = ...
    AUTOFILL_TYPE_TEXT: typing.ClassVar[int] = ...
    AUTOFILL_TYPE_TOGGLE: typing.ClassVar[int] = ...
    CONTENT_SENSITIVITY_AUTO: typing.ClassVar[int] = ...
    CONTENT_SENSITIVITY_NOT_SENSITIVE: typing.ClassVar[int] = ...
    CONTENT_SENSITIVITY_SENSITIVE: typing.ClassVar[int] = ...
    DRAG_FLAG_ACCESSIBILITY_ACTION: typing.ClassVar[int] = ...
    DRAG_FLAG_GLOBAL: typing.ClassVar[int] = ...
    DRAG_FLAG_GLOBAL_PERSISTABLE_URI_PERMISSION: typing.ClassVar[int] = ...
    DRAG_FLAG_GLOBAL_PREFIX_URI_PERMISSION: typing.ClassVar[int] = ...
    DRAG_FLAG_GLOBAL_SAME_APPLICATION: typing.ClassVar[int] = ...
    DRAG_FLAG_GLOBAL_URI_READ: typing.ClassVar[int] = ...
    DRAG_FLAG_GLOBAL_URI_WRITE: typing.ClassVar[int] = ...
    DRAG_FLAG_HIDE_CALLING_TASK_ON_DRAG_START: typing.ClassVar[int] = ...
    DRAG_FLAG_OPAQUE: typing.ClassVar[int] = ...
    DRAG_FLAG_START_INTENT_SENDER_ON_UNHANDLED_DRAG: typing.ClassVar[int] = ...
    DRAWING_CACHE_QUALITY_AUTO: typing.ClassVar[int] = ...
    DRAWING_CACHE_QUALITY_HIGH: typing.ClassVar[int] = ...
    DRAWING_CACHE_QUALITY_LOW: typing.ClassVar[int] = ...
    EMPTY_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    ENABLED_FOCUSED_SELECTED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    ENABLED_FOCUSED_SELECTED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    ENABLED_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    ENABLED_FOCUSED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    ENABLED_SELECTED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    ENABLED_SELECTED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    ENABLED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    ENABLED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    FIND_VIEWS_WITH_CONTENT_DESCRIPTION: typing.ClassVar[int] = ...
    FIND_VIEWS_WITH_TEXT: typing.ClassVar[int] = ...
    FOCUSABLE: typing.ClassVar[int] = ...
    FOCUSABLES_ALL: typing.ClassVar[int] = ...
    FOCUSABLES_TOUCH_MODE: typing.ClassVar[int] = ...
    FOCUSABLE_AUTO: typing.ClassVar[int] = ...
    FOCUSED_SELECTED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    FOCUSED_SELECTED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    FOCUSED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    FOCUS_BACKWARD: typing.ClassVar[int] = ...
    FOCUS_DOWN: typing.ClassVar[int] = ...
    FOCUS_FORWARD: typing.ClassVar[int] = ...
    FOCUS_LEFT: typing.ClassVar[int] = ...
    FOCUS_RIGHT: typing.ClassVar[int] = ...
    FOCUS_UP: typing.ClassVar[int] = ...
    GONE: typing.ClassVar[int] = ...
    HAPTIC_FEEDBACK_ENABLED: typing.ClassVar[int] = ...
    IMPORTANT_FOR_ACCESSIBILITY_AUTO: typing.ClassVar[int] = ...
    IMPORTANT_FOR_ACCESSIBILITY_NO: typing.ClassVar[int] = ...
    IMPORTANT_FOR_ACCESSIBILITY_NO_HIDE_DESCENDANTS: typing.ClassVar[int] = ...
    IMPORTANT_FOR_ACCESSIBILITY_YES: typing.ClassVar[int] = ...
    IMPORTANT_FOR_AUTOFILL_AUTO: typing.ClassVar[int] = ...
    IMPORTANT_FOR_AUTOFILL_NO: typing.ClassVar[int] = ...
    IMPORTANT_FOR_AUTOFILL_NO_EXCLUDE_DESCENDANTS: typing.ClassVar[int] = ...
    IMPORTANT_FOR_AUTOFILL_YES: typing.ClassVar[int] = ...
    IMPORTANT_FOR_AUTOFILL_YES_EXCLUDE_DESCENDANTS: typing.ClassVar[int] = ...
    IMPORTANT_FOR_CONTENT_CAPTURE_AUTO: typing.ClassVar[int] = ...
    IMPORTANT_FOR_CONTENT_CAPTURE_NO: typing.ClassVar[int] = ...
    IMPORTANT_FOR_CONTENT_CAPTURE_NO_EXCLUDE_DESCENDANTS: typing.ClassVar[int] = ...
    IMPORTANT_FOR_CONTENT_CAPTURE_YES: typing.ClassVar[int] = ...
    IMPORTANT_FOR_CONTENT_CAPTURE_YES_EXCLUDE_DESCENDANTS: typing.ClassVar[int] = ...
    INVISIBLE: typing.ClassVar[int] = ...
    KEEP_SCREEN_ON: typing.ClassVar[int] = ...
    LAYER_TYPE_HARDWARE: typing.ClassVar[int] = ...
    LAYER_TYPE_NONE: typing.ClassVar[int] = ...
    LAYER_TYPE_SOFTWARE: typing.ClassVar[int] = ...
    LAYOUT_DIRECTION_INHERIT: typing.ClassVar[int] = ...
    LAYOUT_DIRECTION_LOCALE: typing.ClassVar[int] = ...
    LAYOUT_DIRECTION_LTR: typing.ClassVar[int] = ...
    LAYOUT_DIRECTION_RTL: typing.ClassVar[int] = ...
    MEASURED_HEIGHT_STATE_SHIFT: typing.ClassVar[int] = ...
    MEASURED_SIZE_MASK: typing.ClassVar[int] = ...
    MEASURED_STATE_MASK: typing.ClassVar[int] = ...
    MEASURED_STATE_TOO_SMALL: typing.ClassVar[int] = ...
    NOT_FOCUSABLE: typing.ClassVar[int] = ...
    NO_ID: typing.ClassVar[int] = ...
    OVER_SCROLL_ALWAYS: typing.ClassVar[int] = ...
    OVER_SCROLL_IF_CONTENT_SCROLLS: typing.ClassVar[int] = ...
    OVER_SCROLL_NEVER: typing.ClassVar[int] = ...
    PRESSED_ENABLED_FOCUSED_SELECTED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_ENABLED_FOCUSED_SELECTED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_ENABLED_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_ENABLED_FOCUSED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_ENABLED_SELECTED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_ENABLED_SELECTED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_ENABLED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_ENABLED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_FOCUSED_SELECTED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_FOCUSED_SELECTED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_FOCUSED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_SELECTED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_SELECTED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    PRESSED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    REQUESTED_FRAME_RATE_CATEGORY_DEFAULT: typing.ClassVar[float] = ...
    REQUESTED_FRAME_RATE_CATEGORY_HIGH: typing.ClassVar[float] = ...
    REQUESTED_FRAME_RATE_CATEGORY_LOW: typing.ClassVar[float] = ...
    REQUESTED_FRAME_RATE_CATEGORY_NORMAL: typing.ClassVar[float] = ...
    REQUESTED_FRAME_RATE_CATEGORY_NO_PREFERENCE: typing.ClassVar[float] = ...
    ROTATION: typing.ClassVar[android.util.Property[View, java.lang.Float]] = ...
    ROTATION_X: typing.ClassVar[android.util.Property[View, java.lang.Float]] = ...
    ROTATION_Y: typing.ClassVar[android.util.Property[View, java.lang.Float]] = ...
    SCALE_X: typing.ClassVar[android.util.Property[View, java.lang.Float]] = ...
    SCALE_Y: typing.ClassVar[android.util.Property[View, java.lang.Float]] = ...
    SCREEN_STATE_OFF: typing.ClassVar[int] = ...
    SCREEN_STATE_ON: typing.ClassVar[int] = ...
    SCROLLBARS_INSIDE_INSET: typing.ClassVar[int] = ...
    SCROLLBARS_INSIDE_OVERLAY: typing.ClassVar[int] = ...
    SCROLLBARS_OUTSIDE_INSET: typing.ClassVar[int] = ...
    SCROLLBARS_OUTSIDE_OVERLAY: typing.ClassVar[int] = ...
    SCROLLBAR_POSITION_DEFAULT: typing.ClassVar[int] = ...
    SCROLLBAR_POSITION_LEFT: typing.ClassVar[int] = ...
    SCROLLBAR_POSITION_RIGHT: typing.ClassVar[int] = ...
    SCROLL_AXIS_HORIZONTAL: typing.ClassVar[int] = ...
    SCROLL_AXIS_NONE: typing.ClassVar[int] = ...
    SCROLL_AXIS_VERTICAL: typing.ClassVar[int] = ...
    SCROLL_CAPTURE_HINT_AUTO: typing.ClassVar[int] = ...
    SCROLL_CAPTURE_HINT_EXCLUDE: typing.ClassVar[int] = ...
    SCROLL_CAPTURE_HINT_EXCLUDE_DESCENDANTS: typing.ClassVar[int] = ...
    SCROLL_CAPTURE_HINT_INCLUDE: typing.ClassVar[int] = ...
    SCROLL_INDICATOR_BOTTOM: typing.ClassVar[int] = ...
    SCROLL_INDICATOR_END: typing.ClassVar[int] = ...
    SCROLL_INDICATOR_LEFT: typing.ClassVar[int] = ...
    SCROLL_INDICATOR_RIGHT: typing.ClassVar[int] = ...
    SCROLL_INDICATOR_START: typing.ClassVar[int] = ...
    SCROLL_INDICATOR_TOP: typing.ClassVar[int] = ...
    SELECTED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    SELECTED_WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    SOUND_EFFECTS_ENABLED: typing.ClassVar[int] = ...
    STATUS_BAR_HIDDEN: typing.ClassVar[int] = ...
    STATUS_BAR_VISIBLE: typing.ClassVar[int] = ...
    SYSTEM_UI_FLAG_FULLSCREEN: typing.ClassVar[int] = ...
    SYSTEM_UI_FLAG_HIDE_NAVIGATION: typing.ClassVar[int] = ...
    SYSTEM_UI_FLAG_IMMERSIVE: typing.ClassVar[int] = ...
    SYSTEM_UI_FLAG_IMMERSIVE_STICKY: typing.ClassVar[int] = ...
    SYSTEM_UI_FLAG_LAYOUT_FULLSCREEN: typing.ClassVar[int] = ...
    SYSTEM_UI_FLAG_LAYOUT_HIDE_NAVIGATION: typing.ClassVar[int] = ...
    SYSTEM_UI_FLAG_LAYOUT_STABLE: typing.ClassVar[int] = ...
    SYSTEM_UI_FLAG_LIGHT_NAVIGATION_BAR: typing.ClassVar[int] = ...
    SYSTEM_UI_FLAG_LIGHT_STATUS_BAR: typing.ClassVar[int] = ...
    SYSTEM_UI_FLAG_LOW_PROFILE: typing.ClassVar[int] = ...
    SYSTEM_UI_FLAG_VISIBLE: typing.ClassVar[int] = ...
    SYSTEM_UI_LAYOUT_FLAGS: typing.ClassVar[int] = ...
    TEXT_ALIGNMENT_CENTER: typing.ClassVar[int] = ...
    TEXT_ALIGNMENT_GRAVITY: typing.ClassVar[int] = ...
    TEXT_ALIGNMENT_INHERIT: typing.ClassVar[int] = ...
    TEXT_ALIGNMENT_TEXT_END: typing.ClassVar[int] = ...
    TEXT_ALIGNMENT_TEXT_START: typing.ClassVar[int] = ...
    TEXT_ALIGNMENT_VIEW_END: typing.ClassVar[int] = ...
    TEXT_ALIGNMENT_VIEW_START: typing.ClassVar[int] = ...
    TEXT_DIRECTION_ANY_RTL: typing.ClassVar[int] = ...
    TEXT_DIRECTION_FIRST_STRONG: typing.ClassVar[int] = ...
    TEXT_DIRECTION_FIRST_STRONG_LTR: typing.ClassVar[int] = ...
    TEXT_DIRECTION_FIRST_STRONG_RTL: typing.ClassVar[int] = ...
    TEXT_DIRECTION_INHERIT: typing.ClassVar[int] = ...
    TEXT_DIRECTION_LOCALE: typing.ClassVar[int] = ...
    TEXT_DIRECTION_LTR: typing.ClassVar[int] = ...
    TEXT_DIRECTION_RTL: typing.ClassVar[int] = ...
    TRANSLATION_X: typing.ClassVar[android.util.Property[View, java.lang.Float]] = ...
    TRANSLATION_Y: typing.ClassVar[android.util.Property[View, java.lang.Float]] = ...
    TRANSLATION_Z: typing.ClassVar[android.util.Property[View, java.lang.Float]] = ...
    VIEW_LOG_TAG: typing.ClassVar[str] = ...
    VISIBLE: typing.ClassVar[int] = ...
    WINDOW_FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    X: typing.ClassVar[android.util.Property[View, java.lang.Float]] = ...
    Y: typing.ClassVar[android.util.Property[View, java.lang.Float]] = ...
    Z: typing.ClassVar[android.util.Property[View, java.lang.Float]] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def addChildrenForAccessibility(self, outChildren: java.util.ArrayList[View], /) -> None: ...
    def addExtraDataToAccessibilityNodeInfo(self, info: android.view.accessibility.AccessibilityNodeInfo, extraDataKey: str | java.lang.String, arguments: android.os.Bundle, /) -> None: ...
    @typing.overload
    def addFocusables(self, views: java.util.ArrayList[View], direction: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addFocusables(self, views: java.util.ArrayList[View], direction: int | java.jint | java.lang.Integer, focusableMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def addKeyboardNavigationClusters(self, views: java.util.Collection[View], direction: int | java.jint | java.lang.Integer, /) -> None: ...
    def addOnAttachStateChangeListener(self, listener: View.OnAttachStateChangeListener, /) -> None: ...
    def addOnLayoutChangeListener(self, listener: View.OnLayoutChangeListener, /) -> None: ...
    def addOnUnhandledKeyEventListener(self, listener: View.OnUnhandledKeyEventListener, /) -> None: ...
    def addTouchables(self, views: java.util.ArrayList[View], /) -> None: ...
    def animate(self) -> ViewPropertyAnimator: ...
    def announceForAccessibility(self, text: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def autofill(self, values: android.util.SparseArray[android.view.autofill.AutofillValue], /) -> None: ...
    @typing.overload
    def autofill(self, value: android.view.autofill.AutofillValue, /) -> None: ...
    @typing.overload
    def awakenScrollBars(self) -> bool: ...
    @typing.overload
    def awakenScrollBars(self, startDelay: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def awakenScrollBars(self, startDelay: int | java.jint | java.lang.Integer, invalidate: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def bringToFront(self) -> None: ...
    @typing.overload
    def buildDrawingCache(self) -> None: ...
    @typing.overload
    def buildDrawingCache(self, autoScale: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def buildLayer(self) -> None: ...
    def callOnClick(self) -> bool: ...
    def canResolveLayoutDirection(self) -> bool: ...
    def canResolveTextAlignment(self) -> bool: ...
    def canResolveTextDirection(self) -> bool: ...
    def canScrollHorizontally(self, direction: int | java.jint | java.lang.Integer, /) -> bool: ...
    def canScrollVertically(self, direction: int | java.jint | java.lang.Integer, /) -> bool: ...
    def cancelDragAndDrop(self) -> None: ...
    def cancelLongPress(self) -> None: ...
    def cancelPendingInputEvents(self) -> None: ...
    def checkInputConnectionProxy(self, view: View, /) -> bool: ...
    def clearAnimation(self) -> None: ...
    def clearFocus(self) -> None: ...
    def clearPendingCredentialRequest(self) -> None: ...
    def clearViewTranslationCallback(self) -> None: ...
    @staticmethod
    def combineMeasuredStates(curState: int | java.jint | java.lang.Integer, newState: int | java.jint | java.lang.Integer, /) -> int: ...
    def computeHorizontalScrollExtent(self) -> int: ...
    def computeHorizontalScrollOffset(self) -> int: ...
    def computeHorizontalScrollRange(self) -> int: ...
    def computeScroll(self) -> None: ...
    def computeSystemWindowInsets(self, in_: WindowInsets, outLocalInsets: android.graphics.Rect, /) -> WindowInsets: ...
    def computeVerticalScrollExtent(self) -> int: ...
    def computeVerticalScrollOffset(self) -> int: ...
    def computeVerticalScrollRange(self) -> int: ...
    def createAccessibilityNodeInfo(self) -> android.view.accessibility.AccessibilityNodeInfo: ...
    def createContextMenu(self, menu: ContextMenu, /) -> None: ...
    def destroyDrawingCache(self) -> None: ...
    def dispatchApplyWindowInsets(self, insets: WindowInsets, /) -> WindowInsets: ...
    def dispatchCapturedPointerEvent(self, event: MotionEvent, /) -> bool: ...
    def dispatchConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def dispatchCreateViewTranslationRequest(self, viewIds: java.util.Map[android.view.autofill.AutofillId, java.chaquopy.JavaArrayJLong], supportedFormats: java.chaquopy.JavaArrayJInt, capability: android.view.translation.TranslationCapability, requests: java.util.List[android.view.translation.ViewTranslationRequest], /) -> None: ...
    def dispatchDisplayHint(self, hint: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchDragEvent(self, event: DragEvent, /) -> bool: ...
    def dispatchDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def dispatchDrawableHotspotChanged(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> None: ...
    def dispatchFinishTemporaryDetach(self) -> None: ...
    def dispatchGenericFocusedEvent(self, event: MotionEvent, /) -> bool: ...
    def dispatchGenericMotionEvent(self, event: MotionEvent, /) -> bool: ...
    def dispatchGenericPointerEvent(self, event: MotionEvent, /) -> bool: ...
    def dispatchHoverEvent(self, event: MotionEvent, /) -> bool: ...
    def dispatchKeyEvent(self, event: KeyEvent, /) -> bool: ...
    def dispatchKeyEventPreIme(self, event: KeyEvent, /) -> bool: ...
    def dispatchKeyShortcutEvent(self, event: KeyEvent, /) -> bool: ...
    def dispatchNestedFling(self, velocityX: float | java.jfloat | java.lang.Float, velocityY: float | java.jfloat | java.lang.Float, consumed: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def dispatchNestedPreFling(self, velocityX: float | java.jfloat | java.lang.Float, velocityY: float | java.jfloat | java.lang.Float, /) -> bool: ...
    def dispatchNestedPrePerformAccessibilityAction(self, action: int | java.jint | java.lang.Integer, arguments: android.os.Bundle, /) -> bool: ...
    def dispatchNestedPreScroll(self, dx: int | java.jint | java.lang.Integer, dy: int | java.jint | java.lang.Integer, consumed: java.chaquopy.JavaArrayJInt, offsetInWindow: java.chaquopy.JavaArrayJInt, /) -> bool: ...
    def dispatchNestedScroll(self, dxConsumed: int | java.jint | java.lang.Integer, dyConsumed: int | java.jint | java.lang.Integer, dxUnconsumed: int | java.jint | java.lang.Integer, dyUnconsumed: int | java.jint | java.lang.Integer, offsetInWindow: java.chaquopy.JavaArrayJInt, /) -> bool: ...
    def dispatchPointerCaptureChanged(self, hasCapture: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dispatchPopulateAccessibilityEvent(self, event: android.view.accessibility.AccessibilityEvent, /) -> bool: ...
    def dispatchProvideAutofillStructure(self, structure: ViewStructure, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchProvideStructure(self, structure: ViewStructure, /) -> None: ...
    def dispatchRestoreInstanceState(self, container: android.util.SparseArray[android.os.Parcelable], /) -> None: ...
    def dispatchSaveInstanceState(self, container: android.util.SparseArray[android.os.Parcelable], /) -> None: ...
    def dispatchScrollCaptureSearch(self, localVisibleRect: android.graphics.Rect, windowOffset: android.graphics.Point, targets: java.util.function.Consumer[ScrollCaptureTarget], /) -> None: ...
    def dispatchSetActivated(self, activated: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dispatchSetPressed(self, pressed: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dispatchSetSelected(self, selected: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dispatchStartTemporaryDetach(self) -> None: ...
    def dispatchSystemUiVisibilityChanged(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchTouchEvent(self, event: MotionEvent, /) -> bool: ...
    def dispatchTrackballEvent(self, event: MotionEvent, /) -> bool: ...
    def dispatchUnhandledMove(self, focused: View, direction: int | java.jint | java.lang.Integer, /) -> bool: ...
    def dispatchVisibilityChanged(self, changedView: View, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchWindowFocusChanged(self, hasFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dispatchWindowInsetsAnimationEnd(self, animation: WindowInsetsAnimation, /) -> None: ...
    def dispatchWindowInsetsAnimationPrepare(self, animation: WindowInsetsAnimation, /) -> None: ...
    def dispatchWindowInsetsAnimationProgress(self, insets: WindowInsets, runningAnimations: java.util.List[WindowInsetsAnimation], /) -> WindowInsets: ...
    def dispatchWindowInsetsAnimationStart(self, animation: WindowInsetsAnimation, bounds: WindowInsetsAnimation.Bounds, /) -> WindowInsetsAnimation.Bounds: ...
    def dispatchWindowSystemUiVisiblityChanged(self, visible: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchWindowVisibilityChanged(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def draw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def drawableHotspotChanged(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> None: ...
    def drawableStateChanged(self) -> None: ...
    def findFocus(self) -> View | None: ...
    def findOnBackInvokedDispatcher(self) -> android.window.OnBackInvokedDispatcher | None: ...
    def findViewById(self, id: int | java.jint | java.lang.Integer, /) -> View: ...
    def findViewWithTag(self, tag: java.lang.Object | int | bool | float | str, /) -> View | None: ...
    def findViewsWithText(self, outViews: java.util.ArrayList[View], searched: java.lang.CharSequence, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def fitSystemWindows(self, insets: android.graphics.Rect, /) -> bool: ...
    def focusSearch(self, direction: int | java.jint | java.lang.Integer, /) -> View | None: ...
    def forceHasOverlappingRendering(self, hasOverlappingRendering: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def forceLayout(self) -> None: ...
    def gatherTransparentRegion(self, region: android.graphics.Region, /) -> bool: ...
    def generateDisplayHash(self, hashAlgorithm: str | java.lang.String, bounds: android.graphics.Rect, executor: java.util.concurrent.Executor, callback: android.view.displayhash.DisplayHashResultCallback, /) -> None: ...
    @staticmethod
    def generateViewId() -> int: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getAccessibilityDelegate(self) -> View.AccessibilityDelegate | None: ...
    def getAccessibilityLiveRegion(self) -> int: ...
    def getAccessibilityNodeProvider(self) -> android.view.accessibility.AccessibilityNodeProvider | None: ...
    def getAccessibilityPaneTitle(self) -> java.lang.CharSequence | None: ...
    def getAccessibilityTraversalAfter(self) -> int: ...
    def getAccessibilityTraversalBefore(self) -> int: ...
    def getAllowedHandwritingDelegatePackageName(self) -> str | None: ...
    def getAllowedHandwritingDelegatorPackageName(self) -> str | None: ...
    def getAlpha(self) -> float: ...
    def getAnimation(self) -> android.view.animation.Animation: ...
    def getAnimationMatrix(self) -> android.graphics.Matrix | None: ...
    def getApplicationWindowToken(self) -> android.os.IBinder: ...
    def getAttributeResolutionStack(self, attribute: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def getAttributeSourceResourceMap(self) -> java.util.Map[java.lang.Integer, java.lang.Integer]: ...
    def getAutofillHints(self) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    def getAutofillId(self) -> android.view.autofill.AutofillId: ...
    def getAutofillType(self) -> int: ...
    def getAutofillValue(self) -> android.view.autofill.AutofillValue | None: ...
    def getBackground(self) -> android.graphics.drawable.Drawable: ...
    def getBackgroundTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getBackgroundTintList(self) -> android.content.res.ColorStateList | None: ...
    def getBackgroundTintMode(self) -> android.graphics.PorterDuff.Mode | None: ...
    def getBaseline(self) -> int: ...
    def getBottom(self) -> int: ...
    def getBottomFadingEdgeStrength(self) -> float: ...
    def getBottomPaddingOffset(self) -> int: ...
    def getCameraDistance(self) -> float: ...
    @typing.overload
    def getClipBounds(self) -> android.graphics.Rect | None: ...
    @typing.overload
    def getClipBounds(self, outRect: android.graphics.Rect, /) -> bool: ...
    def getClipToOutline(self) -> bool: ...
    def getContentCaptureSession(self) -> android.view.contentcapture.ContentCaptureSession | None: ...
    def getContentDescription(self) -> java.lang.CharSequence: ...
    def getContentSensitivity(self) -> int: ...
    def getContext(self) -> android.content.Context: ...
    def getContextMenuInfo(self) -> ContextMenu.ContextMenuInfo: ...
    def getDefaultFocusHighlightEnabled(self) -> bool: ...
    @staticmethod
    def getDefaultSize(size: int | java.jint | java.lang.Integer, measureSpec: int | java.jint | java.lang.Integer, /) -> int: ...
    def getDisplay(self) -> Display | None: ...
    def getDrawableState(self) -> java.chaquopy.JavaArrayJInt: ...
    @typing.overload
    def getDrawingCache(self) -> android.graphics.Bitmap | None: ...
    @typing.overload
    def getDrawingCache(self, autoScale: bool | java.jboolean | java.lang.Boolean, /) -> android.graphics.Bitmap | None: ...
    def getDrawingCacheBackgroundColor(self) -> int: ...
    def getDrawingCacheQuality(self) -> int: ...
    def getDrawingRect(self, outRect: android.graphics.Rect, /) -> None: ...
    def getDrawingTime(self) -> int: ...
    def getElevation(self) -> float: ...
    def getExplicitStyle(self) -> int: ...
    def getFilterTouchesWhenObscured(self) -> bool: ...
    def getFitsSystemWindows(self) -> bool: ...
    def getFocusable(self) -> int: ...
    def getFocusables(self, direction: int | java.jint | java.lang.Integer, /) -> java.util.ArrayList[View]: ...
    def getFocusedRect(self, r: android.graphics.Rect, /) -> None: ...
    def getForeground(self) -> android.graphics.drawable.Drawable | None: ...
    def getForegroundGravity(self) -> int: ...
    def getForegroundTintBlendMode(self) -> android.graphics.BlendMode | None: ...
    def getForegroundTintList(self) -> android.content.res.ColorStateList | None: ...
    def getForegroundTintMode(self) -> android.graphics.PorterDuff.Mode | None: ...
    def getFrameContentVelocity(self) -> float: ...
    @typing.overload
    def getGlobalVisibleRect(self, r: android.graphics.Rect, /) -> bool: ...
    @typing.overload
    def getGlobalVisibleRect(self, r: android.graphics.Rect, globalOffset: android.graphics.Point, /) -> bool: ...
    def getHandler(self) -> android.os.Handler: ...
    def getHandwritingBoundsOffsetBottom(self) -> float: ...
    def getHandwritingBoundsOffsetLeft(self) -> float: ...
    def getHandwritingBoundsOffsetRight(self) -> float: ...
    def getHandwritingBoundsOffsetTop(self) -> float: ...
    def getHandwritingDelegateFlags(self) -> int: ...
    def getHandwritingDelegatorCallback(self) -> java.lang.Runnable | None: ...
    def getHasOverlappingRendering(self) -> bool: ...
    def getHeight(self) -> int: ...
    def getHitRect(self, outRect: android.graphics.Rect, /) -> None: ...
    def getHorizontalFadingEdgeLength(self) -> int: ...
    def getHorizontalScrollbarHeight(self) -> int: ...
    def getHorizontalScrollbarThumbDrawable(self) -> android.graphics.drawable.Drawable | None: ...
    def getHorizontalScrollbarTrackDrawable(self) -> android.graphics.drawable.Drawable | None: ...
    def getId(self) -> int: ...
    def getImportantForAccessibility(self) -> int: ...
    def getImportantForAutofill(self) -> int: ...
    def getImportantForContentCapture(self) -> int: ...
    def getKeepScreenOn(self) -> bool: ...
    def getKeyDispatcherState(self) -> KeyEvent.DispatcherState: ...
    def getLabelFor(self) -> int: ...
    def getLayerType(self) -> int: ...
    def getLayoutDirection(self) -> int: ...
    def getLayoutParams(self) -> ViewGroup.LayoutParams | None: ...
    def getLeft(self) -> int: ...
    def getLeftFadingEdgeStrength(self) -> float: ...
    def getLeftPaddingOffset(self) -> int: ...
    def getLocalVisibleRect(self, r: android.graphics.Rect, /) -> bool: ...
    def getLocationInSurface(self, location: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def getLocationInWindow(self, outLocation: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def getLocationOnScreen(self, outLocation: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def getMatrix(self) -> android.graphics.Matrix: ...
    def getMeasuredHeight(self) -> int: ...
    def getMeasuredHeightAndState(self) -> int: ...
    def getMeasuredState(self) -> int: ...
    def getMeasuredWidth(self) -> int: ...
    def getMeasuredWidthAndState(self) -> int: ...
    def getMinimumHeight(self) -> int: ...
    def getMinimumWidth(self) -> int: ...
    def getNextClusterForwardId(self) -> int: ...
    def getNextFocusDownId(self) -> int: ...
    def getNextFocusForwardId(self) -> int: ...
    def getNextFocusLeftId(self) -> int: ...
    def getNextFocusRightId(self) -> int: ...
    def getNextFocusUpId(self) -> int: ...
    def getOnFocusChangeListener(self) -> View.OnFocusChangeListener | None: ...
    def getOutlineAmbientShadowColor(self) -> int: ...
    def getOutlineProvider(self) -> ViewOutlineProvider: ...
    def getOutlineSpotShadowColor(self) -> int: ...
    def getOverScrollMode(self) -> int: ...
    def getOverlay(self) -> ViewOverlay: ...
    def getPaddingBottom(self) -> int: ...
    def getPaddingEnd(self) -> int: ...
    def getPaddingLeft(self) -> int: ...
    def getPaddingRight(self) -> int: ...
    def getPaddingStart(self) -> int: ...
    def getPaddingTop(self) -> int: ...
    def getParent(self) -> ViewParent: ...
    def getParentForAccessibility(self) -> ViewParent: ...
    def getPendingCredentialCallback(self) -> android.os.OutcomeReceiver[android.credentials.GetCredentialResponse, android.credentials.GetCredentialException] | None: ...
    def getPendingCredentialRequest(self) -> android.credentials.GetCredentialRequest | None: ...
    def getPivotX(self) -> float: ...
    def getPivotY(self) -> float: ...
    def getPointerIcon(self) -> PointerIcon: ...
    def getPreferKeepClearRects(self) -> java.util.List[android.graphics.Rect]: ...
    def getReceiveContentMimeTypes(self) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    def getRequestedFrameRate(self) -> float: ...
    def getResources(self) -> android.content.res.Resources: ...
    def getRevealOnFocusHint(self) -> bool: ...
    def getRight(self) -> int: ...
    def getRightFadingEdgeStrength(self) -> float: ...
    def getRightPaddingOffset(self) -> int: ...
    def getRootSurfaceControl(self) -> AttachedSurfaceControl | None: ...
    def getRootView(self) -> View: ...
    def getRootWindowInsets(self) -> WindowInsets | None: ...
    def getRotation(self) -> float: ...
    def getRotationX(self) -> float: ...
    def getRotationY(self) -> float: ...
    def getScaleX(self) -> float: ...
    def getScaleY(self) -> float: ...
    def getScrollBarDefaultDelayBeforeFade(self) -> int: ...
    def getScrollBarFadeDuration(self) -> int: ...
    def getScrollBarSize(self) -> int: ...
    def getScrollBarStyle(self) -> int: ...
    def getScrollCaptureHint(self) -> int: ...
    def getScrollIndicators(self) -> int: ...
    def getScrollX(self) -> int: ...
    def getScrollY(self) -> int: ...
    def getSolidColor(self) -> int: ...
    def getSourceLayoutResId(self) -> int: ...
    def getStateDescription(self) -> java.lang.CharSequence | None: ...
    def getStateListAnimator(self) -> android.animation.StateListAnimator | None: ...
    def getSuggestedMinimumHeight(self) -> int: ...
    def getSuggestedMinimumWidth(self) -> int: ...
    def getSupplementalDescription(self) -> java.lang.CharSequence: ...
    def getSystemGestureExclusionRects(self) -> java.util.List[android.graphics.Rect]: ...
    def getSystemUiVisibility(self) -> int: ...
    @typing.overload
    def getTag(self) -> java.lang.Object: ...
    @typing.overload
    def getTag(self, key: int | java.jint | java.lang.Integer, /) -> java.lang.Object: ...
    def getTextAlignment(self) -> int: ...
    def getTextDirection(self) -> int: ...
    def getTooltipText(self) -> java.lang.CharSequence | None: ...
    def getTop(self) -> int: ...
    def getTopFadingEdgeStrength(self) -> float: ...
    def getTopPaddingOffset(self) -> int: ...
    def getTouchDelegate(self) -> TouchDelegate: ...
    def getTouchables(self) -> java.util.ArrayList[View]: ...
    def getTransitionAlpha(self) -> float: ...
    def getTransitionName(self) -> str | None: ...
    def getTranslationX(self) -> float: ...
    def getTranslationY(self) -> float: ...
    def getTranslationZ(self) -> float: ...
    def getUniqueDrawingId(self) -> int: ...
    def getVerticalFadingEdgeLength(self) -> int: ...
    def getVerticalScrollbarPosition(self) -> int: ...
    def getVerticalScrollbarThumbDrawable(self) -> android.graphics.drawable.Drawable | None: ...
    def getVerticalScrollbarTrackDrawable(self) -> android.graphics.drawable.Drawable | None: ...
    def getVerticalScrollbarWidth(self) -> int: ...
    def getViewTranslationResponse(self) -> android.view.translation.ViewTranslationResponse | None: ...
    def getViewTreeObserver(self) -> ViewTreeObserver: ...
    def getVisibility(self) -> int: ...
    def getWidth(self) -> int: ...
    def getWindowAttachCount(self) -> int: ...
    def getWindowId(self) -> WindowId: ...
    def getWindowInsetsController(self) -> WindowInsetsController | None: ...
    def getWindowSystemUiVisibility(self) -> int: ...
    def getWindowToken(self) -> android.os.IBinder: ...
    def getWindowVisibility(self) -> int: ...
    def getWindowVisibleDisplayFrame(self, outRect: android.graphics.Rect, /) -> None: ...
    def getX(self) -> float: ...
    def getY(self) -> float: ...
    def getZ(self) -> float: ...
    def hasExplicitFocusable(self) -> bool: ...
    def hasFocus(self) -> bool: ...
    def hasFocusable(self) -> bool: ...
    def hasNestedScrollingParent(self) -> bool: ...
    def hasOnClickListeners(self) -> bool: ...
    def hasOnLongClickListeners(self) -> bool: ...
    def hasOverlappingRendering(self) -> bool: ...
    def hasPointerCapture(self) -> bool: ...
    def hasTransientState(self) -> bool: ...
    def hasWindowFocus(self) -> bool: ...
    @staticmethod
    def inflate(context: android.content.Context, resource: int | java.jint | java.lang.Integer, root: ViewGroup, /) -> View: ...
    @typing.overload
    def invalidate(self) -> None: ...
    @typing.overload
    def invalidate(self, dirty: android.graphics.Rect, /) -> None: ...
    @typing.overload
    def invalidate(self, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def invalidateDrawable(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def invalidateOutline(self) -> None: ...
    def isAccessibilityDataSensitive(self) -> bool: ...
    def isAccessibilityFocused(self) -> bool: ...
    def isAccessibilityHeading(self) -> bool: ...
    def isActivated(self) -> bool: ...
    def isAttachedToWindow(self) -> bool: ...
    def isAutoHandwritingEnabled(self) -> bool: ...
    def isClickable(self) -> bool: ...
    def isContentSensitive(self) -> bool: ...
    def isContextClickable(self) -> bool: ...
    def isCredential(self) -> bool: ...
    def isDirty(self) -> bool: ...
    def isDrawingCacheEnabled(self) -> bool: ...
    def isDuplicateParentStateEnabled(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isFocusable(self) -> bool: ...
    def isFocusableInTouchMode(self) -> bool: ...
    def isFocused(self) -> bool: ...
    def isFocusedByDefault(self) -> bool: ...
    def isForceDarkAllowed(self) -> bool: ...
    def isHandwritingDelegate(self) -> bool: ...
    def isHapticFeedbackEnabled(self) -> bool: ...
    def isHardwareAccelerated(self) -> bool: ...
    def isHorizontalFadingEdgeEnabled(self) -> bool: ...
    def isHorizontalScrollBarEnabled(self) -> bool: ...
    def isHovered(self) -> bool: ...
    def isImportantForAccessibility(self) -> bool: ...
    def isImportantForAutofill(self) -> bool: ...
    def isImportantForContentCapture(self) -> bool: ...
    def isInEditMode(self) -> bool: ...
    def isInLayout(self) -> bool: ...
    def isInTouchMode(self) -> bool: ...
    def isKeyboardNavigationCluster(self) -> bool: ...
    def isLaidOut(self) -> bool: ...
    def isLayoutDirectionResolved(self) -> bool: ...
    def isLayoutRequested(self) -> bool: ...
    def isLongClickable(self) -> bool: ...
    def isNestedScrollingEnabled(self) -> bool: ...
    def isOpaque(self) -> bool: ...
    def isPaddingOffsetRequired(self) -> bool: ...
    def isPaddingRelative(self) -> bool: ...
    def isPivotSet(self) -> bool: ...
    def isPreferKeepClear(self) -> bool: ...
    def isPressed(self) -> bool: ...
    def isSaveEnabled(self) -> bool: ...
    def isSaveFromParentEnabled(self) -> bool: ...
    def isScreenReaderFocusable(self) -> bool: ...
    def isScrollContainer(self) -> bool: ...
    def isScrollbarFadingEnabled(self) -> bool: ...
    def isSelected(self) -> bool: ...
    def isShowingLayoutBounds(self) -> bool: ...
    def isShown(self) -> bool: ...
    def isSoundEffectsEnabled(self) -> bool: ...
    def isTemporarilyDetached(self) -> bool: ...
    def isTextAlignmentResolved(self) -> bool: ...
    def isTextDirectionResolved(self) -> bool: ...
    def isVerticalFadingEdgeEnabled(self) -> bool: ...
    def isVerticalScrollBarEnabled(self) -> bool: ...
    def isVisibleToUserForAutofill(self, virtualId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def jumpDrawablesToCurrentState(self) -> None: ...
    def keyboardNavigationClusterSearch(self, currentCluster: View, direction: int | java.jint | java.lang.Integer, /) -> View | None: ...
    def layout(self, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def measure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def mergeDrawableStates(baseState: java.chaquopy.JavaArrayJInt, additionalState: java.chaquopy.JavaArrayJInt, /) -> java.chaquopy.JavaArrayJInt: ...
    def offsetLeftAndRight(self, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def offsetTopAndBottom(self, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def onAnimationEnd(self) -> None: ...
    def onAnimationStart(self) -> None: ...
    def onApplyWindowInsets(self, insets: WindowInsets, /) -> WindowInsets: ...
    def onAttachedToWindow(self) -> None: ...
    def onCancelPendingInputEvents(self) -> None: ...
    def onCapturedPointerEvent(self, event: MotionEvent, /) -> bool: ...
    def onCheckIsTextEditor(self) -> bool: ...
    def onConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def onCreateContextMenu(self, menu: ContextMenu, /) -> None: ...
    def onCreateDrawableState(self, extraSpace: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def onCreateInputConnection(self, outAttrs: android.view.inputmethod.EditorInfo, /) -> android.view.inputmethod.InputConnection: ...
    def onCreateViewTranslationRequest(self, supportedFormats: java.chaquopy.JavaArrayJInt, requestsCollector: java.util.function.Consumer[android.view.translation.ViewTranslationRequest], /) -> None: ...
    def onCreateVirtualViewTranslationRequests(self, virtualIds: java.chaquopy.JavaArrayJLong, supportedFormats: java.chaquopy.JavaArrayJInt, requestsCollector: java.util.function.Consumer[android.view.translation.ViewTranslationRequest], /) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onDisplayHint(self, hint: int | java.jint | java.lang.Integer, /) -> None: ...
    def onDragEvent(self, event: DragEvent, /) -> bool: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onDrawForeground(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onDrawScrollBars(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onFilterTouchEventForSecurity(self, event: MotionEvent, /) -> bool: ...
    def onFinishInflate(self) -> None: ...
    def onFinishTemporaryDetach(self) -> None: ...
    def onFocusChanged(self, gainFocus: bool | java.jboolean | java.lang.Boolean, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> None: ...
    def onGenericMotionEvent(self, event: MotionEvent, /) -> bool: ...
    def onHoverChanged(self, hovered: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onHoverEvent(self, event: MotionEvent, /) -> bool: ...
    def onInitializeAccessibilityEvent(self, event: android.view.accessibility.AccessibilityEvent, /) -> None: ...
    def onInitializeAccessibilityNodeInfo(self, info: android.view.accessibility.AccessibilityNodeInfo, /) -> None: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: KeyEvent, /) -> bool: ...
    def onKeyLongPress(self, keyCode: int | java.jint | java.lang.Integer, event: KeyEvent, /) -> bool: ...
    def onKeyMultiple(self, keyCode: int | java.jint | java.lang.Integer, repeatCount: int | java.jint | java.lang.Integer, event: KeyEvent, /) -> bool: ...
    def onKeyPreIme(self, keyCode: int | java.jint | java.lang.Integer, event: KeyEvent, /) -> bool: ...
    def onKeyShortcut(self, keyCode: int | java.jint | java.lang.Integer, event: KeyEvent, /) -> bool: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: KeyEvent, /) -> bool: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onOverScrolled(self, scrollX: int | java.jint | java.lang.Integer, scrollY: int | java.jint | java.lang.Integer, clampedX: bool | java.jboolean | java.lang.Boolean, clampedY: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onPointerCaptureChange(self, hasCapture: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onPopulateAccessibilityEvent(self, event: android.view.accessibility.AccessibilityEvent, /) -> None: ...
    def onProvideAutofillStructure(self, structure: ViewStructure, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def onProvideAutofillVirtualStructure(self, structure: ViewStructure, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def onProvideContentCaptureStructure(self, structure: ViewStructure, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def onProvideStructure(self, structure: ViewStructure, /) -> None: ...
    def onProvideVirtualStructure(self, structure: ViewStructure, /) -> None: ...
    def onReceiveContent(self, payload: ContentInfo, /) -> ContentInfo | None: ...
    def onResolvePointerIcon(self, event: MotionEvent, pointerIndex: int | java.jint | java.lang.Integer, /) -> PointerIcon: ...
    def onRestoreInstanceState(self, state: android.os.Parcelable, /) -> None: ...
    def onRtlPropertiesChanged(self, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Parcelable: ...
    def onScreenStateChanged(self, screenState: int | java.jint | java.lang.Integer, /) -> None: ...
    def onScrollCaptureSearch(self, localVisibleRect: android.graphics.Rect, windowOffset: android.graphics.Point, targets: java.util.function.Consumer[ScrollCaptureTarget], /) -> None: ...
    def onScrollChanged(self, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, oldl: int | java.jint | java.lang.Integer, oldt: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSetAlpha(self, alpha: int | java.jint | java.lang.Integer, /) -> bool: ...
    def onSizeChanged(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, oldw: int | java.jint | java.lang.Integer, oldh: int | java.jint | java.lang.Integer, /) -> None: ...
    def onStartTemporaryDetach(self) -> None: ...
    def onTouchEvent(self, event: MotionEvent, /) -> bool: ...
    def onTrackballEvent(self, event: MotionEvent, /) -> bool: ...
    def onViewTranslationResponse(self, response: android.view.translation.ViewTranslationResponse, /) -> None: ...
    def onVirtualViewTranslationResponses(self, response: android.util.LongSparseArray[android.view.translation.ViewTranslationResponse], /) -> None: ...
    def onVisibilityAggregated(self, isVisible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onVisibilityChanged(self, changedView: View, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def onWindowFocusChanged(self, hasWindowFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onWindowSystemUiVisibilityChanged(self, visible: int | java.jint | java.lang.Integer, /) -> None: ...
    def onWindowVisibilityChanged(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def overScrollBy(self, deltaX: int | java.jint | java.lang.Integer, deltaY: int | java.jint | java.lang.Integer, scrollX: int | java.jint | java.lang.Integer, scrollY: int | java.jint | java.lang.Integer, scrollRangeX: int | java.jint | java.lang.Integer, scrollRangeY: int | java.jint | java.lang.Integer, maxOverScrollX: int | java.jint | java.lang.Integer, maxOverScrollY: int | java.jint | java.lang.Integer, isTouchEvent: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def performAccessibilityAction(self, action: int | java.jint | java.lang.Integer, arguments: android.os.Bundle, /) -> bool: ...
    def performClick(self) -> bool: ...
    @typing.overload
    def performContextClick(self) -> bool: ...
    @typing.overload
    def performContextClick(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> bool: ...
    @typing.overload
    def performHapticFeedback(self, feedbackConstant: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def performHapticFeedback(self, feedbackConstant: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def performLongClick(self) -> bool: ...
    @typing.overload
    def performLongClick(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> bool: ...
    def performReceiveContent(self, payload: ContentInfo, /) -> ContentInfo | None: ...
    def playSoundEffect(self, soundConstant: int | java.jint | java.lang.Integer, /) -> None: ...
    def post(self, action: java.lang.Runnable, /) -> bool: ...
    def postDelayed(self, action: java.lang.Runnable, delayMillis: int | java.jlong | java.lang.Long, /) -> bool: ...
    @typing.overload
    def postInvalidate(self) -> None: ...
    @typing.overload
    def postInvalidate(self, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def postInvalidateDelayed(self, delayMilliseconds: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def postInvalidateDelayed(self, delayMilliseconds: int | java.jlong | java.lang.Long, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def postInvalidateOnAnimation(self) -> None: ...
    @typing.overload
    def postInvalidateOnAnimation(self, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def postOnAnimation(self, action: java.lang.Runnable, /) -> None: ...
    def postOnAnimationDelayed(self, action: java.lang.Runnable, delayMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def refreshDrawableState(self) -> None: ...
    def releasePointerCapture(self) -> None: ...
    def removeCallbacks(self, action: java.lang.Runnable, /) -> bool: ...
    def removeOnAttachStateChangeListener(self, listener: View.OnAttachStateChangeListener, /) -> None: ...
    def removeOnLayoutChangeListener(self, listener: View.OnLayoutChangeListener, /) -> None: ...
    def removeOnUnhandledKeyEventListener(self, listener: View.OnUnhandledKeyEventListener, /) -> None: ...
    def reportAppJankStats(self, appJankStats: android.app.jank.AppJankStats, /) -> None: ...
    def requestApplyInsets(self) -> None: ...
    def requestFitSystemWindows(self) -> None: ...
    @typing.overload
    def requestFocus(self) -> bool: ...
    @typing.overload
    def requestFocus(self, direction: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def requestFocus(self, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> bool: ...
    def requestFocusFromTouch(self) -> bool: ...
    def requestLayout(self) -> None: ...
    def requestPointerCapture(self) -> None: ...
    @typing.overload
    def requestRectangleOnScreen(self, rectangle: android.graphics.Rect, /) -> bool: ...
    @typing.overload
    def requestRectangleOnScreen(self, rectangle: android.graphics.Rect, immediate: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def requestUnbufferedDispatch(self, source: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def requestUnbufferedDispatch(self, event: MotionEvent, /) -> None: ...
    def requireViewById(self, id: int | java.jint | java.lang.Integer, /) -> View: ...
    def resetPivot(self) -> None: ...
    @staticmethod
    def resolveSize(size: int | java.jint | java.lang.Integer, measureSpec: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def resolveSizeAndState(size: int | java.jint | java.lang.Integer, measureSpec: int | java.jint | java.lang.Integer, childMeasuredState: int | java.jint | java.lang.Integer, /) -> int: ...
    def restoreDefaultFocus(self) -> bool: ...
    def restoreHierarchyState(self, container: android.util.SparseArray[android.os.Parcelable], /) -> None: ...
    def saveAttributeDataForStyleable(self, context: android.content.Context, styleable: java.chaquopy.JavaArrayJInt, attrs: android.util.AttributeSet, t: android.content.res.TypedArray, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def saveHierarchyState(self, container: android.util.SparseArray[android.os.Parcelable], /) -> None: ...
    def scheduleDrawable(self, who: android.graphics.drawable.Drawable, what: java.lang.Runnable, when: int | java.jlong | java.lang.Long, /) -> None: ...
    def scrollBy(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> None: ...
    def scrollTo(self, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, /) -> None: ...
    def sendAccessibilityEvent(self, eventType: int | java.jint | java.lang.Integer, /) -> None: ...
    def sendAccessibilityEventUnchecked(self, event: android.view.accessibility.AccessibilityEvent, /) -> None: ...
    def setAccessibilityDataSensitive(self, accessibilityDataSensitive: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAccessibilityDelegate(self, delegate: View.AccessibilityDelegate, /) -> None: ...
    def setAccessibilityHeading(self, isHeading: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAccessibilityLiveRegion(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAccessibilityPaneTitle(self, accessibilityPaneTitle: java.lang.CharSequence, /) -> None: ...
    def setAccessibilityTraversalAfter(self, afterId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAccessibilityTraversalBefore(self, beforeId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setActivated(self, activated: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAllowClickWhenDisabled(self, clickableWhenDisabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAllowedHandwritingDelegatePackage(self, allowedPackageName: str | java.lang.String, /) -> None: ...
    def setAllowedHandwritingDelegatorPackage(self, allowedPackageName: str | java.lang.String, /) -> None: ...
    def setAlpha(self, alpha: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setAnimation(self, animation: android.view.animation.Animation, /) -> None: ...
    def setAnimationMatrix(self, matrix: android.graphics.Matrix, /) -> None: ...
    def setAutoHandwritingEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAutofillHints(self, *autofillHints: java.lang.String) -> None: ...
    def setAutofillId(self, id: android.view.autofill.AutofillId, /) -> None: ...
    def setBackground(self, background: android.graphics.drawable.Drawable, /) -> None: ...
    def setBackgroundColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBackgroundDrawable(self, background: android.graphics.drawable.Drawable, /) -> None: ...
    def setBackgroundResource(self, resid: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBackgroundTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setBackgroundTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setBackgroundTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> None: ...
    def setBottom(self, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCameraDistance(self, distance: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setClickable(self, clickable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setClipBounds(self, clipBounds: android.graphics.Rect, /) -> None: ...
    def setClipToOutline(self, clipToOutline: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setContentCaptureSession(self, contentCaptureSession: android.view.contentcapture.ContentCaptureSession, /) -> None: ...
    def setContentDescription(self, contentDescription: java.lang.CharSequence, /) -> None: ...
    def setContentSensitivity(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setContextClickable(self, contextClickable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDefaultFocusHighlightEnabled(self, defaultFocusHighlightEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDrawingCacheBackgroundColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDrawingCacheEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDrawingCacheQuality(self, quality: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDuplicateParentStateEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setElevation(self, elevation: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFadingEdgeLength(self, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFilterTouchesWhenObscured(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFitsSystemWindows(self, fitSystemWindows: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setFocusable(self, focusable: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setFocusable(self, focusable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFocusableInTouchMode(self, focusableInTouchMode: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFocusedByDefault(self, isFocusedByDefault: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setForceDarkAllowed(self, allow: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setForeground(self, foreground: android.graphics.drawable.Drawable, /) -> None: ...
    def setForegroundGravity(self, gravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setForegroundTintBlendMode(self, blendMode: android.graphics.BlendMode, /) -> None: ...
    def setForegroundTintList(self, tint: android.content.res.ColorStateList, /) -> None: ...
    def setForegroundTintMode(self, tintMode: android.graphics.PorterDuff.Mode, /) -> None: ...
    def setFrameContentVelocity(self, pixelsPerSecond: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setHandwritingBoundsOffsets(self, offsetLeft: float | java.jfloat | java.lang.Float, offsetTop: float | java.jfloat | java.lang.Float, offsetRight: float | java.jfloat | java.lang.Float, offsetBottom: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setHandwritingDelegateFlags(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def setHandwritingDelegatorCallback(self, callback: java.lang.Runnable, /) -> None: ...
    def setHapticFeedbackEnabled(self, hapticFeedbackEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setHasTransientState(self, hasTransientState: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setHorizontalFadingEdgeEnabled(self, horizontalFadingEdgeEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setHorizontalScrollBarEnabled(self, horizontalScrollBarEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setHorizontalScrollbarThumbDrawable(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def setHorizontalScrollbarTrackDrawable(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def setHovered(self, hovered: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setId(self, id: int | java.jint | java.lang.Integer, /) -> None: ...
    def setImportantForAccessibility(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setImportantForAutofill(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setImportantForContentCapture(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setIsCredential(self, isCredential: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setIsHandwritingDelegate(self, isHandwritingDelegate: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setKeepScreenOn(self, keepScreenOn: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setKeyboardNavigationCluster(self, isCluster: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setLabelFor(self, id: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLayerPaint(self, paint: android.graphics.Paint, /) -> None: ...
    def setLayerType(self, layerType: int | java.jint | java.lang.Integer, paint: android.graphics.Paint, /) -> None: ...
    def setLayoutDirection(self, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLayoutParams(self, params: ViewGroup.LayoutParams, /) -> None: ...
    def setLeft(self, left: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLeftTopRightBottom(self, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLongClickable(self, longClickable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMeasuredDimension(self, measuredWidth: int | java.jint | java.lang.Integer, measuredHeight: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinimumHeight(self, minHeight: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinimumWidth(self, minWidth: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNestedScrollingEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setNextClusterForwardId(self, nextClusterForwardId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNextFocusDownId(self, nextFocusDownId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNextFocusForwardId(self, nextFocusForwardId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNextFocusLeftId(self, nextFocusLeftId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNextFocusRightId(self, nextFocusRightId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNextFocusUpId(self, nextFocusUpId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOnApplyWindowInsetsListener(self, listener: View.OnApplyWindowInsetsListener, /) -> None: ...
    def setOnCapturedPointerListener(self, l: View.OnCapturedPointerListener, /) -> None: ...
    def setOnClickListener(self, l: View.OnClickListener, /) -> None: ...
    def setOnContextClickListener(self, l: View.OnContextClickListener, /) -> None: ...
    def setOnCreateContextMenuListener(self, l: View.OnCreateContextMenuListener, /) -> None: ...
    def setOnDragListener(self, l: View.OnDragListener, /) -> None: ...
    def setOnFocusChangeListener(self, l: View.OnFocusChangeListener, /) -> None: ...
    def setOnGenericMotionListener(self, l: View.OnGenericMotionListener, /) -> None: ...
    def setOnHoverListener(self, l: View.OnHoverListener, /) -> None: ...
    def setOnKeyListener(self, l: View.OnKeyListener, /) -> None: ...
    def setOnLongClickListener(self, l: View.OnLongClickListener, /) -> None: ...
    def setOnReceiveContentListener(self, mimeTypes: java.chaquopy.JavaArray[java.lang.String], listener: OnReceiveContentListener, /) -> None: ...
    def setOnScrollChangeListener(self, l: View.OnScrollChangeListener, /) -> None: ...
    def setOnSystemUiVisibilityChangeListener(self, l: View.OnSystemUiVisibilityChangeListener, /) -> None: ...
    def setOnTouchListener(self, l: View.OnTouchListener, /) -> None: ...
    def setOutlineAmbientShadowColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOutlineProvider(self, provider: ViewOutlineProvider, /) -> None: ...
    def setOutlineSpotShadowColor(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOverScrollMode(self, overScrollMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPadding(self, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPaddingRelative(self, start: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPendingCredentialRequest(self, request: android.credentials.GetCredentialRequest, callback: android.os.OutcomeReceiver[android.credentials.GetCredentialResponse, android.credentials.GetCredentialException], /) -> None: ...
    def setPivotX(self, pivotX: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setPivotY(self, pivotY: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setPointerIcon(self, pointerIcon: PointerIcon, /) -> None: ...
    def setPreferKeepClear(self, preferKeepClear: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setPreferKeepClearRects(self, rects: java.util.List[android.graphics.Rect], /) -> None: ...
    def setPressed(self, pressed: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setRenderEffect(self, renderEffect: android.graphics.RenderEffect, /) -> None: ...
    def setRequestedFrameRate(self, frameRate: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setRevealOnFocusHint(self, revealOnFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setRight(self, right: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRotation(self, rotation: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setRotationX(self, rotationX: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setRotationY(self, rotationY: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setSaveEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSaveFromParentEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setScaleX(self, scaleX: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setScaleY(self, scaleY: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setScreenReaderFocusable(self, screenReaderFocusable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setScrollBarDefaultDelayBeforeFade(self, scrollBarDefaultDelayBeforeFade: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScrollBarFadeDuration(self, scrollBarFadeDuration: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScrollBarSize(self, scrollBarSize: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScrollBarStyle(self, style: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScrollCaptureCallback(self, callback: ScrollCaptureCallback, /) -> None: ...
    def setScrollCaptureHint(self, hint: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScrollContainer(self, isScrollContainer: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setScrollIndicators(self, indicators: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setScrollIndicators(self, indicators: int | java.jint | java.lang.Integer, mask: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScrollX(self, value: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScrollY(self, value: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScrollbarFadingEnabled(self, fadeScrollbars: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSelected(self, selected: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSoundEffectsEnabled(self, soundEffectsEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setStateDescription(self, stateDescription: java.lang.CharSequence, /) -> None: ...
    def setStateListAnimator(self, stateListAnimator: android.animation.StateListAnimator, /) -> None: ...
    def setSupplementalDescription(self, supplementalDescription: java.lang.CharSequence, /) -> None: ...
    def setSystemGestureExclusionRects(self, rects: java.util.List[android.graphics.Rect], /) -> None: ...
    def setSystemUiVisibility(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTag(self, tag: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def setTag(self, key: int | java.jint | java.lang.Integer, tag: java.lang.Object | int | bool | float | str, /) -> None: ...
    def setTextAlignment(self, textAlignment: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTextDirection(self, textDirection: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTooltipText(self, tooltipText: java.lang.CharSequence, /) -> None: ...
    def setTop(self, top: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTouchDelegate(self, delegate: TouchDelegate, /) -> None: ...
    def setTransitionAlpha(self, alpha: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setTransitionName(self, transitionName: str | java.lang.String, /) -> None: ...
    def setTransitionVisibility(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTranslationX(self, translationX: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setTranslationY(self, translationY: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setTranslationZ(self, translationZ: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setVerticalFadingEdgeEnabled(self, verticalFadingEdgeEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setVerticalScrollBarEnabled(self, verticalScrollBarEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setVerticalScrollbarPosition(self, position: int | java.jint | java.lang.Integer, /) -> None: ...
    def setVerticalScrollbarThumbDrawable(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def setVerticalScrollbarTrackDrawable(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def setViewTranslationCallback(self, callback: android.view.translation.ViewTranslationCallback, /) -> None: ...
    def setVisibility(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def setWillNotCacheDrawing(self, willNotCacheDrawing: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setWillNotDraw(self, willNotDraw: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setWindowInsetsAnimationCallback(self, callback: WindowInsetsAnimation.Callback, /) -> None: ...
    def setX(self, x: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setY(self, y: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setZ(self, z: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def showContextMenu(self) -> bool: ...
    @typing.overload
    def showContextMenu(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> bool: ...
    @typing.overload
    def startActionMode(self, callback: ActionMode.Callback, /) -> ActionMode | None: ...
    @typing.overload
    def startActionMode(self, callback: ActionMode.Callback, type: int | java.jint | java.lang.Integer, /) -> ActionMode | None: ...
    def startAnimation(self, animation: android.view.animation.Animation, /) -> None: ...
    def startDrag(self, data: android.content.ClipData, shadowBuilder: View.DragShadowBuilder, myLocalState: java.lang.Object | int | bool | float | str, flags: int | java.jint | java.lang.Integer, /) -> bool: ...
    def startDragAndDrop(self, data: android.content.ClipData, shadowBuilder: View.DragShadowBuilder, myLocalState: java.lang.Object | int | bool | float | str, flags: int | java.jint | java.lang.Integer, /) -> bool: ...
    def startNestedScroll(self, axes: int | java.jint | java.lang.Integer, /) -> bool: ...
    def stopNestedScroll(self) -> None: ...
    def toString(self) -> str: ...
    def transformMatrixToGlobal(self, matrix: android.graphics.Matrix, /) -> None: ...
    def transformMatrixToLocal(self, matrix: android.graphics.Matrix, /) -> None: ...
    @typing.overload
    def unscheduleDrawable(self, who: android.graphics.drawable.Drawable, /) -> None: ...
    @typing.overload
    def unscheduleDrawable(self, who: android.graphics.drawable.Drawable, what: java.lang.Runnable, /) -> None: ...
    def updateDragShadow(self, shadowBuilder: View.DragShadowBuilder, /) -> None: ...
    def verifyDrawable(self, who: android.graphics.drawable.Drawable, /) -> bool: ...
    def willNotCacheDrawing(self) -> bool: ...
    def willNotDraw(self) -> bool: ...

    class OnUnhandledKeyEventListener(java.lang.Object):
        def onUnhandledKeyEvent(self, arg1: View, arg2: KeyEvent, /) -> bool: ...

    class OnTouchListener(java.lang.Object):
        def onTouch(self, arg1: View, arg2: MotionEvent, /) -> bool: ...

    class OnSystemUiVisibilityChangeListener(java.lang.Object):
        def onSystemUiVisibilityChange(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnScrollChangeListener(java.lang.Object):
        def onScrollChange(self, arg1: View, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnLongClickListener(java.lang.Object):
        def onLongClick(self, arg1: View, /) -> bool: ...
        def onLongClickUseDefaultHapticFeedback(self, v: View, /) -> bool: ...

    class OnLayoutChangeListener(java.lang.Object):
        def onLayoutChange(self, arg1: View, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnKeyListener(java.lang.Object):
        def onKey(self, arg1: View, arg2: int | java.jint | java.lang.Integer, arg3: KeyEvent, /) -> bool: ...

    class OnHoverListener(java.lang.Object):
        def onHover(self, arg1: View, arg2: MotionEvent, /) -> bool: ...

    class OnGenericMotionListener(java.lang.Object):
        def onGenericMotion(self, arg1: View, arg2: MotionEvent, /) -> bool: ...

    class OnFocusChangeListener(java.lang.Object):
        def onFocusChange(self, arg1: View, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class OnDragListener(java.lang.Object):
        def onDrag(self, arg1: View, arg2: DragEvent, /) -> bool: ...

    class OnCreateContextMenuListener(java.lang.Object):
        def onCreateContextMenu(self, arg1: ContextMenu, arg2: View, arg3: ContextMenu.ContextMenuInfo, /) -> None: ...

    class OnContextClickListener(java.lang.Object):
        def onContextClick(self, arg1: View, /) -> bool: ...

    class OnClickListener(java.lang.Object):
        def onClick(self, arg1: View, /) -> None: ...

    class OnCapturedPointerListener(java.lang.Object):
        def onCapturedPointer(self, arg1: View, arg2: MotionEvent, /) -> bool: ...

    class OnAttachStateChangeListener(java.lang.Object):
        def onViewAttachedToWindow(self, arg1: View, /) -> None: ...
        def onViewDetachedFromWindow(self, arg1: View, /) -> None: ...

    class OnApplyWindowInsetsListener(java.lang.Object):
        def onApplyWindowInsets(self, arg1: View, arg2: WindowInsets, /) -> WindowInsets: ...

    class MeasureSpec(java.lang.Object):
        AT_MOST: typing.ClassVar[int] = ...
        EXACTLY: typing.ClassVar[int] = ...
        UNSPECIFIED: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...
        @staticmethod
        def getMode(measureSpec: int | java.jint | java.lang.Integer, /) -> int: ...
        @staticmethod
        def getSize(measureSpec: int | java.jint | java.lang.Integer, /) -> int: ...
        @staticmethod
        def makeMeasureSpec(size: int | java.jint | java.lang.Integer, mode: int | java.jint | java.lang.Integer, /) -> int: ...
        @staticmethod
        def toString(measureSpec: int | java.jint | java.lang.Integer, /) -> str: ...

    class DragShadowBuilder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, view: View, /) -> None: ...
        def getView(self) -> View: ...
        def onDrawShadow(self, canvas: android.graphics.Canvas, /) -> None: ...
        def onProvideShadowMetrics(self, outShadowSize: android.graphics.Point, outShadowTouchPoint: android.graphics.Point, /) -> None: ...

    class BaseSavedState(AbsSavedState):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[View.BaseSavedState]] = ...
        @typing.overload
        def __init__(self, source: android.os.Parcel, /) -> None: ...
        @typing.overload
        def __init__(self, superState: android.os.Parcelable, /) -> None: ...
        @typing.overload
        def __init__(self, source: android.os.Parcel, loader: java.lang.ClassLoader, /) -> None: ...
        def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class AccessibilityDelegate(java.lang.Object):
        def __init__(self) -> None: ...
        def addExtraDataToAccessibilityNodeInfo(self, host: View, info: android.view.accessibility.AccessibilityNodeInfo, extraDataKey: str | java.lang.String, arguments: android.os.Bundle, /) -> None: ...
        def dispatchPopulateAccessibilityEvent(self, host: View, event: android.view.accessibility.AccessibilityEvent, /) -> bool: ...
        def getAccessibilityNodeProvider(self, host: View, /) -> android.view.accessibility.AccessibilityNodeProvider: ...
        def onInitializeAccessibilityEvent(self, host: View, event: android.view.accessibility.AccessibilityEvent, /) -> None: ...
        def onInitializeAccessibilityNodeInfo(self, host: View, info: android.view.accessibility.AccessibilityNodeInfo, /) -> None: ...
        def onPopulateAccessibilityEvent(self, host: View, event: android.view.accessibility.AccessibilityEvent, /) -> None: ...
        def onRequestSendAccessibilityEvent(self, host: ViewGroup, child: View, event: android.view.accessibility.AccessibilityEvent, /) -> bool: ...
        def performAccessibilityAction(self, host: View, action: int | java.jint | java.lang.Integer, args: android.os.Bundle, /) -> bool: ...
        def sendAccessibilityEvent(self, host: View, eventType: int | java.jint | java.lang.Integer, /) -> None: ...
        def sendAccessibilityEventUnchecked(self, host: View, event: android.view.accessibility.AccessibilityEvent, /) -> None: ...

class ViewAnimationUtils(java.lang.Object):
    @staticmethod
    def createCircularReveal(view: View, centerX: int | java.jint | java.lang.Integer, centerY: int | java.jint | java.lang.Integer, startRadius: float | java.jfloat | java.lang.Float, endRadius: float | java.jfloat | java.lang.Float, /) -> android.animation.Animator: ...

class ViewConfiguration(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def get(context: android.content.Context, /) -> ViewConfiguration: ...
    @staticmethod
    def getAmbiguousGestureMultiplier() -> float: ...
    @staticmethod
    def getDefaultActionModeHideDuration() -> int: ...
    @staticmethod
    def getDoubleTapTimeout() -> int: ...
    @staticmethod
    def getEdgeSlop() -> int: ...
    @staticmethod
    def getFadingEdgeLength() -> int: ...
    @staticmethod
    def getGlobalActionKeyTimeout() -> int: ...
    @staticmethod
    def getJumpTapTimeout() -> int: ...
    @staticmethod
    def getKeyRepeatDelay() -> int: ...
    @staticmethod
    def getKeyRepeatTimeout() -> int: ...
    @staticmethod
    def getLongPressTimeout() -> int: ...
    @staticmethod
    def getMaximumDrawingCacheSize() -> int: ...
    @staticmethod
    def getMaximumFlingVelocity() -> int: ...
    @staticmethod
    def getMinimumFlingVelocity() -> int: ...
    @staticmethod
    def getMultiPressTimeout() -> int: ...
    @staticmethod
    def getPressedStateDuration() -> int: ...
    def getScaledAmbiguousGestureMultiplier(self) -> float: ...
    def getScaledDoubleTapSlop(self) -> int: ...
    def getScaledEdgeSlop(self) -> int: ...
    def getScaledFadingEdgeLength(self) -> int: ...
    def getScaledHandwritingGestureLineMargin(self) -> int: ...
    def getScaledHandwritingSlop(self) -> int: ...
    def getScaledHorizontalScrollFactor(self) -> float: ...
    def getScaledHoverSlop(self) -> int: ...
    def getScaledMaximumDrawingCacheSize(self) -> int: ...
    @typing.overload
    def getScaledMaximumFlingVelocity(self) -> int: ...
    @typing.overload
    def getScaledMaximumFlingVelocity(self, inputDeviceId: int | java.jint | java.lang.Integer, axis: int | java.jint | java.lang.Integer, source: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getScaledMinimumFlingVelocity(self) -> int: ...
    @typing.overload
    def getScaledMinimumFlingVelocity(self, inputDeviceId: int | java.jint | java.lang.Integer, axis: int | java.jint | java.lang.Integer, source: int | java.jint | java.lang.Integer, /) -> int: ...
    def getScaledMinimumScalingSpan(self) -> int: ...
    def getScaledOverflingDistance(self) -> int: ...
    def getScaledOverscrollDistance(self) -> int: ...
    def getScaledPagingTouchSlop(self) -> int: ...
    def getScaledScrollBarSize(self) -> int: ...
    def getScaledTouchSlop(self) -> int: ...
    def getScaledVerticalScrollFactor(self) -> float: ...
    def getScaledWindowTouchSlop(self) -> int: ...
    @staticmethod
    def getScrollBarFadeDuration() -> int: ...
    @staticmethod
    def getScrollBarSize() -> int: ...
    @staticmethod
    def getScrollDefaultDelay() -> int: ...
    @staticmethod
    def getScrollFriction() -> float: ...
    @staticmethod
    def getTapTimeout() -> int: ...
    @staticmethod
    def getTouchSlop() -> int: ...
    @staticmethod
    def getWindowTouchSlop() -> int: ...
    @staticmethod
    def getZoomControlsTimeout() -> int: ...
    def hasPermanentMenuKey(self) -> bool: ...
    def shouldShowMenuShortcutsWhenKeyboardPresent(self) -> bool: ...

class ViewDebug(java.lang.Object):
    TRACE_HIERARCHY: typing.ClassVar[bool] = ...
    TRACE_RECYCLER: typing.ClassVar[bool] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def dumpCapturedView(tag: str | java.lang.String, view: java.lang.Object | int | bool | float | str, /) -> None: ...
    @staticmethod
    def startHierarchyTracing(prefix: str | java.lang.String, view: View, /) -> None: ...
    @staticmethod
    def startRecyclerTracing(prefix: str | java.lang.String, view: View, /) -> None: ...
    @staticmethod
    def stopHierarchyTracing() -> None: ...
    @staticmethod
    def stopRecyclerTracing() -> None: ...
    @typing.overload
    @staticmethod
    def trace(view: View, type: ViewDebug.HierarchyTraceType, /) -> None: ...
    @typing.overload
    @staticmethod
    def trace(view: View, type: ViewDebug.RecyclerTraceType, /, *parameters: java.jint) -> None: ...

    class RecyclerTraceType(java.lang.Enum[ViewDebug.RecyclerTraceType]):
        BIND_VIEW: typing.ClassVar[ViewDebug.RecyclerTraceType] = ...
        MOVE_FROM_ACTIVE_TO_SCRAP_HEAP: typing.ClassVar[ViewDebug.RecyclerTraceType] = ...
        MOVE_TO_SCRAP_HEAP: typing.ClassVar[ViewDebug.RecyclerTraceType] = ...
        NEW_VIEW: typing.ClassVar[ViewDebug.RecyclerTraceType] = ...
        RECYCLE_FROM_ACTIVE_HEAP: typing.ClassVar[ViewDebug.RecyclerTraceType] = ...
        RECYCLE_FROM_SCRAP_HEAP: typing.ClassVar[ViewDebug.RecyclerTraceType] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> ViewDebug.RecyclerTraceType: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[ViewDebug.RecyclerTraceType]: ...

    class IntToString(java.lang.annotation.Annotation):
        def from_(self) -> int: ...
        def to(self) -> str: ...

    class HierarchyTraceType(java.lang.Enum[ViewDebug.HierarchyTraceType]):
        BUILD_CACHE: typing.ClassVar[ViewDebug.HierarchyTraceType] = ...
        DRAW: typing.ClassVar[ViewDebug.HierarchyTraceType] = ...
        INVALIDATE: typing.ClassVar[ViewDebug.HierarchyTraceType] = ...
        INVALIDATE_CHILD: typing.ClassVar[ViewDebug.HierarchyTraceType] = ...
        INVALIDATE_CHILD_IN_PARENT: typing.ClassVar[ViewDebug.HierarchyTraceType] = ...
        ON_LAYOUT: typing.ClassVar[ViewDebug.HierarchyTraceType] = ...
        ON_MEASURE: typing.ClassVar[ViewDebug.HierarchyTraceType] = ...
        REQUEST_LAYOUT: typing.ClassVar[ViewDebug.HierarchyTraceType] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> ViewDebug.HierarchyTraceType: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[ViewDebug.HierarchyTraceType]: ...

    class FlagToString(java.lang.annotation.Annotation):
        def equals(self) -> int: ...
        def mask(self) -> int: ...
        def name(self) -> str: ...
        def outputIf(self) -> bool: ...

    class ExportedProperty(java.lang.annotation.Annotation):
        def category(self) -> str: ...
        def deepExport(self) -> bool: ...
        def flagMapping(self) -> java.chaquopy.JavaArray[ViewDebug.FlagToString]: ...
        def formatToHexString(self) -> bool: ...
        def hasAdjacentMapping(self) -> bool: ...
        def indexMapping(self) -> java.chaquopy.JavaArray[ViewDebug.IntToString]: ...
        def mapping(self) -> java.chaquopy.JavaArray[ViewDebug.IntToString]: ...
        def prefix(self) -> str: ...
        def resolveId(self) -> bool: ...

    class CapturedViewProperty(java.lang.annotation.Annotation):
        def retrieveReturn(self) -> bool: ...

class ViewGroup(View, ViewManager, ViewParent):
    CLIP_TO_PADDING_MASK: typing.ClassVar[int] = ...
    FOCUS_AFTER_DESCENDANTS: typing.ClassVar[int] = ...
    FOCUS_BEFORE_DESCENDANTS: typing.ClassVar[int] = ...
    FOCUS_BLOCK_DESCENDANTS: typing.ClassVar[int] = ...
    LAYOUT_MODE_CLIP_BOUNDS: typing.ClassVar[int] = ...
    LAYOUT_MODE_OPTICAL_BOUNDS: typing.ClassVar[int] = ...
    PERSISTENT_ALL_CACHES: typing.ClassVar[int] = ...
    PERSISTENT_ANIMATION_CACHE: typing.ClassVar[int] = ...
    PERSISTENT_NO_CACHE: typing.ClassVar[int] = ...
    PERSISTENT_SCROLLING_CACHE: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def addChildrenForAccessibility(self, outChildren: java.util.ArrayList[View], /) -> None: ...
    def addExtraDataToAccessibilityNodeInfo(self, info: android.view.accessibility.AccessibilityNodeInfo, extraDataKey: str | java.lang.String, arguments: android.os.Bundle, /) -> None: ...
    def addFocusables(self, views: java.util.ArrayList[View], direction: int | java.jint | java.lang.Integer, focusableMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def addKeyboardNavigationClusters(self, views: java.util.Collection[View], direction: int | java.jint | java.lang.Integer, /) -> None: ...
    def addStatesFromChildren(self) -> bool: ...
    def addTouchables(self, views: java.util.ArrayList[View], /) -> None: ...
    @typing.overload
    def addView(self, child: View, /) -> None: ...
    @typing.overload
    def addView(self, child: View, index: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addView(self, child: View, params: ViewGroup.LayoutParams, /) -> None: ...
    @typing.overload
    def addView(self, child: View, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addView(self, child: View, index: int | java.jint | java.lang.Integer, params: ViewGroup.LayoutParams, /) -> None: ...
    @typing.overload
    def addViewInLayout(self, child: View, index: int | java.jint | java.lang.Integer, params: ViewGroup.LayoutParams, /) -> bool: ...
    @typing.overload
    def addViewInLayout(self, child: View, index: int | java.jint | java.lang.Integer, params: ViewGroup.LayoutParams, preventRequestLayout: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def attachLayoutAnimationParameters(self, child: View, params: ViewGroup.LayoutParams, index: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...
    def attachViewToParent(self, child: View, index: int | java.jint | java.lang.Integer, params: ViewGroup.LayoutParams, /) -> None: ...
    def bringChildToFront(self, child: View, /) -> None: ...
    def canAnimate(self) -> bool: ...
    def checkLayoutParams(self, p: ViewGroup.LayoutParams, /) -> bool: ...
    def childDrawableStateChanged(self, child: View, /) -> None: ...
    def childHasTransientStateChanged(self, child: View, childHasTransientState: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def cleanupLayoutState(self, child: View, /) -> None: ...
    def clearChildFocus(self, child: View, /) -> None: ...
    def clearDisappearingChildren(self) -> None: ...
    def clearFocus(self) -> None: ...
    def debug(self, depth: int | java.jint | java.lang.Integer, /) -> None: ...
    def detachAllViewsFromParent(self) -> None: ...
    @typing.overload
    def detachViewFromParent(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def detachViewFromParent(self, child: View, /) -> None: ...
    def detachViewsFromParent(self, start: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchApplyWindowInsets(self, insets: WindowInsets, /) -> WindowInsets: ...
    def dispatchCapturedPointerEvent(self, event: MotionEvent, /) -> bool: ...
    def dispatchConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def dispatchCreateViewTranslationRequest(self, viewIds: java.util.Map[android.view.autofill.AutofillId, java.chaquopy.JavaArrayJLong], supportedFormats: java.chaquopy.JavaArrayJInt, capability: android.view.translation.TranslationCapability, requests: java.util.List[android.view.translation.ViewTranslationRequest], /) -> None: ...
    def dispatchDisplayHint(self, hint: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchDragEvent(self, event: DragEvent, /) -> bool: ...
    def dispatchDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def dispatchDrawableHotspotChanged(self, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> None: ...
    def dispatchFinishTemporaryDetach(self) -> None: ...
    def dispatchFreezeSelfOnly(self, container: android.util.SparseArray[android.os.Parcelable], /) -> None: ...
    def dispatchGenericFocusedEvent(self, event: MotionEvent, /) -> bool: ...
    def dispatchGenericPointerEvent(self, event: MotionEvent, /) -> bool: ...
    def dispatchHoverEvent(self, event: MotionEvent, /) -> bool: ...
    def dispatchKeyEvent(self, event: KeyEvent, /) -> bool: ...
    def dispatchKeyEventPreIme(self, event: KeyEvent, /) -> bool: ...
    def dispatchKeyShortcutEvent(self, event: KeyEvent, /) -> bool: ...
    def dispatchPointerCaptureChanged(self, hasCapture: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dispatchProvideAutofillStructure(self, structure: ViewStructure, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchProvideStructure(self, structure: ViewStructure, /) -> None: ...
    def dispatchRestoreInstanceState(self, container: android.util.SparseArray[android.os.Parcelable], /) -> None: ...
    def dispatchSaveInstanceState(self, container: android.util.SparseArray[android.os.Parcelable], /) -> None: ...
    def dispatchScrollCaptureSearch(self, localVisibleRect: android.graphics.Rect, windowOffset: android.graphics.Point, targets: java.util.function.Consumer[ScrollCaptureTarget], /) -> None: ...
    def dispatchSetActivated(self, activated: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dispatchSetPressed(self, pressed: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dispatchSetSelected(self, selected: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dispatchStartTemporaryDetach(self) -> None: ...
    def dispatchSystemUiVisibilityChanged(self, visible: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchThawSelfOnly(self, container: android.util.SparseArray[android.os.Parcelable], /) -> None: ...
    def dispatchTouchEvent(self, ev: MotionEvent, /) -> bool: ...
    def dispatchTrackballEvent(self, event: MotionEvent, /) -> bool: ...
    def dispatchUnhandledMove(self, focused: View, direction: int | java.jint | java.lang.Integer, /) -> bool: ...
    def dispatchVisibilityChanged(self, changedView: View, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchWindowFocusChanged(self, hasFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dispatchWindowInsetsAnimationEnd(self, animation: WindowInsetsAnimation, /) -> None: ...
    def dispatchWindowInsetsAnimationPrepare(self, animation: WindowInsetsAnimation, /) -> None: ...
    def dispatchWindowInsetsAnimationProgress(self, insets: WindowInsets, runningAnimations: java.util.List[WindowInsetsAnimation], /) -> WindowInsets: ...
    def dispatchWindowInsetsAnimationStart(self, animation: WindowInsetsAnimation, bounds: WindowInsetsAnimation.Bounds, /) -> WindowInsetsAnimation.Bounds: ...
    def dispatchWindowSystemUiVisiblityChanged(self, visible: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchWindowVisibilityChanged(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def drawChild(self, canvas: android.graphics.Canvas, child: View, drawingTime: int | java.jlong | java.lang.Long, /) -> bool: ...
    def drawableStateChanged(self) -> None: ...
    def endViewTransition(self, view: View, /) -> None: ...
    def findFocus(self) -> View: ...
    def findOnBackInvokedDispatcherForChild(self, child: View, requester: View, /) -> android.window.OnBackInvokedDispatcher | None: ...
    def findViewsWithText(self, outViews: java.util.ArrayList[View], text: java.lang.CharSequence, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def focusSearch(self, focused: View, direction: int | java.jint | java.lang.Integer, /) -> View: ...
    def focusableViewAvailable(self, v: View, /) -> None: ...
    def gatherTransparentRegion(self, region: android.graphics.Region, /) -> bool: ...
    def generateDefaultLayoutParams(self) -> ViewGroup.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, attrs: android.util.AttributeSet, /) -> ViewGroup.LayoutParams: ...
    @typing.overload
    def generateLayoutParams(self, p: ViewGroup.LayoutParams, /) -> ViewGroup.LayoutParams: ...
    def getAccessibilityClassName(self) -> java.lang.CharSequence: ...
    def getChildAt(self, index: int | java.jint | java.lang.Integer, /) -> View | None: ...
    def getChildCount(self) -> int: ...
    @typing.overload
    def getChildDrawingOrder(self, drawingPosition: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getChildDrawingOrder(self, childCount: int | java.jint | java.lang.Integer, drawingPosition: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getChildMeasureSpec(spec: int | java.jint | java.lang.Integer, padding: int | java.jint | java.lang.Integer, childDimension: int | java.jint | java.lang.Integer, /) -> int: ...
    def getChildStaticTransformation(self, child: View, t: android.view.animation.Transformation, /) -> bool: ...
    def getChildVisibleRect(self, child: View, r: android.graphics.Rect, offset: android.graphics.Point, /) -> bool: ...
    def getClipChildren(self) -> bool: ...
    def getClipToPadding(self) -> bool: ...
    def getDescendantFocusability(self) -> int: ...
    def getFocusedChild(self) -> View | None: ...
    def getLayoutAnimation(self) -> android.view.animation.LayoutAnimationController: ...
    def getLayoutAnimationListener(self) -> android.view.animation.Animation.AnimationListener: ...
    def getLayoutMode(self) -> int: ...
    def getLayoutTransition(self) -> android.animation.LayoutTransition: ...
    def getNestedScrollAxes(self) -> int: ...
    def getOverlay(self) -> ViewGroupOverlay: ...
    def getPersistentDrawingCache(self) -> int: ...
    def getTouchscreenBlocksFocus(self) -> bool: ...
    def hasFocus(self) -> bool: ...
    def hasTransientState(self) -> bool: ...
    def indexOfChild(self, child: View, /) -> int: ...
    def invalidateChild(self, child: View, dirty: android.graphics.Rect, /) -> None: ...
    def invalidateChildInParent(self, location: java.chaquopy.JavaArrayJInt, dirty: android.graphics.Rect, /) -> ViewParent: ...
    def isAlwaysDrawnWithCacheEnabled(self) -> bool: ...
    def isAnimationCacheEnabled(self) -> bool: ...
    def isChildrenDrawingOrderEnabled(self) -> bool: ...
    def isChildrenDrawnWithCacheEnabled(self) -> bool: ...
    def isLayoutSuppressed(self) -> bool: ...
    def isMotionEventSplittingEnabled(self) -> bool: ...
    def isTransitionGroup(self) -> bool: ...
    def jumpDrawablesToCurrentState(self) -> None: ...
    def layout(self, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def measureChild(self, child: View, parentWidthMeasureSpec: int | java.jint | java.lang.Integer, parentHeightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def measureChildWithMargins(self, child: View, parentWidthMeasureSpec: int | java.jint | java.lang.Integer, widthUsed: int | java.jint | java.lang.Integer, parentHeightMeasureSpec: int | java.jint | java.lang.Integer, heightUsed: int | java.jint | java.lang.Integer, /) -> None: ...
    def measureChildren(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def notifySubtreeAccessibilityStateChanged(self, child: View, source: View, changeType: int | java.jint | java.lang.Integer, /) -> None: ...
    def offsetDescendantRectToMyCoords(self, descendant: View, rect: android.graphics.Rect, /) -> None: ...
    def offsetRectIntoDescendantCoords(self, descendant: View, rect: android.graphics.Rect, /) -> None: ...
    def onAttachedToWindow(self) -> None: ...
    def onCreateDrawableState(self, extraSpace: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def onDescendantInvalidated(self, child: View, target: View, /) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onInterceptHoverEvent(self, event: MotionEvent, /) -> bool: ...
    def onInterceptTouchEvent(self, ev: MotionEvent, /) -> bool: ...
    def onLayout(self, arg1: bool | java.jboolean | java.lang.Boolean, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    def onNestedFling(self, target: View, velocityX: float | java.jfloat | java.lang.Float, velocityY: float | java.jfloat | java.lang.Float, consumed: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def onNestedPreFling(self, target: View, velocityX: float | java.jfloat | java.lang.Float, velocityY: float | java.jfloat | java.lang.Float, /) -> bool: ...
    def onNestedPrePerformAccessibilityAction(self, target: View, action: int | java.jint | java.lang.Integer, args: android.os.Bundle, /) -> bool: ...
    def onNestedPreScroll(self, target: View, dx: int | java.jint | java.lang.Integer, dy: int | java.jint | java.lang.Integer, consumed: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def onNestedScroll(self, target: View, dxConsumed: int | java.jint | java.lang.Integer, dyConsumed: int | java.jint | java.lang.Integer, dxUnconsumed: int | java.jint | java.lang.Integer, dyUnconsumed: int | java.jint | java.lang.Integer, /) -> None: ...
    def onNestedScrollAccepted(self, child: View, target: View, axes: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRequestFocusInDescendants(self, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> bool: ...
    def onRequestSendAccessibilityEvent(self, child: View, event: android.view.accessibility.AccessibilityEvent, /) -> bool: ...
    def onResolvePointerIcon(self, event: MotionEvent, pointerIndex: int | java.jint | java.lang.Integer, /) -> PointerIcon: ...
    def onStartNestedScroll(self, child: View, target: View, nestedScrollAxes: int | java.jint | java.lang.Integer, /) -> bool: ...
    def onStopNestedScroll(self, child: View, /) -> None: ...
    def onViewAdded(self, child: View, /) -> None: ...
    def onViewRemoved(self, child: View, /) -> None: ...
    def propagateRequestedFrameRate(self, frameRate: float | java.jfloat | java.lang.Float, forceOverride: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def recomputeViewAttributes(self, child: View, /) -> None: ...
    def removeAllViews(self) -> None: ...
    def removeAllViewsInLayout(self) -> None: ...
    def removeDetachedView(self, child: View, animate: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def removeView(self, view: View, /) -> None: ...
    def removeViewAt(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    def removeViewInLayout(self, view: View, /) -> None: ...
    def removeViews(self, start: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...
    def removeViewsInLayout(self, start: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...
    def requestChildFocus(self, child: View, focused: View, /) -> None: ...
    def requestChildRectangleOnScreen(self, child: View, rectangle: android.graphics.Rect, immediate: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def requestDisallowInterceptTouchEvent(self, disallowIntercept: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def requestFocus(self, direction: int | java.jint | java.lang.Integer, previouslyFocusedRect: android.graphics.Rect, /) -> bool: ...
    def requestSendAccessibilityEvent(self, child: View, event: android.view.accessibility.AccessibilityEvent, /) -> bool: ...
    def requestTransparentRegion(self, child: View, /) -> None: ...
    def restoreDefaultFocus(self) -> bool: ...
    def scheduleLayoutAnimation(self) -> None: ...
    def setAddStatesFromChildren(self, addsStates: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAlwaysDrawnWithCacheEnabled(self, always: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAnimationCacheEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setChildrenDrawingCacheEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setChildrenDrawingOrderEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setChildrenDrawnWithCacheEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setClipChildren(self, clipChildren: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setClipToPadding(self, clipToPadding: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDescendantFocusability(self, focusability: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLayoutAnimation(self, controller: android.view.animation.LayoutAnimationController, /) -> None: ...
    def setLayoutAnimationListener(self, animationListener: android.view.animation.Animation.AnimationListener, /) -> None: ...
    def setLayoutMode(self, layoutMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLayoutTransition(self, transition: android.animation.LayoutTransition, /) -> None: ...
    def setMotionEventSplittingEnabled(self, split: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOnHierarchyChangeListener(self, listener: ViewGroup.OnHierarchyChangeListener, /) -> None: ...
    def setPersistentDrawingCache(self, drawingCacheToKeep: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRequestedFrameRate(self, frameRate: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setStaticTransformationsEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTouchscreenBlocksFocus(self, touchscreenBlocksFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTransitionGroup(self, isTransitionGroup: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setWindowInsetsAnimationCallback(self, callback: WindowInsetsAnimation.Callback, /) -> None: ...
    def shouldDelayChildPressedState(self) -> bool: ...
    @typing.overload
    def showContextMenuForChild(self, originalView: View, /) -> bool: ...
    @typing.overload
    def showContextMenuForChild(self, originalView: View, x: float | java.jfloat | java.lang.Float, y: float | java.jfloat | java.lang.Float, /) -> bool: ...
    @typing.overload
    def startActionModeForChild(self, originalView: View, callback: ActionMode.Callback, /) -> ActionMode: ...
    @typing.overload
    def startActionModeForChild(self, originalView: View, callback: ActionMode.Callback, type: int | java.jint | java.lang.Integer, /) -> ActionMode: ...
    def startLayoutAnimation(self) -> None: ...
    def startViewTransition(self, view: View, /) -> None: ...
    def suppressLayout(self, suppress: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def updateViewLayout(self, view: View, params: ViewGroup.LayoutParams, /) -> None: ...

    class OnHierarchyChangeListener(java.lang.Object):
        def onChildViewAdded(self, arg1: View, arg2: View, /) -> None: ...
        def onChildViewRemoved(self, arg1: View, arg2: View, /) -> None: ...

    class MarginLayoutParams(ViewGroup.LayoutParams):
        bottomMargin: int = ...
        leftMargin: int = ...
        rightMargin: int = ...
        topMargin: int = ...
        @typing.overload
        def __init__(self, source: ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: ViewGroup.MarginLayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, c: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
        def getLayoutDirection(self) -> int: ...
        def getMarginEnd(self) -> int: ...
        def getMarginStart(self) -> int: ...
        def isMarginRelative(self) -> bool: ...
        def resolveLayoutDirection(self, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
        def setLayoutDirection(self, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
        def setMarginEnd(self, end: int | java.jint | java.lang.Integer, /) -> None: ...
        def setMarginStart(self, start: int | java.jint | java.lang.Integer, /) -> None: ...
        def setMargins(self, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...

    class LayoutParams(java.lang.Object):
        FILL_PARENT: typing.ClassVar[int] = ...
        MATCH_PARENT: typing.ClassVar[int] = ...
        WRAP_CONTENT: typing.ClassVar[int] = ...
        height: int = ...
        layoutAnimationParameters: android.view.animation.LayoutAnimationController.AnimationParameters = ...
        width: int = ...
        @typing.overload
        def __init__(self, source: ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, c: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
        def resolveLayoutDirection(self, layoutDirection: int | java.jint | java.lang.Integer, /) -> None: ...
        def setBaseAttributes(self, a: android.content.res.TypedArray, widthAttr: int | java.jint | java.lang.Integer, heightAttr: int | java.jint | java.lang.Integer, /) -> None: ...

class ViewGroupOverlay(ViewOverlay):
    def add(self, view: View, /) -> None: ...
    def remove(self, view: View, /) -> None: ...

class ViewManager(java.lang.Object):
    def addView(self, arg1: View, arg2: ViewGroup.LayoutParams, /) -> None: ...
    def removeView(self, arg1: View, /) -> None: ...
    def updateViewLayout(self, arg1: View, arg2: ViewGroup.LayoutParams, /) -> None: ...

class ViewOutlineProvider(java.lang.Object):
    BACKGROUND: typing.ClassVar[ViewOutlineProvider] = ...
    BOUNDS: typing.ClassVar[ViewOutlineProvider] = ...
    PADDED_BOUNDS: typing.ClassVar[ViewOutlineProvider] = ...
    def __init__(self) -> None: ...
    def getOutline(self, arg1: View, arg2: android.graphics.Outline, /) -> None: ...

class ViewOverlay(java.lang.Object):
    def add(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def clear(self) -> None: ...
    def remove(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...

class ViewParent(java.lang.Object):
    def bringChildToFront(self, arg1: View, /) -> None: ...
    def canResolveLayoutDirection(self) -> bool: ...
    def canResolveTextAlignment(self) -> bool: ...
    def canResolveTextDirection(self) -> bool: ...
    def childDrawableStateChanged(self, arg1: View, /) -> None: ...
    def childHasTransientStateChanged(self, arg1: View, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def clearChildFocus(self, arg1: View, /) -> None: ...
    def createContextMenu(self, arg1: ContextMenu, /) -> None: ...
    def findOnBackInvokedDispatcherForChild(self, child: View, requester: View, /) -> android.window.OnBackInvokedDispatcher | None: ...
    def focusSearch(self, arg1: View, arg2: int | java.jint | java.lang.Integer, /) -> View: ...
    def focusableViewAvailable(self, arg1: View, /) -> None: ...
    def getChildVisibleRect(self, arg1: View, arg2: android.graphics.Rect, arg3: android.graphics.Point, /) -> bool: ...
    def getLayoutDirection(self) -> int: ...
    def getParent(self) -> ViewParent | None: ...
    def getParentForAccessibility(self) -> ViewParent: ...
    def getTextAlignment(self) -> int: ...
    def getTextDirection(self) -> int: ...
    def invalidateChild(self, arg1: View, arg2: android.graphics.Rect, /) -> None: ...
    def invalidateChildInParent(self, arg1: java.chaquopy.JavaArrayJInt, arg2: android.graphics.Rect, /) -> ViewParent | None: ...
    def isLayoutDirectionResolved(self) -> bool: ...
    def isLayoutRequested(self) -> bool: ...
    def isTextAlignmentResolved(self) -> bool: ...
    def isTextDirectionResolved(self) -> bool: ...
    def keyboardNavigationClusterSearch(self, arg1: View, arg2: int | java.jint | java.lang.Integer, /) -> View | None: ...
    def notifySubtreeAccessibilityStateChanged(self, arg1: View, arg2: View, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def onDescendantInvalidated(self, child: View, target: View, /) -> None: ...
    def onNestedFling(self, arg1: View, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def onNestedPreFling(self, arg1: View, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, /) -> bool: ...
    def onNestedPrePerformAccessibilityAction(self, arg1: View, arg2: int | java.jint | java.lang.Integer, arg3: android.os.Bundle, /) -> bool: ...
    def onNestedPreScroll(self, arg1: View, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def onNestedScroll(self, arg1: View, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    def onNestedScrollAccepted(self, arg1: View, arg2: View, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def onStartNestedScroll(self, arg1: View, arg2: View, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...
    def onStopNestedScroll(self, arg1: View, /) -> None: ...
    def recomputeViewAttributes(self, arg1: View, /) -> None: ...
    def requestChildFocus(self, arg1: View, arg2: View, /) -> None: ...
    def requestChildRectangleOnScreen(self, arg1: View, arg2: android.graphics.Rect, arg3: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def requestDisallowInterceptTouchEvent(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def requestFitSystemWindows(self) -> None: ...
    def requestLayout(self) -> None: ...
    def requestSendAccessibilityEvent(self, arg1: View, arg2: android.view.accessibility.AccessibilityEvent, /) -> bool: ...
    def requestTransparentRegion(self, arg1: View, /) -> None: ...
    @typing.overload
    def showContextMenuForChild(self, arg1: View, /) -> bool: ...
    @typing.overload
    def showContextMenuForChild(self, arg1: View, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, /) -> bool: ...
    @typing.overload
    def startActionModeForChild(self, arg1: View, arg2: ActionMode.Callback, /) -> ActionMode | None: ...
    @typing.overload
    def startActionModeForChild(self, arg1: View, arg2: ActionMode.Callback, arg3: int | java.jint | java.lang.Integer, /) -> ActionMode | None: ...

class ViewPropertyAnimator(java.lang.Object):
    def alpha(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def alphaBy(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def cancel(self) -> None: ...
    def getDuration(self) -> int: ...
    def getInterpolator(self) -> android.animation.TimeInterpolator | None: ...
    def getStartDelay(self) -> int: ...
    def rotation(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def rotationBy(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def rotationX(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def rotationXBy(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def rotationY(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def rotationYBy(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def scaleX(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def scaleXBy(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def scaleY(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def scaleYBy(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def setDuration(self, duration: int | java.jlong | java.lang.Long, /) -> ViewPropertyAnimator: ...
    def setInterpolator(self, interpolator: android.animation.TimeInterpolator, /) -> ViewPropertyAnimator: ...
    def setListener(self, listener: android.animation.Animator.AnimatorListener, /) -> ViewPropertyAnimator: ...
    def setStartDelay(self, startDelay: int | java.jlong | java.lang.Long, /) -> ViewPropertyAnimator: ...
    def setUpdateListener(self, listener: android.animation.ValueAnimator.AnimatorUpdateListener, /) -> ViewPropertyAnimator: ...
    def start(self) -> None: ...
    def translationX(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def translationXBy(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def translationY(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def translationYBy(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def translationZ(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def translationZBy(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def withEndAction(self, runnable: java.lang.Runnable, /) -> ViewPropertyAnimator: ...
    def withLayer(self) -> ViewPropertyAnimator: ...
    def withStartAction(self, runnable: java.lang.Runnable, /) -> ViewPropertyAnimator: ...
    def x(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def xBy(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def y(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def yBy(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def z(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...
    def zBy(self, value: float | java.jfloat | java.lang.Float, /) -> ViewPropertyAnimator: ...

class ViewStructure(java.lang.Object):
    EXTRA_VIRTUAL_STRUCTURE_TYPE: typing.ClassVar[str] = ...
    EXTRA_VIRTUAL_STRUCTURE_VERSION_NUMBER: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def addChildCount(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def asyncCommit(self) -> None: ...
    def asyncNewChild(self, arg1: int | java.jint | java.lang.Integer, /) -> ViewStructure: ...
    def clearCredentialManagerRequest(self) -> None: ...
    def getAutofillId(self) -> android.view.autofill.AutofillId | None: ...
    def getChildCount(self) -> int: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getHint(self) -> java.lang.CharSequence: ...
    def getPendingCredentialCallback(self) -> android.os.OutcomeReceiver[android.credentials.GetCredentialResponse, android.credentials.GetCredentialException] | None: ...
    def getPendingCredentialRequest(self) -> android.credentials.GetCredentialRequest | None: ...
    def getText(self) -> java.lang.CharSequence: ...
    def getTextSelectionEnd(self) -> int: ...
    def getTextSelectionStart(self) -> int: ...
    def hasExtras(self) -> bool: ...
    def newChild(self, arg1: int | java.jint | java.lang.Integer, /) -> ViewStructure: ...
    def newHtmlInfoBuilder(self, arg1: str | java.lang.String, /) -> ViewStructure.HtmlInfo.Builder: ...
    def setAccessibilityFocused(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setActivated(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAlpha(self, arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setAutofillHints(self, arg1: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @typing.overload
    def setAutofillId(self, arg1: android.view.autofill.AutofillId, /) -> None: ...
    @typing.overload
    def setAutofillId(self, arg1: android.view.autofill.AutofillId, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAutofillOptions(self, arg1: java.chaquopy.JavaArray[java.lang.CharSequence], /) -> None: ...
    def setAutofillType(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAutofillValue(self, arg1: android.view.autofill.AutofillValue, /) -> None: ...
    def setCheckable(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setChecked(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setChildCount(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setClassName(self, arg1: str | java.lang.String, /) -> None: ...
    def setClickable(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setContentDescription(self, arg1: java.lang.CharSequence, /) -> None: ...
    def setContextClickable(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDataIsSensitive(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDimens(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    def setElevation(self, arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFocusable(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFocused(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setHint(self, arg1: java.lang.CharSequence, /) -> None: ...
    def setHintIdEntry(self, entryName: str | java.lang.String, /) -> None: ...
    def setHtmlInfo(self, arg1: ViewStructure.HtmlInfo, /) -> None: ...
    def setId(self, arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, arg3: str | java.lang.String, arg4: str | java.lang.String, /) -> None: ...
    def setImportantForAutofill(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setInputType(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLocaleList(self, arg1: android.os.LocaleList, /) -> None: ...
    def setLongClickable(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMaxTextEms(self, maxEms: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaxTextLength(self, maxLength: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinTextEms(self, minEms: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOpaque(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setPendingCredentialRequest(self, request: android.credentials.GetCredentialRequest, callback: android.os.OutcomeReceiver[android.credentials.GetCredentialResponse, android.credentials.GetCredentialException], /) -> None: ...
    def setReceiveContentMimeTypes(self, mimeTypes: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setSelected(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setText(self, arg1: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setText(self, arg1: java.lang.CharSequence, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTextIdEntry(self, entryName: str | java.lang.String, /) -> None: ...
    def setTextLines(self, arg1: java.chaquopy.JavaArrayJInt, arg2: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def setTextStyle(self, arg1: float | java.jfloat | java.lang.Float, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTransformation(self, arg1: android.graphics.Matrix, /) -> None: ...
    def setVisibility(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setWebDomain(self, arg1: str | java.lang.String, /) -> None: ...

    class HtmlInfo(java.lang.Object):
        def __init__(self) -> None: ...
        def getAttributes(self) -> java.util.List[android.util.Pair[java.lang.String, java.lang.String]]: ...
        def getTag(self) -> str: ...

        class Builder(java.lang.Object):
            def __init__(self) -> None: ...
            def addAttribute(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> ViewStructure.HtmlInfo.Builder: ...
            def build(self) -> ViewStructure.HtmlInfo: ...

class ViewStub(View):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, layoutResource: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def draw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def getInflatedId(self) -> int: ...
    def getLayoutInflater(self) -> LayoutInflater: ...
    def getLayoutResource(self) -> int: ...
    def inflate(self) -> View: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def setInflatedId(self, inflatedId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLayoutInflater(self, inflater: LayoutInflater, /) -> None: ...
    def setLayoutResource(self, layoutResource: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOnInflateListener(self, inflateListener: ViewStub.OnInflateListener, /) -> None: ...
    def setVisibility(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnInflateListener(java.lang.Object):
        def onInflate(self, arg1: ViewStub, arg2: View, /) -> None: ...

class ViewTreeObserver(java.lang.Object):
    def addOnDrawListener(self, listener: ViewTreeObserver.OnDrawListener, /) -> None: ...
    def addOnGlobalFocusChangeListener(self, listener: ViewTreeObserver.OnGlobalFocusChangeListener, /) -> None: ...
    def addOnGlobalLayoutListener(self, listener: ViewTreeObserver.OnGlobalLayoutListener, /) -> None: ...
    def addOnPreDrawListener(self, listener: ViewTreeObserver.OnPreDrawListener, /) -> None: ...
    def addOnScrollChangedListener(self, listener: ViewTreeObserver.OnScrollChangedListener, /) -> None: ...
    def addOnSystemGestureExclusionRectsChangedListener(self, listener: java.util.function.Consumer[java.util.List[android.graphics.Rect]], /) -> None: ...
    def addOnTouchModeChangeListener(self, listener: ViewTreeObserver.OnTouchModeChangeListener, /) -> None: ...
    def addOnWindowAttachListener(self, listener: ViewTreeObserver.OnWindowAttachListener, /) -> None: ...
    def addOnWindowFocusChangeListener(self, listener: ViewTreeObserver.OnWindowFocusChangeListener, /) -> None: ...
    def addOnWindowVisibilityChangeListener(self, listener: ViewTreeObserver.OnWindowVisibilityChangeListener, /) -> None: ...
    def dispatchOnDraw(self) -> None: ...
    def dispatchOnGlobalLayout(self) -> None: ...
    def dispatchOnPreDraw(self) -> bool: ...
    def isAlive(self) -> bool: ...
    def registerFrameCommitCallback(self, callback: java.lang.Runnable, /) -> None: ...
    def removeGlobalOnLayoutListener(self, victim: ViewTreeObserver.OnGlobalLayoutListener, /) -> None: ...
    def removeOnDrawListener(self, victim: ViewTreeObserver.OnDrawListener, /) -> None: ...
    def removeOnGlobalFocusChangeListener(self, victim: ViewTreeObserver.OnGlobalFocusChangeListener, /) -> None: ...
    def removeOnGlobalLayoutListener(self, victim: ViewTreeObserver.OnGlobalLayoutListener, /) -> None: ...
    def removeOnPreDrawListener(self, victim: ViewTreeObserver.OnPreDrawListener, /) -> None: ...
    def removeOnScrollChangedListener(self, victim: ViewTreeObserver.OnScrollChangedListener, /) -> None: ...
    def removeOnSystemGestureExclusionRectsChangedListener(self, listener: java.util.function.Consumer[java.util.List[android.graphics.Rect]], /) -> None: ...
    def removeOnTouchModeChangeListener(self, victim: ViewTreeObserver.OnTouchModeChangeListener, /) -> None: ...
    def removeOnWindowAttachListener(self, victim: ViewTreeObserver.OnWindowAttachListener, /) -> None: ...
    def removeOnWindowFocusChangeListener(self, victim: ViewTreeObserver.OnWindowFocusChangeListener, /) -> None: ...
    def removeOnWindowVisibilityChangeListener(self, victim: ViewTreeObserver.OnWindowVisibilityChangeListener, /) -> None: ...
    def unregisterFrameCommitCallback(self, callback: java.lang.Runnable, /) -> bool: ...

    class OnWindowVisibilityChangeListener(java.lang.Object):
        def onWindowVisibilityChanged(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnWindowFocusChangeListener(java.lang.Object):
        def onWindowFocusChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class OnWindowAttachListener(java.lang.Object):
        def onWindowAttached(self) -> None: ...
        def onWindowDetached(self) -> None: ...

    class OnTouchModeChangeListener(java.lang.Object):
        def onTouchModeChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class OnScrollChangedListener(java.lang.Object):
        def onScrollChanged(self) -> None: ...

    class OnPreDrawListener(java.lang.Object):
        def onPreDraw(self) -> bool: ...

    class OnGlobalLayoutListener(java.lang.Object):
        def onGlobalLayout(self) -> None: ...

    class OnGlobalFocusChangeListener(java.lang.Object):
        def onGlobalFocusChanged(self, arg1: View, arg2: View, /) -> None: ...

    class OnDrawListener(java.lang.Object):
        def onDraw(self) -> None: ...

class Window(java.lang.Object):
    DECOR_CAPTION_SHADE_AUTO: typing.ClassVar[int] = ...
    DECOR_CAPTION_SHADE_DARK: typing.ClassVar[int] = ...
    DECOR_CAPTION_SHADE_LIGHT: typing.ClassVar[int] = ...
    DEFAULT_FEATURES: typing.ClassVar[int] = ...
    FEATURE_ACTION_BAR: typing.ClassVar[int] = ...
    FEATURE_ACTION_BAR_OVERLAY: typing.ClassVar[int] = ...
    FEATURE_ACTION_MODE_OVERLAY: typing.ClassVar[int] = ...
    FEATURE_ACTIVITY_TRANSITIONS: typing.ClassVar[int] = ...
    FEATURE_CONTENT_TRANSITIONS: typing.ClassVar[int] = ...
    FEATURE_CONTEXT_MENU: typing.ClassVar[int] = ...
    FEATURE_CUSTOM_TITLE: typing.ClassVar[int] = ...
    FEATURE_INDETERMINATE_PROGRESS: typing.ClassVar[int] = ...
    FEATURE_LEFT_ICON: typing.ClassVar[int] = ...
    FEATURE_NO_TITLE: typing.ClassVar[int] = ...
    FEATURE_OPTIONS_PANEL: typing.ClassVar[int] = ...
    FEATURE_PROGRESS: typing.ClassVar[int] = ...
    FEATURE_RIGHT_ICON: typing.ClassVar[int] = ...
    FEATURE_SWIPE_TO_DISMISS: typing.ClassVar[int] = ...
    ID_ANDROID_CONTENT: typing.ClassVar[int] = ...
    NAVIGATION_BAR_BACKGROUND_TRANSITION_NAME: typing.ClassVar[str] = ...
    PROGRESS_END: typing.ClassVar[int] = ...
    PROGRESS_INDETERMINATE_OFF: typing.ClassVar[int] = ...
    PROGRESS_INDETERMINATE_ON: typing.ClassVar[int] = ...
    PROGRESS_SECONDARY_END: typing.ClassVar[int] = ...
    PROGRESS_SECONDARY_START: typing.ClassVar[int] = ...
    PROGRESS_START: typing.ClassVar[int] = ...
    PROGRESS_VISIBILITY_OFF: typing.ClassVar[int] = ...
    PROGRESS_VISIBILITY_ON: typing.ClassVar[int] = ...
    STATUS_BAR_BACKGROUND_TRANSITION_NAME: typing.ClassVar[str] = ...
    def __init__(self, context: android.content.Context, /) -> None: ...
    def addContentView(self, arg1: View, arg2: ViewGroup.LayoutParams, /) -> None: ...
    def addFlags(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def addOnFrameMetricsAvailableListener(self, listener: Window.OnFrameMetricsAvailableListener, handler: android.os.Handler, /) -> None: ...
    def clearFlags(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def closeAllPanels(self) -> None: ...
    def closePanel(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def findViewById(self, id: int | java.jint | java.lang.Integer, /) -> View: ...
    def getAllowEnterTransitionOverlap(self) -> bool: ...
    def getAllowReturnTransitionOverlap(self) -> bool: ...
    def getAttributes(self) -> WindowManager.LayoutParams: ...
    def getCallback(self) -> Window.Callback: ...
    def getColorMode(self) -> int: ...
    def getContainer(self) -> Window | None: ...
    def getContentScene(self) -> android.transition.Scene | None: ...
    def getContext(self) -> android.content.Context: ...
    def getCurrentFocus(self) -> View | None: ...
    def getDecorView(self) -> View: ...
    @staticmethod
    def getDefaultFeatures(context: android.content.Context, /) -> int: ...
    def getDesiredHdrHeadroom(self) -> float: ...
    def getEnterTransition(self) -> android.transition.Transition: ...
    def getExitTransition(self) -> android.transition.Transition: ...
    def getFeatures(self) -> int: ...
    def getForcedWindowFlags(self) -> int: ...
    def getFrameRateBoostOnTouchEnabled(self) -> bool: ...
    def getInsetsController(self) -> WindowInsetsController | None: ...
    def getLayoutInflater(self) -> LayoutInflater: ...
    def getLocalFeatures(self) -> int: ...
    def getMediaController(self) -> android.media.session.MediaController: ...
    def getNavigationBarColor(self) -> int: ...
    def getNavigationBarDividerColor(self) -> int: ...
    def getOnBackInvokedDispatcher(self) -> android.window.OnBackInvokedDispatcher: ...
    def getReenterTransition(self) -> android.transition.Transition: ...
    def getReturnTransition(self) -> android.transition.Transition: ...
    def getRootSurfaceControl(self) -> AttachedSurfaceControl | None: ...
    def getSharedElementEnterTransition(self) -> android.transition.Transition: ...
    def getSharedElementExitTransition(self) -> android.transition.Transition: ...
    def getSharedElementReenterTransition(self) -> android.transition.Transition: ...
    def getSharedElementReturnTransition(self) -> android.transition.Transition: ...
    def getSharedElementsUseOverlay(self) -> bool: ...
    def getStatusBarColor(self) -> int: ...
    def getSystemGestureExclusionRects(self) -> java.util.List[android.graphics.Rect]: ...
    def getTransitionBackgroundFadeDuration(self) -> int: ...
    def getTransitionManager(self) -> android.transition.TransitionManager | None: ...
    def getVolumeControlStream(self) -> int: ...
    def getWindowManager(self) -> WindowManager: ...
    def getWindowStyle(self) -> android.content.res.TypedArray: ...
    def hasChildren(self) -> bool: ...
    def hasFeature(self, feature: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hasSoftInputMode(self) -> bool: ...
    def injectInputEvent(self, event: InputEvent, /) -> None: ...
    def invalidatePanelMenu(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def isActive(self) -> bool: ...
    def isFloating(self) -> bool: ...
    def isFrameRatePowerSavingsBalanced(self) -> bool: ...
    def isNavigationBarContrastEnforced(self) -> bool: ...
    def isShortcutKey(self, arg1: int | java.jint | java.lang.Integer, arg2: KeyEvent, /) -> bool: ...
    def isStatusBarContrastEnforced(self) -> bool: ...
    def isWideColorGamut(self) -> bool: ...
    def makeActive(self) -> None: ...
    def onActive(self) -> None: ...
    def onConfigurationChanged(self, arg1: android.content.res.Configuration, /) -> None: ...
    def openPanel(self, arg1: int | java.jint | java.lang.Integer, arg2: KeyEvent, /) -> None: ...
    def peekDecorView(self) -> View | None: ...
    def performContextMenuIdentifierAction(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> bool: ...
    def performPanelIdentifierAction(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...
    def performPanelShortcut(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: KeyEvent, arg4: int | java.jint | java.lang.Integer, /) -> bool: ...
    def registerScrollCaptureCallback(self, callback: ScrollCaptureCallback, /) -> None: ...
    def removeOnFrameMetricsAvailableListener(self, listener: Window.OnFrameMetricsAvailableListener, /) -> None: ...
    def requestFeature(self, featureId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def requireViewById(self, id: int | java.jint | java.lang.Integer, /) -> View: ...
    def restoreHierarchyState(self, arg1: android.os.Bundle, /) -> None: ...
    def saveHierarchyState(self) -> android.os.Bundle: ...
    def setAllowEnterTransitionOverlap(self, allow: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAllowReturnTransitionOverlap(self, allow: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAttributes(self, a: WindowManager.LayoutParams, /) -> None: ...
    def setBackgroundBlurRadius(self, blurRadius: int | java.jint | java.lang.Integer, /) -> None: ...
    def setBackgroundDrawable(self, arg1: android.graphics.drawable.Drawable, /) -> None: ...
    def setBackgroundDrawableResource(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCallback(self, callback: Window.Callback, /) -> None: ...
    def setChildDrawable(self, arg1: int | java.jint | java.lang.Integer, arg2: android.graphics.drawable.Drawable, /) -> None: ...
    def setChildInt(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def setClipToOutline(self, clipToOutline: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setColorMode(self, colorMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setContainer(self, container: Window, /) -> None: ...
    @typing.overload
    def setContentView(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setContentView(self, arg1: View, /) -> None: ...
    @typing.overload
    def setContentView(self, arg1: View, arg2: ViewGroup.LayoutParams, /) -> None: ...
    def setDecorCaptionShade(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDecorFitsSystemWindows(self, decorFitsSystemWindows: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDefaultWindowFormat(self, format: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDesiredHdrHeadroom(self, desiredHeadroom: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setDimAmount(self, amount: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setElevation(self, elevation: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setEnterTransition(self, transition: android.transition.Transition, /) -> None: ...
    def setExitTransition(self, transition: android.transition.Transition, /) -> None: ...
    def setFeatureDrawable(self, arg1: int | java.jint | java.lang.Integer, arg2: android.graphics.drawable.Drawable, /) -> None: ...
    def setFeatureDrawableAlpha(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFeatureDrawableResource(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFeatureDrawableUri(self, arg1: int | java.jint | java.lang.Integer, arg2: android.net.Uri, /) -> None: ...
    def setFeatureInt(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFlags(self, flags: int | java.jint | java.lang.Integer, mask: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFormat(self, format: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFrameRateBoostOnTouchEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFrameRatePowerSavingsBalanced(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setGravity(self, gravity: int | java.jint | java.lang.Integer, /) -> None: ...
    def setHideOverlayWindows(self, hide: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setIcon(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLayout(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLocalFocus(self, hasFocus: bool | java.jboolean | java.lang.Boolean, inTouchMode: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setLogo(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMediaController(self, controller: android.media.session.MediaController, /) -> None: ...
    def setNavigationBarColor(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNavigationBarContrastEnforced(self, enforceContrast: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setNavigationBarDividerColor(self, dividerColor: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPreferMinimalPostProcessing(self, isPreferred: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setReenterTransition(self, transition: android.transition.Transition, /) -> None: ...
    def setResizingCaptionDrawable(self, arg1: android.graphics.drawable.Drawable, /) -> None: ...
    def setRestrictedCaptionAreaListener(self, listener: Window.OnRestrictedCaptionAreaChangedListener, /) -> None: ...
    def setReturnTransition(self, transition: android.transition.Transition, /) -> None: ...
    def setSharedElementEnterTransition(self, transition: android.transition.Transition, /) -> None: ...
    def setSharedElementExitTransition(self, transition: android.transition.Transition, /) -> None: ...
    def setSharedElementReenterTransition(self, transition: android.transition.Transition, /) -> None: ...
    def setSharedElementReturnTransition(self, transition: android.transition.Transition, /) -> None: ...
    def setSharedElementsUseOverlay(self, sharedElementsUseOverlay: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSoftInputMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setStatusBarColor(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setStatusBarContrastEnforced(self, ensureContrast: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSustainedPerformanceMode(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSystemGestureExclusionRects(self, rects: java.util.List[android.graphics.Rect], /) -> None: ...
    def setTitle(self, arg1: java.lang.CharSequence, /) -> None: ...
    def setTitleColor(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTransitionBackgroundFadeDuration(self, fadeDurationMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def setTransitionManager(self, tm: android.transition.TransitionManager, /) -> None: ...
    def setType(self, type: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setUiOptions(self, uiOptions: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setUiOptions(self, uiOptions: int | java.jint | java.lang.Integer, mask: int | java.jint | java.lang.Integer, /) -> None: ...
    def setVolumeControlStream(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setWindowAnimations(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setWindowManager(self, wm: WindowManager, appToken: android.os.IBinder, appName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setWindowManager(self, wm: WindowManager, appToken: android.os.IBinder, appName: str | java.lang.String, hardwareAccelerated: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def superDispatchGenericMotionEvent(self, arg1: MotionEvent, /) -> bool: ...
    def superDispatchKeyEvent(self, arg1: KeyEvent, /) -> bool: ...
    def superDispatchKeyShortcutEvent(self, arg1: KeyEvent, /) -> bool: ...
    def superDispatchTouchEvent(self, arg1: MotionEvent, /) -> bool: ...
    def superDispatchTrackballEvent(self, arg1: MotionEvent, /) -> bool: ...
    def takeInputQueue(self, arg1: InputQueue.Callback, /) -> None: ...
    def takeKeyEvents(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def takeSurface(self, arg1: SurfaceHolder.Callback2, /) -> None: ...
    def togglePanel(self, arg1: int | java.jint | java.lang.Integer, arg2: KeyEvent, /) -> None: ...
    def unregisterScrollCaptureCallback(self, callback: ScrollCaptureCallback, /) -> None: ...

    class OnRestrictedCaptionAreaChangedListener(java.lang.Object):
        def onRestrictedCaptionAreaChanged(self, arg1: android.graphics.Rect, /) -> None: ...

    class OnFrameMetricsAvailableListener(java.lang.Object):
        def onFrameMetricsAvailable(self, arg1: Window, arg2: FrameMetrics, arg3: int | java.jint | java.lang.Integer, /) -> None: ...

    class Callback(java.lang.Object):
        def dispatchGenericMotionEvent(self, arg1: MotionEvent, /) -> bool: ...
        def dispatchKeyEvent(self, arg1: KeyEvent, /) -> bool: ...
        def dispatchKeyShortcutEvent(self, arg1: KeyEvent, /) -> bool: ...
        def dispatchPopulateAccessibilityEvent(self, arg1: android.view.accessibility.AccessibilityEvent, /) -> bool: ...
        def dispatchTouchEvent(self, arg1: MotionEvent, /) -> bool: ...
        def dispatchTrackballEvent(self, arg1: MotionEvent, /) -> bool: ...
        def onActionModeFinished(self, arg1: ActionMode, /) -> None: ...
        def onActionModeStarted(self, arg1: ActionMode, /) -> None: ...
        def onAttachedToWindow(self) -> None: ...
        def onContentChanged(self) -> None: ...
        def onCreatePanelMenu(self, arg1: int | java.jint | java.lang.Integer, arg2: Menu, /) -> bool: ...
        def onCreatePanelView(self, arg1: int | java.jint | java.lang.Integer, /) -> View: ...
        def onDetachedFromWindow(self) -> None: ...
        def onMenuItemSelected(self, arg1: int | java.jint | java.lang.Integer, arg2: MenuItem, /) -> bool: ...
        def onMenuOpened(self, arg1: int | java.jint | java.lang.Integer, arg2: Menu, /) -> bool: ...
        def onPanelClosed(self, arg1: int | java.jint | java.lang.Integer, arg2: Menu, /) -> None: ...
        def onPointerCaptureChanged(self, hasCapture: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onPreparePanel(self, arg1: int | java.jint | java.lang.Integer, arg2: View, arg3: Menu, /) -> bool: ...
        def onProvideKeyboardShortcuts(self, data: java.util.List[KeyboardShortcutGroup], menu: Menu, deviceId: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def onSearchRequested(self) -> bool: ...
        @typing.overload
        def onSearchRequested(self, arg1: SearchEvent, /) -> bool: ...
        def onWindowAttributesChanged(self, arg1: WindowManager.LayoutParams, /) -> None: ...
        def onWindowFocusChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        @typing.overload
        def onWindowStartingActionMode(self, arg1: ActionMode.Callback, /) -> ActionMode: ...
        @typing.overload
        def onWindowStartingActionMode(self, arg1: ActionMode.Callback, arg2: int | java.jint | java.lang.Integer, /) -> ActionMode: ...

class WindowAnimationFrameStats(android.os.Parcelable, FrameStats):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WindowAnimationFrameStats]] = ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class WindowContentFrameStats(android.os.Parcelable, FrameStats):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WindowContentFrameStats]] = ...
    def describeContents(self) -> int: ...
    def getFramePostedTimeNano(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    def getFrameReadyTimeNano(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class WindowId(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WindowId]] = ...
    def describeContents(self) -> int: ...
    def equals(self, otherObj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def isFocused(self) -> bool: ...
    def registerFocusObserver(self, observer: WindowId.FocusObserver, /) -> None: ...
    def toString(self) -> str: ...
    def unregisterFocusObserver(self, observer: WindowId.FocusObserver, /) -> None: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class FocusObserver(java.lang.Object):
        def __init__(self) -> None: ...
        def onFocusGained(self, arg1: WindowId, /) -> None: ...
        def onFocusLost(self, arg1: WindowId, /) -> None: ...

class WindowInsets(java.lang.Object):
    CONSUMED: typing.ClassVar[WindowInsets] = ...
    def __init__(self, src: WindowInsets, /) -> None: ...
    def consumeDisplayCutout(self) -> WindowInsets: ...
    def consumeStableInsets(self) -> WindowInsets: ...
    def consumeSystemWindowInsets(self) -> WindowInsets: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBoundingRects(self, typeMask: int | java.jint | java.lang.Integer, /) -> java.util.List[android.graphics.Rect]: ...
    def getBoundingRectsIgnoringVisibility(self, typeMask: int | java.jint | java.lang.Integer, /) -> java.util.List[android.graphics.Rect]: ...
    def getDisplayCutout(self) -> DisplayCutout | None: ...
    def getDisplayShape(self) -> DisplayShape | None: ...
    def getFrame(self) -> android.util.Size: ...
    def getInsets(self, typeMask: int | java.jint | java.lang.Integer, /) -> android.graphics.Insets: ...
    def getInsetsIgnoringVisibility(self, typeMask: int | java.jint | java.lang.Integer, /) -> android.graphics.Insets: ...
    def getMandatorySystemGestureInsets(self) -> android.graphics.Insets: ...
    def getPrivacyIndicatorBounds(self) -> android.graphics.Rect | None: ...
    def getRoundedCorner(self, position: int | java.jint | java.lang.Integer, /) -> RoundedCorner | None: ...
    def getStableInsetBottom(self) -> int: ...
    def getStableInsetLeft(self) -> int: ...
    def getStableInsetRight(self) -> int: ...
    def getStableInsetTop(self) -> int: ...
    def getStableInsets(self) -> android.graphics.Insets: ...
    def getSystemGestureInsets(self) -> android.graphics.Insets: ...
    def getSystemWindowInsetBottom(self) -> int: ...
    def getSystemWindowInsetLeft(self) -> int: ...
    def getSystemWindowInsetRight(self) -> int: ...
    def getSystemWindowInsetTop(self) -> int: ...
    def getSystemWindowInsets(self) -> android.graphics.Insets: ...
    def getTappableElementInsets(self) -> android.graphics.Insets: ...
    def hasInsets(self) -> bool: ...
    def hasStableInsets(self) -> bool: ...
    def hasSystemWindowInsets(self) -> bool: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def inset(self, insets: android.graphics.Insets, /) -> WindowInsets: ...
    @typing.overload
    def inset(self, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> WindowInsets: ...
    def isConsumed(self) -> bool: ...
    def isRound(self) -> bool: ...
    def isVisible(self, typeMask: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def replaceSystemWindowInsets(self, systemWindowInsets: android.graphics.Rect, /) -> WindowInsets: ...
    @typing.overload
    def replaceSystemWindowInsets(self, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> WindowInsets: ...
    def toString(self) -> str: ...

    class Type(java.lang.Object):
        @staticmethod
        def captionBar() -> int: ...
        @staticmethod
        def displayCutout() -> int: ...
        @staticmethod
        def ime() -> int: ...
        @staticmethod
        def mandatorySystemGestures() -> int: ...
        @staticmethod
        def navigationBars() -> int: ...
        @staticmethod
        def statusBars() -> int: ...
        @staticmethod
        def systemBars() -> int: ...
        @staticmethod
        def systemGestures() -> int: ...
        @staticmethod
        def systemOverlays() -> int: ...
        @staticmethod
        def tappableElement() -> int: ...

    class Side(java.lang.Object):
        BOTTOM: typing.ClassVar[int] = ...
        LEFT: typing.ClassVar[int] = ...
        RIGHT: typing.ClassVar[int] = ...
        TOP: typing.ClassVar[int] = ...
        @staticmethod
        def all() -> int: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, insets: WindowInsets, /) -> None: ...
        def build(self) -> WindowInsets: ...
        def setBoundingRects(self, typeMask: int | java.jint | java.lang.Integer, rects: java.util.List[android.graphics.Rect], /) -> WindowInsets.Builder: ...
        def setBoundingRectsIgnoringVisibility(self, typeMask: int | java.jint | java.lang.Integer, rects: java.util.List[android.graphics.Rect], /) -> WindowInsets.Builder: ...
        def setDisplayCutout(self, displayCutout: DisplayCutout, /) -> WindowInsets.Builder: ...
        def setDisplayShape(self, displayShape: DisplayShape, /) -> WindowInsets.Builder: ...
        def setFrame(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> WindowInsets.Builder: ...
        def setInsets(self, typeMask: int | java.jint | java.lang.Integer, insets: android.graphics.Insets, /) -> WindowInsets.Builder: ...
        def setInsetsIgnoringVisibility(self, typeMask: int | java.jint | java.lang.Integer, insets: android.graphics.Insets, /) -> WindowInsets.Builder: ...
        def setMandatorySystemGestureInsets(self, insets: android.graphics.Insets, /) -> WindowInsets.Builder: ...
        def setPrivacyIndicatorBounds(self, bounds: android.graphics.Rect, /) -> WindowInsets.Builder: ...
        def setRoundedCorner(self, position: int | java.jint | java.lang.Integer, roundedCorner: RoundedCorner, /) -> WindowInsets.Builder: ...
        def setStableInsets(self, stableInsets: android.graphics.Insets, /) -> WindowInsets.Builder: ...
        def setSystemGestureInsets(self, insets: android.graphics.Insets, /) -> WindowInsets.Builder: ...
        def setSystemWindowInsets(self, systemWindowInsets: android.graphics.Insets, /) -> WindowInsets.Builder: ...
        def setTappableElementInsets(self, insets: android.graphics.Insets, /) -> WindowInsets.Builder: ...
        def setVisible(self, typeMask: int | java.jint | java.lang.Integer, visible: bool | java.jboolean | java.lang.Boolean, /) -> WindowInsets.Builder: ...

class WindowInsetsAnimation(java.lang.Object):
    def __init__(self, typeMask: int | java.jint | java.lang.Integer, interpolator: android.view.animation.Interpolator, durationMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def getAlpha(self) -> float: ...
    def getDurationMillis(self) -> int: ...
    def getFraction(self) -> float: ...
    def getInterpolatedFraction(self) -> float: ...
    def getInterpolator(self) -> android.view.animation.Interpolator | None: ...
    def getTypeMask(self) -> int: ...
    def setAlpha(self, alpha: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setFraction(self, fraction: float | java.jfloat | java.lang.Float, /) -> None: ...

    class Callback(java.lang.Object):
        DISPATCH_MODE_CONTINUE_ON_SUBTREE: typing.ClassVar[int] = ...
        DISPATCH_MODE_STOP: typing.ClassVar[int] = ...
        def __init__(self, dispatchMode: int | java.jint | java.lang.Integer, /) -> None: ...
        def getDispatchMode(self) -> int: ...
        def onEnd(self, animation: WindowInsetsAnimation, /) -> None: ...
        def onPrepare(self, animation: WindowInsetsAnimation, /) -> None: ...
        def onProgress(self, arg1: WindowInsets, arg2: java.util.List[WindowInsetsAnimation], /) -> WindowInsets: ...
        def onStart(self, animation: WindowInsetsAnimation, bounds: WindowInsetsAnimation.Bounds, /) -> WindowInsetsAnimation.Bounds: ...

    class Bounds(java.lang.Object):
        def __init__(self, lowerBound: android.graphics.Insets, upperBound: android.graphics.Insets, /) -> None: ...
        def getLowerBound(self) -> android.graphics.Insets: ...
        def getUpperBound(self) -> android.graphics.Insets: ...
        def inset(self, insets: android.graphics.Insets, /) -> WindowInsetsAnimation.Bounds: ...
        def toString(self) -> str: ...

class WindowInsetsAnimationControlListener(java.lang.Object):
    def onCancelled(self, arg1: WindowInsetsAnimationController, /) -> None: ...
    def onFinished(self, arg1: WindowInsetsAnimationController, /) -> None: ...
    def onReady(self, arg1: WindowInsetsAnimationController, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

class WindowInsetsAnimationController(java.lang.Object):
    def finish(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def getCurrentAlpha(self) -> float: ...
    def getCurrentFraction(self) -> float: ...
    def getCurrentInsets(self) -> android.graphics.Insets: ...
    def getHiddenStateInsets(self) -> android.graphics.Insets: ...
    def getShownStateInsets(self) -> android.graphics.Insets: ...
    def getTypes(self) -> int: ...
    def isCancelled(self) -> bool: ...
    def isFinished(self) -> bool: ...
    def isReady(self) -> bool: ...
    def setInsetsAndAlpha(self, arg1: android.graphics.Insets, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, /) -> None: ...

class WindowInsetsController(java.lang.Object):
    APPEARANCE_LIGHT_CAPTION_BARS: typing.ClassVar[int] = ...
    APPEARANCE_LIGHT_NAVIGATION_BARS: typing.ClassVar[int] = ...
    APPEARANCE_LIGHT_STATUS_BARS: typing.ClassVar[int] = ...
    APPEARANCE_TRANSPARENT_CAPTION_BAR_BACKGROUND: typing.ClassVar[int] = ...
    BEHAVIOR_DEFAULT: typing.ClassVar[int] = ...
    BEHAVIOR_SHOW_BARS_BY_SWIPE: typing.ClassVar[int] = ...
    BEHAVIOR_SHOW_BARS_BY_TOUCH: typing.ClassVar[int] = ...
    BEHAVIOR_SHOW_TRANSIENT_BARS_BY_SWIPE: typing.ClassVar[int] = ...
    def addOnControllableInsetsChangedListener(self, arg1: WindowInsetsController.OnControllableInsetsChangedListener, /) -> None: ...
    def controlWindowInsetsAnimation(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jlong | java.lang.Long, arg3: android.view.animation.Interpolator, arg4: android.os.CancellationSignal, arg5: WindowInsetsAnimationControlListener, /) -> None: ...
    def getSystemBarsAppearance(self) -> int: ...
    def getSystemBarsBehavior(self) -> int: ...
    def hide(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def removeOnControllableInsetsChangedListener(self, arg1: WindowInsetsController.OnControllableInsetsChangedListener, /) -> None: ...
    def setSystemBarsAppearance(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSystemBarsBehavior(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def show(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnControllableInsetsChangedListener(java.lang.Object):
        def onControllableInsetsChanged(self, arg1: WindowInsetsController, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

class WindowManager(ViewManager):
    COMPAT_SMALL_COVER_SCREEN_OPT_IN: typing.ClassVar[int] = ...
    PROPERTY_ACTIVITY_EMBEDDING_ALLOW_SYSTEM_OVERRIDE: typing.ClassVar[str] = ...
    PROPERTY_ACTIVITY_EMBEDDING_SPLITS_ENABLED: typing.ClassVar[str] = ...
    PROPERTY_CAMERA_COMPAT_ALLOW_FORCE_ROTATION: typing.ClassVar[str] = ...
    PROPERTY_CAMERA_COMPAT_ALLOW_REFRESH: typing.ClassVar[str] = ...
    PROPERTY_CAMERA_COMPAT_ENABLE_REFRESH_VIA_PAUSE: typing.ClassVar[str] = ...
    PROPERTY_COMPAT_ALLOW_DISPLAY_ORIENTATION_OVERRIDE: typing.ClassVar[str] = ...
    PROPERTY_COMPAT_ALLOW_IGNORING_ORIENTATION_REQUEST_WHEN_LOOP_DETECTED: typing.ClassVar[str] = ...
    PROPERTY_COMPAT_ALLOW_MIN_ASPECT_RATIO_OVERRIDE: typing.ClassVar[str] = ...
    PROPERTY_COMPAT_ALLOW_ORIENTATION_OVERRIDE: typing.ClassVar[str] = ...
    PROPERTY_COMPAT_ALLOW_RESIZEABLE_ACTIVITY_OVERRIDES: typing.ClassVar[str] = ...
    PROPERTY_COMPAT_ALLOW_SANDBOXING_VIEW_BOUNDS_APIS: typing.ClassVar[str] = ...
    PROPERTY_COMPAT_ALLOW_SMALL_COVER_SCREEN: typing.ClassVar[str] = ...
    PROPERTY_COMPAT_ALLOW_USER_ASPECT_RATIO_FULLSCREEN_OVERRIDE: typing.ClassVar[str] = ...
    PROPERTY_COMPAT_ALLOW_USER_ASPECT_RATIO_OVERRIDE: typing.ClassVar[str] = ...
    PROPERTY_COMPAT_ENABLE_FAKE_FOCUS: typing.ClassVar[str] = ...
    PROPERTY_COMPAT_IGNORE_REQUESTED_ORIENTATION: typing.ClassVar[str] = ...
    PROPERTY_SUPPORTS_MULTI_INSTANCE_SYSTEM_UI: typing.ClassVar[str] = ...
    SCREEN_RECORDING_STATE_NOT_VISIBLE: typing.ClassVar[int] = ...
    SCREEN_RECORDING_STATE_VISIBLE: typing.ClassVar[int] = ...
    @typing.overload
    def addCrossWindowBlurEnabledListener(self, listener: java.util.function.Consumer[java.lang.Boolean], /) -> None: ...
    @typing.overload
    def addCrossWindowBlurEnabledListener(self, executor: java.util.concurrent.Executor, listener: java.util.function.Consumer[java.lang.Boolean], /) -> None: ...
    def addProposedRotationListener(self, executor: java.util.concurrent.Executor, listener: java.util.function.IntConsumer, /) -> None: ...
    def addScreenRecordingCallback(self, executor: java.util.concurrent.Executor, callback: java.util.function.Consumer[java.lang.Integer], /) -> int: ...
    def getCurrentWindowMetrics(self) -> WindowMetrics: ...
    def getDefaultDisplay(self) -> Display: ...
    def getMaximumWindowMetrics(self) -> WindowMetrics: ...
    def isCrossWindowBlurEnabled(self) -> bool: ...
    def registerBatchedSurfaceControlInputReceiver(self, hostInputTransferToken: android.window.InputTransferToken, surfaceControl: SurfaceControl, choreographer: Choreographer, receiver: SurfaceControlInputReceiver, /) -> android.window.InputTransferToken: ...
    def registerTrustedPresentationListener(self, window: android.os.IBinder, thresholds: android.window.TrustedPresentationThresholds, executor: java.util.concurrent.Executor, listener: java.util.function.Consumer[java.lang.Boolean], /) -> None: ...
    def registerUnbatchedSurfaceControlInputReceiver(self, hostInputTransferToken: android.window.InputTransferToken, surfaceControl: SurfaceControl, looper: android.os.Looper, receiver: SurfaceControlInputReceiver, /) -> android.window.InputTransferToken: ...
    def removeCrossWindowBlurEnabledListener(self, listener: java.util.function.Consumer[java.lang.Boolean], /) -> None: ...
    def removeProposedRotationListener(self, listener: java.util.function.IntConsumer, /) -> None: ...
    def removeScreenRecordingCallback(self, callback: java.util.function.Consumer[java.lang.Integer], /) -> None: ...
    def removeViewImmediate(self, arg1: View, /) -> None: ...
    def transferTouchGesture(self, transferFromToken: android.window.InputTransferToken, transferToToken: android.window.InputTransferToken, /) -> bool: ...
    def unregisterSurfaceControlInputReceiver(self, surfaceControl: SurfaceControl, /) -> None: ...
    def unregisterTrustedPresentationListener(self, listener: java.util.function.Consumer[java.lang.Boolean], /) -> None: ...

    class LayoutParams(android.os.Parcelable, ViewGroup.LayoutParams):
        ALPHA_CHANGED: typing.ClassVar[int] = ...
        ANIMATION_CHANGED: typing.ClassVar[int] = ...
        BRIGHTNESS_OVERRIDE_FULL: typing.ClassVar[float] = ...
        BRIGHTNESS_OVERRIDE_NONE: typing.ClassVar[float] = ...
        BRIGHTNESS_OVERRIDE_OFF: typing.ClassVar[float] = ...
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WindowManager.LayoutParams]] = ...
        DIM_AMOUNT_CHANGED: typing.ClassVar[int] = ...
        DISPLAY_FLAG_DISABLE_HDR_CONVERSION: typing.ClassVar[int] = ...
        FIRST_APPLICATION_WINDOW: typing.ClassVar[int] = ...
        FIRST_SUB_WINDOW: typing.ClassVar[int] = ...
        FIRST_SYSTEM_WINDOW: typing.ClassVar[int] = ...
        FLAGS_CHANGED: typing.ClassVar[int] = ...
        FLAG_ALLOW_LOCK_WHILE_SCREEN_ON: typing.ClassVar[int] = ...
        FLAG_ALT_FOCUSABLE_IM: typing.ClassVar[int] = ...
        FLAG_BLUR_BEHIND: typing.ClassVar[int] = ...
        FLAG_DIM_BEHIND: typing.ClassVar[int] = ...
        FLAG_DISMISS_KEYGUARD: typing.ClassVar[int] = ...
        FLAG_DITHER: typing.ClassVar[int] = ...
        FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS: typing.ClassVar[int] = ...
        FLAG_FORCE_NOT_FULLSCREEN: typing.ClassVar[int] = ...
        FLAG_FULLSCREEN: typing.ClassVar[int] = ...
        FLAG_HARDWARE_ACCELERATED: typing.ClassVar[int] = ...
        FLAG_IGNORE_CHEEK_PRESSES: typing.ClassVar[int] = ...
        FLAG_KEEP_SCREEN_ON: typing.ClassVar[int] = ...
        FLAG_LAYOUT_ATTACHED_IN_DECOR: typing.ClassVar[int] = ...
        FLAG_LAYOUT_INSET_DECOR: typing.ClassVar[int] = ...
        FLAG_LAYOUT_IN_OVERSCAN: typing.ClassVar[int] = ...
        FLAG_LAYOUT_IN_SCREEN: typing.ClassVar[int] = ...
        FLAG_LAYOUT_NO_LIMITS: typing.ClassVar[int] = ...
        FLAG_LOCAL_FOCUS_MODE: typing.ClassVar[int] = ...
        FLAG_NOT_FOCUSABLE: typing.ClassVar[int] = ...
        FLAG_NOT_TOUCHABLE: typing.ClassVar[int] = ...
        FLAG_NOT_TOUCH_MODAL: typing.ClassVar[int] = ...
        FLAG_SCALED: typing.ClassVar[int] = ...
        FLAG_SECURE: typing.ClassVar[int] = ...
        FLAG_SHOW_WALLPAPER: typing.ClassVar[int] = ...
        FLAG_SHOW_WHEN_LOCKED: typing.ClassVar[int] = ...
        FLAG_SPLIT_TOUCH: typing.ClassVar[int] = ...
        FLAG_TOUCHABLE_WHEN_WAKING: typing.ClassVar[int] = ...
        FLAG_TRANSLUCENT_NAVIGATION: typing.ClassVar[int] = ...
        FLAG_TRANSLUCENT_STATUS: typing.ClassVar[int] = ...
        FLAG_TURN_SCREEN_ON: typing.ClassVar[int] = ...
        FLAG_WATCH_OUTSIDE_TOUCH: typing.ClassVar[int] = ...
        FORMAT_CHANGED: typing.ClassVar[int] = ...
        LAST_APPLICATION_WINDOW: typing.ClassVar[int] = ...
        LAST_SUB_WINDOW: typing.ClassVar[int] = ...
        LAST_SYSTEM_WINDOW: typing.ClassVar[int] = ...
        LAYOUT_CHANGED: typing.ClassVar[int] = ...
        LAYOUT_IN_DISPLAY_CUTOUT_MODE_ALWAYS: typing.ClassVar[int] = ...
        LAYOUT_IN_DISPLAY_CUTOUT_MODE_DEFAULT: typing.ClassVar[int] = ...
        LAYOUT_IN_DISPLAY_CUTOUT_MODE_NEVER: typing.ClassVar[int] = ...
        LAYOUT_IN_DISPLAY_CUTOUT_MODE_SHORT_EDGES: typing.ClassVar[int] = ...
        MEMORY_TYPE_CHANGED: typing.ClassVar[int] = ...
        MEMORY_TYPE_GPU: typing.ClassVar[int] = ...
        MEMORY_TYPE_HARDWARE: typing.ClassVar[int] = ...
        MEMORY_TYPE_NORMAL: typing.ClassVar[int] = ...
        MEMORY_TYPE_PUSH_BUFFERS: typing.ClassVar[int] = ...
        ROTATION_ANIMATION_CHANGED: typing.ClassVar[int] = ...
        ROTATION_ANIMATION_CROSSFADE: typing.ClassVar[int] = ...
        ROTATION_ANIMATION_JUMPCUT: typing.ClassVar[int] = ...
        ROTATION_ANIMATION_ROTATE: typing.ClassVar[int] = ...
        ROTATION_ANIMATION_SEAMLESS: typing.ClassVar[int] = ...
        SCREEN_BRIGHTNESS_CHANGED: typing.ClassVar[int] = ...
        SCREEN_ORIENTATION_CHANGED: typing.ClassVar[int] = ...
        SOFT_INPUT_ADJUST_NOTHING: typing.ClassVar[int] = ...
        SOFT_INPUT_ADJUST_PAN: typing.ClassVar[int] = ...
        SOFT_INPUT_ADJUST_RESIZE: typing.ClassVar[int] = ...
        SOFT_INPUT_ADJUST_UNSPECIFIED: typing.ClassVar[int] = ...
        SOFT_INPUT_IS_FORWARD_NAVIGATION: typing.ClassVar[int] = ...
        SOFT_INPUT_MASK_ADJUST: typing.ClassVar[int] = ...
        SOFT_INPUT_MASK_STATE: typing.ClassVar[int] = ...
        SOFT_INPUT_MODE_CHANGED: typing.ClassVar[int] = ...
        SOFT_INPUT_STATE_ALWAYS_HIDDEN: typing.ClassVar[int] = ...
        SOFT_INPUT_STATE_ALWAYS_VISIBLE: typing.ClassVar[int] = ...
        SOFT_INPUT_STATE_HIDDEN: typing.ClassVar[int] = ...
        SOFT_INPUT_STATE_UNCHANGED: typing.ClassVar[int] = ...
        SOFT_INPUT_STATE_UNSPECIFIED: typing.ClassVar[int] = ...
        SOFT_INPUT_STATE_VISIBLE: typing.ClassVar[int] = ...
        TITLE_CHANGED: typing.ClassVar[int] = ...
        TYPE_ACCESSIBILITY_OVERLAY: typing.ClassVar[int] = ...
        TYPE_APPLICATION: typing.ClassVar[int] = ...
        TYPE_APPLICATION_ATTACHED_DIALOG: typing.ClassVar[int] = ...
        TYPE_APPLICATION_MEDIA: typing.ClassVar[int] = ...
        TYPE_APPLICATION_OVERLAY: typing.ClassVar[int] = ...
        TYPE_APPLICATION_PANEL: typing.ClassVar[int] = ...
        TYPE_APPLICATION_STARTING: typing.ClassVar[int] = ...
        TYPE_APPLICATION_SUB_PANEL: typing.ClassVar[int] = ...
        TYPE_BASE_APPLICATION: typing.ClassVar[int] = ...
        TYPE_CHANGED: typing.ClassVar[int] = ...
        TYPE_DRAWN_APPLICATION: typing.ClassVar[int] = ...
        TYPE_INPUT_METHOD: typing.ClassVar[int] = ...
        TYPE_INPUT_METHOD_DIALOG: typing.ClassVar[int] = ...
        TYPE_KEYGUARD_DIALOG: typing.ClassVar[int] = ...
        TYPE_PHONE: typing.ClassVar[int] = ...
        TYPE_PRIORITY_PHONE: typing.ClassVar[int] = ...
        TYPE_PRIVATE_PRESENTATION: typing.ClassVar[int] = ...
        TYPE_SEARCH_BAR: typing.ClassVar[int] = ...
        TYPE_STATUS_BAR: typing.ClassVar[int] = ...
        TYPE_SYSTEM_ALERT: typing.ClassVar[int] = ...
        TYPE_SYSTEM_DIALOG: typing.ClassVar[int] = ...
        TYPE_SYSTEM_ERROR: typing.ClassVar[int] = ...
        TYPE_SYSTEM_OVERLAY: typing.ClassVar[int] = ...
        TYPE_TOAST: typing.ClassVar[int] = ...
        TYPE_WALLPAPER: typing.ClassVar[int] = ...
        alpha: float = ...
        buttonBrightness: float = ...
        dimAmount: float = ...
        flags: int = ...
        format: int = ...
        gravity: int = ...
        horizontalMargin: float = ...
        horizontalWeight: float = ...
        layoutInDisplayCutoutMode: int = ...
        memoryType: int = ...
        packageName: str = ...
        preferMinimalPostProcessing: bool = ...
        preferredDisplayModeId: int = ...
        preferredRefreshRate: float = ...
        rotationAnimation: int = ...
        screenBrightness: float = ...
        screenOrientation: int = ...
        softInputMode: int = ...
        systemUiVisibility: int = ...
        token: android.os.IBinder = ...
        type: int = ...
        verticalMargin: float = ...
        verticalWeight: float = ...
        windowAnimations: int = ...
        x: int = ...
        y: int = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, type: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, in_: android.os.Parcel, /) -> None: ...
        @typing.overload
        def __init__(self, type: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, type: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, format: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, format: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, xpos: int | java.jint | java.lang.Integer, ypos: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, format: int | java.jint | java.lang.Integer, /) -> None: ...
        def areWallpaperTouchEventsEnabled(self) -> bool: ...
        def canPlayMoveAnimation(self) -> bool: ...
        def copyFrom(self, o: WindowManager.LayoutParams, /) -> int: ...
        def debug(self, output: str | java.lang.String, /) -> str: ...
        def describeContents(self) -> int: ...
        def getBlurBehindRadius(self) -> int: ...
        def getColorMode(self) -> int: ...
        def getDesiredHdrHeadroom(self) -> float: ...
        def getFitInsetsSides(self) -> int: ...
        def getFitInsetsTypes(self) -> int: ...
        def getFrameRateBoostOnTouchEnabled(self) -> bool: ...
        def getTitle(self) -> java.lang.CharSequence: ...
        def isFitInsetsIgnoringVisibility(self) -> bool: ...
        def isFrameRatePowerSavingsBalanced(self) -> bool: ...
        def isHdrConversionEnabled(self) -> bool: ...
        @staticmethod
        def mayUseInputMethod(flags: int | java.jint | java.lang.Integer, /) -> bool: ...
        def setBlurBehindRadius(self, blurBehindRadius: int | java.jint | java.lang.Integer, /) -> None: ...
        def setCanPlayMoveAnimation(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def setColorMode(self, colorMode: int | java.jint | java.lang.Integer, /) -> None: ...
        def setDesiredHdrHeadroom(self, desiredHeadroom: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setFitInsetsIgnoringVisibility(self, ignore: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def setFitInsetsSides(self, sides: int | java.jint | java.lang.Integer, /) -> None: ...
        def setFitInsetsTypes(self, types: int | java.jint | java.lang.Integer, /) -> None: ...
        def setFrameRateBoostOnTouchEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def setFrameRatePowerSavingsBalanced(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def setHdrConversionEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def setTitle(self, title: java.lang.CharSequence, /) -> None: ...
        def setWallpaperTouchEventsEnabled(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def toString(self) -> str: ...
        def writeToParcel(self, out: android.os.Parcel, parcelableFlags: int | java.jint | java.lang.Integer, /) -> None: ...

    class InvalidDisplayException(java.lang.RuntimeException):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, name: str | java.lang.String, /) -> None: ...

    class BadTokenException(java.lang.RuntimeException):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, name: str | java.lang.String, /) -> None: ...

class WindowMetrics(java.lang.Object):
    @typing.overload
    def __init__(self, bounds: android.graphics.Rect, windowInsets: WindowInsets, /) -> None: ...
    @typing.overload
    def __init__(self, bounds: android.graphics.Rect, windowInsets: WindowInsets, density: float | java.jfloat | java.lang.Float, /) -> None: ...
    def getBounds(self) -> android.graphics.Rect: ...
    def getDensity(self) -> float: ...
    def getWindowInsets(self) -> WindowInsets: ...
    def toString(self) -> str: ...
